/*******************************************************************************
* Copyright 2014-2019 Intel Corporation.
*
* This software and the related documents are Intel copyrighted  materials,  and
* your use of  them is  governed by the  express license  under which  they were
* provided to you (License).  Unless the License provides otherwise, you may not
* use, modify, copy, publish, distribute,  disclose or transmit this software or
* the related documents without Intel's prior written permission.
*
* This software and the related documents  are provided as  is,  with no express
* or implied  warranties,  other  than those  that are  expressly stated  in the
* License.
*******************************************************************************/


#define SWIGPYTHON
#define SWIG_DIRECTORS
#define SWIG_PYTHON_THREADS


#ifdef __cplusplus
/* SwigValueWrapper is described in swig.swg */
template<typename T> class SwigValueWrapper {
  struct SwigMovePointer {
    T *ptr;
    SwigMovePointer(T *p) : ptr(p) { }
    ~SwigMovePointer() { delete ptr; }
    SwigMovePointer& operator=(SwigMovePointer& rhs) { T* oldptr = ptr; ptr = 0; delete oldptr; ptr = rhs.ptr; rhs.ptr = 0; return *this; }
  } pointer;
  SwigValueWrapper& operator=(const SwigValueWrapper<T>& rhs);
  SwigValueWrapper(const SwigValueWrapper<T>& rhs);
public:
  SwigValueWrapper() : pointer(0) { }
  SwigValueWrapper& operator=(const T& t) { SwigMovePointer tmp(new T(t)); pointer = tmp; return *this; }
  operator T&() const { return *pointer.ptr; }
  T *operator&() { return pointer.ptr; }
};

template <typename T> T SwigValueInit() {
  return T();
}
#endif

/* -----------------------------------------------------------------------------
 *  This section contains generic SWIG labels for method/variable
 *  declarations/attributes, and other compiler dependent labels.
 * ----------------------------------------------------------------------------- */

/* template workaround for compilers that cannot correctly implement the C++ standard */
#ifndef SWIGTEMPLATEDISAMBIGUATOR
# if defined(__SUNPRO_CC) && (__SUNPRO_CC <= 0x560)
#  define SWIGTEMPLATEDISAMBIGUATOR template
# elif defined(__HP_aCC)
/* Needed even with `aCC -AA' when `aCC -V' reports HP ANSI C++ B3910B A.03.55 */
/* If we find a maximum version that requires this, the test would be __HP_aCC <= 35500 for A.03.55 */
#  define SWIGTEMPLATEDISAMBIGUATOR template
# else
#  define SWIGTEMPLATEDISAMBIGUATOR
# endif
#endif

/* inline attribute */
#ifndef SWIGINLINE
# if defined(__cplusplus) || (defined(__GNUC__) && !defined(__STRICT_ANSI__))
#   define SWIGINLINE inline
# else
#   define SWIGINLINE
# endif
#endif

/* attribute recognised by some compilers to avoid 'unused' warnings */
#ifndef SWIGUNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define SWIGUNUSED __attribute__ ((__unused__))
#   else
#     define SWIGUNUSED
#   endif
# elif defined(__ICC)
#   define SWIGUNUSED __attribute__ ((__unused__))
# else
#   define SWIGUNUSED
# endif
#endif

#ifndef SWIG_MSC_UNSUPPRESS_4505
# if defined(_MSC_VER)
#   pragma warning(disable : 4505) /* unreferenced local function has been removed */
# endif
#endif

#ifndef SWIGUNUSEDPARM
# ifdef __cplusplus
#   define SWIGUNUSEDPARM(p)
# else
#   define SWIGUNUSEDPARM(p) p SWIGUNUSED
# endif
#endif

/* internal SWIG method */
#ifndef SWIGINTERN
# define SWIGINTERN static SWIGUNUSED
#endif

/* internal inline SWIG method */
#ifndef SWIGINTERNINLINE
# define SWIGINTERNINLINE SWIGINTERN SWIGINLINE
#endif

/* exporting methods */
#if (__GNUC__ >= 4) || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4)
#  ifndef GCC_HASCLASSVISIBILITY
#    define GCC_HASCLASSVISIBILITY
#  endif
#endif

#ifndef SWIGEXPORT
# if defined(_WIN32) || defined(__WIN32__) || defined(__CYGWIN__)
#   if defined(STATIC_LINKED)
#     define SWIGEXPORT
#   else
#     define SWIGEXPORT __declspec(dllexport)
#   endif
# else
#   if defined(__GNUC__) && defined(GCC_HASCLASSVISIBILITY)
#     define SWIGEXPORT __attribute__ ((visibility("default")))
#   else
#     define SWIGEXPORT
#   endif
# endif
#endif

/* calling conventions for Windows */
#ifndef SWIGSTDCALL
# if defined(_WIN32) || defined(__WIN32__) || defined(__CYGWIN__)
#   define SWIGSTDCALL __stdcall
# else
#   define SWIGSTDCALL
# endif
#endif

/* Deal with Microsoft's attempt at deprecating C standard runtime functions */
#if !defined(SWIG_NO_CRT_SECURE_NO_DEPRECATE) && defined(_MSC_VER) && !defined(_CRT_SECURE_NO_DEPRECATE)
# define _CRT_SECURE_NO_DEPRECATE
#endif

/* Deal with Microsoft's attempt at deprecating methods in the standard C++ library */
#if !defined(SWIG_NO_SCL_SECURE_NO_DEPRECATE) && defined(_MSC_VER) && !defined(_SCL_SECURE_NO_DEPRECATE)
# define _SCL_SECURE_NO_DEPRECATE
#endif

/* Deal with Apple's deprecated 'AssertMacros.h' from Carbon-framework */
#if defined(__APPLE__) && !defined(__ASSERT_MACROS_DEFINE_VERSIONS_WITHOUT_UNDERSCORES)
# define __ASSERT_MACROS_DEFINE_VERSIONS_WITHOUT_UNDERSCORES 0
#endif

/* Intel's compiler complains if a variable which was never initialised is
 * cast to void, which is a common idiom which we use to indicate that we
 * are aware a variable isn't used.  So we just silence that warning.
 * See: https://github.com/swig/swig/issues/192 for more discussion.
 */
#ifdef __INTEL_COMPILER
# pragma warning disable 592
#endif


#if defined(_DEBUG) && defined(SWIG_PYTHON_INTERPRETER_NO_DEBUG)
/* Use debug wrappers with the Python release dll */
# undef _DEBUG
# include <Python.h>
# define _DEBUG
#else
# include <Python.h>
#endif

/* -----------------------------------------------------------------------------
 * swigrun.swg
 *
 * This file contains generic C API SWIG runtime support for pointer
 * type checking.
 * ----------------------------------------------------------------------------- */

/* This should only be incremented when either the layout of swig_type_info changes,
   or for whatever reason, the runtime changes incompatibly */
#define SWIG_RUNTIME_VERSION "4"

/* define SWIG_TYPE_TABLE_NAME as "SWIG_TYPE_TABLE" */
#ifdef SWIG_TYPE_TABLE
# define SWIG_QUOTE_STRING(x) #x
# define SWIG_EXPAND_AND_QUOTE_STRING(x) SWIG_QUOTE_STRING(x)
# define SWIG_TYPE_TABLE_NAME SWIG_EXPAND_AND_QUOTE_STRING(SWIG_TYPE_TABLE)
#else
# define SWIG_TYPE_TABLE_NAME
#endif

/*
  You can use the SWIGRUNTIME and SWIGRUNTIMEINLINE macros for
  creating a static or dynamic library from the SWIG runtime code.
  In 99.9% of the cases, SWIG just needs to declare them as 'static'.

  But only do this if strictly necessary, ie, if you have problems
  with your compiler or suchlike.
*/

#ifndef SWIGRUNTIME
# define SWIGRUNTIME SWIGINTERN
#endif

#ifndef SWIGRUNTIMEINLINE
# define SWIGRUNTIMEINLINE SWIGRUNTIME SWIGINLINE
#endif

/*  Generic buffer size */
#ifndef SWIG_BUFFER_SIZE
# define SWIG_BUFFER_SIZE 1024
#endif

/* Flags for pointer conversions */
#define SWIG_POINTER_DISOWN        0x1
#define SWIG_CAST_NEW_MEMORY       0x2

/* Flags for new pointer objects */
#define SWIG_POINTER_OWN           0x1


/*
   Flags/methods for returning states.

   The SWIG conversion methods, as ConvertPtr, return an integer
   that tells if the conversion was successful or not. And if not,
   an error code can be returned (see swigerrors.swg for the codes).

   Use the following macros/flags to set or process the returning
   states.

   In old versions of SWIG, code such as the following was usually written:

     if (SWIG_ConvertPtr(obj,vptr,ty.flags) != -1) {
       // success code
     } else {
       //fail code
     }

   Now you can be more explicit:

    int res = SWIG_ConvertPtr(obj,vptr,ty.flags);
    if (SWIG_IsOK(res)) {
      // success code
    } else {
      // fail code
    }

   which is the same really, but now you can also do

    Type *ptr;
    int res = SWIG_ConvertPtr(obj,(void **)(&ptr),ty.flags);
    if (SWIG_IsOK(res)) {
      // success code
      if (SWIG_IsNewObj(res) {
        ...
	delete *ptr;
      } else {
        ...
      }
    } else {
      // fail code
    }

   I.e., now SWIG_ConvertPtr can return new objects and you can
   identify the case and take care of the deallocation. Of course that
   also requires SWIG_ConvertPtr to return new result values, such as

      int SWIG_ConvertPtr(obj, ptr,...) {
        if (<obj is ok>) {
          if (<need new object>) {
            *ptr = <ptr to new allocated object>;
            return SWIG_NEWOBJ;
          } else {
            *ptr = <ptr to old object>;
            return SWIG_OLDOBJ;
          }
        } else {
          return SWIG_BADOBJ;
        }
      }

   Of course, returning the plain '0(success)/-1(fail)' still works, but you can be
   more explicit by returning SWIG_BADOBJ, SWIG_ERROR or any of the
   SWIG errors code.

   Finally, if the SWIG_CASTRANK_MODE is enabled, the result code
   allows to return the 'cast rank', for example, if you have this

       int food(double)
       int fooi(int);

   and you call

      food(1)   // cast rank '1'  (1 -> 1.0)
      fooi(1)   // cast rank '0'

   just use the SWIG_AddCast()/SWIG_CheckState()
*/

#define SWIG_OK                    (0)
#define SWIG_ERROR                 (-1)
#define SWIG_IsOK(r)               (r >= 0)
#define SWIG_ArgError(r)           ((r != SWIG_ERROR) ? r : SWIG_TypeError)

/* The CastRankLimit says how many bits are used for the cast rank */
#define SWIG_CASTRANKLIMIT         (1 << 8)
/* The NewMask denotes the object was created (using new/malloc) */
#define SWIG_NEWOBJMASK            (SWIG_CASTRANKLIMIT  << 1)
/* The TmpMask is for in/out typemaps that use temporal objects */
#define SWIG_TMPOBJMASK            (SWIG_NEWOBJMASK << 1)
/* Simple returning values */
#define SWIG_BADOBJ                (SWIG_ERROR)
#define SWIG_OLDOBJ                (SWIG_OK)
#define SWIG_NEWOBJ                (SWIG_OK | SWIG_NEWOBJMASK)
#define SWIG_TMPOBJ                (SWIG_OK | SWIG_TMPOBJMASK)
/* Check, add and del mask methods */
#define SWIG_AddNewMask(r)         (SWIG_IsOK(r) ? (r | SWIG_NEWOBJMASK) : r)
#define SWIG_DelNewMask(r)         (SWIG_IsOK(r) ? (r & ~SWIG_NEWOBJMASK) : r)
#define SWIG_IsNewObj(r)           (SWIG_IsOK(r) && (r & SWIG_NEWOBJMASK))
#define SWIG_AddTmpMask(r)         (SWIG_IsOK(r) ? (r | SWIG_TMPOBJMASK) : r)
#define SWIG_DelTmpMask(r)         (SWIG_IsOK(r) ? (r & ~SWIG_TMPOBJMASK) : r)
#define SWIG_IsTmpObj(r)           (SWIG_IsOK(r) && (r & SWIG_TMPOBJMASK))

/* Cast-Rank Mode */
#if defined(SWIG_CASTRANK_MODE)
#  ifndef SWIG_TypeRank
#    define SWIG_TypeRank             unsigned long
#  endif
#  ifndef SWIG_MAXCASTRANK            /* Default cast allowed */
#    define SWIG_MAXCASTRANK          (2)
#  endif
#  define SWIG_CASTRANKMASK          ((SWIG_CASTRANKLIMIT) -1)
#  define SWIG_CastRank(r)           (r & SWIG_CASTRANKMASK)
SWIGINTERNINLINE int SWIG_AddCast(int r) {
  return SWIG_IsOK(r) ? ((SWIG_CastRank(r) < SWIG_MAXCASTRANK) ? (r + 1) : SWIG_ERROR) : r;
}
SWIGINTERNINLINE int SWIG_CheckState(int r) {
  return SWIG_IsOK(r) ? SWIG_CastRank(r) + 1 : 0;
}
#else /* no cast-rank mode */
#  define SWIG_AddCast(r) (r)
#  define SWIG_CheckState(r) (SWIG_IsOK(r) ? 1 : 0)
#endif


#include <string.h>

#ifdef __cplusplus
extern "C" {
#endif

typedef void *(*swig_converter_func)(void *, int *);
typedef struct swig_type_info *(*swig_dycast_func)(void **);

/* Structure to store information on one type */
typedef struct swig_type_info {
  const char             *name;			/* mangled name of this type */
  const char             *str;			/* human readable name of this type */
  swig_dycast_func        dcast;		/* dynamic cast function down a hierarchy */
  struct swig_cast_info  *cast;			/* linked list of types that can cast into this type */
  void                   *clientdata;		/* language specific type data */
  int                    owndata;		/* flag if the structure owns the clientdata */
} swig_type_info;

/* Structure to store a type and conversion function used for casting */
typedef struct swig_cast_info {
  swig_type_info         *type;			/* pointer to type that is equivalent to this type */
  swig_converter_func     converter;		/* function to cast the void pointers */
  struct swig_cast_info  *next;			/* pointer to next cast in linked list */
  struct swig_cast_info  *prev;			/* pointer to the previous cast */
} swig_cast_info;

/* Structure used to store module information
 * Each module generates one structure like this, and the runtime collects
 * all of these structures and stores them in a circularly linked list.*/
typedef struct swig_module_info {
  swig_type_info         **types;		/* Array of pointers to swig_type_info structures that are in this module */
  size_t                 size;		        /* Number of types in this module */
  struct swig_module_info *next;		/* Pointer to next element in circularly linked list */
  swig_type_info         **type_initial;	/* Array of initially generated type structures */
  swig_cast_info         **cast_initial;	/* Array of initially generated casting structures */
  void                    *clientdata;		/* Language specific module data */
} swig_module_info;

/*
  Compare two type names skipping the space characters, therefore
  "char*" == "char *" and "Class<int>" == "Class<int >", etc.

  Return 0 when the two name types are equivalent, as in
  strncmp, but skipping ' '.
*/
SWIGRUNTIME int
SWIG_TypeNameComp(const char *f1, const char *l1,
		  const char *f2, const char *l2) {
  for (;(f1 != l1) && (f2 != l2); ++f1, ++f2) {
    while ((*f1 == ' ') && (f1 != l1)) ++f1;
    while ((*f2 == ' ') && (f2 != l2)) ++f2;
    if (*f1 != *f2) return (*f1 > *f2) ? 1 : -1;
  }
  return (int)((l1 - f1) - (l2 - f2));
}

/*
  Check type equivalence in a name list like <name1>|<name2>|...
  Return 0 if equal, -1 if nb < tb, 1 if nb > tb
*/
SWIGRUNTIME int
SWIG_TypeCmp(const char *nb, const char *tb) {
  int equiv = 1;
  const char* te = tb + strlen(tb);
  const char* ne = nb;
  while (equiv != 0 && *ne) {
    for (nb = ne; *ne; ++ne) {
      if (*ne == '|') break;
    }
    equiv = SWIG_TypeNameComp(nb, ne, tb, te);
    if (*ne) ++ne;
  }
  return equiv;
}

/*
  Check type equivalence in a name list like <name1>|<name2>|...
  Return 0 if not equal, 1 if equal
*/
SWIGRUNTIME int
SWIG_TypeEquiv(const char *nb, const char *tb) {
  return SWIG_TypeCmp(nb, tb) == 0 ? 1 : 0;
}

/*
  Check the typename
*/
SWIGRUNTIME swig_cast_info *
SWIG_TypeCheck(const char *c, swig_type_info *ty) {
  if (ty) {
    swig_cast_info *iter = ty->cast;
    while (iter) {
      if (strcmp(iter->type->name, c) == 0) {
        if (iter == ty->cast)
          return iter;
        /* Move iter to the top of the linked list */
        iter->prev->next = iter->next;
        if (iter->next)
          iter->next->prev = iter->prev;
        iter->next = ty->cast;
        iter->prev = 0;
        if (ty->cast) ty->cast->prev = iter;
        ty->cast = iter;
        return iter;
      }
      iter = iter->next;
    }
  }
  return 0;
}

/*
  Identical to SWIG_TypeCheck, except strcmp is replaced with a pointer comparison
*/
SWIGRUNTIME swig_cast_info *
SWIG_TypeCheckStruct(swig_type_info *from, swig_type_info *ty) {
  if (ty) {
    swig_cast_info *iter = ty->cast;
    while (iter) {
      if (iter->type == from) {
        if (iter == ty->cast)
          return iter;
        /* Move iter to the top of the linked list */
        iter->prev->next = iter->next;
        if (iter->next)
          iter->next->prev = iter->prev;
        iter->next = ty->cast;
        iter->prev = 0;
        if (ty->cast) ty->cast->prev = iter;
        ty->cast = iter;
        return iter;
      }
      iter = iter->next;
    }
  }
  return 0;
}

/*
  Cast a pointer up an inheritance hierarchy
*/
SWIGRUNTIMEINLINE void *
SWIG_TypeCast(swig_cast_info *ty, void *ptr, int *newmemory) {
  return ((!ty) || (!ty->converter)) ? ptr : (*ty->converter)(ptr, newmemory);
}

/*
   Dynamic pointer casting. Down an inheritance hierarchy
*/
SWIGRUNTIME swig_type_info *
SWIG_TypeDynamicCast(swig_type_info *ty, void **ptr) {
  swig_type_info *lastty = ty;
  if (!ty || !ty->dcast) return ty;
  while (ty && (ty->dcast)) {
    ty = (*ty->dcast)(ptr);
    if (ty) lastty = ty;
  }
  return lastty;
}

/*
  Return the name associated with this type
*/
SWIGRUNTIMEINLINE const char *
SWIG_TypeName(const swig_type_info *ty) {
  return ty->name;
}

/*
  Return the pretty name associated with this type,
  that is an unmangled type name in a form presentable to the user.
*/
SWIGRUNTIME const char *
SWIG_TypePrettyName(const swig_type_info *type) {
  /* The "str" field contains the equivalent pretty names of the
     type, separated by vertical-bar characters.  We choose
     to print the last name, as it is often (?) the most
     specific. */
  if (!type) return NULL;
  if (type->str != NULL) {
    const char *last_name = type->str;
    const char *s;
    for (s = type->str; *s; s++)
      if (*s == '|') last_name = s+1;
    return last_name;
  }
  else
    return type->name;
}

/*
   Set the clientdata field for a type
*/
SWIGRUNTIME void
SWIG_TypeClientData(swig_type_info *ti, void *clientdata) {
  swig_cast_info *cast = ti->cast;
  /* if (ti->clientdata == clientdata) return; */
  ti->clientdata = clientdata;

  while (cast) {
    if (!cast->converter) {
      swig_type_info *tc = cast->type;
      if (!tc->clientdata) {
	SWIG_TypeClientData(tc, clientdata);
      }
    }
    cast = cast->next;
  }
}
SWIGRUNTIME void
SWIG_TypeNewClientData(swig_type_info *ti, void *clientdata) {
  SWIG_TypeClientData(ti, clientdata);
  ti->owndata = 1;
}

/*
  Search for a swig_type_info structure only by mangled name
  Search is a O(log #types)

  We start searching at module start, and finish searching when start == end.
  Note: if start == end at the beginning of the function, we go all the way around
  the circular list.
*/
SWIGRUNTIME swig_type_info *
SWIG_MangledTypeQueryModule(swig_module_info *start,
                            swig_module_info *end,
		            const char *name) {
  swig_module_info *iter = start;
  do {
    if (iter->size) {
      size_t l = 0;
      size_t r = iter->size - 1;
      do {
	/* since l+r >= 0, we can (>> 1) instead (/ 2) */
	size_t i = (l + r) >> 1;
	const char *iname = iter->types[i]->name;
	if (iname) {
	  int compare = strcmp(name, iname);
	  if (compare == 0) {
	    return iter->types[i];
	  } else if (compare < 0) {
	    if (i) {
	      r = i - 1;
	    } else {
	      break;
	    }
	  } else if (compare > 0) {
	    l = i + 1;
	  }
	} else {
	  break; /* should never happen */
	}
      } while (l <= r);
    }
    iter = iter->next;
  } while (iter != end);
  return 0;
}

/*
  Search for a swig_type_info structure for either a mangled name or a human readable name.
  It first searches the mangled names of the types, which is a O(log #types)
  If a type is not found it then searches the human readable names, which is O(#types).

  We start searching at module start, and finish searching when start == end.
  Note: if start == end at the beginning of the function, we go all the way around
  the circular list.
*/
SWIGRUNTIME swig_type_info *
SWIG_TypeQueryModule(swig_module_info *start,
                     swig_module_info *end,
		     const char *name) {
  /* STEP 1: Search the name field using binary search */
  swig_type_info *ret = SWIG_MangledTypeQueryModule(start, end, name);
  if (ret) {
    return ret;
  } else {
    /* STEP 2: If the type hasn't been found, do a complete search
       of the str field (the human readable name) */
    swig_module_info *iter = start;
    do {
      size_t i = 0;
      for (; i < iter->size; ++i) {
	if (iter->types[i]->str && (SWIG_TypeEquiv(iter->types[i]->str, name)))
	  return iter->types[i];
      }
      iter = iter->next;
    } while (iter != end);
  }

  /* neither found a match */
  return 0;
}

/*
   Pack binary data into a string
*/
SWIGRUNTIME char *
SWIG_PackData(char *c, void *ptr, size_t sz) {
  static const char hex[17] = "0123456789abcdef";
  const unsigned char *u = (unsigned char *) ptr;
  const unsigned char *eu =  u + sz;
  for (; u != eu; ++u) {
    unsigned char uu = *u;
    *(c++) = hex[(uu & 0xf0) >> 4];
    *(c++) = hex[uu & 0xf];
  }
  return c;
}

/*
   Unpack binary data from a string
*/
SWIGRUNTIME const char *
SWIG_UnpackData(const char *c, void *ptr, size_t sz) {
  unsigned char *u = (unsigned char *) ptr;
  const unsigned char *eu = u + sz;
  for (; u != eu; ++u) {
    char d = *(c++);
    unsigned char uu;
    if ((d >= '0') && (d <= '9'))
      uu = ((d - '0') << 4);
    else if ((d >= 'a') && (d <= 'f'))
      uu = ((d - ('a'-10)) << 4);
    else
      return (char *) 0;
    d = *(c++);
    if ((d >= '0') && (d <= '9'))
      uu |= (d - '0');
    else if ((d >= 'a') && (d <= 'f'))
      uu |= (d - ('a'-10));
    else
      return (char *) 0;
    *u = uu;
  }
  return c;
}

/*
   Pack 'void *' into a string buffer.
*/
SWIGRUNTIME char *
SWIG_PackVoidPtr(char *buff, void *ptr, const char *name, size_t bsz) {
  char *r = buff;
  if ((2*sizeof(void *) + 2) > bsz) return 0;
  *(r++) = '_';
  r = SWIG_PackData(r,&ptr,sizeof(void *));
  if (strlen(name) + 1 > (bsz - (r - buff))) return 0;
  strcpy(r,name);
  return buff;
}

SWIGRUNTIME const char *
SWIG_UnpackVoidPtr(const char *c, void **ptr, const char *name) {
  if (*c != '_') {
    if (strcmp(c,"NULL") == 0) {
      *ptr = (void *) 0;
      return name;
    } else {
      return 0;
    }
  }
  return SWIG_UnpackData(++c,ptr,sizeof(void *));
}

SWIGRUNTIME char *
SWIG_PackDataName(char *buff, void *ptr, size_t sz, const char *name, size_t bsz) {
  char *r = buff;
  size_t lname = (name ? strlen(name) : 0);
  if ((2*sz + 2 + lname) > bsz) return 0;
  *(r++) = '_';
  r = SWIG_PackData(r,ptr,sz);
  if (lname) {
    strncpy(r,name,lname+1);
  } else {
    *r = 0;
  }
  return buff;
}

SWIGRUNTIME const char *
SWIG_UnpackDataName(const char *c, void *ptr, size_t sz, const char *name) {
  if (*c != '_') {
    if (strcmp(c,"NULL") == 0) {
      memset(ptr,0,sz);
      return name;
    } else {
      return 0;
    }
  }
  return SWIG_UnpackData(++c,ptr,sz);
}

#ifdef __cplusplus
}
#endif

/*  Errors in SWIG */
#define  SWIG_UnknownError    	   -1
#define  SWIG_IOError        	   -2
#define  SWIG_RuntimeError   	   -3
#define  SWIG_IndexError     	   -4
#define  SWIG_TypeError      	   -5
#define  SWIG_DivisionByZero 	   -6
#define  SWIG_OverflowError  	   -7
#define  SWIG_SyntaxError    	   -8
#define  SWIG_ValueError     	   -9
#define  SWIG_SystemError    	   -10
#define  SWIG_AttributeError 	   -11
#define  SWIG_MemoryError    	   -12
#define  SWIG_NullReferenceError   -13



/* Compatibility macros for Python 3 */
#if PY_VERSION_HEX >= 0x03000000

#define PyClass_Check(obj) PyObject_IsInstance(obj, (PyObject *)&PyType_Type)
#define PyInt_Check(x) PyLong_Check(x)
#define PyInt_AsLong(x) PyLong_AsLong(x)
#define PyInt_FromLong(x) PyLong_FromLong(x)
#define PyInt_FromSize_t(x) PyLong_FromSize_t(x)
#define PyString_Check(name) PyBytes_Check(name)
#define PyString_FromString(x) PyUnicode_FromString(x)
#define PyString_Format(fmt, args)  PyUnicode_Format(fmt, args)
#define PyString_AsString(str) PyBytes_AsString(str)
#define PyString_Size(str) PyBytes_Size(str)	
#define PyString_InternFromString(key) PyUnicode_InternFromString(key)
#define Py_TPFLAGS_HAVE_CLASS Py_TPFLAGS_BASETYPE
#define PyString_AS_STRING(x) PyUnicode_AS_STRING(x)
#define _PyLong_FromSsize_t(x) PyLong_FromSsize_t(x)

#endif

#ifndef Py_TYPE
#  define Py_TYPE(op) ((op)->ob_type)
#endif

/* SWIG APIs for compatibility of both Python 2 & 3 */

#if PY_VERSION_HEX >= 0x03000000
#  define SWIG_Python_str_FromFormat PyUnicode_FromFormat
#else
#  define SWIG_Python_str_FromFormat PyString_FromFormat
#endif


/* Warning: This function will allocate a new string in Python 3,
 * so please call SWIG_Python_str_DelForPy3(x) to free the space.
 */
SWIGINTERN char*
SWIG_Python_str_AsChar(PyObject *str)
{
#if PY_VERSION_HEX >= 0x03000000
  char *cstr;
  char *newstr;
  Py_ssize_t len;
  str = PyUnicode_AsUTF8String(str);
  PyBytes_AsStringAndSize(str, &cstr, &len);
  newstr = (char *) malloc(len+1);
  memcpy(newstr, cstr, len+1);
  Py_XDECREF(str);
  return newstr;
#else
  return PyString_AsString(str);
#endif
}

#if PY_VERSION_HEX >= 0x03000000
#  define SWIG_Python_str_DelForPy3(x) free( (void*) (x) )
#else
#  define SWIG_Python_str_DelForPy3(x) 
#endif


SWIGINTERN PyObject*
SWIG_Python_str_FromChar(const char *c)
{
#if PY_VERSION_HEX >= 0x03000000
  return PyUnicode_FromString(c); 
#else
  return PyString_FromString(c);
#endif
}

/* Add PyOS_snprintf for old Pythons */
#if PY_VERSION_HEX < 0x02020000
# if defined(_MSC_VER) || defined(__BORLANDC__) || defined(_WATCOM)
#  define PyOS_snprintf _snprintf
# else
#  define PyOS_snprintf snprintf
# endif
#endif

/* A crude PyString_FromFormat implementation for old Pythons */
#if PY_VERSION_HEX < 0x02020000

#ifndef SWIG_PYBUFFER_SIZE
# define SWIG_PYBUFFER_SIZE 1024
#endif

static PyObject *
PyString_FromFormat(const char *fmt, ...) {
  va_list ap;
  char buf[SWIG_PYBUFFER_SIZE * 2];
  int res;
  va_start(ap, fmt);
  res = vsnprintf(buf, sizeof(buf), fmt, ap);
  va_end(ap);
  return (res < 0 || res >= (int)sizeof(buf)) ? 0 : PyString_FromString(buf);
}
#endif

/* Add PyObject_Del for old Pythons */
#if PY_VERSION_HEX < 0x01060000
# define PyObject_Del(op) PyMem_DEL((op))
#endif
#ifndef PyObject_DEL
# define PyObject_DEL PyObject_Del
#endif

/* A crude PyExc_StopIteration exception for old Pythons */
#if PY_VERSION_HEX < 0x02020000
# ifndef PyExc_StopIteration
#  define PyExc_StopIteration PyExc_RuntimeError
# endif
# ifndef PyObject_GenericGetAttr
#  define PyObject_GenericGetAttr 0
# endif
#endif

/* Py_NotImplemented is defined in 2.1 and up. */
#if PY_VERSION_HEX < 0x02010000
# ifndef Py_NotImplemented
#  define Py_NotImplemented PyExc_RuntimeError
# endif
#endif

/* A crude PyString_AsStringAndSize implementation for old Pythons */
#if PY_VERSION_HEX < 0x02010000
# ifndef PyString_AsStringAndSize
#  define PyString_AsStringAndSize(obj, s, len) {*s = PyString_AsString(obj); *len = *s ? strlen(*s) : 0;}
# endif
#endif

/* PySequence_Size for old Pythons */
#if PY_VERSION_HEX < 0x02000000
# ifndef PySequence_Size
#  define PySequence_Size PySequence_Length
# endif
#endif

/* PyBool_FromLong for old Pythons */
#if PY_VERSION_HEX < 0x02030000
static
PyObject *PyBool_FromLong(long ok)
{
  PyObject *result = ok ? Py_True : Py_False;
  Py_INCREF(result);
  return result;
}
#endif

/* Py_ssize_t for old Pythons */
/* This code is as recommended by: */
/* http://www.python.org/dev/peps/pep-0353/#conversion-guidelines */
#if PY_VERSION_HEX < 0x02050000 && !defined(PY_SSIZE_T_MIN)
typedef int Py_ssize_t;
# define PY_SSIZE_T_MAX INT_MAX
# define PY_SSIZE_T_MIN INT_MIN
typedef inquiry lenfunc;
typedef intargfunc ssizeargfunc;
typedef intintargfunc ssizessizeargfunc;
typedef intobjargproc ssizeobjargproc;
typedef intintobjargproc ssizessizeobjargproc;
typedef getreadbufferproc readbufferproc;
typedef getwritebufferproc writebufferproc;
typedef getsegcountproc segcountproc;
typedef getcharbufferproc charbufferproc;
static long PyNumber_AsSsize_t (PyObject *x, void *SWIGUNUSEDPARM(exc))
{
  long result = 0;
  PyObject *i = PyNumber_Int(x);
  if (i) {
    result = PyInt_AsLong(i);
    Py_DECREF(i);
  }
  return result;
}
#endif

#if PY_VERSION_HEX < 0x02050000
#define PyInt_FromSize_t(x) PyInt_FromLong((long)x)
#endif

#if PY_VERSION_HEX < 0x02040000
#define Py_VISIT(op)				\
  do { 						\
    if (op) {					\
      int vret = visit((op), arg);		\
      if (vret)					\
        return vret;				\
    }						\
  } while (0)
#endif

#if PY_VERSION_HEX < 0x02030000
typedef struct {
  PyTypeObject type;
  PyNumberMethods as_number;
  PyMappingMethods as_mapping;
  PySequenceMethods as_sequence;
  PyBufferProcs as_buffer;
  PyObject *name, *slots;
} PyHeapTypeObject;
#endif

#if PY_VERSION_HEX < 0x02030000
typedef destructor freefunc;
#endif

#if ((PY_MAJOR_VERSION == 2 && PY_MINOR_VERSION > 6) || \
     (PY_MAJOR_VERSION == 3 && PY_MINOR_VERSION > 0) || \
     (PY_MAJOR_VERSION > 3))
# define SWIGPY_USE_CAPSULE
# define SWIGPY_CAPSULE_NAME ((char*)"swig_runtime_data" SWIG_RUNTIME_VERSION ".type_pointer_capsule" SWIG_TYPE_TABLE_NAME)
#endif

#if PY_VERSION_HEX < 0x03020000
#define PyDescr_TYPE(x) (((PyDescrObject *)(x))->d_type)
#define PyDescr_NAME(x) (((PyDescrObject *)(x))->d_name)
#endif

/* -----------------------------------------------------------------------------
 * error manipulation
 * ----------------------------------------------------------------------------- */

SWIGRUNTIME PyObject*
SWIG_Python_ErrorType(int code) {
  PyObject* type = 0;
  switch(code) {
  case SWIG_MemoryError:
    type = PyExc_MemoryError;
    break;
  case SWIG_IOError:
    type = PyExc_IOError;
    break;
  case SWIG_RuntimeError:
    type = PyExc_RuntimeError;
    break;
  case SWIG_IndexError:
    type = PyExc_IndexError;
    break;
  case SWIG_TypeError:
    type = PyExc_TypeError;
    break;
  case SWIG_DivisionByZero:
    type = PyExc_ZeroDivisionError;
    break;
  case SWIG_OverflowError:
    type = PyExc_OverflowError;
    break;
  case SWIG_SyntaxError:
    type = PyExc_SyntaxError;
    break;
  case SWIG_ValueError:
    type = PyExc_ValueError;
    break;
  case SWIG_SystemError:
    type = PyExc_SystemError;
    break;
  case SWIG_AttributeError:
    type = PyExc_AttributeError;
    break;
  default:
    type = PyExc_RuntimeError;
  }
  return type;
}


SWIGRUNTIME void
SWIG_Python_AddErrorMsg(const char* mesg)
{
  PyObject *type = 0;
  PyObject *value = 0;
  PyObject *traceback = 0;

  if (PyErr_Occurred()) PyErr_Fetch(&type, &value, &traceback);
  if (value) {
    char *tmp;
    PyObject *old_str = PyObject_Str(value);
    PyErr_Clear();
    Py_XINCREF(type);

    PyErr_Format(type, "%s %s", tmp = SWIG_Python_str_AsChar(old_str), mesg);
    SWIG_Python_str_DelForPy3(tmp);
    Py_DECREF(old_str);
    Py_DECREF(value);
  } else {
    PyErr_SetString(PyExc_RuntimeError, mesg);
  }
}

#if defined(SWIG_PYTHON_NO_THREADS)
#  if defined(SWIG_PYTHON_THREADS)
#    undef SWIG_PYTHON_THREADS
#  endif
#endif
#if defined(SWIG_PYTHON_THREADS) /* Threading support is enabled */
#  if !defined(SWIG_PYTHON_USE_GIL) && !defined(SWIG_PYTHON_NO_USE_GIL)
#    if (PY_VERSION_HEX >= 0x02030000) /* For 2.3 or later, use the PyGILState calls */
#      define SWIG_PYTHON_USE_GIL
#    endif
#  endif
#  if defined(SWIG_PYTHON_USE_GIL) /* Use PyGILState threads calls */
#    ifndef SWIG_PYTHON_INITIALIZE_THREADS
#     define SWIG_PYTHON_INITIALIZE_THREADS  PyEval_InitThreads() 
#    endif
#    ifdef __cplusplus /* C++ code */
       class SWIG_Python_Thread_Block {
         bool status;
         PyGILState_STATE state;
       public:
         void end() { if (status) { PyGILState_Release(state); status = false;} }
         SWIG_Python_Thread_Block() : status(true), state(PyGILState_Ensure()) {}
         ~SWIG_Python_Thread_Block() { end(); }
       };
       class SWIG_Python_Thread_Allow {
         bool status;
         PyThreadState *save;
       public:
         void end() { if (status) { PyEval_RestoreThread(save); status = false; }}
         SWIG_Python_Thread_Allow() : status(true), save(PyEval_SaveThread()) {}
         ~SWIG_Python_Thread_Allow() { end(); }
       };
#      define SWIG_PYTHON_THREAD_BEGIN_BLOCK   SWIG_Python_Thread_Block _swig_thread_block
#      define SWIG_PYTHON_THREAD_END_BLOCK     _swig_thread_block.end()
#      define SWIG_PYTHON_THREAD_BEGIN_ALLOW   SWIG_Python_Thread_Allow _swig_thread_allow
#      define SWIG_PYTHON_THREAD_END_ALLOW     _swig_thread_allow.end()
#    else /* C code */
#      define SWIG_PYTHON_THREAD_BEGIN_BLOCK   PyGILState_STATE _swig_thread_block = PyGILState_Ensure()
#      define SWIG_PYTHON_THREAD_END_BLOCK     PyGILState_Release(_swig_thread_block)
#      define SWIG_PYTHON_THREAD_BEGIN_ALLOW   PyThreadState *_swig_thread_allow = PyEval_SaveThread()
#      define SWIG_PYTHON_THREAD_END_ALLOW     PyEval_RestoreThread(_swig_thread_allow)
#    endif
#  else /* Old thread way, not implemented, user must provide it */
#    if !defined(SWIG_PYTHON_INITIALIZE_THREADS)
#      define SWIG_PYTHON_INITIALIZE_THREADS
#    endif
#    if !defined(SWIG_PYTHON_THREAD_BEGIN_BLOCK)
#      define SWIG_PYTHON_THREAD_BEGIN_BLOCK
#    endif
#    if !defined(SWIG_PYTHON_THREAD_END_BLOCK)
#      define SWIG_PYTHON_THREAD_END_BLOCK
#    endif
#    if !defined(SWIG_PYTHON_THREAD_BEGIN_ALLOW)
#      define SWIG_PYTHON_THREAD_BEGIN_ALLOW
#    endif
#    if !defined(SWIG_PYTHON_THREAD_END_ALLOW)
#      define SWIG_PYTHON_THREAD_END_ALLOW
#    endif
#  endif
#else /* No thread support */
#  define SWIG_PYTHON_INITIALIZE_THREADS
#  define SWIG_PYTHON_THREAD_BEGIN_BLOCK
#  define SWIG_PYTHON_THREAD_END_BLOCK
#  define SWIG_PYTHON_THREAD_BEGIN_ALLOW
#  define SWIG_PYTHON_THREAD_END_ALLOW
#endif

/* -----------------------------------------------------------------------------
 * Python API portion that goes into the runtime
 * ----------------------------------------------------------------------------- */

#ifdef __cplusplus
extern "C" {
#endif

/* -----------------------------------------------------------------------------
 * Constant declarations
 * ----------------------------------------------------------------------------- */

/* Constant Types */
#define SWIG_PY_POINTER 4
#define SWIG_PY_BINARY  5

/* Constant information structure */
typedef struct swig_const_info {
  int type;
  char *name;
  long lvalue;
  double dvalue;
  void   *pvalue;
  swig_type_info **ptype;
} swig_const_info;


/* -----------------------------------------------------------------------------
 * Wrapper of PyInstanceMethod_New() used in Python 3
 * It is exported to the generated module, used for -fastproxy
 * ----------------------------------------------------------------------------- */
#if PY_VERSION_HEX >= 0x03000000
SWIGRUNTIME PyObject* SWIG_PyInstanceMethod_New(PyObject *SWIGUNUSEDPARM(self), PyObject *func)
{
  return PyInstanceMethod_New(func);
}
#else
SWIGRUNTIME PyObject* SWIG_PyInstanceMethod_New(PyObject *SWIGUNUSEDPARM(self), PyObject *SWIGUNUSEDPARM(func))
{
  return NULL;
}
#endif

#ifdef __cplusplus
}
#endif


/* -----------------------------------------------------------------------------
 * pyrun.swg
 *
 * This file contains the runtime support for Python modules
 * and includes code for managing global variables and pointer
 * type checking.
 *
 * ----------------------------------------------------------------------------- */

/* Common SWIG API */

/* for raw pointers */
#define SWIG_Python_ConvertPtr(obj, pptr, type, flags)  SWIG_Python_ConvertPtrAndOwn(obj, pptr, type, flags, 0)
#define SWIG_ConvertPtr(obj, pptr, type, flags)         SWIG_Python_ConvertPtr(obj, pptr, type, flags)
#define SWIG_ConvertPtrAndOwn(obj,pptr,type,flags,own)  SWIG_Python_ConvertPtrAndOwn(obj, pptr, type, flags, own)

#ifdef SWIGPYTHON_BUILTIN
#define SWIG_NewPointerObj(ptr, type, flags)            SWIG_Python_NewPointerObj(self, ptr, type, flags)
#else
#define SWIG_NewPointerObj(ptr, type, flags)            SWIG_Python_NewPointerObj(NULL, ptr, type, flags)
#endif

#define SWIG_InternalNewPointerObj(ptr, type, flags)	SWIG_Python_NewPointerObj(NULL, ptr, type, flags)

#define SWIG_CheckImplicit(ty)                          SWIG_Python_CheckImplicit(ty) 
#define SWIG_AcquirePtr(ptr, src)                       SWIG_Python_AcquirePtr(ptr, src)
#define swig_owntype                                    int

/* for raw packed data */
#define SWIG_ConvertPacked(obj, ptr, sz, ty)            SWIG_Python_ConvertPacked(obj, ptr, sz, ty)
#define SWIG_NewPackedObj(ptr, sz, type)                SWIG_Python_NewPackedObj(ptr, sz, type)

/* for class or struct pointers */
#define SWIG_ConvertInstance(obj, pptr, type, flags)    SWIG_ConvertPtr(obj, pptr, type, flags)
#define SWIG_NewInstanceObj(ptr, type, flags)           SWIG_NewPointerObj(ptr, type, flags)

/* for C or C++ function pointers */
#define SWIG_ConvertFunctionPtr(obj, pptr, type)        SWIG_Python_ConvertFunctionPtr(obj, pptr, type)
#define SWIG_NewFunctionPtrObj(ptr, type)               SWIG_Python_NewPointerObj(NULL, ptr, type, 0)

/* for C++ member pointers, ie, member methods */
#define SWIG_ConvertMember(obj, ptr, sz, ty)            SWIG_Python_ConvertPacked(obj, ptr, sz, ty)
#define SWIG_NewMemberObj(ptr, sz, type)                SWIG_Python_NewPackedObj(ptr, sz, type)


/* Runtime API */

#define SWIG_GetModule(clientdata)                      SWIG_Python_GetModule(clientdata)
#define SWIG_SetModule(clientdata, pointer)             SWIG_Python_SetModule(pointer)
#define SWIG_NewClientData(obj)                         SwigPyClientData_New(obj)

#define SWIG_SetErrorObj                                SWIG_Python_SetErrorObj                            
#define SWIG_SetErrorMsg                        	SWIG_Python_SetErrorMsg				   
#define SWIG_ErrorType(code)                    	SWIG_Python_ErrorType(code)                        
#define SWIG_Error(code, msg)            		SWIG_Python_SetErrorMsg(SWIG_ErrorType(code), msg) 
#define SWIG_fail                        		goto fail					   


/* Runtime API implementation */

/* Error manipulation */

SWIGINTERN void 
SWIG_Python_SetErrorObj(PyObject *errtype, PyObject *obj) {
  SWIG_PYTHON_THREAD_BEGIN_BLOCK; 
  PyErr_SetObject(errtype, obj);
  Py_DECREF(obj);
  SWIG_PYTHON_THREAD_END_BLOCK;
}

SWIGINTERN void 
SWIG_Python_SetErrorMsg(PyObject *errtype, const char *msg) {
  SWIG_PYTHON_THREAD_BEGIN_BLOCK;
  PyErr_SetString(errtype, msg);
  SWIG_PYTHON_THREAD_END_BLOCK;
}

#define SWIG_Python_Raise(obj, type, desc)  SWIG_Python_SetErrorObj(SWIG_Python_ExceptionType(desc), obj)

/* Set a constant value */

#if defined(SWIGPYTHON_BUILTIN)

SWIGINTERN void
SwigPyBuiltin_AddPublicSymbol(PyObject *seq, const char *key) {
  PyObject *s = PyString_InternFromString(key);
  PyList_Append(seq, s);
  Py_DECREF(s);
}

SWIGINTERN void
SWIG_Python_SetConstant(PyObject *d, PyObject *public_interface, const char *name, PyObject *obj) {   
#if PY_VERSION_HEX < 0x02030000
  PyDict_SetItemString(d, (char *)name, obj);
#else
  PyDict_SetItemString(d, name, obj);
#endif
  Py_DECREF(obj);
  if (public_interface)
    SwigPyBuiltin_AddPublicSymbol(public_interface, name);
}

#else

SWIGINTERN void
SWIG_Python_SetConstant(PyObject *d, const char *name, PyObject *obj) {   
#if PY_VERSION_HEX < 0x02030000
  PyDict_SetItemString(d, (char *)name, obj);
#else
  PyDict_SetItemString(d, name, obj);
#endif
  Py_DECREF(obj);                            
}

#endif

/* Append a value to the result obj */

SWIGINTERN PyObject*
SWIG_Python_AppendOutput(PyObject* result, PyObject* obj) {
#if !defined(SWIG_PYTHON_OUTPUT_TUPLE)
  if (!result) {
    result = obj;
  } else if (result == Py_None) {
    Py_DECREF(result);
    result = obj;
  } else {
    if (!PyList_Check(result)) {
      PyObject *o2 = result;
      result = PyList_New(1);
      PyList_SetItem(result, 0, o2);
    }
    PyList_Append(result,obj);
    Py_DECREF(obj);
  }
  return result;
#else
  PyObject*   o2;
  PyObject*   o3;
  if (!result) {
    result = obj;
  } else if (result == Py_None) {
    Py_DECREF(result);
    result = obj;
  } else {
    if (!PyTuple_Check(result)) {
      o2 = result;
      result = PyTuple_New(1);
      PyTuple_SET_ITEM(result, 0, o2);
    }
    o3 = PyTuple_New(1);
    PyTuple_SET_ITEM(o3, 0, obj);
    o2 = result;
    result = PySequence_Concat(o2, o3);
    Py_DECREF(o2);
    Py_DECREF(o3);
  }
  return result;
#endif
}

/* Unpack the argument tuple */

SWIGINTERN int
SWIG_Python_UnpackTuple(PyObject *args, const char *name, Py_ssize_t min, Py_ssize_t max, PyObject **objs)
{
  if (!args) {
    if (!min && !max) {
      return 1;
    } else {
      PyErr_Format(PyExc_TypeError, "%s expected %s%d arguments, got none", 
		   name, (min == max ? "" : "at least "), (int)min);
      return 0;
    }
  }  
  if (!PyTuple_Check(args)) {
    if (min <= 1 && max >= 1) {
      int i;
      objs[0] = args;
      for (i = 1; i < max; ++i) {
	objs[i] = 0;
      }
      return 2;
    }
    PyErr_SetString(PyExc_SystemError, "UnpackTuple() argument list is not a tuple");
    return 0;
  } else {
    Py_ssize_t l = PyTuple_GET_SIZE(args);
    if (l < min) {
      PyErr_Format(PyExc_TypeError, "%s expected %s%d arguments, got %d", 
		   name, (min == max ? "" : "at least "), (int)min, (int)l);
      return 0;
    } else if (l > max) {
      PyErr_Format(PyExc_TypeError, "%s expected %s%d arguments, got %d", 
		   name, (min == max ? "" : "at most "), (int)max, (int)l);
      return 0;
    } else {
      int i;
      for (i = 0; i < l; ++i) {
	objs[i] = PyTuple_GET_ITEM(args, i);
      }
      for (; l < max; ++l) {
	objs[l] = 0;
      }
      return i + 1;
    }    
  }
}

/* A functor is a function object with one single object argument */
#if PY_VERSION_HEX >= 0x02020000
#define SWIG_Python_CallFunctor(functor, obj)	        PyObject_CallFunctionObjArgs(functor, obj, NULL);
#else
#define SWIG_Python_CallFunctor(functor, obj)	        PyObject_CallFunction(functor, "O", obj);
#endif

/*
  Helper for static pointer initialization for both C and C++ code, for example
  static PyObject *SWIG_STATIC_POINTER(MyVar) = NewSomething(...);
*/
#ifdef __cplusplus
#define SWIG_STATIC_POINTER(var)  var
#else
#define SWIG_STATIC_POINTER(var)  var = 0; if (!var) var
#endif

/* -----------------------------------------------------------------------------
 * Pointer declarations
 * ----------------------------------------------------------------------------- */

/* Flags for new pointer objects */
#define SWIG_POINTER_NOSHADOW       (SWIG_POINTER_OWN      << 1)
#define SWIG_POINTER_NEW            (SWIG_POINTER_NOSHADOW | SWIG_POINTER_OWN)

#define SWIG_POINTER_IMPLICIT_CONV  (SWIG_POINTER_DISOWN   << 1)

#define SWIG_BUILTIN_TP_INIT	    (SWIG_POINTER_OWN << 2)
#define SWIG_BUILTIN_INIT	    (SWIG_BUILTIN_TP_INIT | SWIG_POINTER_OWN)

#ifdef __cplusplus
extern "C" {
#endif

/*  How to access Py_None */
#if defined(_WIN32) || defined(__WIN32__) || defined(__CYGWIN__)
#  ifndef SWIG_PYTHON_NO_BUILD_NONE
#    ifndef SWIG_PYTHON_BUILD_NONE
#      define SWIG_PYTHON_BUILD_NONE
#    endif
#  endif
#endif

#ifdef SWIG_PYTHON_BUILD_NONE
#  ifdef Py_None
#   undef Py_None
#   define Py_None SWIG_Py_None()
#  endif
SWIGRUNTIMEINLINE PyObject * 
_SWIG_Py_None(void)
{
  PyObject *none = Py_BuildValue((char*)"");
  Py_DECREF(none);
  return none;
}
SWIGRUNTIME PyObject * 
SWIG_Py_None(void)
{
  static PyObject *SWIG_STATIC_POINTER(none) = _SWIG_Py_None();
  return none;
}
#endif

/* The python void return value */

SWIGRUNTIMEINLINE PyObject * 
SWIG_Py_Void(void)
{
  PyObject *none = Py_None;
  Py_INCREF(none);
  return none;
}

/* SwigPyClientData */

typedef struct {
  PyObject *klass;
  PyObject *newraw;
  PyObject *newargs;
  PyObject *destroy;
  int delargs;
  int implicitconv;
  PyTypeObject *pytype;
} SwigPyClientData;

SWIGRUNTIMEINLINE int 
SWIG_Python_CheckImplicit(swig_type_info *ty)
{
  SwigPyClientData *data = (SwigPyClientData *)ty->clientdata;
  return data ? data->implicitconv : 0;
}

SWIGRUNTIMEINLINE PyObject *
SWIG_Python_ExceptionType(swig_type_info *desc) {
  SwigPyClientData *data = desc ? (SwigPyClientData *) desc->clientdata : 0;
  PyObject *klass = data ? data->klass : 0;
  return (klass ? klass : PyExc_RuntimeError);
}


SWIGRUNTIME SwigPyClientData * 
SwigPyClientData_New(PyObject* obj)
{
  if (!obj) {
    return 0;
  } else {
    SwigPyClientData *data = (SwigPyClientData *)malloc(sizeof(SwigPyClientData));
    if (!data) {
        return 0;
    }
    /* the klass element */
    data->klass = obj;
    Py_INCREF(data->klass);
    /* the newraw method and newargs arguments used to create a new raw instance */
    if (PyClass_Check(obj)) {
      data->newraw = 0;
      data->newargs = obj;
      Py_INCREF(obj);
    } else {
#if (PY_VERSION_HEX < 0x02020000)
      data->newraw = 0;
#else
      data->newraw = PyObject_GetAttrString(data->klass, (char *)"__new__");
#endif
      if (data->newraw) {
	Py_INCREF(data->newraw);
	data->newargs = PyTuple_New(1);
	PyTuple_SetItem(data->newargs, 0, obj);
      } else {
	data->newargs = obj;
      }
      Py_INCREF(data->newargs);
    }
    /* the destroy method, aka as the C++ delete method */
    data->destroy = PyObject_GetAttrString(data->klass, (char *)"__swig_destroy__");
    if (PyErr_Occurred()) {
      PyErr_Clear();
      data->destroy = 0;
    }
    if (data->destroy) {
      int flags;
      Py_INCREF(data->destroy);
      flags = PyCFunction_GET_FLAGS(data->destroy);
#ifdef METH_O
      data->delargs = !(flags & (METH_O));
#else
      data->delargs = 0;
#endif
    } else {
      data->delargs = 0;
    }
    data->implicitconv = 0;
    data->pytype = 0;
    return data;
  }
}

SWIGRUNTIME void 
SwigPyClientData_Del(SwigPyClientData *data) {
  Py_XDECREF(data->newraw);
  Py_XDECREF(data->newargs);
  Py_XDECREF(data->destroy);
}

/* =============== SwigPyObject =====================*/

typedef struct {
  PyObject_HEAD
  void *ptr;
  swig_type_info *ty;
  int own;
  PyObject *next;
#ifdef SWIGPYTHON_BUILTIN
  PyObject *dict;
#endif
} SwigPyObject;

SWIGRUNTIME PyObject *
SwigPyObject_long(SwigPyObject *v)
{
  return PyLong_FromVoidPtr(v->ptr);
}

SWIGRUNTIME PyObject *
SwigPyObject_format(const char* fmt, SwigPyObject *v)
{
  PyObject *res = NULL;
  PyObject *args = PyTuple_New(1);
  if (args) {
    if (PyTuple_SetItem(args, 0, SwigPyObject_long(v)) == 0) {
      PyObject *ofmt = SWIG_Python_str_FromChar(fmt);
      if (ofmt) {
#if PY_VERSION_HEX >= 0x03000000
	res = PyUnicode_Format(ofmt,args);
#else
	res = PyString_Format(ofmt,args);
#endif
	Py_DECREF(ofmt);
      }
      Py_DECREF(args);
    }
  }
  return res;
}

SWIGRUNTIME PyObject *
SwigPyObject_oct(SwigPyObject *v)
{
  return SwigPyObject_format("%o",v);
}

SWIGRUNTIME PyObject *
SwigPyObject_hex(SwigPyObject *v)
{
  return SwigPyObject_format("%x",v);
}

SWIGRUNTIME PyObject *
#ifdef METH_NOARGS
SwigPyObject_repr(SwigPyObject *v)
#else
SwigPyObject_repr(SwigPyObject *v, PyObject *args)
#endif
{
  const char *name = SWIG_TypePrettyName(v->ty);
  PyObject *repr = SWIG_Python_str_FromFormat("<Swig Object of type '%s' at %p>", (name ? name : "unknown"), (void *)v);
  if (v->next) {
# ifdef METH_NOARGS
    PyObject *nrep = SwigPyObject_repr((SwigPyObject *)v->next);
# else
    PyObject *nrep = SwigPyObject_repr((SwigPyObject *)v->next, args);
# endif
# if PY_VERSION_HEX >= 0x03000000
    PyObject *joined = PyUnicode_Concat(repr, nrep);
    Py_DecRef(repr);
    Py_DecRef(nrep);
    repr = joined;
# else
    PyString_ConcatAndDel(&repr,nrep);
# endif
  }
  return repr;  
}

SWIGRUNTIME int
SwigPyObject_compare(SwigPyObject *v, SwigPyObject *w)
{
  void *i = v->ptr;
  void *j = w->ptr;
  return (i < j) ? -1 : ((i > j) ? 1 : 0);
}

/* Added for Python 3.x, would it also be useful for Python 2.x? */
SWIGRUNTIME PyObject*
SwigPyObject_richcompare(SwigPyObject *v, SwigPyObject *w, int op)
{
  PyObject* res;
  if( op != Py_EQ && op != Py_NE ) {
    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
  }
  res = PyBool_FromLong( (SwigPyObject_compare(v, w)==0) == (op == Py_EQ) ? 1 : 0);
  return res;  
}


SWIGRUNTIME PyTypeObject* SwigPyObject_TypeOnce(void);

#ifdef SWIGPYTHON_BUILTIN
static swig_type_info *SwigPyObject_stype = 0;
SWIGRUNTIME PyTypeObject*
SwigPyObject_type(void) {
    SwigPyClientData *cd;
    assert(SwigPyObject_stype);
    cd = (SwigPyClientData*) SwigPyObject_stype->clientdata;
    assert(cd);
    assert(cd->pytype);
    return cd->pytype;
}
#else
SWIGRUNTIME PyTypeObject*
SwigPyObject_type(void) {
  static PyTypeObject *SWIG_STATIC_POINTER(type) = SwigPyObject_TypeOnce();
  return type;
}
#endif

SWIGRUNTIMEINLINE int
SwigPyObject_Check(PyObject *op) {
#ifdef SWIGPYTHON_BUILTIN
  PyTypeObject *target_tp = SwigPyObject_type();
  if (PyType_IsSubtype(op->ob_type, target_tp))
    return 1;
  return (strcmp(op->ob_type->tp_name, "SwigPyObject") == 0);
#else
  return (Py_TYPE(op) == SwigPyObject_type())
    || (strcmp(Py_TYPE(op)->tp_name,"SwigPyObject") == 0);
#endif
}

SWIGRUNTIME PyObject *
SwigPyObject_New(void *ptr, swig_type_info *ty, int own);

SWIGRUNTIME void
SwigPyObject_dealloc(PyObject *v)
{
  SwigPyObject *sobj = (SwigPyObject *) v;
  PyObject *next = sobj->next;
  if (sobj->own == SWIG_POINTER_OWN) {
    swig_type_info *ty = sobj->ty;
    SwigPyClientData *data = ty ? (SwigPyClientData *) ty->clientdata : 0;
    PyObject *destroy = data ? data->destroy : 0;
    if (destroy) {
      /* destroy is always a VARARGS method */
      PyObject *res;
      if (data->delargs) {
	/* we need to create a temporary object to carry the destroy operation */
	PyObject *tmp = SwigPyObject_New(sobj->ptr, ty, 0);
	res = SWIG_Python_CallFunctor(destroy, tmp);
	Py_DECREF(tmp);
      } else {
	PyCFunction meth = PyCFunction_GET_FUNCTION(destroy);
	PyObject *mself = PyCFunction_GET_SELF(destroy);
	res = ((*meth)(mself, v));
      }
      Py_XDECREF(res);
    } 
#if !defined(SWIG_PYTHON_SILENT_MEMLEAK)
    else {
      const char *name = SWIG_TypePrettyName(ty);
      printf("swig/python detected a memory leak of type '%s', no destructor found.\n", (name ? name : "unknown"));
    }
#endif
  } 
  Py_XDECREF(next);
  PyObject_DEL(v);
}

SWIGRUNTIME PyObject* 
SwigPyObject_append(PyObject* v, PyObject* next)
{
  SwigPyObject *sobj = (SwigPyObject *) v;
#ifndef METH_O
  PyObject *tmp = 0;
  if (!PyArg_ParseTuple(next,(char *)"O:append", &tmp)) return NULL;
  next = tmp;
#endif
  if (!SwigPyObject_Check(next)) {
    return NULL;
  }
  sobj->next = next;
  Py_INCREF(next);
  return SWIG_Py_Void();
}

SWIGRUNTIME PyObject* 
#ifdef METH_NOARGS
SwigPyObject_next(PyObject* v)
#else
SwigPyObject_next(PyObject* v, PyObject *SWIGUNUSEDPARM(args))
#endif
{
  SwigPyObject *sobj = (SwigPyObject *) v;
  if (sobj->next) {    
    Py_INCREF(sobj->next);
    return sobj->next;
  } else {
    return SWIG_Py_Void();
  }
}

SWIGINTERN PyObject*
#ifdef METH_NOARGS
SwigPyObject_disown(PyObject *v)
#else
SwigPyObject_disown(PyObject* v, PyObject *SWIGUNUSEDPARM(args))
#endif
{
  SwigPyObject *sobj = (SwigPyObject *)v;
  sobj->own = 0;
  return SWIG_Py_Void();
}

SWIGINTERN PyObject*
#ifdef METH_NOARGS
SwigPyObject_acquire(PyObject *v)
#else
SwigPyObject_acquire(PyObject* v, PyObject *SWIGUNUSEDPARM(args))
#endif
{
  SwigPyObject *sobj = (SwigPyObject *)v;
  sobj->own = SWIG_POINTER_OWN;
  return SWIG_Py_Void();
}

SWIGINTERN PyObject*
SwigPyObject_own(PyObject *v, PyObject *args)
{
  PyObject *val = 0;
#if (PY_VERSION_HEX < 0x02020000)
  if (!PyArg_ParseTuple(args,(char *)"|O:own",&val))
#elif (PY_VERSION_HEX < 0x02050000)
  if (!PyArg_UnpackTuple(args, (char *)"own", 0, 1, &val)) 
#else
  if (!PyArg_UnpackTuple(args, "own", 0, 1, &val)) 
#endif
    {
      return NULL;
    } 
  else
    {
      SwigPyObject *sobj = (SwigPyObject *)v;
      PyObject *obj = PyBool_FromLong(sobj->own);
      if (val) {
#ifdef METH_NOARGS
	if (PyObject_IsTrue(val)) {
	  SwigPyObject_acquire(v);
	} else {
	  SwigPyObject_disown(v);
	}
#else
	if (PyObject_IsTrue(val)) {
	  SwigPyObject_acquire(v,args);
	} else {
	  SwigPyObject_disown(v,args);
	}
#endif
      } 
      return obj;
    }
}

#ifdef METH_O
static PyMethodDef
swigobject_methods[] = {
  {(char *)"disown",  (PyCFunction)SwigPyObject_disown,  METH_NOARGS,  (char *)"releases ownership of the pointer"},
  {(char *)"acquire", (PyCFunction)SwigPyObject_acquire, METH_NOARGS,  (char *)"acquires ownership of the pointer"},
  {(char *)"own",     (PyCFunction)SwigPyObject_own,     METH_VARARGS, (char *)"returns/sets ownership of the pointer"},
  {(char *)"append",  (PyCFunction)SwigPyObject_append,  METH_O,       (char *)"appends another 'this' object"},
  {(char *)"next",    (PyCFunction)SwigPyObject_next,    METH_NOARGS,  (char *)"returns the next 'this' object"},
  {(char *)"__repr__",(PyCFunction)SwigPyObject_repr,    METH_NOARGS,  (char *)"returns object representation"},
  {0, 0, 0, 0}  
};
#else
static PyMethodDef
swigobject_methods[] = {
  {(char *)"disown",  (PyCFunction)SwigPyObject_disown,  METH_VARARGS,  (char *)"releases ownership of the pointer"},
  {(char *)"acquire", (PyCFunction)SwigPyObject_acquire, METH_VARARGS,  (char *)"aquires ownership of the pointer"},
  {(char *)"own",     (PyCFunction)SwigPyObject_own,     METH_VARARGS,  (char *)"returns/sets ownership of the pointer"},
  {(char *)"append",  (PyCFunction)SwigPyObject_append,  METH_VARARGS,  (char *)"appends another 'this' object"},
  {(char *)"next",    (PyCFunction)SwigPyObject_next,    METH_VARARGS,  (char *)"returns the next 'this' object"},
  {(char *)"__repr__",(PyCFunction)SwigPyObject_repr,   METH_VARARGS,  (char *)"returns object representation"},
  {0, 0, 0, 0}  
};
#endif

#if PY_VERSION_HEX < 0x02020000
SWIGINTERN PyObject *
SwigPyObject_getattr(SwigPyObject *sobj,char *name)
{
  return Py_FindMethod(swigobject_methods, (PyObject *)sobj, name);
}
#endif

SWIGRUNTIME PyTypeObject*
SwigPyObject_TypeOnce(void) {
  static char swigobject_doc[] = "Swig object carries a C/C++ instance pointer";

  static PyNumberMethods SwigPyObject_as_number = {
    (binaryfunc)0, /*nb_add*/
    (binaryfunc)0, /*nb_subtract*/
    (binaryfunc)0, /*nb_multiply*/
    /* nb_divide removed in Python 3 */
#if PY_VERSION_HEX < 0x03000000
    (binaryfunc)0, /*nb_divide*/
#endif
    (binaryfunc)0, /*nb_remainder*/
    (binaryfunc)0, /*nb_divmod*/
    (ternaryfunc)0,/*nb_power*/
    (unaryfunc)0,  /*nb_negative*/
    (unaryfunc)0,  /*nb_positive*/
    (unaryfunc)0,  /*nb_absolute*/
    (inquiry)0,    /*nb_nonzero*/
    0,		   /*nb_invert*/
    0,		   /*nb_lshift*/
    0,		   /*nb_rshift*/
    0,		   /*nb_and*/
    0,		   /*nb_xor*/
    0,		   /*nb_or*/
#if PY_VERSION_HEX < 0x03000000
    0,   /*nb_coerce*/
#endif
    (unaryfunc)SwigPyObject_long, /*nb_int*/
#if PY_VERSION_HEX < 0x03000000
    (unaryfunc)SwigPyObject_long, /*nb_long*/
#else
    0, /*nb_reserved*/
#endif
    (unaryfunc)0,                 /*nb_float*/
#if PY_VERSION_HEX < 0x03000000
    (unaryfunc)SwigPyObject_oct,  /*nb_oct*/
    (unaryfunc)SwigPyObject_hex,  /*nb_hex*/
#endif
#if PY_VERSION_HEX >= 0x03000000 /* 3.0 */
    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0 /* nb_inplace_add -> nb_index, nb_inplace_divide removed */
#elif PY_VERSION_HEX >= 0x02050000 /* 2.5.0 */
    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0 /* nb_inplace_add -> nb_index */
#elif PY_VERSION_HEX >= 0x02020000 /* 2.2.0 */
    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0 /* nb_inplace_add -> nb_inplace_true_divide */
#elif PY_VERSION_HEX >= 0x02000000 /* 2.0.0 */
    0,0,0,0,0,0,0,0,0,0,0 /* nb_inplace_add -> nb_inplace_or */
#endif
  };

  static PyTypeObject swigpyobject_type;
  static int type_init = 0;
  if (!type_init) {
    const PyTypeObject tmp = {
      /* PyObject header changed in Python 3 */
#if PY_VERSION_HEX >= 0x03000000
      PyVarObject_HEAD_INIT(NULL, 0)
#else
      PyObject_HEAD_INIT(NULL)
      0,                                    /* ob_size */
#endif
      (char *)"SwigPyObject",               /* tp_name */
      sizeof(SwigPyObject),                 /* tp_basicsize */
      0,                                    /* tp_itemsize */
      (destructor)SwigPyObject_dealloc,     /* tp_dealloc */
      0,				    /* tp_print */
#if PY_VERSION_HEX < 0x02020000
      (getattrfunc)SwigPyObject_getattr,    /* tp_getattr */
#else
      (getattrfunc)0,                       /* tp_getattr */
#endif
      (setattrfunc)0,                       /* tp_setattr */
#if PY_VERSION_HEX >= 0x03000000
    0, /* tp_reserved in 3.0.1, tp_compare in 3.0.0 but not used */
#else
      (cmpfunc)SwigPyObject_compare,        /* tp_compare */
#endif
      (reprfunc)SwigPyObject_repr,          /* tp_repr */
      &SwigPyObject_as_number,              /* tp_as_number */
      0,                                    /* tp_as_sequence */
      0,                                    /* tp_as_mapping */
      (hashfunc)0,                          /* tp_hash */
      (ternaryfunc)0,                       /* tp_call */
      0,				    /* tp_str */
      PyObject_GenericGetAttr,              /* tp_getattro */
      0,                                    /* tp_setattro */
      0,                                    /* tp_as_buffer */
      Py_TPFLAGS_DEFAULT,                   /* tp_flags */
      swigobject_doc,                       /* tp_doc */
      0,                                    /* tp_traverse */
      0,                                    /* tp_clear */
      (richcmpfunc)SwigPyObject_richcompare,/* tp_richcompare */
      0,                                    /* tp_weaklistoffset */
#if PY_VERSION_HEX >= 0x02020000
      0,                                    /* tp_iter */
      0,                                    /* tp_iternext */
      swigobject_methods,                   /* tp_methods */
      0,                                    /* tp_members */
      0,                                    /* tp_getset */
      0,                                    /* tp_base */
      0,                                    /* tp_dict */
      0,                                    /* tp_descr_get */
      0,                                    /* tp_descr_set */
      0,                                    /* tp_dictoffset */
      0,                                    /* tp_init */
      0,                                    /* tp_alloc */
      0,                                    /* tp_new */
      0,                                    /* tp_free */
      0,                                    /* tp_is_gc */
      0,                                    /* tp_bases */
      0,                                    /* tp_mro */
      0,                                    /* tp_cache */
      0,                                    /* tp_subclasses */
      0,                                    /* tp_weaklist */
#endif
#if PY_VERSION_HEX >= 0x02030000
      0,                                    /* tp_del */
#endif
#if PY_VERSION_HEX >= 0x02060000
      0,                                    /* tp_version */
#endif
#ifdef COUNT_ALLOCS
      0,0,0,0                               /* tp_alloc -> tp_next */
#endif
    };
    swigpyobject_type = tmp;
    type_init = 1;
#if PY_VERSION_HEX < 0x02020000
    swigpyobject_type.ob_type = &PyType_Type;
#else
    if (PyType_Ready(&swigpyobject_type) < 0)
      return NULL;
#endif
  }
  return &swigpyobject_type;
}

SWIGRUNTIME PyObject *
SwigPyObject_New(void *ptr, swig_type_info *ty, int own)
{
  SwigPyObject *sobj = PyObject_NEW(SwigPyObject, SwigPyObject_type());
  if (sobj) {
    sobj->ptr  = ptr;
    sobj->ty   = ty;
    sobj->own  = own;
    sobj->next = 0;
  }
  return (PyObject *)sobj;
}

/* -----------------------------------------------------------------------------
 * Implements a simple Swig Packed type, and use it instead of string
 * ----------------------------------------------------------------------------- */

typedef struct {
  PyObject_HEAD
  void *pack;
  swig_type_info *ty;
  size_t size;
} SwigPyPacked;

SWIGRUNTIME int
SwigPyPacked_print(SwigPyPacked *v, FILE *fp, int SWIGUNUSEDPARM(flags))
{
  char result[SWIG_BUFFER_SIZE];
  fputs("<Swig Packed ", fp); 
  if (SWIG_PackDataName(result, v->pack, v->size, 0, sizeof(result))) {
    fputs("at ", fp); 
    fputs(result, fp); 
  }
  fputs(v->ty->name,fp); 
  fputs(">", fp);
  return 0; 
}
  
SWIGRUNTIME PyObject *
SwigPyPacked_repr(SwigPyPacked *v)
{
  char result[SWIG_BUFFER_SIZE];
  if (SWIG_PackDataName(result, v->pack, v->size, 0, sizeof(result))) {
    return SWIG_Python_str_FromFormat("<Swig Packed at %s%s>", result, v->ty->name);
  } else {
    return SWIG_Python_str_FromFormat("<Swig Packed %s>", v->ty->name);
  }  
}

SWIGRUNTIME PyObject *
SwigPyPacked_str(SwigPyPacked *v)
{
  char result[SWIG_BUFFER_SIZE];
  if (SWIG_PackDataName(result, v->pack, v->size, 0, sizeof(result))){
    return SWIG_Python_str_FromFormat("%s%s", result, v->ty->name);
  } else {
    return SWIG_Python_str_FromChar(v->ty->name);
  }  
}

SWIGRUNTIME int
SwigPyPacked_compare(SwigPyPacked *v, SwigPyPacked *w)
{
  size_t i = v->size;
  size_t j = w->size;
  int s = (i < j) ? -1 : ((i > j) ? 1 : 0);
  return s ? s : strncmp((char *)v->pack, (char *)w->pack, 2*v->size);
}

SWIGRUNTIME PyTypeObject* SwigPyPacked_TypeOnce(void);

SWIGRUNTIME PyTypeObject*
SwigPyPacked_type(void) {
  static PyTypeObject *SWIG_STATIC_POINTER(type) = SwigPyPacked_TypeOnce();
  return type;
}

SWIGRUNTIMEINLINE int
SwigPyPacked_Check(PyObject *op) {
  return ((op)->ob_type == SwigPyPacked_TypeOnce()) 
    || (strcmp((op)->ob_type->tp_name,"SwigPyPacked") == 0);
}

SWIGRUNTIME void
SwigPyPacked_dealloc(PyObject *v)
{
  if (SwigPyPacked_Check(v)) {
    SwigPyPacked *sobj = (SwigPyPacked *) v;
    free(sobj->pack);
  }
  PyObject_DEL(v);
}

SWIGRUNTIME PyTypeObject*
SwigPyPacked_TypeOnce(void) {
  static char swigpacked_doc[] = "Swig object carries a C/C++ instance pointer";
  static PyTypeObject swigpypacked_type;
  static int type_init = 0;
  if (!type_init) {
    const PyTypeObject tmp = {
      /* PyObject header changed in Python 3 */
#if PY_VERSION_HEX>=0x03000000
      PyVarObject_HEAD_INIT(NULL, 0)
#else
      PyObject_HEAD_INIT(NULL)
      0,                                    /* ob_size */
#endif
      (char *)"SwigPyPacked",               /* tp_name */
      sizeof(SwigPyPacked),                 /* tp_basicsize */
      0,                                    /* tp_itemsize */
      (destructor)SwigPyPacked_dealloc,     /* tp_dealloc */
      (printfunc)SwigPyPacked_print,        /* tp_print */
      (getattrfunc)0,                       /* tp_getattr */
      (setattrfunc)0,                       /* tp_setattr */
#if PY_VERSION_HEX>=0x03000000
      0, /* tp_reserved in 3.0.1 */
#else
      (cmpfunc)SwigPyPacked_compare,        /* tp_compare */
#endif
      (reprfunc)SwigPyPacked_repr,          /* tp_repr */
      0,                                    /* tp_as_number */
      0,                                    /* tp_as_sequence */
      0,                                    /* tp_as_mapping */
      (hashfunc)0,                          /* tp_hash */
      (ternaryfunc)0,                       /* tp_call */
      (reprfunc)SwigPyPacked_str,           /* tp_str */
      PyObject_GenericGetAttr,              /* tp_getattro */
      0,                                    /* tp_setattro */
      0,                                    /* tp_as_buffer */
      Py_TPFLAGS_DEFAULT,                   /* tp_flags */
      swigpacked_doc,                       /* tp_doc */
      0,                                    /* tp_traverse */
      0,                                    /* tp_clear */
      0,                                    /* tp_richcompare */
      0,                                    /* tp_weaklistoffset */
#if PY_VERSION_HEX >= 0x02020000
      0,                                    /* tp_iter */
      0,                                    /* tp_iternext */
      0,                                    /* tp_methods */
      0,                                    /* tp_members */
      0,                                    /* tp_getset */
      0,                                    /* tp_base */
      0,                                    /* tp_dict */
      0,                                    /* tp_descr_get */
      0,                                    /* tp_descr_set */
      0,                                    /* tp_dictoffset */
      0,                                    /* tp_init */
      0,                                    /* tp_alloc */
      0,                                    /* tp_new */
      0,                                    /* tp_free */
      0,                                    /* tp_is_gc */
      0,                                    /* tp_bases */
      0,                                    /* tp_mro */
      0,                                    /* tp_cache */
      0,                                    /* tp_subclasses */
      0,                                    /* tp_weaklist */
#endif
#if PY_VERSION_HEX >= 0x02030000
      0,                                    /* tp_del */
#endif
#if PY_VERSION_HEX >= 0x02060000
      0,                                    /* tp_version */
#endif
#ifdef COUNT_ALLOCS
      0,0,0,0                               /* tp_alloc -> tp_next */
#endif
    };
    swigpypacked_type = tmp;
    type_init = 1;
#if PY_VERSION_HEX < 0x02020000
    swigpypacked_type.ob_type = &PyType_Type;
#else
    if (PyType_Ready(&swigpypacked_type) < 0)
      return NULL;
#endif
  }
  return &swigpypacked_type;
}

SWIGRUNTIME PyObject *
SwigPyPacked_New(void *ptr, size_t size, swig_type_info *ty)
{
  SwigPyPacked *sobj = PyObject_NEW(SwigPyPacked, SwigPyPacked_type());
  if (sobj) {
    void *pack = malloc(size);
    if (pack) {
      memcpy(pack, ptr, size);
      sobj->pack = pack;
      sobj->ty   = ty;
      sobj->size = size;
    } else {
      PyObject_DEL((PyObject *) sobj);
      sobj = 0;
    }
  }
  return (PyObject *) sobj;
}

SWIGRUNTIME swig_type_info *
SwigPyPacked_UnpackData(PyObject *obj, void *ptr, size_t size)
{
  if (SwigPyPacked_Check(obj)) {
    SwigPyPacked *sobj = (SwigPyPacked *)obj;
    if (sobj->size != size) return 0;
    memcpy(ptr, sobj->pack, size);
    return sobj->ty;
  } else {
    return 0;
  }
}

/* -----------------------------------------------------------------------------
 * pointers/data manipulation
 * ----------------------------------------------------------------------------- */

SWIGRUNTIMEINLINE PyObject *
_SWIG_This(void)
{
    return SWIG_Python_str_FromChar("this");
}

static PyObject *swig_this = NULL;

SWIGRUNTIME PyObject *
SWIG_This(void)
{
  if (swig_this == NULL)
    swig_this = _SWIG_This();
  return swig_this;
}

/* #define SWIG_PYTHON_SLOW_GETSET_THIS */

/* TODO: I don't know how to implement the fast getset in Python 3 right now */
#if PY_VERSION_HEX>=0x03000000
#define SWIG_PYTHON_SLOW_GETSET_THIS 
#endif

SWIGRUNTIME SwigPyObject *
SWIG_Python_GetSwigThis(PyObject *pyobj) 
{
  PyObject *obj;

  if (SwigPyObject_Check(pyobj))
    return (SwigPyObject *) pyobj;

#ifdef SWIGPYTHON_BUILTIN
  (void)obj;
# ifdef PyWeakref_CheckProxy
  if (PyWeakref_CheckProxy(pyobj)) {
    pyobj = PyWeakref_GET_OBJECT(pyobj);
    if (pyobj && SwigPyObject_Check(pyobj))
      return (SwigPyObject*) pyobj;
  }
# endif
  return NULL;
#else

  obj = 0;

#if (!defined(SWIG_PYTHON_SLOW_GETSET_THIS) && (PY_VERSION_HEX >= 0x02030000))
  if (PyInstance_Check(pyobj)) {
    obj = _PyInstance_Lookup(pyobj, SWIG_This());      
  } else {
    PyObject **dictptr = _PyObject_GetDictPtr(pyobj);
    if (dictptr != NULL) {
      PyObject *dict = *dictptr;
      obj = dict ? PyDict_GetItem(dict, SWIG_This()) : 0;
    } else {
#ifdef PyWeakref_CheckProxy
      if (PyWeakref_CheckProxy(pyobj)) {
	PyObject *wobj = PyWeakref_GET_OBJECT(pyobj);
	return wobj ? SWIG_Python_GetSwigThis(wobj) : 0;
      }
#endif
      obj = PyObject_GetAttr(pyobj,SWIG_This());
      if (obj) {
	Py_DECREF(obj);
      } else {
	if (PyErr_Occurred()) PyErr_Clear();
	return 0;
      }
    }
  }
#else
  obj = PyObject_GetAttr(pyobj,SWIG_This());
  if (obj) {
    Py_DECREF(obj);
  } else {
    if (PyErr_Occurred()) PyErr_Clear();
    return 0;
  }
#endif
  if (obj && !SwigPyObject_Check(obj)) {
    /* a PyObject is called 'this', try to get the 'real this'
       SwigPyObject from it */ 
    return SWIG_Python_GetSwigThis(obj);
  }
  return (SwigPyObject *)obj;
#endif
}

/* Acquire a pointer value */

SWIGRUNTIME int
SWIG_Python_AcquirePtr(PyObject *obj, int own) {
  if (own == SWIG_POINTER_OWN) {
    SwigPyObject *sobj = SWIG_Python_GetSwigThis(obj);
    if (sobj) {
      int oldown = sobj->own;
      sobj->own = own;
      return oldown;
    }
  }
  return 0;
}

/* Convert a pointer value */

SWIGRUNTIME int
SWIG_Python_ConvertPtrAndOwn(PyObject *obj, void **ptr, swig_type_info *ty, int flags, int *own) {
  int res;
  SwigPyObject *sobj;
  int implicit_conv = (flags & SWIG_POINTER_IMPLICIT_CONV) != 0;

  if (!obj)
    return SWIG_ERROR;
  if (obj == Py_None && !implicit_conv) {
    if (ptr)
      *ptr = 0;
    return SWIG_OK;
  }

  res = SWIG_ERROR;

  sobj = SWIG_Python_GetSwigThis(obj);
  if (own)
    *own = 0;
  while (sobj) {
    void *vptr = sobj->ptr;
    if (ty) {
      swig_type_info *to = sobj->ty;
      if (to == ty) {
        /* no type cast needed */
        if (ptr) *ptr = vptr;
        break;
      } else {
        swig_cast_info *tc = SWIG_TypeCheck(to->name,ty);
        if (!tc) {
          sobj = (SwigPyObject *)sobj->next;
        } else {
          if (ptr) {
            int newmemory = 0;
            *ptr = SWIG_TypeCast(tc,vptr,&newmemory);
            if (newmemory == SWIG_CAST_NEW_MEMORY) {
              assert(own); /* badly formed typemap which will lead to a memory leak - it must set and use own to delete *ptr */
              if (own)
                *own = *own | SWIG_CAST_NEW_MEMORY;
            }
          }
          break;
        }
      }
    } else {
      if (ptr) *ptr = vptr;
      break;
    }
  }
  if (sobj) {
    if (own)
      *own = *own | sobj->own;
    if (flags & SWIG_POINTER_DISOWN) {
      sobj->own = 0;
    }
    res = SWIG_OK;
  } else {
    if (implicit_conv) {
      SwigPyClientData *data = ty ? (SwigPyClientData *) ty->clientdata : 0;
      if (data && !data->implicitconv) {
        PyObject *klass = data->klass;
        if (klass) {
          PyObject *impconv;
          data->implicitconv = 1; /* avoid recursion and call 'explicit' constructors*/
          impconv = SWIG_Python_CallFunctor(klass, obj);
          data->implicitconv = 0;
          if (PyErr_Occurred()) {
            PyErr_Clear();
            impconv = 0;
          }
          if (impconv) {
            SwigPyObject *iobj = SWIG_Python_GetSwigThis(impconv);
            if (iobj) {
              void *vptr;
              res = SWIG_Python_ConvertPtrAndOwn((PyObject*)iobj, &vptr, ty, 0, 0);
              if (SWIG_IsOK(res)) {
                if (ptr) {
                  *ptr = vptr;
                  /* transfer the ownership to 'ptr' */
                  iobj->own = 0;
                  res = SWIG_AddCast(res);
                  res = SWIG_AddNewMask(res);
                } else {
                  res = SWIG_AddCast(res);		    
                }
              }
            }
            Py_DECREF(impconv);
          }
        }
      }
    }
    if (!SWIG_IsOK(res) && obj == Py_None) {
      if (ptr)
        *ptr = 0;
      if (PyErr_Occurred())
        PyErr_Clear();
      res = SWIG_OK;
    }
  }
  return res;
}

/* Convert a function ptr value */

SWIGRUNTIME int
SWIG_Python_ConvertFunctionPtr(PyObject *obj, void **ptr, swig_type_info *ty) {
  if (!PyCFunction_Check(obj)) {
    return SWIG_ConvertPtr(obj, ptr, ty, 0);
  } else {
    void *vptr = 0;
    
    /* here we get the method pointer for callbacks */
    const char *doc = (((PyCFunctionObject *)obj) -> m_ml -> ml_doc);
    const char *desc = doc ? strstr(doc, "swig_ptr: ") : 0;
    if (desc)
      desc = ty ? SWIG_UnpackVoidPtr(desc + 10, &vptr, ty->name) : 0;
    if (!desc) 
      return SWIG_ERROR;
    if (ty) {
      swig_cast_info *tc = SWIG_TypeCheck(desc,ty);
      if (tc) {
        int newmemory = 0;
        *ptr = SWIG_TypeCast(tc,vptr,&newmemory);
        assert(!newmemory); /* newmemory handling not yet implemented */
      } else {
        return SWIG_ERROR;
      }
    } else {
      *ptr = vptr;
    }
    return SWIG_OK;
  }
}

/* Convert a packed value value */

SWIGRUNTIME int
SWIG_Python_ConvertPacked(PyObject *obj, void *ptr, size_t sz, swig_type_info *ty) {
  swig_type_info *to = SwigPyPacked_UnpackData(obj, ptr, sz);
  if (!to) return SWIG_ERROR;
  if (ty) {
    if (to != ty) {
      /* check type cast? */
      swig_cast_info *tc = SWIG_TypeCheck(to->name,ty);
      if (!tc) return SWIG_ERROR;
    }
  }
  return SWIG_OK;
}  

/* -----------------------------------------------------------------------------
 * Create a new pointer object
 * ----------------------------------------------------------------------------- */

/*
  Create a new instance object, without calling __init__, and set the
  'this' attribute.
*/

SWIGRUNTIME PyObject* 
SWIG_Python_NewShadowInstance(SwigPyClientData *data, PyObject *swig_this)
{
#if (PY_VERSION_HEX >= 0x02020000)
  PyObject *inst = 0;
  PyObject *newraw = data->newraw;
  if (newraw) {
    inst = PyObject_Call(newraw, data->newargs, NULL);
    if (inst) {
#if !defined(SWIG_PYTHON_SLOW_GETSET_THIS)
      PyObject **dictptr = _PyObject_GetDictPtr(inst);
      if (dictptr != NULL) {
	PyObject *dict = *dictptr;
	if (dict == NULL) {
	  dict = PyDict_New();
	  *dictptr = dict;
	  PyDict_SetItem(dict, SWIG_This(), swig_this);
	}
      }
#else
      PyObject *key = SWIG_This();
      PyObject_SetAttr(inst, key, swig_this);
#endif
    }
  } else {
#if PY_VERSION_HEX >= 0x03000000
    inst = ((PyTypeObject*) data->newargs)->tp_new((PyTypeObject*) data->newargs, Py_None, Py_None);
    if (inst) {
      PyObject_SetAttr(inst, SWIG_This(), swig_this);
      Py_TYPE(inst)->tp_flags &= ~Py_TPFLAGS_VALID_VERSION_TAG;
    }
#else
    PyObject *dict = PyDict_New();
    if (dict) {
      PyDict_SetItem(dict, SWIG_This(), swig_this);
      inst = PyInstance_NewRaw(data->newargs, dict);
      Py_DECREF(dict);
    }
#endif
  }
  return inst;
#else
#if (PY_VERSION_HEX >= 0x02010000)
  PyObject *inst = 0;
  PyObject *dict = PyDict_New();
  if (dict) {
    PyDict_SetItem(dict, SWIG_This(), swig_this);
    inst = PyInstance_NewRaw(data->newargs, dict);
    Py_DECREF(dict);
  }
  return (PyObject *) inst;
#else
  PyInstanceObject *inst = PyObject_NEW(PyInstanceObject, &PyInstance_Type);
  if (inst == NULL) {
    return NULL;
  }
  inst->in_class = (PyClassObject *)data->newargs;
  Py_INCREF(inst->in_class);
  inst->in_dict = PyDict_New();
  if (inst->in_dict == NULL) {
    Py_DECREF(inst);
    return NULL;
  }
#ifdef Py_TPFLAGS_HAVE_WEAKREFS
  inst->in_weakreflist = NULL;
#endif
#ifdef Py_TPFLAGS_GC
  PyObject_GC_Init(inst);
#endif
  PyDict_SetItem(inst->in_dict, SWIG_This(), swig_this);
  return (PyObject *) inst;
#endif
#endif
}

SWIGRUNTIME void
SWIG_Python_SetSwigThis(PyObject *inst, PyObject *swig_this)
{
 PyObject *dict;
#if (PY_VERSION_HEX >= 0x02020000) && !defined(SWIG_PYTHON_SLOW_GETSET_THIS)
 PyObject **dictptr = _PyObject_GetDictPtr(inst);
 if (dictptr != NULL) {
   dict = *dictptr;
   if (dict == NULL) {
     dict = PyDict_New();
     *dictptr = dict;
   }
   PyDict_SetItem(dict, SWIG_This(), swig_this);
   return;
 }
#endif
 dict = PyObject_GetAttrString(inst, (char*)"__dict__");
 PyDict_SetItem(dict, SWIG_This(), swig_this);
 Py_DECREF(dict);
} 


SWIGINTERN PyObject *
SWIG_Python_InitShadowInstance(PyObject *args) {
  PyObject *obj[2];
  if (!SWIG_Python_UnpackTuple(args, "swiginit", 2, 2, obj)) {
    return NULL;
  } else {
    SwigPyObject *sthis = SWIG_Python_GetSwigThis(obj[0]);
    if (sthis) {
      SwigPyObject_append((PyObject*) sthis, obj[1]);
    } else {
      SWIG_Python_SetSwigThis(obj[0], obj[1]);
    }
    return SWIG_Py_Void();
  }
}

/* Create a new pointer object */

SWIGRUNTIME PyObject *
SWIG_Python_NewPointerObj(PyObject *self, void *ptr, swig_type_info *type, int flags) {
  SwigPyClientData *clientdata;
  PyObject * robj;
  int own;

  if (!ptr)
    return SWIG_Py_Void();

  clientdata = type ? (SwigPyClientData *)(type->clientdata) : 0;
  own = (flags & SWIG_POINTER_OWN) ? SWIG_POINTER_OWN : 0;
  if (clientdata && clientdata->pytype) {
    SwigPyObject *newobj;
    if (flags & SWIG_BUILTIN_TP_INIT) {
      newobj = (SwigPyObject*) self;
      if (newobj->ptr) {
        PyObject *next_self = clientdata->pytype->tp_alloc(clientdata->pytype, 0);
        while (newobj->next)
	  newobj = (SwigPyObject *) newobj->next;
        newobj->next = next_self;
        newobj = (SwigPyObject *)next_self;
      }
    } else {
      newobj = PyObject_New(SwigPyObject, clientdata->pytype);
    }
    if (newobj) {
      newobj->ptr = ptr;
      newobj->ty = type;
      newobj->own = own;
      newobj->next = 0;
#ifdef SWIGPYTHON_BUILTIN
      newobj->dict = 0;
#endif
      return (PyObject*) newobj;
    }
    return SWIG_Py_Void();
  }

  assert(!(flags & SWIG_BUILTIN_TP_INIT));

  robj = SwigPyObject_New(ptr, type, own);
  if (robj && clientdata && !(flags & SWIG_POINTER_NOSHADOW)) {
    PyObject *inst = SWIG_Python_NewShadowInstance(clientdata, robj);
    Py_DECREF(robj);
    robj = inst;
  }
  return robj;
}

/* Create a new packed object */

SWIGRUNTIMEINLINE PyObject *
SWIG_Python_NewPackedObj(void *ptr, size_t sz, swig_type_info *type) {
  return ptr ? SwigPyPacked_New((void *) ptr, sz, type) : SWIG_Py_Void();
}

/* -----------------------------------------------------------------------------*
 *  Get type list 
 * -----------------------------------------------------------------------------*/

#ifdef SWIG_LINK_RUNTIME
void *SWIG_ReturnGlobalTypeList(void *);
#endif

SWIGRUNTIME swig_module_info *
SWIG_Python_GetModule(void *SWIGUNUSEDPARM(clientdata)) {
  static void *type_pointer = (void *)0;
  /* first check if module already created */
  if (!type_pointer) {
#ifdef SWIG_LINK_RUNTIME
    type_pointer = SWIG_ReturnGlobalTypeList((void *)0);
#else
# ifdef SWIGPY_USE_CAPSULE
    type_pointer = PyCapsule_Import(SWIGPY_CAPSULE_NAME, 0);
# else
    type_pointer = PyCObject_Import((char*)"swig_runtime_data" SWIG_RUNTIME_VERSION,
				    (char*)"type_pointer" SWIG_TYPE_TABLE_NAME);
# endif
    if (PyErr_Occurred()) {
      PyErr_Clear();
      type_pointer = (void *)0;
    }
#endif
  }
  return (swig_module_info *) type_pointer;
}

#if PY_MAJOR_VERSION < 2
/* PyModule_AddObject function was introduced in Python 2.0.  The following function
   is copied out of Python/modsupport.c in python version 2.3.4 */
SWIGINTERN int
PyModule_AddObject(PyObject *m, char *name, PyObject *o)
{
  PyObject *dict;
  if (!PyModule_Check(m)) {
    PyErr_SetString(PyExc_TypeError,
		    "PyModule_AddObject() needs module as first arg");
    return SWIG_ERROR;
  }
  if (!o) {
    PyErr_SetString(PyExc_TypeError,
		    "PyModule_AddObject() needs non-NULL value");
    return SWIG_ERROR;
  }
  
  dict = PyModule_GetDict(m);
  if (dict == NULL) {
    /* Internal error -- modules must have a dict! */
    PyErr_Format(PyExc_SystemError, "module '%s' has no __dict__",
		 PyModule_GetName(m));
    return SWIG_ERROR;
  }
  if (PyDict_SetItemString(dict, name, o))
    return SWIG_ERROR;
  Py_DECREF(o);
  return SWIG_OK;
}
#endif

SWIGRUNTIME void
#ifdef SWIGPY_USE_CAPSULE
SWIG_Python_DestroyModule(PyObject *obj)
#else
SWIG_Python_DestroyModule(void *vptr)
#endif
{
#ifdef SWIGPY_USE_CAPSULE
  swig_module_info *swig_module = (swig_module_info *) PyCapsule_GetPointer(obj, SWIGPY_CAPSULE_NAME);
#else
  swig_module_info *swig_module = (swig_module_info *) vptr;
#endif
  swig_type_info **types = swig_module->types;
  size_t i;
  for (i =0; i < swig_module->size; ++i) {
    swig_type_info *ty = types[i];
    if (ty->owndata) {
      SwigPyClientData *data = (SwigPyClientData *) ty->clientdata;
      if (data) SwigPyClientData_Del(data);
    }
  }
  Py_DECREF(SWIG_This());
  swig_this = NULL;
}

SWIGRUNTIME void
SWIG_Python_SetModule(swig_module_info *swig_module) {
#if PY_VERSION_HEX >= 0x03000000
 /* Add a dummy module object into sys.modules */
  PyObject *module = PyImport_AddModule((char*)"swig_runtime_data" SWIG_RUNTIME_VERSION);
#else
  static PyMethodDef swig_empty_runtime_method_table[] = { {NULL, NULL, 0, NULL} }; /* Sentinel */
  PyObject *module = Py_InitModule((char*)"swig_runtime_data" SWIG_RUNTIME_VERSION, swig_empty_runtime_method_table);
#endif
#ifdef SWIGPY_USE_CAPSULE
  PyObject *pointer = PyCapsule_New((void *) swig_module, SWIGPY_CAPSULE_NAME, SWIG_Python_DestroyModule);
  if (pointer && module) {
    PyModule_AddObject(module, (char*)"type_pointer_capsule" SWIG_TYPE_TABLE_NAME, pointer);
  } else {
    Py_XDECREF(pointer);
  }
#else
  PyObject *pointer = PyCObject_FromVoidPtr((void *) swig_module, SWIG_Python_DestroyModule);
  if (pointer && module) {
    PyModule_AddObject(module, (char*)"type_pointer" SWIG_TYPE_TABLE_NAME, pointer);
  } else {
    Py_XDECREF(pointer);
  }
#endif
}

/* The python cached type query */
SWIGRUNTIME PyObject *
SWIG_Python_TypeCache(void) {
  static PyObject *SWIG_STATIC_POINTER(cache) = PyDict_New();
  return cache;
}

SWIGRUNTIME swig_type_info *
SWIG_Python_TypeQuery(const char *type)
{
  PyObject *cache = SWIG_Python_TypeCache();
  PyObject *key = SWIG_Python_str_FromChar(type); 
  PyObject *obj = PyDict_GetItem(cache, key);
  swig_type_info *descriptor;
  if (obj) {
#ifdef SWIGPY_USE_CAPSULE
    descriptor = (swig_type_info *) PyCapsule_GetPointer(obj, NULL);
#else
    descriptor = (swig_type_info *) PyCObject_AsVoidPtr(obj);
#endif
  } else {
    swig_module_info *swig_module = SWIG_GetModule(0);
    if (!swig_module) {
        return 0;
    }
    descriptor = SWIG_TypeQueryModule(swig_module, swig_module, type);
    if (descriptor) {
#ifdef SWIGPY_USE_CAPSULE
      obj = PyCapsule_New((void*) descriptor, NULL, NULL);
#else
      obj = PyCObject_FromVoidPtr(descriptor, NULL);
#endif
      PyDict_SetItem(cache, key, obj);
      Py_DECREF(obj);
    }
  }
  Py_DECREF(key);
  return descriptor;
}

/* 
   For backward compatibility only
*/
#define SWIG_POINTER_EXCEPTION  0
#define SWIG_arg_fail(arg)      SWIG_Python_ArgFail(arg)
#define SWIG_MustGetPtr(p, type, argnum, flags)  SWIG_Python_MustGetPtr(p, type, argnum, flags)

SWIGRUNTIME int
SWIG_Python_AddErrMesg(const char* mesg, int infront)
{  
  if (PyErr_Occurred()) {
    PyObject *type = 0;
    PyObject *value = 0;
    PyObject *traceback = 0;
    PyErr_Fetch(&type, &value, &traceback);
    if (value) {
      char *tmp;
      PyObject *old_str = PyObject_Str(value);
      Py_XINCREF(type);
      PyErr_Clear();
      if (infront) {
	PyErr_Format(type, "%s %s", mesg, tmp = SWIG_Python_str_AsChar(old_str));
      } else {
	PyErr_Format(type, "%s %s", tmp = SWIG_Python_str_AsChar(old_str), mesg);
      }
      SWIG_Python_str_DelForPy3(tmp);
      Py_DECREF(old_str);
    }
    return 1;
  } else {
    return 0;
  }
}
  
SWIGRUNTIME int
SWIG_Python_ArgFail(int argnum)
{
  if (PyErr_Occurred()) {
    /* add information about failing argument */
    char mesg[256];
    PyOS_snprintf(mesg, sizeof(mesg), "argument number %d:", argnum);
    return SWIG_Python_AddErrMesg(mesg, 1);
  } else {
    return 0;
  }
}

SWIGRUNTIMEINLINE const char *
SwigPyObject_GetDesc(PyObject *self)
{
  SwigPyObject *v = (SwigPyObject *)self;
  swig_type_info *ty = v ? v->ty : 0;
  return ty ? ty->str : "";
}

SWIGRUNTIME void
SWIG_Python_TypeError(const char *type, PyObject *obj)
{
  if (type) {
#if defined(SWIG_COBJECT_TYPES)
    if (obj && SwigPyObject_Check(obj)) {
      const char *otype = (const char *) SwigPyObject_GetDesc(obj);
      if (otype) {
	PyErr_Format(PyExc_TypeError, "a '%s' is expected, 'SwigPyObject(%s)' is received",
		     type, otype);
	return;
      }
    } else 
#endif      
    {
      const char *otype = (obj ? obj->ob_type->tp_name : 0); 
      if (otype) {
	PyObject *str = PyObject_Str(obj);
	const char *cstr = str ? SWIG_Python_str_AsChar(str) : 0;
	if (cstr) {
	  PyErr_Format(PyExc_TypeError, "a '%s' is expected, '%s(%s)' is received",
		       type, otype, cstr);
          SWIG_Python_str_DelForPy3(cstr);
	} else {
	  PyErr_Format(PyExc_TypeError, "a '%s' is expected, '%s' is received",
		       type, otype);
	}
	Py_XDECREF(str);
	return;
      }
    }   
    PyErr_Format(PyExc_TypeError, "a '%s' is expected", type);
  } else {
    PyErr_Format(PyExc_TypeError, "unexpected type is received");
  }
}


/* Convert a pointer value, signal an exception on a type mismatch */
SWIGRUNTIME void *
SWIG_Python_MustGetPtr(PyObject *obj, swig_type_info *ty, int SWIGUNUSEDPARM(argnum), int flags) {
  void *result;
  if (SWIG_Python_ConvertPtr(obj, &result, ty, flags) == -1) {
    PyErr_Clear();
#if SWIG_POINTER_EXCEPTION
    if (flags) {
      SWIG_Python_TypeError(SWIG_TypePrettyName(ty), obj);
      SWIG_Python_ArgFail(argnum);
    }
#endif
  }
  return result;
}

#ifdef SWIGPYTHON_BUILTIN
SWIGRUNTIME int
SWIG_Python_NonDynamicSetAttr(PyObject *obj, PyObject *name, PyObject *value) {
  PyTypeObject *tp = obj->ob_type;
  PyObject *descr;
  PyObject *encoded_name;
  descrsetfunc f;
  int res = -1;

# ifdef Py_USING_UNICODE
  if (PyString_Check(name)) {
    name = PyUnicode_Decode(PyString_AsString(name), PyString_Size(name), NULL, NULL);
    if (!name)
      return -1;
  } else if (!PyUnicode_Check(name))
# else
  if (!PyString_Check(name))
# endif
  {
    PyErr_Format(PyExc_TypeError, "attribute name must be string, not '%.200s'", name->ob_type->tp_name);
    return -1;
  } else {
    Py_INCREF(name);
  }

  if (!tp->tp_dict) {
    if (PyType_Ready(tp) < 0)
      goto done;
  }

  descr = _PyType_Lookup(tp, name);
  f = NULL;
  if (descr != NULL)
    f = descr->ob_type->tp_descr_set;
  if (!f) {
    if (PyString_Check(name)) {
      encoded_name = name;
      Py_INCREF(name);
    } else {
      encoded_name = PyUnicode_AsUTF8String(name);
    }
    PyErr_Format(PyExc_AttributeError, "'%.100s' object has no attribute '%.200s'", tp->tp_name, PyString_AsString(encoded_name));
    Py_DECREF(encoded_name);
  } else {
    res = f(descr, obj, value);
  }
  
  done:
  Py_DECREF(name);
  return res;
}
#endif


#ifdef __cplusplus
}
#endif



#define SWIG_exception_fail(code, msg) do { SWIG_Error(code, msg); SWIG_fail; } while(0) 

#define SWIG_contract_assert(expr, msg) if (!(expr)) { SWIG_Error(SWIG_RuntimeError, msg); SWIG_fail; } else 



  #define SWIG_exception(code, msg) do { SWIG_Error(code, msg); SWIG_fail;; } while(0) 

/* -----------------------------------------------------------------------------
 * director_common.swg
 *
 * This file contains support for director classes which is common between
 * languages.
 * ----------------------------------------------------------------------------- */

/*
  Use -DSWIG_DIRECTOR_STATIC if you prefer to avoid the use of the
  'Swig' namespace. This could be useful for multi-modules projects.
*/
#ifdef SWIG_DIRECTOR_STATIC
/* Force anonymous (static) namespace */
#define Swig
#endif
/* -----------------------------------------------------------------------------
 * director.swg
 *
 * This file contains support for director classes so that Python proxy
 * methods can be called from C++.
 * ----------------------------------------------------------------------------- */

#ifndef SWIG_DIRECTOR_PYTHON_HEADER_
#define SWIG_DIRECTOR_PYTHON_HEADER_

#include <string>
#include <iostream>
#include <exception>
#include <vector>
#include <map>


/*
  Use -DSWIG_PYTHON_DIRECTOR_NO_VTABLE if you don't want to generate a 'virtual
  table', and avoid multiple GetAttr calls to retrieve the python
  methods.
*/

#ifndef SWIG_PYTHON_DIRECTOR_NO_VTABLE
#ifndef SWIG_PYTHON_DIRECTOR_VTABLE
#define SWIG_PYTHON_DIRECTOR_VTABLE
#endif
#endif



/*
  Use -DSWIG_DIRECTOR_NO_UEH if you prefer to avoid the use of the
  Undefined Exception Handler provided by swig.
*/
#ifndef SWIG_DIRECTOR_NO_UEH
#ifndef SWIG_DIRECTOR_UEH
#define SWIG_DIRECTOR_UEH
#endif
#endif


/*
  Use -DSWIG_DIRECTOR_NORTTI if you prefer to avoid the use of the
  native C++ RTTI and dynamic_cast<>. But be aware that directors
  could stop working when using this option.
*/
#ifdef SWIG_DIRECTOR_NORTTI
/*
   When we don't use the native C++ RTTI, we implement a minimal one
   only for Directors.
*/
# ifndef SWIG_DIRECTOR_RTDIR
# define SWIG_DIRECTOR_RTDIR

namespace Swig {
  class Director;
  SWIGINTERN std::map<void *, Director *>& get_rtdir_map() {
    static std::map<void *, Director *> rtdir_map;
    return rtdir_map;
  }

  SWIGINTERNINLINE void set_rtdir(void *vptr, Director *rtdir) {
    get_rtdir_map()[vptr] = rtdir;
  }

  SWIGINTERNINLINE Director *get_rtdir(void *vptr) {
    std::map<void *, Director *>::const_iterator pos = get_rtdir_map().find(vptr);
    Director *rtdir = (pos != get_rtdir_map().end()) ? pos->second : 0;
    return rtdir;
  }
}
# endif /* SWIG_DIRECTOR_RTDIR */

# define SWIG_DIRECTOR_CAST(ARG) Swig::get_rtdir(static_cast<void *>(ARG))
# define SWIG_DIRECTOR_RGTR(ARG1, ARG2) Swig::set_rtdir(static_cast<void *>(ARG1), ARG2)

#else

# define SWIG_DIRECTOR_CAST(ARG) dynamic_cast<Swig::Director *>(ARG)
# define SWIG_DIRECTOR_RGTR(ARG1, ARG2)

#endif /* SWIG_DIRECTOR_NORTTI */

extern "C" {
  struct swig_type_info;
}

namespace Swig {

  /* memory handler */
  struct GCItem {
    virtual ~GCItem() {}

    virtual int get_own() const {
      return 0;
    }
  };

  struct GCItem_var {
    GCItem_var(GCItem *item = 0) : _item(item) {
    }

    GCItem_var& operator=(GCItem *item) {
      GCItem *tmp = _item;
      _item = item;
      delete tmp;
      return *this;
    }

    ~GCItem_var() {
      delete _item;
    }

    GCItem * operator->() const {
      return _item;
    }

  private:
    GCItem *_item;
  };

  struct GCItem_Object : GCItem {
    GCItem_Object(int own) : _own(own) {
    }

    virtual ~GCItem_Object() {
    }

    int get_own() const {
      return _own;
    }

  private:
    int _own;
  };

  template <typename Type>
  struct GCItem_T : GCItem {
    GCItem_T(Type *ptr) : _ptr(ptr) {
    }

    virtual ~GCItem_T() {
      delete _ptr;
    }

  private:
    Type *_ptr;
  };

  template <typename Type>
  struct GCArray_T : GCItem {
    GCArray_T(Type *ptr) : _ptr(ptr) {
    }

    virtual ~GCArray_T() {
      delete[] _ptr;
    }

  private:
    Type *_ptr;
  };

  /* base class for director exceptions */
  class DirectorException : public std::exception {
  protected:
    std::string swig_msg;
  public:
    DirectorException(PyObject *error, const char *hdr ="", const char *msg ="") : swig_msg(hdr) {
      SWIG_PYTHON_THREAD_BEGIN_BLOCK;
      if (msg[0]) {
        swig_msg += " ";
        swig_msg += msg;
      }
      if (!PyErr_Occurred()) {
        PyErr_SetString(error, what());
      }
      SWIG_PYTHON_THREAD_END_BLOCK;
    }

    virtual ~DirectorException() throw() {
    }

    /* Deprecated, use what() instead */
    const char *getMessage() const {
      return what();
    }

    const char *what() const throw() {
      return swig_msg.c_str();
    }

    static void raise(PyObject *error, const char *msg) {
      throw DirectorException(error, msg);
    }

    static void raise(const char *msg) {
      raise(PyExc_RuntimeError, msg);
    }
  };

  /* unknown exception handler  */
  class UnknownExceptionHandler {
#ifdef SWIG_DIRECTOR_UEH
    static void handler() {
      try {
        throw;
      } catch (DirectorException& e) {
        std::cerr << "SWIG Director exception caught:" << std::endl
                  << e.what() << std::endl;
      } catch (std::exception& e) {
        std::cerr << "std::exception caught: "<< e.what() << std::endl;
      } catch (...) {
        std::cerr << "Unknown exception caught." << std::endl;
      }

      std::cerr << std::endl
                << "Python interpreter traceback:" << std::endl;
      PyErr_Print();
      std::cerr << std::endl;

      std::cerr << "This exception was caught by the SWIG unexpected exception handler." << std::endl
                << "Try using %feature(\"director:except\") to avoid reaching this point." << std::endl
                << std::endl
                << "Exception is being re-thrown, program will likely abort/terminate." << std::endl;
      throw;
    }

  public:

    std::unexpected_handler old;
    UnknownExceptionHandler(std::unexpected_handler nh = handler) {
      old = std::set_unexpected(nh);
    }

    ~UnknownExceptionHandler() {
      std::set_unexpected(old);
    }
#endif
  };

  /* type mismatch in the return value from a python method call */
  class DirectorTypeMismatchException : public DirectorException {
  public:
    DirectorTypeMismatchException(PyObject *error, const char *msg="")
      : DirectorException(error, "SWIG director type mismatch", msg) {
    }

    DirectorTypeMismatchException(const char *msg="")
      : DirectorException(PyExc_TypeError, "SWIG director type mismatch", msg) {
    }

    static void raise(PyObject *error, const char *msg) {
      throw DirectorTypeMismatchException(error, msg);
    }

    static void raise(const char *msg) {
      throw DirectorTypeMismatchException(msg);
    }
  };

  /* any python exception that occurs during a director method call */
  class DirectorMethodException : public DirectorException {
  public:
    DirectorMethodException(const char *msg = "")
      : DirectorException(PyExc_RuntimeError, "SWIG director method error.", msg) {
    }

    static void raise(const char *msg) {
      throw DirectorMethodException(msg);
    }
  };

  /* attempt to call a pure virtual method via a director method */
  class DirectorPureVirtualException : public DirectorException {
  public:
    DirectorPureVirtualException(const char *msg = "")
      : DirectorException(PyExc_RuntimeError, "SWIG director pure virtual method called", msg) {
    }

    static void raise(const char *msg) {
      throw DirectorPureVirtualException(msg);
    }
  };


#if defined(SWIG_PYTHON_THREADS)
/*  __THREAD__ is the old macro to activate some thread support */
# if !defined(__THREAD__)
#   define __THREAD__ 1
# endif
#endif

#ifdef __THREAD__
# include "pythread.h"
  class Guard {
    PyThread_type_lock &mutex_;

  public:
    Guard(PyThread_type_lock & mutex) : mutex_(mutex) {
      PyThread_acquire_lock(mutex_, WAIT_LOCK);
    }

    ~Guard() {
      PyThread_release_lock(mutex_);
    }
  };
# define SWIG_GUARD(mutex) Guard _guard(mutex)
#else
# define SWIG_GUARD(mutex)
#endif

  /* director base class */
  class Director {
  private:
    /* pointer to the wrapped python object */
    PyObject *swig_self;
    /* flag indicating whether the object is owned by python or c++ */
    mutable bool swig_disown_flag;

    /* decrement the reference count of the wrapped python object */
    void swig_decref() const {
      if (swig_disown_flag) {
        SWIG_PYTHON_THREAD_BEGIN_BLOCK;
        Py_DECREF(swig_self);
        SWIG_PYTHON_THREAD_END_BLOCK;
      }
    }

  public:
    /* wrap a python object, optionally taking ownership */
    Director(PyObject *self) : swig_self(self), swig_disown_flag(false) {
      swig_incref();
    }

    /* discard our reference at destruction */
    virtual ~Director() {
      swig_decref();
    }

    /* return a pointer to the wrapped python object */
    PyObject *swig_get_self() const {
      return swig_self;
    }

    /* acquire ownership of the wrapped python object (the sense of "disown" is from python) */
    void swig_disown() const {
      if (!swig_disown_flag) {
        swig_disown_flag=true;
        swig_incref();
      }
    }

    /* increase the reference count of the wrapped python object */
    void swig_incref() const {
      if (swig_disown_flag) {
        Py_INCREF(swig_self);
      }
    }

    /* methods to implement pseudo protected director members */
    virtual bool swig_get_inner(const char * /* swig_protected_method_name */) const {
      return true;
    }

    virtual void swig_set_inner(const char * /* swig_protected_method_name */, bool /* swig_val */) const {
    }

  /* ownership management */
  private:
    typedef std::map<void *, GCItem_var> swig_ownership_map;
    mutable swig_ownership_map swig_owner;
#ifdef __THREAD__
    static PyThread_type_lock swig_mutex_own;
#endif

  public:
    template <typename Type>
    void swig_acquire_ownership_array(Type *vptr) const {
      if (vptr) {
        SWIG_GUARD(swig_mutex_own);
        swig_owner[vptr] = new GCArray_T<Type>(vptr);
      }
    }

    template <typename Type>
    void swig_acquire_ownership(Type *vptr) const {
      if (vptr) {
        SWIG_GUARD(swig_mutex_own);
        swig_owner[vptr] = new GCItem_T<Type>(vptr);
      }
    }

    void swig_acquire_ownership_obj(void *vptr, int own) const {
      if (vptr && own) {
        SWIG_GUARD(swig_mutex_own);
        swig_owner[vptr] = new GCItem_Object(own);
      }
    }

    int swig_release_ownership(void *vptr) const {
      int own = 0;
      if (vptr) {
        SWIG_GUARD(swig_mutex_own);
        swig_ownership_map::iterator iter = swig_owner.find(vptr);
        if (iter != swig_owner.end()) {
          own = iter->second->get_own();
          swig_owner.erase(iter);
        }
      }
      return own;
    }

    template <typename Type>
    static PyObject *swig_pyobj_disown(PyObject *pyobj, PyObject *SWIGUNUSEDPARM(args)) {
      SwigPyObject *sobj = (SwigPyObject *)pyobj;
      sobj->own = 0;
      Director *d = SWIG_DIRECTOR_CAST(reinterpret_cast<Type *>(sobj->ptr));
      if (d)
        d->swig_disown();
      return PyWeakref_NewProxy(pyobj, NULL);
    }
  };

#ifdef __THREAD__
  PyThread_type_lock Director::swig_mutex_own = PyThread_allocate_lock();
#endif
}

#endif

/* -------- TYPES TABLE (BEGIN) -------- */

#define SWIGTYPE_p_baseDataType swig_types[0]
#define SWIGTYPE_p_char swig_types[1]
#define SWIGTYPE_p_daal__Base swig_types[2]
#define SWIGTYPE_p_daal__data_management__ColumnFilter swig_types[3]
#define SWIGTYPE_p_daal__data_management__FeatureAuxData swig_types[4]
#define SWIGTYPE_p_daal__data_management__MakeCategorical swig_types[5]
#define SWIGTYPE_p_daal__data_management__ModifierIface swig_types[6]
#define SWIGTYPE_p_daal__data_management__OneHotEncoder swig_types[7]
#define SWIGTYPE_p_daal__data_management__features__interface1__FeatureId swig_types[8]
#define SWIGTYPE_p_daal__data_management__features__interface1__FeatureIdCollection swig_types[9]
#define SWIGTYPE_p_daal__data_management__features__interface1__FeatureIdCollectionIface swig_types[10]
#define SWIGTYPE_p_daal__data_management__features__interface1__FeatureIdIface swig_types[11]
#define SWIGTYPE_p_daal__data_management__features__interface1__FeatureIdMapping swig_types[12]
#define SWIGTYPE_p_daal__data_management__features__interface1__FeatureIdMappingIface swig_types[13]
#define SWIGTYPE_p_daal__data_management__features__interface1__FeatureIndices swig_types[14]
#define SWIGTYPE_p_daal__data_management__features__interface1__FeatureIndicesIface swig_types[15]
#define SWIGTYPE_p_daal__data_management__interface1__BlockDescriptorT_double_t swig_types[16]
#define SWIGTYPE_p_daal__data_management__interface1__BlockDescriptorT_float_t swig_types[17]
#define SWIGTYPE_p_daal__data_management__interface1__BlockDescriptorT_int_t swig_types[18]
#define SWIGTYPE_p_daal__data_management__interface1__Bzip2CompressionParameter swig_types[19]
#define SWIGTYPE_p_daal__data_management__interface1__CSRBlockDescriptorT_double_t swig_types[20]
#define SWIGTYPE_p_daal__data_management__interface1__CSRBlockDescriptorT_float_t swig_types[21]
#define SWIGTYPE_p_daal__data_management__interface1__CSRBlockDescriptorT_int_t swig_types[22]
#define SWIGTYPE_p_daal__data_management__interface1__CSRNumericTable swig_types[23]
#define SWIGTYPE_p_daal__data_management__interface1__CSRNumericTableIface swig_types[24]
#define SWIGTYPE_p_daal__data_management__interface1__CSVFeatureManager swig_types[25]
#define SWIGTYPE_p_daal__data_management__interface1__CategoricalFeatureDictionary swig_types[26]
#define SWIGTYPE_p_daal__data_management__interface1__CompressedDataArchive swig_types[27]
#define SWIGTYPE_p_daal__data_management__interface1__Compression swig_types[28]
#define SWIGTYPE_p_daal__data_management__interface1__CompressionIface swig_types[29]
#define SWIGTYPE_p_daal__data_management__interface1__CompressionParameter swig_types[30]
#define SWIGTYPE_p_daal__data_management__interface1__CompressionStream swig_types[31]
#define SWIGTYPE_p_daal__data_management__interface1__CompressorImpl swig_types[32]
#define SWIGTYPE_p_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_t swig_types[33]
#define SWIGTYPE_p_daal__data_management__interface1__CompressorT_daal__data_management__lzo_t swig_types[34]
#define SWIGTYPE_p_daal__data_management__interface1__CompressorT_daal__data_management__rle_t swig_types[35]
#define SWIGTYPE_p_daal__data_management__interface1__CompressorT_daal__data_management__zlib_t swig_types[36]
#define SWIGTYPE_p_daal__data_management__interface1__CsvDataSourceOptions swig_types[37]
#define SWIGTYPE_p_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t swig_types[38]
#define SWIGTYPE_p_daal__data_management__interface1__DataArchive swig_types[39]
#define SWIGTYPE_p_daal__data_management__interface1__DataArchiveIface swig_types[40]
#define SWIGTYPE_p_daal__data_management__interface1__DataArchiveImpl swig_types[41]
#define SWIGTYPE_p_daal__data_management__interface1__DataBlock swig_types[42]
#define SWIGTYPE_p_daal__data_management__interface1__DataBlockIface swig_types[43]
#define SWIGTYPE_p_daal__data_management__interface1__DataCollection swig_types[44]
#define SWIGTYPE_p_daal__data_management__interface1__DataSource swig_types[45]
#define SWIGTYPE_p_daal__data_management__interface1__DataSourceFeature swig_types[46]
#define SWIGTYPE_p_daal__data_management__interface1__DataSourceIface swig_types[47]
#define SWIGTYPE_p_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t swig_types[48]
#define SWIGTYPE_p_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_float_t_double_t swig_types[49]
#define SWIGTYPE_p_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_int_t_double_t swig_types[50]
#define SWIGTYPE_p_daal__data_management__interface1__DecompressedDataArchive swig_types[51]
#define SWIGTYPE_p_daal__data_management__interface1__DecompressionStream swig_types[52]
#define SWIGTYPE_p_daal__data_management__interface1__DecompressorImpl swig_types[53]
#define SWIGTYPE_p_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_t swig_types[54]
#define SWIGTYPE_p_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_t swig_types[55]
#define SWIGTYPE_p_daal__data_management__interface1__DecompressorT_daal__data_management__rle_t swig_types[56]
#define SWIGTYPE_p_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_t swig_types[57]
#define SWIGTYPE_p_daal__data_management__interface1__DenseNumericTableIface swig_types[58]
#define SWIGTYPE_p_daal__data_management__interface1__DenseTensorIface swig_types[59]
#define SWIGTYPE_p_daal__data_management__interface1__DictionaryIface swig_types[60]
#define SWIGTYPE_p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t swig_types[61]
#define SWIGTYPE_p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t swig_types[62]
#define SWIGTYPE_p_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t swig_types[63]
#define SWIGTYPE_p_daal__data_management__interface1__HomogenNumericTableT_double_t swig_types[64]
#define SWIGTYPE_p_daal__data_management__interface1__HomogenNumericTableT_float_t swig_types[65]
#define SWIGTYPE_p_daal__data_management__interface1__HomogenNumericTableT_int_t swig_types[66]
#define SWIGTYPE_p_daal__data_management__interface1__HomogenTensorT_double_t swig_types[67]
#define SWIGTYPE_p_daal__data_management__interface1__HomogenTensorT_float_t swig_types[68]
#define SWIGTYPE_p_daal__data_management__interface1__HomogenTensorT_int_t swig_types[69]
#define SWIGTYPE_p_daal__data_management__interface1__InputDataArchive swig_types[70]
#define SWIGTYPE_p_daal__data_management__interface1__KeyValueCollectionT_algorithms__Input_t swig_types[71]
#define SWIGTYPE_p_daal__data_management__interface1__KeyValueCollectionT_daal__algorithms__interface1__Input_t swig_types[72]
#define SWIGTYPE_p_daal__data_management__interface1__KeyValueCollectionT_daal__data_management__interface1__SerializationIface_t swig_types[73]
#define SWIGTYPE_p_daal__data_management__interface1__LzoCompressionParameter swig_types[74]
#define SWIGTYPE_p_daal__data_management__interface1__MatrixT_double_t swig_types[75]
#define SWIGTYPE_p_daal__data_management__interface1__MatrixT_float_t swig_types[76]
#define SWIGTYPE_p_daal__data_management__interface1__MatrixT_int_t swig_types[77]
#define SWIGTYPE_p_daal__data_management__interface1__MergedNumericTable swig_types[78]
#define SWIGTYPE_p_daal__data_management__interface1__NpyAOSNumericTable swig_types[79]
#define SWIGTYPE_p_daal__data_management__interface1__NumericTable swig_types[80]
#define SWIGTYPE_p_daal__data_management__interface1__NumericTableFeature swig_types[81]
#define SWIGTYPE_p_daal__data_management__interface1__NumericTableIface swig_types[82]
#define SWIGTYPE_p_daal__data_management__interface1__NumericTable__BasicStatisticsDataCollection swig_types[83]
#define SWIGTYPE_p_daal__data_management__interface1__OutputDataArchive swig_types[84]
#define SWIGTYPE_p_daal__data_management__interface1__PackedArrayNumericTableIface swig_types[85]
#define SWIGTYPE_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t swig_types[86]
#define SWIGTYPE_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t swig_types[87]
#define SWIGTYPE_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t swig_types[88]
#define SWIGTYPE_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t swig_types[89]
#define SWIGTYPE_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t swig_types[90]
#define SWIGTYPE_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t swig_types[91]
#define SWIGTYPE_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t swig_types[92]
#define SWIGTYPE_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t swig_types[93]
#define SWIGTYPE_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t swig_types[94]
#define SWIGTYPE_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t swig_types[95]
#define SWIGTYPE_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t swig_types[96]
#define SWIGTYPE_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t swig_types[97]
#define SWIGTYPE_p_daal__data_management__interface1__RleCompressionParameter swig_types[98]
#define SWIGTYPE_p_daal__data_management__interface1__RowMergedNumericTable swig_types[99]
#define SWIGTYPE_p_daal__data_management__interface1__SOANumericTable swig_types[100]
#define SWIGTYPE_p_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t swig_types[101]
#define SWIGTYPE_p_daal__data_management__interface1__SerializationDesc swig_types[102]
#define SWIGTYPE_p_daal__data_management__interface1__SerializationIface swig_types[103]
#define SWIGTYPE_p_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t swig_types[104]
#define SWIGTYPE_p_daal__data_management__interface1__StringRowFeatureManagerIface swig_types[105]
#define SWIGTYPE_p_daal__data_management__interface1__SubtensorDescriptorT_double_t swig_types[106]
#define SWIGTYPE_p_daal__data_management__interface1__SubtensorDescriptorT_float_t swig_types[107]
#define SWIGTYPE_p_daal__data_management__interface1__SubtensorDescriptorT_int_t swig_types[108]
#define SWIGTYPE_p_daal__data_management__interface1__Tensor swig_types[109]
#define SWIGTYPE_p_daal__data_management__interface1__TensorIface swig_types[110]
#define SWIGTYPE_p_daal__data_management__interface1__TensorLayout swig_types[111]
#define SWIGTYPE_p_daal__data_management__interface1__TensorLayoutIface swig_types[112]
#define SWIGTYPE_p_daal__data_management__interface1__TensorOffsetLayout swig_types[113]
#define SWIGTYPE_p_daal__data_management__interface1__ZlibCompressionParameter swig_types[114]
#define SWIGTYPE_p_daal__data_management__modifiers__csv__interface1__Config swig_types[115]
#define SWIGTYPE_p_daal__data_management__modifiers__csv__interface1__Context swig_types[116]
#define SWIGTYPE_p_daal__data_management__modifiers__csv__interface1__FeatureModifier swig_types[117]
#define SWIGTYPE_p_daal__data_management__modifiers__csv__interface1__PyFeatureModifier swig_types[118]
#define SWIGTYPE_p_daal__services__CollectionT_daal__data_management__FeatureAuxData_t swig_types[119]
#define SWIGTYPE_p_daal__services__CollectionT_daal__services__SharedPtrT_daal__algorithms__interface1__Input_t_t swig_types[120]
#define SWIGTYPE_p_daal__services__CollectionT_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t_t swig_types[121]
#define SWIGTYPE_p_daal__services__CollectionT_size_t_t swig_types[122]
#define SWIGTYPE_p_daal__services__CollectionT_void_fpFfchar_const_p_daal__data_management__FeatureAuxData_R_double_pF_t swig_types[123]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__Base_t swig_types[124]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__batch_t_t swig_types[125]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__distributed_t_t swig_types[126]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__online_t_t swig_types[127]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__batch_t_t swig_types[128]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__distributed_t_t swig_types[129]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__online_t_t swig_types[130]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__DistributedPredictionContainerIface_t swig_types[131]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__DistributedPrediction_t swig_types[132]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__PredictionContainerIface_t swig_types[133]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__Prediction_t swig_types[134]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__batch_t_t swig_types[135]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__distributed_t_t swig_types[136]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__online_t_t swig_types[137]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIfaceImpl_t swig_types[138]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIface_t swig_types[139]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__batch_t_t swig_types[140]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__distributed_t_t swig_types[141]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__online_t_t swig_types[142]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__batch_t_t swig_types[143]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__distributed_t_t swig_types[144]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__online_t_t swig_types[145]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmDispatchContainer_t swig_types[146]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIfaceImpl_t swig_types[147]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIface_t swig_types[148]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__batch_t_t swig_types[149]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__distributed_t_t swig_types[150]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__online_t_t swig_types[151]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__batch_t_t swig_types[152]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__distributed_t_t swig_types[153]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__online_t_t swig_types[154]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__Argument_t swig_types[155]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__HostAppIface_t swig_types[156]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__Input_t swig_types[157]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__Kernel_t swig_types[158]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__Model_t swig_types[159]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__OptionalArgument_t swig_types[160]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__Parameter_t swig_types[161]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__PartialResult_t swig_types[162]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__Result_t swig_types[163]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__SerializableArgument_t swig_types[164]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdCollectionIface_t swig_types[165]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdCollection_t swig_types[166]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdIface_t swig_types[167]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdMappingIface_t swig_types[168]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdMapping_t swig_types[169]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureId_t swig_types[170]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndexTraits_t swig_types[171]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndicesIface_t swig_types[172]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndices_t swig_types[173]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BasicStatisticsDataCollection_t swig_types[174]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t swig_types[175]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t swig_types[176]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t swig_types[177]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_double_t_t swig_types[178]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_float_t_t swig_types[179]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_int_t_t swig_types[180]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTableIface_t swig_types[181]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t swig_types[182]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSVFeatureManager_t swig_types[183]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CategoricalFeatureDictionary_t swig_types[184]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__ColumnFilter_t swig_types[185]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressedDataArchive_t swig_types[186]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t swig_types[187]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionStream_t swig_types[188]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t swig_types[189]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_t swig_types[190]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_t_t swig_types[191]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__lzo_t_t swig_types[192]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__rle_t_t swig_types[193]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__zlib_t_t swig_types[194]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t swig_types[195]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_t swig_types[196]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveImpl_t swig_types[197]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchive_t swig_types[198]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlockIface_t swig_types[199]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t swig_types[200]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataCollection_t swig_types[201]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t swig_types[202]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t swig_types[203]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t_t swig_types[204]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_float_t_double_t_t swig_types[205]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_int_t_double_t_t swig_types[206]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t swig_types[207]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressedDataArchive_t swig_types[208]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressionStream_t swig_types[209]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_t swig_types[210]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_t_t swig_types[211]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_t_t swig_types[212]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__rle_t_t swig_types[213]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_t_t swig_types[214]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t swig_types[215]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t swig_types[216]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryIface_t swig_types[217]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_t swig_types[218]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t swig_types[219]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdCollectionIface_t swig_types[220]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdCollection_t swig_types[221]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdIface_t swig_types[222]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdMappingIface_t swig_types[223]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdMapping_t swig_types[224]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureId_t swig_types[225]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIndexTraits_t swig_types[226]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIndicesIface_t swig_types[227]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIndices_t swig_types[228]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t swig_types[229]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t swig_types[230]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t swig_types[231]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t swig_types[232]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t swig_types[233]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t swig_types[234]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t swig_types[235]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__InputDataArchive_t swig_types[236]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_algorithms__Input_t_const_t swig_types[237]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_algorithms__Input_t_t swig_types[238]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__algorithms__interface1__Input_t_t swig_types[239]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t swig_types[240]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MakeCategorical_t swig_types[241]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t swig_types[242]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t swig_types[243]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t swig_types[244]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t swig_types[245]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__ModifierIface_t swig_types[246]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t swig_types[247]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_t swig_types[248]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t swig_types[249]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_const_t swig_types[250]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t swig_types[251]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__OneHotEncoder_t swig_types[252]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__OutputDataArchive_t swig_types[253]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t swig_types[254]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t swig_types[255]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t swig_types[256]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t swig_types[257]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t swig_types[258]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t swig_types[259]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t swig_types[260]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t swig_types[261]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t swig_types[262]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t swig_types[263]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t swig_types[264]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t swig_types[265]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t swig_types[266]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t swig_types[267]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t swig_types[268]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_const_t swig_types[269]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t swig_types[270]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t swig_types[271]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t swig_types[272]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__StringRowFeatureManagerIface_t swig_types[273]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t swig_types[274]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t swig_types[275]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t swig_types[276]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorIface_t swig_types[277]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayoutIface_t swig_types[278]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayout_t swig_types[279]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t swig_types[280]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t swig_types[281]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__ConfigIface_t swig_types[282]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Config_t swig_types[283]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__ContextIface_t swig_types[284]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Context_t swig_types[285]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifierIface_t swig_types[286]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifier_t swig_types[287]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__PyFeatureModifier_t swig_types[288]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__modifiers__interface1__ConfigIface_t swig_types[289]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__modifiers__interface1__ContextIface_t swig_types[290]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__backward__LayerIfacePtr_t_t swig_types[291]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__forward__LayerIfacePtr_t_t swig_types[292]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__forward__interface1__LayerDescriptor_t_t swig_types[293]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__interface1__NextLayers_t_t swig_types[294]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__data_management__interface1__SerializationIfacePtr_t_t swig_types[295]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t_t_t swig_types[296]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__services__interface1__Environment_t swig_types[297]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__services__interface1__ErrorCollection_t swig_types[298]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__services__interface1__Error_t swig_types[299]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__services__interface1__KernelErrorCollection_t swig_types[300]
#define SWIGTYPE_p_daal__services__SharedPtrT_daal__services__interface1__LibraryVersionInfo_t swig_types[301]
#define SWIGTYPE_p_daal__services__SharedPtrT_double_t swig_types[302]
#define SWIGTYPE_p_daal__services__SharedPtrT_float_t swig_types[303]
#define SWIGTYPE_p_daal__services__SharedPtrT_int_t swig_types[304]
#define SWIGTYPE_p_daal__services__SharedPtrT_size_t_t swig_types[305]
#define SWIGTYPE_p_daal__services__SharedPtrT_unsigned_char_t swig_types[306]
#define SWIGTYPE_p_daal__services__String swig_types[307]
#define SWIGTYPE_p_daal__services__interface1__CollectionT_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t_t swig_types[308]
#define SWIGTYPE_p_daal__services__interface1__Environment swig_types[309]
#define SWIGTYPE_p_daal__services__interface1__LibraryVersionInfo swig_types[310]
#define SWIGTYPE_p_daal__services__interface1__Status swig_types[311]
#define SWIGTYPE_p_double swig_types[312]
#define SWIGTYPE_p_env swig_types[313]
#define SWIGTYPE_p_f___p_daal__data_management__interface1__CSRNumericTable swig_types[314]
#define SWIGTYPE_p_f___p_daal__data_management__interface1__DataCollection swig_types[315]
#define SWIGTYPE_p_f___p_daal__data_management__interface1__DataSourceFeature swig_types[316]
#define SWIGTYPE_p_f___p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t swig_types[317]
#define SWIGTYPE_p_f___p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t swig_types[318]
#define SWIGTYPE_p_f___p_daal__data_management__interface1__HomogenNumericTableT_double_t swig_types[319]
#define SWIGTYPE_p_f___p_daal__data_management__interface1__HomogenNumericTableT_float_t swig_types[320]
#define SWIGTYPE_p_f___p_daal__data_management__interface1__HomogenNumericTableT_int_t swig_types[321]
#define SWIGTYPE_p_f___p_daal__data_management__interface1__HomogenTensorT_double_t swig_types[322]
#define SWIGTYPE_p_f___p_daal__data_management__interface1__HomogenTensorT_float_t swig_types[323]
#define SWIGTYPE_p_f___p_daal__data_management__interface1__HomogenTensorT_int_t swig_types[324]
#define SWIGTYPE_p_f___p_daal__data_management__interface1__MatrixT_double_t swig_types[325]
#define SWIGTYPE_p_f___p_daal__data_management__interface1__MatrixT_float_t swig_types[326]
#define SWIGTYPE_p_f___p_daal__data_management__interface1__MatrixT_int_t swig_types[327]
#define SWIGTYPE_p_f___p_daal__data_management__interface1__MergedNumericTable swig_types[328]
#define SWIGTYPE_p_f___p_daal__data_management__interface1__NpyAOSNumericTable swig_types[329]
#define SWIGTYPE_p_f___p_daal__data_management__interface1__NumericTable swig_types[330]
#define SWIGTYPE_p_f___p_daal__data_management__interface1__NumericTableFeature swig_types[331]
#define SWIGTYPE_p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t swig_types[332]
#define SWIGTYPE_p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t swig_types[333]
#define SWIGTYPE_p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t swig_types[334]
#define SWIGTYPE_p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t swig_types[335]
#define SWIGTYPE_p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t swig_types[336]
#define SWIGTYPE_p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t swig_types[337]
#define SWIGTYPE_p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t swig_types[338]
#define SWIGTYPE_p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t swig_types[339]
#define SWIGTYPE_p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t swig_types[340]
#define SWIGTYPE_p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t swig_types[341]
#define SWIGTYPE_p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t swig_types[342]
#define SWIGTYPE_p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t swig_types[343]
#define SWIGTYPE_p_f___p_daal__data_management__interface1__RowMergedNumericTable swig_types[344]
#define SWIGTYPE_p_f___p_daal__data_management__interface1__SOANumericTable swig_types[345]
#define SWIGTYPE_p_f___p_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t swig_types[346]
#define SWIGTYPE_p_f___p_daal__data_management__interface1__SerializationIface swig_types[347]
#define SWIGTYPE_p_f___p_daal__data_management__interface1__Tensor swig_types[348]
#define SWIGTYPE_p_f___p_daal__data_management__interface1__TensorLayout swig_types[349]
#define SWIGTYPE_p_f___p_daal__data_management__interface1__TensorOffsetLayout swig_types[350]
#define SWIGTYPE_p_first_type swig_types[351]
#define SWIGTYPE_p_float swig_types[352]
#define SWIGTYPE_p_int swig_types[353]
#define SWIGTYPE_p_numericTableType swig_types[354]
#define SWIGTYPE_p_p_daal__data_management__interface1__BlockDescriptorT_double_t swig_types[355]
#define SWIGTYPE_p_p_daal__data_management__interface1__BlockDescriptorT_float_t swig_types[356]
#define SWIGTYPE_p_p_daal__data_management__interface1__BlockDescriptorT_int_t swig_types[357]
#define SWIGTYPE_p_p_daal__data_management__interface1__CSRNumericTable swig_types[358]
#define SWIGTYPE_p_p_daal__data_management__interface1__DataCollection swig_types[359]
#define SWIGTYPE_p_p_daal__data_management__interface1__DataSourceFeature swig_types[360]
#define SWIGTYPE_p_p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t swig_types[361]
#define SWIGTYPE_p_p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t swig_types[362]
#define SWIGTYPE_p_p_daal__data_management__interface1__HomogenNumericTableT_double_t swig_types[363]
#define SWIGTYPE_p_p_daal__data_management__interface1__HomogenNumericTableT_float_t swig_types[364]
#define SWIGTYPE_p_p_daal__data_management__interface1__HomogenNumericTableT_int_t swig_types[365]
#define SWIGTYPE_p_p_daal__data_management__interface1__HomogenTensorT_double_t swig_types[366]
#define SWIGTYPE_p_p_daal__data_management__interface1__HomogenTensorT_float_t swig_types[367]
#define SWIGTYPE_p_p_daal__data_management__interface1__HomogenTensorT_int_t swig_types[368]
#define SWIGTYPE_p_p_daal__data_management__interface1__MatrixT_double_t swig_types[369]
#define SWIGTYPE_p_p_daal__data_management__interface1__MatrixT_float_t swig_types[370]
#define SWIGTYPE_p_p_daal__data_management__interface1__MatrixT_int_t swig_types[371]
#define SWIGTYPE_p_p_daal__data_management__interface1__MergedNumericTable swig_types[372]
#define SWIGTYPE_p_p_daal__data_management__interface1__NpyAOSNumericTable swig_types[373]
#define SWIGTYPE_p_p_daal__data_management__interface1__NumericTable swig_types[374]
#define SWIGTYPE_p_p_daal__data_management__interface1__NumericTableFeature swig_types[375]
#define SWIGTYPE_p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t swig_types[376]
#define SWIGTYPE_p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t swig_types[377]
#define SWIGTYPE_p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t swig_types[378]
#define SWIGTYPE_p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t swig_types[379]
#define SWIGTYPE_p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t swig_types[380]
#define SWIGTYPE_p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t swig_types[381]
#define SWIGTYPE_p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t swig_types[382]
#define SWIGTYPE_p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t swig_types[383]
#define SWIGTYPE_p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t swig_types[384]
#define SWIGTYPE_p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t swig_types[385]
#define SWIGTYPE_p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t swig_types[386]
#define SWIGTYPE_p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t swig_types[387]
#define SWIGTYPE_p_p_daal__data_management__interface1__RowMergedNumericTable swig_types[388]
#define SWIGTYPE_p_p_daal__data_management__interface1__SOANumericTable swig_types[389]
#define SWIGTYPE_p_p_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t swig_types[390]
#define SWIGTYPE_p_p_daal__data_management__interface1__SerializationIface swig_types[391]
#define SWIGTYPE_p_p_daal__data_management__interface1__Tensor swig_types[392]
#define SWIGTYPE_p_p_daal__data_management__interface1__TensorLayout swig_types[393]
#define SWIGTYPE_p_p_daal__data_management__interface1__TensorOffsetLayout swig_types[394]
#define SWIGTYPE_p_p_daal__services__CollectionT_size_t_t swig_types[395]
#define SWIGTYPE_p_p_size_t swig_types[396]
#define SWIGTYPE_p_second_type swig_types[397]
#define SWIGTYPE_p_size_t swig_types[398]
#define SWIGTYPE_p_std__mapT_std__string_std__pairT_int_int_t_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__pairT_int_int_t_t_t_t swig_types[399]
#define SWIGTYPE_p_super swig_types[400]
#define SWIGTYPE_p_unsigned_char swig_types[401]
#define SWIGTYPE_p_void swig_types[402]
static swig_type_info *swig_types[404];
static swig_module_info swig_module = {swig_types, 403, 0, 0, 0, 0};
#define SWIG_TypeQuery(name) SWIG_TypeQueryModule(&swig_module, &swig_module, name)
#define SWIG_MangledTypeQuery(name) SWIG_MangledTypeQueryModule(&swig_module, &swig_module, name)

/* -------- TYPES TABLE (END) -------- */

#if (PY_VERSION_HEX <= 0x02000000)
# if !defined(SWIG_PYTHON_CLASSIC)
#  error "This python version requires swig to be run with the '-classic' option"
# endif
#endif

/*-----------------------------------------------
              @(target):= _data_management_.so
  ------------------------------------------------*/
#if PY_VERSION_HEX >= 0x03000000
#  define SWIG_init    PyInit__data_management_

#else
#  define SWIG_init    init_data_management_

#endif
#define SWIG_name    "_data_management_"

#define SWIGVERSION 0x030006 
#define SWIG_VERSION SWIGVERSION


#define SWIG_as_voidptr(a) const_cast< void * >(static_cast< const void * >(a)) 
#define SWIG_as_voidptrptr(a) ((void)SWIG_as_voidptr(*a),reinterpret_cast< void** >(a)) 


#include <stdexcept>


namespace swig {
  class SwigPtr_PyObject {
  protected:
    PyObject *_obj;

  public:
    SwigPtr_PyObject() :_obj(0)
    {
    }

    SwigPtr_PyObject(const SwigPtr_PyObject& item) : _obj(item._obj)
    {
      SWIG_PYTHON_THREAD_BEGIN_BLOCK;
      Py_XINCREF(_obj);      
      SWIG_PYTHON_THREAD_END_BLOCK;
    }
    
    SwigPtr_PyObject(PyObject *obj, bool initial_ref = true) :_obj(obj)
    {
      if (initial_ref) {
        SWIG_PYTHON_THREAD_BEGIN_BLOCK;
        Py_XINCREF(_obj);
        SWIG_PYTHON_THREAD_END_BLOCK;
      }
    }
    
    SwigPtr_PyObject & operator=(const SwigPtr_PyObject& item) 
    {
      SWIG_PYTHON_THREAD_BEGIN_BLOCK;
      Py_XINCREF(item._obj);
      Py_XDECREF(_obj);
      _obj = item._obj;
      SWIG_PYTHON_THREAD_END_BLOCK;
      return *this;      
    }
    
    ~SwigPtr_PyObject() 
    {
      SWIG_PYTHON_THREAD_BEGIN_BLOCK;
      Py_XDECREF(_obj);
      SWIG_PYTHON_THREAD_END_BLOCK;
    }
    
    operator PyObject *() const
    {
      return _obj;
    }

    PyObject *operator->() const
    {
      return _obj;
    }
  };
}


namespace swig {
  struct SwigVar_PyObject : SwigPtr_PyObject {
    SwigVar_PyObject(PyObject* obj = 0) : SwigPtr_PyObject(obj, false) { }
    
    SwigVar_PyObject & operator = (PyObject* obj)
    {
      Py_XDECREF(_obj);
      _obj = obj;
      return *this;      
    }
  };
}


#define SWIG_FILE_WITH_INIT
// includes etc. needed to compile wrappers

#include <daal.h>

template<typename T> void my_delete(void * p ) { delete static_cast<T*>(p); }

using namespace daal::data_management;
// for SOA; can't be below as it would be included too late
// note that the use of 'self' should be '$self' but this doesn't
// work with the expansion order in SWIG. So we rely on SWIG to
// expand '$self' to 'self'.
#define SETARRAY_(_T) { daal::services::SharedPtr< _T > _tmp(reinterpret_cast< _T * >(PyArray_DATA(ary)), NumpyDeleter(ary)); self->setArray(_tmp, idx); }


#define SWIG_FILE_WITH_INIT
//#define DAAL_NOTHROW_EXCEPTIONS // for DAAL_ResultErrorsException
//#define protected public //for DAAL_ResultErrorsException

#if PY_MAJOR_VERSION >= 3
# define PyInt_AsSsize_t PyLong_AsSsize_t
# define CHECK_STRING(s) PyUnicode_Check(s)
# define GET_STRING(s) PyUnicode_AsUTF8(s)
#else
# define CHECK_STRING(s) PyString_Check(s)
# define GET_STRING(s) PyString_AsString(s)
#endif

#include <daal.h>
#include <data_management/data_source/modifiers/csv/pyfeaturemodifier.h>


#ifndef SWIG_FILE_WITH_INIT
#define NO_IMPORT_ARRAY
#endif
#include "stdio.h"
#include "math.h"
#include <cassert>
#define NPY_NO_DEPRECATED_API NPY_1_7_API_VERSION
#include <numpy/arrayobject.h>

#define FORCE_INPLACE true
#define ALLOW_CONVERSION false


#include <string>


#include <stddef.h>


namespace swig {
  struct stop_iteration {
  };

  struct SwigPyIterator {
  private:
    SwigPtr_PyObject _seq;

  protected:
    SwigPyIterator(PyObject *seq) : _seq(seq)
    {
    }
      
  public:
    virtual ~SwigPyIterator() {}

    // Access iterator method, required by Python
    virtual PyObject *value() const = 0;

    // Forward iterator method, required by Python
    virtual SwigPyIterator *incr(size_t n = 1) = 0;
    
    // Backward iterator method, very common in C++, but not required in Python
    virtual SwigPyIterator *decr(size_t /*n*/ = 1)
    {
      throw stop_iteration();
    }

    // Random access iterator methods, but not required in Python
    virtual ptrdiff_t distance(const SwigPyIterator &/*x*/) const
    {
      throw std::invalid_argument("operation not supported");
    }

    virtual bool equal (const SwigPyIterator &/*x*/) const
    {
      throw std::invalid_argument("operation not supported");
    }
    
    // C++ common/needed methods
    virtual SwigPyIterator *copy() const = 0;

    PyObject *next()     
    {
      SWIG_PYTHON_THREAD_BEGIN_BLOCK; // disable threads       
      PyObject *obj = value();
      incr();       
      SWIG_PYTHON_THREAD_END_BLOCK; // re-enable threads
      return obj;     
    }

    /* Make an alias for Python 3.x */
    PyObject *__next__()
    {
      return next();
    }

    PyObject *previous()
    {
      SWIG_PYTHON_THREAD_BEGIN_BLOCK; // disable threads       
      decr();
      PyObject *obj = value();
      SWIG_PYTHON_THREAD_END_BLOCK; // re-enable threads       
      return obj;
    }

    SwigPyIterator *advance(ptrdiff_t n)
    {
      return  (n > 0) ?  incr(n) : decr(-n);
    }
      
    bool operator == (const SwigPyIterator& x)  const
    {
      return equal(x);
    }
      
    bool operator != (const SwigPyIterator& x) const
    {
      return ! operator==(x);
    }
      
    SwigPyIterator& operator += (ptrdiff_t n)
    {
      return *advance(n);
    }

    SwigPyIterator& operator -= (ptrdiff_t n)
    {
      return *advance(-n);
    }
      
    SwigPyIterator* operator + (ptrdiff_t n) const
    {
      return copy()->advance(n);
    }

    SwigPyIterator* operator - (ptrdiff_t n) const
    {
      return copy()->advance(-n);
    }
      
    ptrdiff_t operator - (const SwigPyIterator& x) const
    {
      return x.distance(*this);
    }
      
    static swig_type_info* descriptor() {
      static int init = 0;
      static swig_type_info* desc = 0;
      if (!init) {
	desc = SWIG_TypeQuery("swig::SwigPyIterator *");
	init = 1;
      }	
      return desc;
    }    
  };

#if defined(SWIGPYTHON_BUILTIN)
  inline PyObject* make_output_iterator_builtin (PyObject *pyself)
  {
    Py_INCREF(pyself);
    return pyself;
  }
#endif
}


#include <algorithm>


SWIGINTERNINLINE PyObject*
  SWIG_From_int  (int value)
{
  return PyInt_FromLong((long) value);
}


#include <limits.h>
#if !defined(SWIG_NO_LLONG_MAX)
# if !defined(LLONG_MAX) && defined(__GNUC__) && defined (__LONG_LONG_MAX__)
#   define LLONG_MAX __LONG_LONG_MAX__
#   define LLONG_MIN (-LLONG_MAX - 1LL)
#   define ULLONG_MAX (LLONG_MAX * 2ULL + 1ULL)
# endif
#endif


SWIGINTERN int
SWIG_AsVal_double (PyObject *obj, double *val)
{
  int res = SWIG_TypeError;
  if (PyFloat_Check(obj)) {
    if (val) *val = PyFloat_AsDouble(obj);
    return SWIG_OK;
  } else if (PyInt_Check(obj)) {
    if (val) *val = PyInt_AsLong(obj);
    return SWIG_OK;
  } else if (PyLong_Check(obj)) {
    double v = PyLong_AsDouble(obj);
    if (!PyErr_Occurred()) {
      if (val) *val = v;
      return SWIG_OK;
    } else {
      PyErr_Clear();
    }
  }
#ifdef SWIG_PYTHON_CAST_MODE
  {
    int dispatch = 0;
    double d = PyFloat_AsDouble(obj);
    if (!PyErr_Occurred()) {
      if (val) *val = d;
      return SWIG_AddCast(SWIG_OK);
    } else {
      PyErr_Clear();
    }
    if (!dispatch) {
      long v = PyLong_AsLong(obj);
      if (!PyErr_Occurred()) {
	if (val) *val = v;
	return SWIG_AddCast(SWIG_AddCast(SWIG_OK));
      } else {
	PyErr_Clear();
      }
    }
  }
#endif
  return res;
}


#include <float.h>


#include <math.h>


SWIGINTERNINLINE int
SWIG_CanCastAsInteger(double *d, double min, double max) {
  double x = *d;
  if ((min <= x && x <= max)) {
   double fx = floor(x);
   double cx = ceil(x);
   double rd =  ((x - fx) < 0.5) ? fx : cx; /* simple rint */
   if ((errno == EDOM) || (errno == ERANGE)) {
     errno = 0;
   } else {
     double summ, reps, diff;
     if (rd < x) {
       diff = x - rd;
     } else if (rd > x) {
       diff = rd - x;
     } else {
       return 1;
     }
     summ = rd + x;
     reps = diff/summ;
     if (reps < 8*DBL_EPSILON) {
       *d = rd;
       return 1;
     }
   }
  }
  return 0;
}


SWIGINTERN int
SWIG_AsVal_long (PyObject *obj, long* val)
{
  if (PyInt_Check(obj)) {
    if (val) *val = PyInt_AsLong(obj);
    return SWIG_OK;
  } else if (PyLong_Check(obj)) {
    long v = PyLong_AsLong(obj);
    if (!PyErr_Occurred()) {
      if (val) *val = v;
      return SWIG_OK;
    } else {
      PyErr_Clear();
    }
  }
#ifdef SWIG_PYTHON_CAST_MODE
  {
    int dispatch = 0;
    long v = PyInt_AsLong(obj);
    if (!PyErr_Occurred()) {
      if (val) *val = v;
      return SWIG_AddCast(SWIG_OK);
    } else {
      PyErr_Clear();
    }
    if (!dispatch) {
      double d;
      int res = SWIG_AddCast(SWIG_AsVal_double (obj,&d));
      if (SWIG_IsOK(res) && SWIG_CanCastAsInteger(&d, LONG_MIN, LONG_MAX)) {
	if (val) *val = (long)(d);
	return res;
      }
    }
  }
#endif
  return SWIG_TypeError;
}


SWIGINTERN int
SWIG_AsVal_int (PyObject * obj, int *val)
{
  long v;
  int res = SWIG_AsVal_long (obj, &v);
  if (SWIG_IsOK(res)) {
    if ((v < INT_MIN || v > INT_MAX)) {
      return SWIG_OverflowError;
    } else {
      if (val) *val = static_cast< int >(v);
    }
  }  
  return res;
}


// FS: Intel(R) DAAL has its own deleter iface
struct SWIG_null_deleter : public daal::services::DeleterIface
{
    void operator() (void *) const {}

    // FS: from daal::services::DeleterIface
    virtual void operator() (const void *ptr) {}
};
#define SWIG_NO_NULL_DELETER_0 , SWIG_null_deleter()
#define SWIG_NO_NULL_DELETER_1
#define SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW
#define SWIG_NO_NULL_DELETER_SWIG_POINTER_OWN


#define SWIG_NO_NULL_DELETER_SWIG_BUILTIN_INIT


  #define SWIG_From_long   PyLong_FromLong 


SWIGINTERNINLINE PyObject* 
SWIG_From_unsigned_SS_long  (unsigned long value)
{
  return (value > LONG_MAX) ?
    PyLong_FromUnsignedLong(value) : PyLong_FromLong(static_cast< long >(value)); 
}


SWIGINTERNINLINE PyObject *
SWIG_From_size_t  (size_t value)
{    
  return SWIG_From_unsigned_SS_long  (static_cast< unsigned long >(value));
}


#if NPY_API_VERSION < 0x00000007
#define NPY_ARRAY_DEFAULT NPY_DEFAULT
#define NPY_ARRAY_FARRAY  NPY_FARRAY
#define NPY_FORTRANORDER  NPY_FORTRAN
#endif


/* Macros to extract array attributes.
 */
#if NPY_API_VERSION < 0x00000007
#define is_array(a)            ((a) && PyArray_Check((PyArrayObject*)a))
#define array_type(a)          (int)(PyArray_TYPE((PyArrayObject*)a))
#define array_numdims(a)       (((PyArrayObject*)a)->nd)
#define array_dimensions(a)    (((PyArrayObject*)a)->dimensions)
#define array_size(a,i)        (((PyArrayObject*)a)->dimensions[i])
#define array_strides(a)       (((PyArrayObject*)a)->strides)
#define array_stride(a,i)      (((PyArrayObject*)a)->strides[i])
#define array_data(a)          (((PyArrayObject*)a)->data)
#define array_descr(a)         (((PyArrayObject*)a)->descr)
#define array_flags(a)         (((PyArrayObject*)a)->flags)
#define array_enableflags(a,f) (((PyArrayObject*)a)->flags) = f
#else
#define is_array(a)            ((a) && PyArray_Check(a))
#define array_type(a)          PyArray_TYPE((PyArrayObject*)a)
#define array_numdims(a)       PyArray_NDIM((PyArrayObject*)a)
#define array_dimensions(a)    PyArray_DIMS((PyArrayObject*)a)
#define array_strides(a)       PyArray_STRIDES((PyArrayObject*)a)
#define array_stride(a,i)      PyArray_STRIDE((PyArrayObject*)a,i)
#define array_size(a,i)        PyArray_DIM((PyArrayObject*)a,i)
#define array_data(a)          PyArray_DATA((PyArrayObject*)a)
#define array_descr(a)         PyArray_DESCR((PyArrayObject*)a)
#define array_flags(a)         PyArray_FLAGS((PyArrayObject*)a)
#define array_enableflags(a,f) PyArray_ENABLEFLAGS((PyArrayObject*)a,f)
#endif
#define array_is_contiguous(a) (PyArray_ISCONTIGUOUS((PyArrayObject*)a))
#define array_is_native(a)     (PyArray_ISNOTSWAPPED((PyArrayObject*)a))
#define array_is_fortran(a)    (PyArray_ISFORTRAN((PyArrayObject*)a))


  /* Given a PyObject, return a string describing its type.
   */
  const char* pytype_string(PyObject* py_obj)
  {
    if (py_obj == NULL          ) return "C NULL value";
    if (py_obj == Py_None       ) return "Python None" ;
    if (PyCallable_Check(py_obj)) return "callable"    ;
    if (PyString_Check(  py_obj)) return "string"      ;
    if (PyInt_Check(     py_obj)) return "int"         ;
    if (PyFloat_Check(   py_obj)) return "float"       ;
    if (PyDict_Check(    py_obj)) return "dict"        ;
    if (PyList_Check(    py_obj)) return "list"        ;
    if (PyTuple_Check(   py_obj)) return "tuple"       ;
#if PY_MAJOR_VERSION < 3
    if (PyFile_Check(    py_obj)) return "file"        ;
    if (PyModule_Check(  py_obj)) return "module"      ;
    if (PyInstance_Check(py_obj)) return "instance"    ;
#endif

    return "unkown type";
  }

  /* Given a NumPy typecode, return a string describing the type.
   */
  const char* typecode_string(int typecode)
  {
    static const char* type_names[25] = {"bool",
                                         "byte",
                                         "unsigned byte",
                                         "short",
                                         "unsigned short",
                                         "int",
                                         "unsigned int",
                                         "long",
                                         "unsigned long",
                                         "long long",
                                         "unsigned long long",
                                         "float",
                                         "double",
                                         "long double",
                                         "complex float",
                                         "complex double",
                                         "complex long double",
                                         "object",
                                         "string",
                                         "unicode",
                                         "void",
                                         "ntypes",
                                         "notype",
                                         "char",
                                         "unknown"};
    return typecode < 24 ? type_names[typecode] : type_names[24];
  }

  /* Make sure input has correct numpy type.  This now just calls
     PyArray_EquivTypenums().
   */
  int type_match(int actual_type,
                 int desired_type)
  {
    return PyArray_EquivTypenums(actual_type, desired_type);
  }

#ifdef SWIGPY_USE_CAPSULE
  void free_cap(PyObject * cap)
  {
    void* array = (void*) PyCapsule_GetPointer(cap,SWIGPY_CAPSULE_NAME);
    if (array != NULL) free(array);
  }
#endif




  /* Given a PyObject pointer, cast it to a PyArrayObject pointer if
   * legal.  If not, set the python error string appropriately and
   * return NULL.
   */
  PyArrayObject* obj_to_array_no_conversion(PyObject* input,
                                            int        typecode)
  {
    PyArrayObject* ary = NULL;
    if (is_array(input) && (typecode == NPY_NOTYPE ||
                            PyArray_EquivTypenums(array_type(input), typecode)))
    {
      ary = (PyArrayObject*) input;
    }
    else if is_array(input)
    {
      const char* desired_type = typecode_string(typecode);
      const char* actual_type  = typecode_string(array_type(input));
      PyErr_Format(PyExc_TypeError,
                   "Array of type '%s' required.  Array of type '%s' given",
                   desired_type, actual_type);
      ary = NULL;
    }
    else
    {
      const char* desired_type = typecode_string(typecode);
      const char* actual_type  = pytype_string(input);
      PyErr_Format(PyExc_TypeError,
                   "Array of type '%s' required.  A '%s' was given",
                   desired_type,
                   actual_type);
      ary = NULL;
    }
    return ary;
  }

  /* Convert the given PyObject to a NumPy array with the given
   * typecode.  On success, return a valid PyArrayObject* with the
   * correct type.  On failure, the python error string will be set and
   * the routine returns NULL.
   */
  PyArrayObject* obj_to_array_allow_conversion(PyObject* input,
                                               int       typecode,
                                               int*      is_new_object)
  {
    PyArrayObject* ary = NULL;
    PyObject*      py_obj;
    if (is_array(input) && (typecode == NPY_NOTYPE ||
                            PyArray_EquivTypenums(array_type(input),typecode)))
    {
      ary = (PyArrayObject*) input;
      *is_new_object = 0;
    }
    else
    {
      py_obj = PyArray_FROMANY(input, typecode, 0, 0, NPY_ARRAY_DEFAULT);
      /* If NULL, PyArray_FromObject will have set python error value.*/
      ary = (PyArrayObject*) py_obj;
      *is_new_object = 1;
    }
    return ary;
  }

  /* Given a PyArrayObject, check to see if it is contiguous.  If so,
   * return the input pointer and flag it as not a new object.  If it is
   * not contiguous, create a new PyArrayObject using the original data,
   * flag it as a new object and return the pointer.
   */
  PyArrayObject* make_contiguous(PyArrayObject* ary,
                                 int*           is_new_object,
                                 int            min_dims,
                                 int            max_dims)
  {
    PyArrayObject* result;
    if (array_is_contiguous(ary))
    {
      result = ary;
      *is_new_object = 0;
    }
    else
    {
      result = (PyArrayObject*) PyArray_ContiguousFromObject((PyObject*)ary,
                                                              array_type(ary),
                                                              min_dims,
                                                              max_dims);
      *is_new_object = 1;
    }
    return result;
  }

  /* Given a PyArrayObject, check to see if it is Fortran-contiguous.
   * If so, return the input pointer, but do not flag it as not a new
   * object.  If it is not Fortran-contiguous, create a new
   * PyArrayObject using the original data, flag it as a new object
   * and return the pointer.
   */
  PyArrayObject* make_fortran(PyArrayObject* ary,
                              int*           is_new_object)
  {
    PyArrayObject* result;
    if (array_is_fortran(ary))
    {
      result = ary;
      *is_new_object = 0;
    }
    else
    {
      Py_INCREF(array_descr(ary));
      result = (PyArrayObject*) PyArray_FromArray(ary,
                                                  array_descr(ary),
                                                  NPY_FORTRANORDER);
      *is_new_object = 1;
    }
    return result;
  }

  /* Convert a given PyObject to a contiguous PyArrayObject of the
   * specified type.  If the input object is not a contiguous
   * PyArrayObject, a new one will be created and the new object flag
   * will be set.
   */
  PyArrayObject* obj_to_array_contiguous_allow_conversion(PyObject* input,
                                                          int       typecode,
                                                          int*      is_new_object)
  {
    int is_new1 = 0;
    int is_new2 = 0;
    PyArrayObject* ary2;
    PyArrayObject* ary1 = obj_to_array_allow_conversion(input,
                                                        typecode,
                                                        &is_new1);
    if (ary1)
    {
      ary2 = make_contiguous(ary1, &is_new2, 0, 0);
      if ( is_new1 && is_new2)
      {
        Py_DECREF(ary1);
      }
      ary1 = ary2;
    }
    *is_new_object = is_new1 || is_new2;
    return ary1;
  }

  /* Convert a given PyObject to a Fortran-ordered PyArrayObject of the
   * specified type.  If the input object is not a Fortran-ordered
   * PyArrayObject, a new one will be created and the new object flag
   * will be set.
   */
  PyArrayObject* obj_to_array_fortran_allow_conversion(PyObject* input,
                                                       int       typecode,
                                                       int*      is_new_object)
  {
    int is_new1 = 0;
    int is_new2 = 0;
    PyArrayObject* ary2;
    PyArrayObject* ary1 = obj_to_array_allow_conversion(input,
                                                        typecode,
                                                        &is_new1);
    if (ary1)
    {
      ary2 = make_fortran(ary1, &is_new2);
      if (is_new1 && is_new2)
      {
        Py_DECREF(ary1);
      }
      ary1 = ary2;
    }
    *is_new_object = is_new1 || is_new2;
    return ary1;
  }

/* ****************************************************************************
   * Intel(R) Data Analytics Acceleration Library (Intel(R) DAAL) extensions  *
   ****************************************************************************/
  class NumpyDeleter : public daal::services::DeleterIface
  {
  public:
      // constructor to initialize with ndarray
      NumpyDeleter(PyArrayObject* a) : _ndarray(a) {}
      // DeleterIface must be copy-constrible
      NumpyDeleter(const NumpyDeleter & o) : _ndarray(o._ndarray) {}
      // ref-count reached 0 -> decref reference to python object
      void operator() (const void *ptr) 
      {
          // This gets called from destructors, the SWIG wrappers release the GIL
          // -> need to protect calls to python API
          // Note: at termination time, even when no threads are running, this breaks without the protection
          SWIG_PYTHON_THREAD_BEGIN_BLOCK;
          assert((void *)array_data(_ndarray) == ptr);
          Py_DECREF(_ndarray);
          SWIG_PYTHON_THREAD_END_BLOCK;
      }
  private:
      PyArrayObject* _ndarray;
  };

  // An empty virtual base class (used by TVSP) for shared pointer handling
  // we use this to have a generic type for all shared pointers
  // e.g. used in daalsp_free functions below
  class VSP 
  {
  public:
      // we need a virtual destructor
      virtual ~VSP() {};
  };
  // typed virtual shared pointer, for simplicity we make it a Intel(R) DAAL shared pointer
  template< typename T >
  class TVSP : public VSP, public daal::services::SharedPtr<T>
  {
  public:
      TVSP(const daal::services::SharedPtr<T> & org) : daal::services::SharedPtr<T>(org) {}
      virtual ~TVSP() {};
  };

  // define our own free functions for wrapping python objects holding our shared pointers
#ifdef SWIGPY_USE_CAPSULE
  void daalsp_free_cap(PyObject * cap)
  {
      VSP * sp = (VSP*) PyCapsule_GetPointer(cap,SWIGPY_CAPSULE_NAME);
      if (sp) delete sp;
  }
#else
  void daalsp_free(PyObject * cap)
  {
      VSP * sp = (VSP*) PyCObject_AsVoidPtr(cap);
      if (sp) delete sp;
  }
#endif
     
  template< typename T >
  void set_sp_base(PyArrayObject * ary, daal::services::SharedPtr<T> & sp)
  {
      void * tmp_sp = (void*) new TVSP<T>(sp);
#ifdef SWIGPY_USE_CAPSULE
      PyObject* cap = PyCapsule_New(tmp_sp, SWIGPY_CAPSULE_NAME, daalsp_free_cap);
#else
      PyObject* cap = PyCObject_FromVoidPtr(tmp_sp, daalsp_free);
#endif
      PyArray_SetBaseObject(ary, cap);
    }

/* ****************************************************************************
   * Intel(R) Data Analytics Acceleration Library (Intel(R) DAAL) extensions  *
   ****************************************************************************/



  /* Test whether a python object is contiguous.  If array is
   * contiguous, return 1.  Otherwise, set the python error string and
   * return 0.
   */
  int require_contiguous(PyArrayObject* ary)
  {
    int contiguous = 1;
    if (!array_is_contiguous(ary))
    {
      PyErr_SetString(PyExc_TypeError,
                      "Array must be contiguous.  A non-contiguous array was given");
      contiguous = 0;
    }
    return contiguous;
  }

  /* Test whether a python object is (C_ or F_) contiguous.  If array is
   * contiguous, return 1.  Otherwise, set the python error string and
   * return 0.
   */
  int require_c_or_f_contiguous(PyArrayObject* ary)
  {
    int contiguous = 1;
    if (!(array_is_contiguous(ary) || array_is_fortran(ary)))
    {
      PyErr_SetString(PyExc_TypeError,
                      "Array must be contiguous (C_ or F_).  A non-contiguous array was given");
      contiguous = 0;
    }
    return contiguous;
  }

  /* Require that a numpy array is not byte-swapped.  If the array is
   * not byte-swapped, return 1.  Otherwise, set the python error string
   * and return 0.
   */
  int require_native(PyArrayObject* ary)
  {
    int native = 1;
    if (!array_is_native(ary))
    {
      PyErr_SetString(PyExc_TypeError,
                      "Array must have native byteorder.  "
                      "A byte-swapped array was given");
      native = 0;
    }
    return native;
  }

  /* Require the given PyArrayObject to have a specified number of
   * dimensions.  If the array has the specified number of dimensions,
   * return 1.  Otherwise, set the python error string and return 0.
   */
  int require_dimensions(PyArrayObject* ary,
                         int            exact_dimensions)
  {
    int success = 1;
    if (array_numdims(ary) != exact_dimensions)
    {
      PyErr_Format(PyExc_TypeError,
                   "Array must have %d dimensions.  Given array has %d dimensions",
                   exact_dimensions,
                   array_numdims(ary));
      success = 0;
    }
    return success;
  }

  /* Require the given PyArrayObject to have one of a list of specified
   * number of dimensions.  If the array has one of the specified number
   * of dimensions, return 1.  Otherwise, set the python error string
   * and return 0.
   */
  int require_dimensions_n(PyArrayObject* ary,
                           int*           exact_dimensions,
                           int            n)
  {
    int success = 0;
    int i;
    char dims_str[255] = "";
    char s[255];
    for (i = 0; i < n && !success; i++)
    {
      if (array_numdims(ary) == exact_dimensions[i])
      {
        success = 1;
      }
    }
    if (!success)
    {
      for (i = 0; i < n-1; i++)
      {
        sprintf(s, "%d, ", exact_dimensions[i]);
        strcat(dims_str,s);
      }
      sprintf(s, " or %d", exact_dimensions[n-1]);
      strcat(dims_str,s);
      PyErr_Format(PyExc_TypeError,
                   "Array must have %s dimensions.  Given array has %d dimensions",
                   dims_str,
                   array_numdims(ary));
    }
    return success;
  }

  /* Require the given PyArrayObject to have a specified shape.  If the
   * array has the specified shape, return 1.  Otherwise, set the python
   * error string and return 0.
   */
  int require_size(PyArrayObject* ary,
                   npy_intp*      size,
                   int            n)
  {
    int i;
    int success = 1;
    int len;
    char desired_dims[255] = "[";
    char s[255];
    char actual_dims[255] = "[";
    for(i=0; i < n;i++)
    {
      if (size[i] != -1 &&  size[i] != array_size(ary,i))
      {
        success = 0;
      }
    }
    if (!success)
    {
      for (i = 0; i < n; i++)
      {
        if (size[i] == -1)
        {
          sprintf(s, "*,");
        }
        else
        {
          sprintf(s, "%ld,", (long int)size[i]);
        }
        strcat(desired_dims,s);
      }
      len = strlen(desired_dims);
      desired_dims[len-1] = ']';
      for (i = 0; i < n; i++)
      {
        sprintf(s, "%ld,", (long int)array_size(ary,i));
        strcat(actual_dims,s);
      }
      len = strlen(actual_dims);
      actual_dims[len-1] = ']';
      PyErr_Format(PyExc_TypeError,
                   "Array must have shape of %s.  Given array has shape of %s",
                   desired_dims,
                   actual_dims);
    }
    return success;
  }

  /* Require the given PyArrayObject to to be Fortran ordered.  If the
   * the PyArrayObject is already Fortran ordered, do nothing.  Else,
   * set the Fortran ordering flag and recompute the strides.
   */
  int require_fortran(PyArrayObject* ary)
  {
    int success = 1;
    int nd = array_numdims(ary);
    int i;
    npy_intp * strides = array_strides(ary);
    if (array_is_fortran(ary)) return success;
    /* Set the Fortran ordered flag */
    array_enableflags(ary,NPY_ARRAY_FARRAY);
    /* Recompute the strides */
    strides[0] = strides[nd-1];
    for (i=1; i < nd; ++i)
      strides[i] = strides[i-1] * array_size(ary,i-1);
    return success;
  }



SWIGINTERN daal::data_management::interface1::DataBlock *new_daal_data_management_interface1_DataBlock__SWIG_1(daal::byte *outBlock,size_t size){
            return new DataBlock(outBlock, size);
        }
SWIGINTERN void daal_data_management_interface1_DataBlock_getArray(daal::data_management::interface1::DataBlock *self,size_t *as_,daal::services::SharedPtr< daal::byte > *arr_){
            *as_ = self->getSize();
            *arr_  = self->getSharedPtr();
        }
SWIGINTERN void daal_data_management_interface1_DataBlock_setArray(daal::data_management::interface1::DataBlock *self,daal::byte *outBlock,size_t size){
            self->setSize(size);
            self->setPtr(outBlock);
        }

SWIGINTERN int
SWIG_AsVal_unsigned_SS_long (PyObject *obj, unsigned long *val) 
{
#if PY_VERSION_HEX < 0x03000000
  if (PyInt_Check(obj)) {
    long v = PyInt_AsLong(obj);
    if (v >= 0) {
      if (val) *val = v;
      return SWIG_OK;
    } else {
      return SWIG_OverflowError;
    }
  } else
#endif
  if (PyLong_Check(obj)) {
    unsigned long v = PyLong_AsUnsignedLong(obj);
    if (!PyErr_Occurred()) {
      if (val) *val = v;
      return SWIG_OK;
    } else {
      PyErr_Clear();
#if PY_VERSION_HEX >= 0x03000000
      {
        long v = PyLong_AsLong(obj);
        if (!PyErr_Occurred()) {
          if (v < 0) {
            return SWIG_OverflowError;
          }
        } else {
          PyErr_Clear();
        }
      }
#endif
    }
  }
#ifdef SWIG_PYTHON_CAST_MODE
  {
    int dispatch = 0;
    unsigned long v = PyLong_AsUnsignedLong(obj);
    if (!PyErr_Occurred()) {
      if (val) *val = v;
      return SWIG_AddCast(SWIG_OK);
    } else {
      PyErr_Clear();
    }
    if (!dispatch) {
      double d;
      int res = SWIG_AddCast(SWIG_AsVal_double (obj,&d));
      if (SWIG_IsOK(res) && SWIG_CanCastAsInteger(&d, 0, ULONG_MAX)) {
	if (val) *val = (unsigned long)(d);
	return res;
      }
    }
  }
#endif
  return SWIG_TypeError;
}


SWIGINTERNINLINE int
SWIG_AsVal_size_t (PyObject * obj, size_t *val)
{
  unsigned long v;
  int res = SWIG_AsVal_unsigned_SS_long (obj, val ? &v : 0);
  if (SWIG_IsOK(res) && val) *val = static_cast< size_t >(v);
  return res;
}


SWIGINTERNINLINE PyObject*
  SWIG_From_bool  (bool value)
{
  return PyBool_FromLong(value ? 1 : 0);
}

SWIGINTERN void daal_data_management_interface1_CompressionStream_push_back(daal::data_management::interface1::CompressionStream *self,daal::byte *inBlock,size_t size){
            DataBlock db(inBlock, size);
            self->push_back(&db);
        }
SWIGINTERN void daal_data_management_interface1_DecompressionStream_push_back(daal::data_management::interface1::DecompressionStream *self,daal::byte *inBlock,size_t size){
            DataBlock db(inBlock, size);
            self->push_back(&db);
        }

SWIGINTERN int
SWIG_AsVal_bool (PyObject *obj, bool *val)
{
  int r;
  if (!PyBool_Check(obj))
    return SWIG_ERROR;
  r = PyObject_IsTrue(obj);
  if (r == -1)
    return SWIG_ERROR;
  if (val) *val = r ? true : false;
  return SWIG_OK;
}


SWIGINTERN swig_type_info*
SWIG_pchar_descriptor(void)
{
  static int init = 0;
  static swig_type_info* info = 0;
  if (!init) {
    info = SWIG_TypeQuery("_p_char");
    init = 1;
  }
  return info;
}


SWIGINTERNINLINE PyObject *
SWIG_FromCharPtrAndSize(const char* carray, size_t size)
{
  if (carray) {
    if (size > INT_MAX) {
      swig_type_info* pchar_descriptor = SWIG_pchar_descriptor();
      return pchar_descriptor ? 
	SWIG_InternalNewPointerObj(const_cast< char * >(carray), pchar_descriptor, 0) : SWIG_Py_Void();
    } else {
#if PY_VERSION_HEX >= 0x03000000
#if PY_VERSION_HEX >= 0x03010000
      return PyUnicode_DecodeUTF8(carray, static_cast< int >(size), "surrogateescape");
#else
      return PyUnicode_FromStringAndSize(carray, static_cast< int >(size));
#endif
#else
      return PyString_FromStringAndSize(carray, static_cast< int >(size));
#endif
    }
  } else {
    return SWIG_Py_Void();
  }
}


SWIGINTERNINLINE PyObject *
SWIG_From_std_string  (const std::string& s)
{
  return SWIG_FromCharPtrAndSize(s.data(), s.size());
}

SWIGINTERN void daal_data_management_interface1_DataArchive_getArchiveAsArray_(daal::data_management::interface1::DataArchive *self,daal::services::SharedPtr< daal::byte > *ptr,size_t *size){
            *size = self->getSizeOfArchive();
            *ptr  = self->getArchiveAsArraySharedPtr();
        }
SWIGINTERN void daal_data_management_interface1_InputDataArchive_getArchiveAsArray_(daal::data_management::interface1::InputDataArchive *self,daal::services::SharedPtr< daal::byte > *ptr,size_t *size){
            *size = self->getSizeOfArchive();
            *ptr  = self->getArchiveAsArraySharedPtr();
        }
SWIGINTERN daal::data_management::interface1::SerializationIfacePtr &daal_data_management_interface1_DataCollection___getitem__(daal::data_management::interface1::DataCollection *self,size_t i){
        return (*self)[i];
    }
SWIGINTERN daal::data_management::interface1::SerializationIfacePtr &daal_data_management_interface1_DataCollection___setitem__(daal::data_management::interface1::DataCollection *self,size_t i,daal::data_management::interface1::SerializationIfacePtr &v){
        return (*self)[i] = v;
    }

SWIGINTERN int
SWIG_AsCharPtrAndSize(PyObject *obj, char** cptr, size_t* psize, int *alloc)
{
#if PY_VERSION_HEX>=0x03000000
  if (PyUnicode_Check(obj))
#else  
  if (PyString_Check(obj))
#endif
  {
    char *cstr; Py_ssize_t len;
#if PY_VERSION_HEX>=0x03000000
    if (!alloc && cptr) {
        /* We can't allow converting without allocation, since the internal
           representation of string in Python 3 is UCS-2/UCS-4 but we require
           a UTF-8 representation.
           TODO(bhy) More detailed explanation */
        return SWIG_RuntimeError;
    }
    obj = PyUnicode_AsUTF8String(obj);
    PyBytes_AsStringAndSize(obj, &cstr, &len);
    if(alloc) *alloc = SWIG_NEWOBJ;
#else
    PyString_AsStringAndSize(obj, &cstr, &len);
#endif
    if (cptr) {
      if (alloc) {
	/* 
	   In python the user should not be able to modify the inner
	   string representation. To warranty that, if you define
	   SWIG_PYTHON_SAFE_CSTRINGS, a new/copy of the python string
	   buffer is always returned.

	   The default behavior is just to return the pointer value,
	   so, be careful.
	*/ 
#if defined(SWIG_PYTHON_SAFE_CSTRINGS)
	if (*alloc != SWIG_OLDOBJ) 
#else
	if (*alloc == SWIG_NEWOBJ) 
#endif
	  {
	    *cptr = reinterpret_cast< char* >(memcpy((new char[len + 1]), cstr, sizeof(char)*(len + 1)));
	    *alloc = SWIG_NEWOBJ;
	  }
	else {
	  *cptr = cstr;
	  *alloc = SWIG_OLDOBJ;
	}
      } else {
        #if PY_VERSION_HEX>=0x03000000
        assert(0); /* Should never reach here in Python 3 */
        #endif
	*cptr = SWIG_Python_str_AsChar(obj);
      }
    }
    if (psize) *psize = len + 1;
#if PY_VERSION_HEX>=0x03000000
    Py_XDECREF(obj);
#endif
    return SWIG_OK;
  } else {
    swig_type_info* pchar_descriptor = SWIG_pchar_descriptor();
    if (pchar_descriptor) {
      void* vptr = 0;
      if (SWIG_ConvertPtr(obj, &vptr, pchar_descriptor, 0) == SWIG_OK) {
	if (cptr) *cptr = (char *) vptr;
	if (psize) *psize = vptr ? (strlen((char *)vptr) + 1) : 0;
	if (alloc) *alloc = SWIG_OLDOBJ;
	return SWIG_OK;
      }
    }
  }
  return SWIG_TypeError;
}





SWIGINTERNINLINE PyObject * 
SWIG_FromCharPtr(const char *cptr)
{ 
  return SWIG_FromCharPtrAndSize(cptr, (cptr ? strlen(cptr) : 0));
}

SWIGINTERN void daal_data_management_interface1_DenseNumericTableIface_getBlockOfRowsAsDouble(daal::data_management::interface1::DenseNumericTableIface *self,size_t vector_idx,size_t vector_num,daal::data_management::interface1::BlockDescriptor< double > **block_){
                *block_ = new daal::data_management::BlockDescriptor<double>;
                self->getBlockOfRows(vector_idx, vector_num, daal::data_management::readOnly, **block_);
            }
SWIGINTERN void daal_data_management_interface1_DenseNumericTableIface_getBlockOfColumnValuesAsDouble(daal::data_management::interface1::DenseNumericTableIface *self,size_t feature_idx,size_t vector_idx,size_t value_num,daal::data_management::interface1::BlockDescriptor< double > **block_){
                *block_ = new daal::data_management::BlockDescriptor<double>;
                self->getBlockOfColumnValues(feature_idx, vector_idx, value_num, daal::data_management::readOnly, **block_);
            }
SWIGINTERN void daal_data_management_interface1_DenseNumericTableIface_getBlockOfRowsAsFloat(daal::data_management::interface1::DenseNumericTableIface *self,size_t vector_idx,size_t vector_num,daal::data_management::interface1::BlockDescriptor< float > **block_){
                *block_ = new daal::data_management::BlockDescriptor<float>;
                self->getBlockOfRows(vector_idx, vector_num, daal::data_management::readOnly, **block_);
            }
SWIGINTERN void daal_data_management_interface1_DenseNumericTableIface_getBlockOfColumnValuesAsFloat(daal::data_management::interface1::DenseNumericTableIface *self,size_t feature_idx,size_t vector_idx,size_t value_num,daal::data_management::interface1::BlockDescriptor< float > **block_){
                *block_ = new daal::data_management::BlockDescriptor<float>;
                self->getBlockOfColumnValues(feature_idx, vector_idx, value_num, daal::data_management::readOnly, **block_);
            }
SWIGINTERN void daal_data_management_interface1_DenseNumericTableIface_getBlockOfRowsAsInt(daal::data_management::interface1::DenseNumericTableIface *self,size_t vector_idx,size_t vector_num,daal::data_management::interface1::BlockDescriptor< int > **block_){
                *block_ = new daal::data_management::BlockDescriptor<int>;
                self->getBlockOfRows(vector_idx, vector_num, daal::data_management::readOnly, **block_);
            }
SWIGINTERN void daal_data_management_interface1_DenseNumericTableIface_getBlockOfColumnValuesAsInt(daal::data_management::interface1::DenseNumericTableIface *self,size_t feature_idx,size_t vector_idx,size_t value_num,daal::data_management::interface1::BlockDescriptor< int > **block_){
                *block_ = new daal::data_management::BlockDescriptor<int>;
                self->getBlockOfColumnValues(feature_idx, vector_idx, value_num, daal::data_management::readOnly, **block_);
            }

/* Getting isfinite working pre C99 across multiple platforms is non-trivial. Users can provide SWIG_isfinite on older platforms. */
#ifndef SWIG_isfinite
# if defined(isfinite)
#  define SWIG_isfinite(X) (isfinite(X))
# elif defined(_MSC_VER)
#  define SWIG_isfinite(X) (_finite(X))
# elif defined(__sun) && defined(__SVR4)
#  include <ieeefp.h>
#  define SWIG_isfinite(X) (finite(X))
# endif
#endif


/* Accept infinite as a valid float value unless we are unable to check if a value is finite */
#ifdef SWIG_isfinite
# define SWIG_Float_Overflow_Check(X) ((X < -FLT_MAX || X > FLT_MAX) && SWIG_isfinite(X))
#else
# define SWIG_Float_Overflow_Check(X) ((X < -FLT_MAX || X > FLT_MAX))
#endif


SWIGINTERN int
SWIG_AsVal_float (PyObject * obj, float *val)
{
  double v;
  int res = SWIG_AsVal_double (obj, &v);
  if (SWIG_IsOK(res)) {
    if (SWIG_Float_Overflow_Check(v)) {
      return SWIG_OverflowError;
    } else {
      if (val) *val = static_cast< float >(v);
    }
  }  
  return res;
}


  #define SWIG_From_double   PyFloat_FromDouble 


SWIGINTERNINLINE PyObject *
SWIG_From_float  (float value)
{    
  return SWIG_From_double  (value);
}

SWIGINTERN void daal_data_management_interface1_SOANumericTable_setArray(daal::data_management::interface1::SOANumericTable *self,PyArrayObject *ary,size_t idx){
            // assume we have a type check
            if( self->getDictionary() == NULL ) {
                self->setDictionary(new NumericTableDictionary());
            }
            Py_INCREF(ary);
            SET_NPY_FEATURE( ((PyArrayObject_fields *)ary)->descr->type, SETARRAY_ );
        }
SWIGINTERN PyObject *daal_data_management_interface1_SOANumericTable_getArray(daal::data_management::interface1::SOANumericTable *self,int index){
            int typenum = get_npy_type(self->getDictionary(), index);
            npy_intp dims = self->getNumberOfRows();
            void * data = self->getArray(index);
            return PyArray_SimpleNewFromData(1, &dims, typenum, data);
        }
SWIGINTERN daal::data_management::interface1::CSRNumericTable *new_daal_data_management_interface1_CSRNumericTable__SWIG_3(daal::services::SharedPtr< double > const &values,size_t nvals,daal::services::SharedPtr< size_t > const &colIndices,size_t ncols,daal::services::SharedPtr< size_t > const &rowOffsets,size_t noffs,size_t nColumns,size_t nRows){
            assert(nRows+1 == noffs);
            return new CSRNumericTable(values, colIndices, rowOffsets, nColumns, nRows);
        }
SWIGINTERN void daal_data_management_interface1_CSRNumericTable_setArrays__SWIG_2(daal::data_management::interface1::CSRNumericTable *self,daal::services::SharedPtr< double > const &values,size_t nvals,daal::services::SharedPtr< size_t > const &colIndices,size_t ncols,daal::services::SharedPtr< size_t > const &rowOffsets,size_t noffs){
             self->setArrays(values, colIndices, rowOffsets);
        }
SWIGINTERN daal::data_management::interface1::CSRNumericTable *new_daal_data_management_interface1_CSRNumericTable__SWIG_4(daal::services::SharedPtr< float > const &values,size_t nvals,daal::services::SharedPtr< size_t > const &colIndices,size_t ncols,daal::services::SharedPtr< size_t > const &rowOffsets,size_t noffs,size_t nColumns,size_t nRows){
            assert(nRows+1 == noffs);
            return new CSRNumericTable(values, colIndices, rowOffsets, nColumns, nRows);
        }
SWIGINTERN void daal_data_management_interface1_CSRNumericTable_setArrays__SWIG_3(daal::data_management::interface1::CSRNumericTable *self,daal::services::SharedPtr< float > const &values,size_t nvals,daal::services::SharedPtr< size_t > const &colIndices,size_t ncols,daal::services::SharedPtr< size_t > const &rowOffsets,size_t noffs){
             self->setArrays(values, colIndices, rowOffsets);
        }
SWIGINTERN daal::data_management::interface1::CSRNumericTable *new_daal_data_management_interface1_CSRNumericTable__SWIG_5(daal::services::SharedPtr< int > const &values,size_t nvals,daal::services::SharedPtr< size_t > const &colIndices,size_t ncols,daal::services::SharedPtr< size_t > const &rowOffsets,size_t noffs,size_t nColumns,size_t nRows){
            assert(nRows+1 == noffs);
            return new CSRNumericTable(values, colIndices, rowOffsets, nColumns, nRows);
        }
SWIGINTERN void daal_data_management_interface1_CSRNumericTable_setArrays__SWIG_4(daal::data_management::interface1::CSRNumericTable *self,daal::services::SharedPtr< int > const &values,size_t nvals,daal::services::SharedPtr< size_t > const &colIndices,size_t ncols,daal::services::SharedPtr< size_t > const &rowOffsets,size_t noffs){
             self->setArrays(values, colIndices, rowOffsets);
        }
SWIGINTERN PyObject *daal_data_management_interface1_CSRNumericTable_getArrays(daal::data_management::interface1::CSRNumericTable *self,size_t *as1_,daal::services::SharedPtr< size_t > *arr1_,size_t *as2_,daal::services::SharedPtr< size_t > *arr2_){
            // SWIG combines the return value and the 2 arg-out paramters into a 3-tuple, yey!
            *as1_ = self->getDataSize();
            *as2_ = self->getNumberOfRows() + 1;
            daal::services::SharedPtr<daal::byte> data;
            self->getArrays(data, *arr1_, *arr2_);
            npy_intp nv = (npy_intp)*as1_;
            int typenum = get_npy_type(self->getDictionary());
            return PyArray_SimpleNewFromData(1, &nv, typenum, data.get());
        }

SWIGINTERN int
SWIG_AsPtr_std_string (PyObject * obj, std::string **val) 
{
  char* buf = 0 ; size_t size = 0; int alloc = SWIG_OLDOBJ;
  if (SWIG_IsOK((SWIG_AsCharPtrAndSize(obj, &buf, &size, &alloc)))) {
    if (buf) {
      if (val) *val = new std::string(buf, size - 1);
      if (alloc == SWIG_NEWOBJ) delete[] buf;
      return SWIG_NEWOBJ;
    } else {
      if (val) *val = 0;
      return SWIG_OLDOBJ;
    }
  } else {
    static int init = 0;
    static swig_type_info* descriptor = 0;
    if (!init) {
      descriptor = SWIG_TypeQuery("std::string" " *");
      init = 1;
    }
    if (descriptor) {
      std::string *vptr;
      int res = SWIG_ConvertPtr(obj, (void**)&vptr, descriptor, 0);
      if (SWIG_IsOK(res) && val) *val = vptr;
      return res;
    }
  }
  return SWIG_ERROR;
}


SWIGINTERN int
SWIG_AsCharArray(PyObject * obj, char *val, size_t size)
{ 
  char* cptr = 0; size_t csize = 0; int alloc = SWIG_OLDOBJ;
  int res = SWIG_AsCharPtrAndSize(obj, &cptr, &csize, &alloc);
  if (SWIG_IsOK(res)) {
    /* special case of single char conversion when we don't need space for NUL */
    if (size == 1 && csize == 2 && cptr && !cptr[1]) --csize;
    if (csize <= size) {
      if (val) {
	if (csize) memcpy(val, cptr, csize*sizeof(char));
	if (csize < size) memset(val + csize, 0, (size - csize)*sizeof(char));
      }
      if (alloc == SWIG_NEWOBJ) {
	delete[] cptr;
	res = SWIG_DelNewMask(res);
      }      
      return res;
    }
    if (alloc == SWIG_NEWOBJ) delete[] cptr;
  }
  return SWIG_TypeError;
}


SWIGINTERN int
SWIG_AsVal_char (PyObject * obj, char *val)
{    
  int res = SWIG_AsCharArray(obj, val, 1);
  if (!SWIG_IsOK(res)) {
    long v;
    res = SWIG_AddCast(SWIG_AsVal_long (obj, &v));
    if (SWIG_IsOK(res)) {
      if ((CHAR_MIN <= v) && (v <= CHAR_MAX)) {
	if (val) *val = static_cast< char >(v);
      } else {
	res = SWIG_OverflowError;
      }
    }
  }
  return res;
}

SWIGINTERN daal::data_management::interface1::NumericTableFeature &daal_data_management_interface1_Dictionary_Sl_daal_data_management_interface1_NumericTableFeature_Sc_6000_Sg____getitem__(daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *self,size_t i){
        return (*self)[i];
    }
SWIGINTERN daal::data_management::interface1::NumericTableFeature &daal_data_management_interface1_Dictionary_Sl_daal_data_management_interface1_NumericTableFeature_Sc_6000_Sg____setitem__(daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *self,size_t i,daal::data_management::interface1::NumericTableFeature &v){
        return (*self)[i] = v;
    }
SWIGINTERN daal::data_management::interface1::DataSourceFeature &daal_data_management_interface1_Dictionary_Sl_daal_data_management_interface1_DataSourceFeature_Sc_6010_Sg____getitem__(daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *self,size_t i){
        return (*self)[i];
    }
SWIGINTERN daal::data_management::interface1::DataSourceFeature &daal_data_management_interface1_Dictionary_Sl_daal_data_management_interface1_DataSourceFeature_Sc_6010_Sg____setitem__(daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *self,size_t i,daal::data_management::interface1::DataSourceFeature &v){
        return (*self)[i] = v;
    }
SWIGINTERN void daal_data_management_interface1_BlockDescriptor_Sl_double_Sg__getArray(daal::data_management::interface1::BlockDescriptor< double > *self,daal::services::SharedPtr< double > *ptr,size_t *nColumns,size_t *nRows){
                *ptr = self->getBlockSharedPtr();
                *nColumns = self->getNumberOfColumns();
                *nRows = self->getNumberOfRows();
            }
SWIGINTERN void daal_data_management_interface1_BlockDescriptor_Sl_float_Sg__getArray(daal::data_management::interface1::BlockDescriptor< float > *self,daal::services::SharedPtr< float > *ptr,size_t *nColumns,size_t *nRows){
                *ptr = self->getBlockSharedPtr();
                *nColumns = self->getNumberOfColumns();
                *nRows = self->getNumberOfRows();
            }
SWIGINTERN void daal_data_management_interface1_BlockDescriptor_Sl_int_Sg__getArray(daal::data_management::interface1::BlockDescriptor< int > *self,daal::services::SharedPtr< int > *ptr,size_t *nColumns,size_t *nRows){
                *ptr = self->getBlockSharedPtr();
                *nColumns = self->getNumberOfColumns();
                *nRows = self->getNumberOfRows();
            }
SWIGINTERN void daal_data_management_interface1_CSRBlockDescriptor_Sl_double_Sg__getBlockColumnIndices(daal::data_management::interface1::CSRBlockDescriptor< double > const *self,size_t *as1_,daal::services::SharedPtr< size_t > *arr1_){
            *as1_ = self->getDataSize();
            *arr1_ = self->getBlockColumnIndicesSharedPtr();
        }
SWIGINTERN void daal_data_management_interface1_CSRBlockDescriptor_Sl_double_Sg__getBlockRowIndices(daal::data_management::interface1::CSRBlockDescriptor< double > const *self,size_t *as1_,daal::services::SharedPtr< size_t > *arr1_){
            *as1_ = self->getNumberOfRows() + 1;
            *arr1_ = self->getBlockRowIndicesSharedPtr();
        }
SWIGINTERN void daal_data_management_interface1_CSRBlockDescriptor_Sl_double_Sg__getBlockValues(daal::data_management::interface1::CSRBlockDescriptor< double > const *self,size_t *as_,daal::services::SharedPtr< double > *arr_){
            *as_ = self->getDataSize();
            *arr_ = self->getBlockValuesSharedPtr();
        }
SWIGINTERN void daal_data_management_interface1_CSRBlockDescriptor_Sl_float_Sg__getBlockColumnIndices(daal::data_management::interface1::CSRBlockDescriptor< float > const *self,size_t *as1_,daal::services::SharedPtr< size_t > *arr1_){
            *as1_ = self->getDataSize();
            *arr1_ = self->getBlockColumnIndicesSharedPtr();
        }
SWIGINTERN void daal_data_management_interface1_CSRBlockDescriptor_Sl_float_Sg__getBlockRowIndices(daal::data_management::interface1::CSRBlockDescriptor< float > const *self,size_t *as1_,daal::services::SharedPtr< size_t > *arr1_){
            *as1_ = self->getNumberOfRows() + 1;
            *arr1_ = self->getBlockRowIndicesSharedPtr();
        }
SWIGINTERN void daal_data_management_interface1_CSRBlockDescriptor_Sl_float_Sg__getBlockValues(daal::data_management::interface1::CSRBlockDescriptor< float > const *self,size_t *as_,daal::services::SharedPtr< float > *arr_){
            *as_ = self->getDataSize();
            *arr_ = self->getBlockValuesSharedPtr();
        }
SWIGINTERN void daal_data_management_interface1_CSRBlockDescriptor_Sl_int_Sg__getBlockColumnIndices(daal::data_management::interface1::CSRBlockDescriptor< int > const *self,size_t *as1_,daal::services::SharedPtr< size_t > *arr1_){
            *as1_ = self->getDataSize();
            *arr1_ = self->getBlockColumnIndicesSharedPtr();
        }
SWIGINTERN void daal_data_management_interface1_CSRBlockDescriptor_Sl_int_Sg__getBlockRowIndices(daal::data_management::interface1::CSRBlockDescriptor< int > const *self,size_t *as1_,daal::services::SharedPtr< size_t > *arr1_){
            *as1_ = self->getNumberOfRows() + 1;
            *arr1_ = self->getBlockRowIndicesSharedPtr();
        }
SWIGINTERN void daal_data_management_interface1_CSRBlockDescriptor_Sl_int_Sg__getBlockValues(daal::data_management::interface1::CSRBlockDescriptor< int > const *self,size_t *as_,daal::services::SharedPtr< int > *arr_){
            *as_ = self->getDataSize();
            *arr_ = self->getBlockValuesSharedPtr();
        }
SWIGINTERN double *daal_data_management_interface1_HomogenNumericTable_Sl_double_Sg____getitem__(daal::data_management::interface1::HomogenNumericTable< double > *self,size_t i){
        return (*self)[i];
    }
SWIGINTERN void daal_data_management_interface1_HomogenNumericTable_Sl_double_Sg__getArray(daal::data_management::interface1::HomogenNumericTable< double > *self,daal::services::SharedPtr< double > *ptr,size_t *nColumns,size_t *nRows){
                    *ptr = self->getArraySharedPtr();
                    *nColumns = self->getNumberOfColumns();
                    *nRows = self->getNumberOfRows();
                }
SWIGINTERN float *daal_data_management_interface1_HomogenNumericTable_Sl_float_Sg____getitem__(daal::data_management::interface1::HomogenNumericTable< float > *self,size_t i){
        return (*self)[i];
    }
SWIGINTERN void daal_data_management_interface1_HomogenNumericTable_Sl_float_Sg__getArray(daal::data_management::interface1::HomogenNumericTable< float > *self,daal::services::SharedPtr< float > *ptr,size_t *nColumns,size_t *nRows){
                    *ptr = self->getArraySharedPtr();
                    *nColumns = self->getNumberOfColumns();
                    *nRows = self->getNumberOfRows();
                }
SWIGINTERN int *daal_data_management_interface1_HomogenNumericTable_Sl_int_Sg____getitem__(daal::data_management::interface1::HomogenNumericTable< int > *self,size_t i){
        return (*self)[i];
    }
SWIGINTERN void daal_data_management_interface1_HomogenNumericTable_Sl_int_Sg__getArray(daal::data_management::interface1::HomogenNumericTable< int > *self,daal::services::SharedPtr< int > *ptr,size_t *nColumns,size_t *nRows){
                    *ptr = self->getArraySharedPtr();
                    *nColumns = self->getNumberOfColumns();
                    *nRows = self->getNumberOfRows();
                }
SWIGINTERN void daal_data_management_interface1_HomogenTensor_Sl_double_Sg__getArray(daal::data_management::interface1::HomogenTensor< double > *self,daal::services::Collection< size_t > const **nDims,daal::services::SharedPtr< double > *data){
                *nDims = &(self->getDimensions());
                *data = self->getArraySharedPtr();
            }
SWIGINTERN void daal_data_management_interface1_HomogenTensor_Sl_float_Sg__getArray(daal::data_management::interface1::HomogenTensor< float > *self,daal::services::Collection< size_t > const **nDims,daal::services::SharedPtr< float > *data){
                *nDims = &(self->getDimensions());
                *data = self->getArraySharedPtr();
            }
SWIGINTERN void daal_data_management_interface1_HomogenTensor_Sl_int_Sg__getArray(daal::data_management::interface1::HomogenTensor< int > *self,daal::services::Collection< size_t > const **nDims,daal::services::SharedPtr< int > *data){
                *nDims = &(self->getDimensions());
                *data = self->getArraySharedPtr();
            }
SWIGINTERN daal::services::interface1::SharedPtr< daal::data_management::interface1::SerializationIface > &daal_data_management_interface1_KeyValueCollection_Sl_daal_data_management_interface1_SerializationIface_Sg____getitem__(daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > *self,size_t i){
        return (*self)[i];
    }
SWIGINTERN daal::services::interface1::SharedPtr< daal::data_management::interface1::SerializationIface > &daal_data_management_interface1_KeyValueCollection_Sl_daal_data_management_interface1_SerializationIface_Sg____setitem__(daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > *self,size_t i,daal::services::interface1::SharedPtr< daal::data_management::interface1::SerializationIface > &v){
        return (*self)[i] = v;
    }
SWIGINTERN daal::services::interface1::SharedPtr< daal::algorithms::interface1::Input > &daal_data_management_interface1_KeyValueCollection_Sl_daal_algorithms_interface1_Input_Sg____getitem__(daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > *self,size_t i){
        return (*self)[i];
    }
SWIGINTERN daal::services::interface1::SharedPtr< daal::algorithms::interface1::Input > &daal_data_management_interface1_KeyValueCollection_Sl_daal_algorithms_interface1_Input_Sg____setitem__(daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > *self,size_t i,daal::services::interface1::SharedPtr< daal::algorithms::interface1::Input > &v){
        return (*self)[i] = v;
    }
SWIGINTERN daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > daal_data_management_interface1_Matrix_Sl_double_Sg__create__SWIG_30(daal::services::SharedPtr< double > const &ptr,size_t nColumns,size_t nRows){
            return Matrix<double>::create(nColumns, nRows, const_cast<daal::services::SharedPtr< double > &>(ptr));
        }
SWIGINTERN daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > daal_data_management_interface1_Matrix_Sl_double_Sg__create__SWIG_31(daal::services::SharedPtr< double > const &ptr,size_t nColumns,size_t nRows,double const &v){
            return Matrix<double>::create(nColumns, nRows, ptr, v);
        }
SWIGINTERN daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > daal_data_management_interface1_Matrix_Sl_float_Sg__create__SWIG_30(daal::services::SharedPtr< float > const &ptr,size_t nColumns,size_t nRows){
            return Matrix<float>::create(nColumns, nRows, const_cast<daal::services::SharedPtr< float > &>(ptr));
        }
SWIGINTERN daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > daal_data_management_interface1_Matrix_Sl_float_Sg__create__SWIG_31(daal::services::SharedPtr< float > const &ptr,size_t nColumns,size_t nRows,float const &v){
            return Matrix<float>::create(nColumns, nRows, ptr, v);
        }
SWIGINTERN daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > daal_data_management_interface1_Matrix_Sl_int_Sg__create__SWIG_30(daal::services::SharedPtr< int > const &ptr,size_t nColumns,size_t nRows){
            return Matrix<int>::create(nColumns, nRows, const_cast<daal::services::SharedPtr< int > &>(ptr));
        }
SWIGINTERN daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > daal_data_management_interface1_Matrix_Sl_int_Sg__create__SWIG_31(daal::services::SharedPtr< int > const &ptr,size_t nColumns,size_t nRows,int const &v){
            return Matrix<int>::create(nColumns, nRows, ptr, v);
        }
SWIGINTERN void daal_data_management_interface1_SubtensorDescriptor_Sl_double_Sg__getArray(daal::data_management::interface1::SubtensorDescriptor< double > *self,size_t *nDims,size_t **dimSizes,daal::services::SharedPtr< double > *data){
                *data = self->getSharedPtr();
                *nDims = self->getNumberOfDims();
                *dimSizes = self->getSubtensorDimSizes();
            }
SWIGINTERN PyObject *daal_data_management_interface1_SubtensorDescriptor_Sl_double_Sg__getSubtensorDimSizes(daal::data_management::interface1::SubtensorDescriptor< double > *self){
                npy_intp dims[1] = { (npy_intp)self->getNumberOfDims() };
                PyObject* array = PyArray_SimpleNew(1, dims, NPY_UINT64);
                if( ! array ) throw std::runtime_error("Creating Numpy array returned NULL");
                memcpy(array_data(array), self->getSubtensorDimSizes(), *dims * sizeof(size_t));
                return array;
            }
SWIGINTERN PyObject *daal_data_management_interface1_SubtensorDescriptor_Sl_double_Sg__getFixedDimNums(daal::data_management::interface1::SubtensorDescriptor< double > *self){
                npy_intp dims[1] = { (npy_intp)self->getFixedDims() };
                PyObject* array = PyArray_SimpleNew(1, dims, NPY_UINT64);
                if( ! array ) throw std::runtime_error("Creating Numpy array returned NULL");
                memcpy(array_data(array), self->getFixedDimNums(), *dims * sizeof(size_t));
                return array;
            }
SWIGINTERN void daal_data_management_interface1_SubtensorDescriptor_Sl_float_Sg__getArray(daal::data_management::interface1::SubtensorDescriptor< float > *self,size_t *nDims,size_t **dimSizes,daal::services::SharedPtr< float > *data){
                *data = self->getSharedPtr();
                *nDims = self->getNumberOfDims();
                *dimSizes = self->getSubtensorDimSizes();
            }
SWIGINTERN PyObject *daal_data_management_interface1_SubtensorDescriptor_Sl_float_Sg__getSubtensorDimSizes(daal::data_management::interface1::SubtensorDescriptor< float > *self){
                npy_intp dims[1] = { (npy_intp)self->getNumberOfDims() };
                PyObject* array = PyArray_SimpleNew(1, dims, NPY_UINT64);
                if( ! array ) throw std::runtime_error("Creating Numpy array returned NULL");
                memcpy(array_data(array), self->getSubtensorDimSizes(), *dims * sizeof(size_t));
                return array;
            }
SWIGINTERN PyObject *daal_data_management_interface1_SubtensorDescriptor_Sl_float_Sg__getFixedDimNums(daal::data_management::interface1::SubtensorDescriptor< float > *self){
                npy_intp dims[1] = { (npy_intp)self->getFixedDims() };
                PyObject* array = PyArray_SimpleNew(1, dims, NPY_UINT64);
                if( ! array ) throw std::runtime_error("Creating Numpy array returned NULL");
                memcpy(array_data(array), self->getFixedDimNums(), *dims * sizeof(size_t));
                return array;
            }
SWIGINTERN void daal_data_management_interface1_SubtensorDescriptor_Sl_int_Sg__getArray(daal::data_management::interface1::SubtensorDescriptor< int > *self,size_t *nDims,size_t **dimSizes,daal::services::SharedPtr< int > *data){
                *data = self->getSharedPtr();
                *nDims = self->getNumberOfDims();
                *dimSizes = self->getSubtensorDimSizes();
            }
SWIGINTERN PyObject *daal_data_management_interface1_SubtensorDescriptor_Sl_int_Sg__getSubtensorDimSizes(daal::data_management::interface1::SubtensorDescriptor< int > *self){
                npy_intp dims[1] = { (npy_intp)self->getNumberOfDims() };
                PyObject* array = PyArray_SimpleNew(1, dims, NPY_UINT64);
                if( ! array ) throw std::runtime_error("Creating Numpy array returned NULL");
                memcpy(array_data(array), self->getSubtensorDimSizes(), *dims * sizeof(size_t));
                return array;
            }
SWIGINTERN PyObject *daal_data_management_interface1_SubtensorDescriptor_Sl_int_Sg__getFixedDimNums(daal::data_management::interface1::SubtensorDescriptor< int > *self){
                npy_intp dims[1] = { (npy_intp)self->getFixedDims() };
                PyObject* array = PyArray_SimpleNew(1, dims, NPY_UINT64);
                if( ! array ) throw std::runtime_error("Creating Numpy array returned NULL");
                memcpy(array_data(array), self->getFixedDimNums(), *dims * sizeof(size_t));
                return array;
            }


/* ---------------------------------------------------
 * C++ director class methods
 * --------------------------------------------------- */

#include "_data_management.h"

#ifdef __cplusplus
extern "C" {
#endif
SWIGINTERN PyObject *_wrap_delete_SerializationIface(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SerializationIface *arg1 = (daal::data_management::interface1::SerializationIface *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SerializationIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SerializationIface > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_SerializationIface",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_SerializationIface" "', argument " "1"" of type '" "daal::data_management::interface1::SerializationIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SerializationIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SerializationIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SerializationIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SerializationIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SerializationIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_SerializationIface" "', argument " "1"" of type '" "daal::data_management::interface1::SerializationIface *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SerializationIface_serialize(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SerializationIface *arg1 = (daal::data_management::interface1::SerializationIface *) 0 ;
  daal::data_management::interface1::InputDataArchive *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SerializationIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SerializationIface > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::InputDataArchive > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:SerializationIface_serialize",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SerializationIface_serialize" "', argument " "1"" of type '" "daal::data_management::interface1::SerializationIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SerializationIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SerializationIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SerializationIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SerializationIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SerializationIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SerializationIface_serialize" "', argument " "1"" of type '" "daal::data_management::interface1::SerializationIface *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__InputDataArchive_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SerializationIface_serialize" "', argument " "2"" of type '" "daal::data_management::interface1::InputDataArchive &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SerializationIface_serialize" "', argument " "2"" of type '" "daal::data_management::interface1::InputDataArchive &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::InputDataArchive > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::InputDataArchive > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::InputDataArchive * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::InputDataArchive * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::InputDataArchive > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SerializationIface_serialize" "', argument " "2"" of type '" "daal::data_management::interface1::InputDataArchive &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->serialize(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SerializationIface_deserialize(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SerializationIface *arg1 = (daal::data_management::interface1::SerializationIface *) 0 ;
  daal::data_management::interface1::OutputDataArchive *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SerializationIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SerializationIface > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::OutputDataArchive > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:SerializationIface_deserialize",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SerializationIface_deserialize" "', argument " "1"" of type '" "daal::data_management::interface1::SerializationIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SerializationIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SerializationIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SerializationIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SerializationIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SerializationIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SerializationIface_deserialize" "', argument " "1"" of type '" "daal::data_management::interface1::SerializationIface *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__OutputDataArchive_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SerializationIface_deserialize" "', argument " "2"" of type '" "daal::data_management::interface1::OutputDataArchive &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SerializationIface_deserialize" "', argument " "2"" of type '" "daal::data_management::interface1::OutputDataArchive &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::OutputDataArchive > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::OutputDataArchive > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::OutputDataArchive * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::OutputDataArchive * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::OutputDataArchive > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SerializationIface_deserialize" "', argument " "2"" of type '" "daal::data_management::interface1::OutputDataArchive &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->deserialize(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SerializationIface_getSerializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SerializationIface *arg1 = (daal::data_management::interface1::SerializationIface *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SerializationIface const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SerializationIface const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:SerializationIface_getSerializationTag",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SerializationIface_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::SerializationIface const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SerializationIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SerializationIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SerializationIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SerializationIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SerializationIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SerializationIface_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::SerializationIface const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)((daal::data_management::interface1::SerializationIface const *)arg1)->getSerializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *SerializationIface_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_SerializationDesc(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SerializationDesc::creatorFunc arg1 = (daal::data_management::interface1::SerializationDesc::creatorFunc) 0 ;
  int arg2 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::data_management::interface1::SerializationDesc *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:new_SerializationDesc",&obj0,&obj1)) SWIG_fail;
  {
    int res = SWIG_ConvertFunctionPtr(obj0, (void**)(&arg1), SWIGTYPE_p_f___p_daal__data_management__interface1__SerializationIface);
    if (!SWIG_IsOK(res)) {
      SWIG_exception_fail(SWIG_ArgError(res), "in method '" "new_SerializationDesc" "', argument " "1"" of type '" "daal::data_management::interface1::SerializationDesc::creatorFunc""'"); 
    }
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "new_SerializationDesc" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::SerializationDesc *)new daal::data_management::interface1::SerializationDesc(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_daal__data_management__interface1__SerializationDesc, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SerializationDesc_tag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SerializationDesc *arg1 = (daal::data_management::interface1::SerializationDesc *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:SerializationDesc_tag",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__interface1__SerializationDesc, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SerializationDesc_tag" "', argument " "1"" of type '" "daal::data_management::interface1::SerializationDesc const *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::interface1::SerializationDesc * >(argp1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)((daal::data_management::interface1::SerializationDesc const *)arg1)->tag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SerializationDesc_creator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SerializationDesc *arg1 = (daal::data_management::interface1::SerializationDesc *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::SerializationDesc::creatorFunc result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:SerializationDesc_creator",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__interface1__SerializationDesc, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SerializationDesc_creator" "', argument " "1"" of type '" "daal::data_management::interface1::SerializationDesc const *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::interface1::SerializationDesc * >(argp1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::SerializationDesc::creatorFunc)((daal::data_management::interface1::SerializationDesc const *)arg1)->creator();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewFunctionPtrObj((void *)(result), SWIGTYPE_p_f___p_daal__data_management__interface1__SerializationIface);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SerializationDesc_next(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SerializationDesc *arg1 = (daal::data_management::interface1::SerializationDesc *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::SerializationDesc *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:SerializationDesc_next",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__interface1__SerializationDesc, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SerializationDesc_next" "', argument " "1"" of type '" "daal::data_management::interface1::SerializationDesc const *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::interface1::SerializationDesc * >(argp1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::SerializationDesc *)((daal::data_management::interface1::SerializationDesc const *)arg1)->next();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_daal__data_management__interface1__SerializationDesc, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SerializationDesc_first(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SerializationDesc *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":SerializationDesc_first")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::SerializationDesc *)daal::data_management::interface1::SerializationDesc::first();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_daal__data_management__interface1__SerializationDesc, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_SerializationDesc(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SerializationDesc *arg1 = (daal::data_management::interface1::SerializationDesc *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_SerializationDesc",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__interface1__SerializationDesc, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_SerializationDesc" "', argument " "1"" of type '" "daal::data_management::interface1::SerializationDesc *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::interface1::SerializationDesc * >(argp1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete arg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *SerializationDesc_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__data_management__interface1__SerializationDesc, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_DataBlock__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataBlock *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_DataBlock")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::DataBlock *)new daal::data_management::interface1::DataBlock();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::DataBlock > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::DataBlock >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_DataBlock(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataBlock *arg1 = (daal::data_management::interface1::DataBlock *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataBlock > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataBlock > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_DataBlock",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_DataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::DataBlock *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataBlock > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataBlock > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataBlock * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataBlock > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataBlock * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_DataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::DataBlock *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataBlock_getSize(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataBlock *arg1 = (daal::data_management::interface1::DataBlock *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataBlock const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataBlock const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataBlock_getSize",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataBlock_getSize" "', argument " "1"" of type '" "daal::data_management::interface1::DataBlock const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataBlock > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataBlock > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataBlock * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataBlock > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataBlock * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataBlock_getSize" "', argument " "1"" of type '" "daal::data_management::interface1::DataBlock const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::DataBlock const *)arg1)->getSize();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_DataBlock__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::byte *arg1 = (daal::byte *) 0 ;
  size_t arg2 ;
  PyArrayObject *array1 = NULL ;
  int i1 = 1 ;
  int is_new_object1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::DataBlock *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:new_DataBlock",&obj0)) SWIG_fail;
  {
    array1 = (FORCE_INPLACE == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj0, NPY_UBYTE)
      :obj_to_array_contiguous_allow_conversion(obj0, NPY_UBYTE, &is_new_object1));
    if (!array1 || !require_dimensions(array1, 1) || !require_contiguous(array1) || !require_native(array1)) SWIG_fail;
    arg1 = (unsigned char*) array_data(array1);
    arg2 = (size_t) array_size(array1,0);
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::DataBlock *)new_daal_data_management_interface1_DataBlock__SWIG_1(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::DataBlock > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::DataBlock >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object1 && array1) {
      Py_DECREF(array1);
    }
  }
  return resultobj;
fail:
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object1 && array1) {
      Py_DECREF(array1);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_DataBlock(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[2];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 1) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_new_DataBlock__SWIG_0(self, args);
  }
  if (argc == 1) {
    int _v;
    {
      _v = (FORCE_INPLACE == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_UBYTE))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      if (argc <= 1) {
        return _wrap_new_DataBlock__SWIG_1(self, args);
      }
      return _wrap_new_DataBlock__SWIG_1(self, args);
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'new_DataBlock'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::DataBlock::DataBlock()\n"
    "    daal::data_management::interface1::DataBlock::DataBlock(daal::byte *,size_t)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_DataBlock_getArray(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataBlock *arg1 = (daal::data_management::interface1::DataBlock *) 0 ;
  size_t *arg2 = (size_t *) 0 ;
  daal::services::SharedPtr< daal::byte > *arg3 = (daal::services::SharedPtr< daal::byte > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataBlock > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataBlock > *smartarg1 = 0 ;
  daal::services::SharedPtr< unsigned char > data_temp2 ;
  size_t dim_temp2 ;
  PyObject * obj0 = 0 ;
  
  {
    arg2 = &dim_temp2;
    arg3 = &data_temp2;
  }
  if (!PyArg_ParseTuple(args,(char *)"O:DataBlock_getArray",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataBlock_getArray" "', argument " "1"" of type '" "daal::data_management::interface1::DataBlock *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataBlock > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataBlock > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataBlock * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataBlock > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataBlock * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataBlock_getArray" "', argument " "1"" of type '" "daal::data_management::interface1::DataBlock *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        daal_data_management_interface1_DataBlock_getArray(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    npy_intp dims[1] = {
      static_cast<npy_intp>(*arg2) 
    }; // Intel/FS static-cast
    PyObject* obj = PyArray_SimpleNewFromData(1, dims, NPY_UBYTE, (void*)(arg3->get()));
    if (!obj) SWIG_fail;
    set_sp_base((PyArrayObject*)obj, *arg3);
    resultobj = SWIG_Python_AppendOutput(resultobj,obj);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataBlock_setArray(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataBlock *arg1 = (daal::data_management::interface1::DataBlock *) 0 ;
  daal::byte *arg2 = (daal::byte *) 0 ;
  size_t arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataBlock > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataBlock > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int i2 = 1 ;
  int is_new_object2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DataBlock_setArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataBlock_setArray" "', argument " "1"" of type '" "daal::data_management::interface1::DataBlock *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataBlock > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataBlock > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataBlock * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataBlock > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataBlock * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataBlock_setArray" "', argument " "1"" of type '" "daal::data_management::interface1::DataBlock *""'"); 
  }
  {
    array2 = (FORCE_INPLACE == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UBYTE)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UBYTE, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (unsigned char*) array_data(array2);
    arg3 = (size_t) array_size(array2,0);
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        daal_data_management_interface1_DataBlock_setArray(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *DataBlock_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *defaultLevel_swigconstant(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *module;
  PyObject *d;
  if (!PyArg_ParseTuple(args,(char*)"O:swigconstant", &module)) return NULL;
  d = PyModule_GetDict(module);
  if (!d) return NULL;
  SWIG_Python_SetConstant(d, "defaultLevel",SWIG_From_int(static_cast< int >(daal::data_management::defaultLevel)));
  return SWIG_Py_Void();
}


SWIGINTERN PyObject *level0_swigconstant(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *module;
  PyObject *d;
  if (!PyArg_ParseTuple(args,(char*)"O:swigconstant", &module)) return NULL;
  d = PyModule_GetDict(module);
  if (!d) return NULL;
  SWIG_Python_SetConstant(d, "level0",SWIG_From_int(static_cast< int >(daal::data_management::level0)));
  return SWIG_Py_Void();
}


SWIGINTERN PyObject *level1_swigconstant(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *module;
  PyObject *d;
  if (!PyArg_ParseTuple(args,(char*)"O:swigconstant", &module)) return NULL;
  d = PyModule_GetDict(module);
  if (!d) return NULL;
  SWIG_Python_SetConstant(d, "level1",SWIG_From_int(static_cast< int >(daal::data_management::level1)));
  return SWIG_Py_Void();
}


SWIGINTERN PyObject *level2_swigconstant(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *module;
  PyObject *d;
  if (!PyArg_ParseTuple(args,(char*)"O:swigconstant", &module)) return NULL;
  d = PyModule_GetDict(module);
  if (!d) return NULL;
  SWIG_Python_SetConstant(d, "level2",SWIG_From_int(static_cast< int >(daal::data_management::level2)));
  return SWIG_Py_Void();
}


SWIGINTERN PyObject *level3_swigconstant(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *module;
  PyObject *d;
  if (!PyArg_ParseTuple(args,(char*)"O:swigconstant", &module)) return NULL;
  d = PyModule_GetDict(module);
  if (!d) return NULL;
  SWIG_Python_SetConstant(d, "level3",SWIG_From_int(static_cast< int >(daal::data_management::level3)));
  return SWIG_Py_Void();
}


SWIGINTERN PyObject *level4_swigconstant(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *module;
  PyObject *d;
  if (!PyArg_ParseTuple(args,(char*)"O:swigconstant", &module)) return NULL;
  d = PyModule_GetDict(module);
  if (!d) return NULL;
  SWIG_Python_SetConstant(d, "level4",SWIG_From_int(static_cast< int >(daal::data_management::level4)));
  return SWIG_Py_Void();
}


SWIGINTERN PyObject *level5_swigconstant(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *module;
  PyObject *d;
  if (!PyArg_ParseTuple(args,(char*)"O:swigconstant", &module)) return NULL;
  d = PyModule_GetDict(module);
  if (!d) return NULL;
  SWIG_Python_SetConstant(d, "level5",SWIG_From_int(static_cast< int >(daal::data_management::level5)));
  return SWIG_Py_Void();
}


SWIGINTERN PyObject *level6_swigconstant(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *module;
  PyObject *d;
  if (!PyArg_ParseTuple(args,(char*)"O:swigconstant", &module)) return NULL;
  d = PyModule_GetDict(module);
  if (!d) return NULL;
  SWIG_Python_SetConstant(d, "level6",SWIG_From_int(static_cast< int >(daal::data_management::level6)));
  return SWIG_Py_Void();
}


SWIGINTERN PyObject *level7_swigconstant(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *module;
  PyObject *d;
  if (!PyArg_ParseTuple(args,(char*)"O:swigconstant", &module)) return NULL;
  d = PyModule_GetDict(module);
  if (!d) return NULL;
  SWIG_Python_SetConstant(d, "level7",SWIG_From_int(static_cast< int >(daal::data_management::level7)));
  return SWIG_Py_Void();
}


SWIGINTERN PyObject *level8_swigconstant(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *module;
  PyObject *d;
  if (!PyArg_ParseTuple(args,(char*)"O:swigconstant", &module)) return NULL;
  d = PyModule_GetDict(module);
  if (!d) return NULL;
  SWIG_Python_SetConstant(d, "level8",SWIG_From_int(static_cast< int >(daal::data_management::level8)));
  return SWIG_Py_Void();
}


SWIGINTERN PyObject *level9_swigconstant(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *module;
  PyObject *d;
  if (!PyArg_ParseTuple(args,(char*)"O:swigconstant", &module)) return NULL;
  d = PyModule_GetDict(module);
  if (!d) return NULL;
  SWIG_Python_SetConstant(d, "level9",SWIG_From_int(static_cast< int >(daal::data_management::level9)));
  return SWIG_Py_Void();
}


SWIGINTERN PyObject *lastCompressionLevel_swigconstant(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *module;
  PyObject *d;
  if (!PyArg_ParseTuple(args,(char*)"O:swigconstant", &module)) return NULL;
  d = PyModule_GetDict(module);
  if (!d) return NULL;
  SWIG_Python_SetConstant(d, "lastCompressionLevel",SWIG_From_int(static_cast< int >(daal::data_management::lastCompressionLevel)));
  return SWIG_Py_Void();
}


SWIGINTERN PyObject *zlib_swigconstant(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *module;
  PyObject *d;
  if (!PyArg_ParseTuple(args,(char*)"O:swigconstant", &module)) return NULL;
  d = PyModule_GetDict(module);
  if (!d) return NULL;
  SWIG_Python_SetConstant(d, "zlib",SWIG_From_int(static_cast< int >(daal::data_management::zlib)));
  return SWIG_Py_Void();
}


SWIGINTERN PyObject *lzo_swigconstant(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *module;
  PyObject *d;
  if (!PyArg_ParseTuple(args,(char*)"O:swigconstant", &module)) return NULL;
  d = PyModule_GetDict(module);
  if (!d) return NULL;
  SWIG_Python_SetConstant(d, "lzo",SWIG_From_int(static_cast< int >(daal::data_management::lzo)));
  return SWIG_Py_Void();
}


SWIGINTERN PyObject *rle_swigconstant(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *module;
  PyObject *d;
  if (!PyArg_ParseTuple(args,(char*)"O:swigconstant", &module)) return NULL;
  d = PyModule_GetDict(module);
  if (!d) return NULL;
  SWIG_Python_SetConstant(d, "rle",SWIG_From_int(static_cast< int >(daal::data_management::rle)));
  return SWIG_Py_Void();
}


SWIGINTERN PyObject *bzip2_swigconstant(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *module;
  PyObject *d;
  if (!PyArg_ParseTuple(args,(char*)"O:swigconstant", &module)) return NULL;
  d = PyModule_GetDict(module);
  if (!d) return NULL;
  SWIG_Python_SetConstant(d, "bzip2",SWIG_From_int(static_cast< int >(daal::data_management::bzip2)));
  return SWIG_Py_Void();
}


SWIGINTERN PyObject *_wrap_CompressionParameter_level_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CompressionParameter *arg1 = (daal::data_management::interface1::CompressionParameter *) 0 ;
  daal::data_management::CompressionLevel arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:CompressionParameter_level_set",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__interface1__CompressionParameter, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CompressionParameter_level_set" "', argument " "1"" of type '" "daal::data_management::interface1::CompressionParameter *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::interface1::CompressionParameter * >(argp1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CompressionParameter_level_set" "', argument " "2"" of type '" "daal::data_management::CompressionLevel""'");
  } 
  arg2 = static_cast< daal::data_management::CompressionLevel >(val2);
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    if (arg1) (arg1)->level = arg2;
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CompressionParameter_level_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CompressionParameter *arg1 = (daal::data_management::interface1::CompressionParameter *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::CompressionLevel result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:CompressionParameter_level_get",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__interface1__CompressionParameter, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CompressionParameter_level_get" "', argument " "1"" of type '" "daal::data_management::interface1::CompressionParameter *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::interface1::CompressionParameter * >(argp1);
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    result = (daal::data_management::CompressionLevel) ((arg1)->level);
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_CompressionParameter__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::CompressionLevel arg1 ;
  int val1 ;
  int ecode1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::CompressionParameter *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:new_CompressionParameter",&obj0)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_CompressionParameter" "', argument " "1"" of type '" "daal::data_management::CompressionLevel""'");
  } 
  arg1 = static_cast< daal::data_management::CompressionLevel >(val1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::CompressionParameter *)new daal::data_management::interface1::CompressionParameter(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_daal__data_management__interface1__CompressionParameter, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_CompressionParameter__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CompressionParameter *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_CompressionParameter")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::CompressionParameter *)new daal::data_management::interface1::CompressionParameter();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_daal__data_management__interface1__CompressionParameter, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_CompressionParameter(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[2];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 1) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_new_CompressionParameter__SWIG_1(self, args);
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_new_CompressionParameter__SWIG_0(self, args);
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'new_CompressionParameter'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::CompressionParameter::CompressionParameter(daal::data_management::CompressionLevel)\n"
    "    daal::data_management::interface1::CompressionParameter::CompressionParameter()\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_CompressionParameter(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CompressionParameter *arg1 = (daal::data_management::interface1::CompressionParameter *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_CompressionParameter",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__interface1__CompressionParameter, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_CompressionParameter" "', argument " "1"" of type '" "daal::data_management::interface1::CompressionParameter *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::interface1::CompressionParameter * >(argp1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete arg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *CompressionParameter_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__data_management__interface1__CompressionParameter, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_CompressionIface_setInputDataBlock(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CompressionIface *arg1 = (daal::data_management::interface1::CompressionIface *) 0 ;
  daal::byte *arg2 = (daal::byte *) 0 ;
  size_t arg3 ;
  size_t arg4 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CompressionIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CompressionIface > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int i2 = 1 ;
  int is_new_object2 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:CompressionIface_setInputDataBlock",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CompressionIface_setInputDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::CompressionIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressionIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressionIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CompressionIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressionIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CompressionIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CompressionIface_setInputDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::CompressionIface *""'"); 
  }
  {
    array2 = (FORCE_INPLACE == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UBYTE)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UBYTE, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (unsigned char*) array_data(array2);
    arg3 = (size_t) array_size(array2,0);
  }
  ecode4 = SWIG_AsVal_size_t(obj2, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "CompressionIface_setInputDataBlock" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->setInputDataBlock(arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_CompressionIface_isOutputDataBlockFull(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CompressionIface *arg1 = (daal::data_management::interface1::CompressionIface *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CompressionIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CompressionIface > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:CompressionIface_isOutputDataBlockFull",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CompressionIface_isOutputDataBlockFull" "', argument " "1"" of type '" "daal::data_management::interface1::CompressionIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressionIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressionIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CompressionIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressionIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CompressionIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CompressionIface_isOutputDataBlockFull" "', argument " "1"" of type '" "daal::data_management::interface1::CompressionIface *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (bool)(arg1)->isOutputDataBlockFull();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CompressionIface_getUsedOutputDataBlockSize(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CompressionIface *arg1 = (daal::data_management::interface1::CompressionIface *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CompressionIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CompressionIface > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:CompressionIface_getUsedOutputDataBlockSize",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CompressionIface_getUsedOutputDataBlockSize" "', argument " "1"" of type '" "daal::data_management::interface1::CompressionIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressionIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressionIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CompressionIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressionIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CompressionIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CompressionIface_getUsedOutputDataBlockSize" "', argument " "1"" of type '" "daal::data_management::interface1::CompressionIface *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getUsedOutputDataBlockSize();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CompressionIface_run(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CompressionIface *arg1 = (daal::data_management::interface1::CompressionIface *) 0 ;
  daal::byte *arg2 = (daal::byte *) 0 ;
  size_t arg3 ;
  size_t arg4 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CompressionIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CompressionIface > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int i2 = 1 ;
  int is_new_object2 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:CompressionIface_run",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CompressionIface_run" "', argument " "1"" of type '" "daal::data_management::interface1::CompressionIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressionIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressionIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CompressionIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressionIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CompressionIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CompressionIface_run" "', argument " "1"" of type '" "daal::data_management::interface1::CompressionIface *""'"); 
  }
  {
    array2 = (FORCE_INPLACE == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UBYTE)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UBYTE, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (unsigned char*) array_data(array2);
    arg3 = (size_t) array_size(array2,0);
  }
  ecode4 = SWIG_AsVal_size_t(obj2, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "CompressionIface_run" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->run(arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_CompressionIface(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CompressionIface *arg1 = (daal::data_management::interface1::CompressionIface *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CompressionIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CompressionIface > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_CompressionIface",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_CompressionIface" "', argument " "1"" of type '" "daal::data_management::interface1::CompressionIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressionIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressionIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CompressionIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressionIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CompressionIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_CompressionIface" "', argument " "1"" of type '" "daal::data_management::interface1::CompressionIface *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *CompressionIface_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_Compression_setInputDataBlock(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Compression *arg1 = (daal::data_management::interface1::Compression *) 0 ;
  daal::byte *arg2 = (daal::byte *) 0 ;
  size_t arg3 ;
  size_t arg4 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compression > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compression > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int i2 = 1 ;
  int is_new_object2 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Compression_setInputDataBlock",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Compression_setInputDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::Compression *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compression > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compression > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compression * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compression > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compression * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Compression_setInputDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::Compression *""'"); 
  }
  {
    array2 = (FORCE_INPLACE == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UBYTE)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UBYTE, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (unsigned char*) array_data(array2);
    arg3 = (size_t) array_size(array2,0);
  }
  ecode4 = SWIG_AsVal_size_t(obj2, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Compression_setInputDataBlock" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->setInputDataBlock(arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_Compression_isOutputDataBlockFull(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Compression *arg1 = (daal::data_management::interface1::Compression *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compression > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compression > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Compression_isOutputDataBlockFull",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Compression_isOutputDataBlockFull" "', argument " "1"" of type '" "daal::data_management::interface1::Compression *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compression > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compression > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compression * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compression > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compression * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Compression_isOutputDataBlockFull" "', argument " "1"" of type '" "daal::data_management::interface1::Compression *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (bool)(arg1)->isOutputDataBlockFull();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Compression_getUsedOutputDataBlockSize(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Compression *arg1 = (daal::data_management::interface1::Compression *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compression > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compression > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Compression_getUsedOutputDataBlockSize",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Compression_getUsedOutputDataBlockSize" "', argument " "1"" of type '" "daal::data_management::interface1::Compression *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compression > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compression > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compression * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compression > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compression * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Compression_getUsedOutputDataBlockSize" "', argument " "1"" of type '" "daal::data_management::interface1::Compression *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getUsedOutputDataBlockSize();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Compression_run(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Compression *arg1 = (daal::data_management::interface1::Compression *) 0 ;
  daal::byte *arg2 = (daal::byte *) 0 ;
  size_t arg3 ;
  size_t arg4 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compression > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compression > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int i2 = 1 ;
  int is_new_object2 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Compression_run",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Compression_run" "', argument " "1"" of type '" "daal::data_management::interface1::Compression *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compression > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compression > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compression * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compression > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compression * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Compression_run" "', argument " "1"" of type '" "daal::data_management::interface1::Compression *""'"); 
  }
  {
    array2 = (FORCE_INPLACE == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UBYTE)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UBYTE, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (unsigned char*) array_data(array2);
    arg3 = (size_t) array_size(array2,0);
  }
  ecode4 = SWIG_AsVal_size_t(obj2, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Compression_run" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->run(arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_Compression(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Compression *arg1 = (daal::data_management::interface1::Compression *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compression > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compression > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_Compression",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Compression" "', argument " "1"" of type '" "daal::data_management::interface1::Compression *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compression > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compression > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compression * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compression > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compression * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Compression" "', argument " "1"" of type '" "daal::data_management::interface1::Compression *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Compression_checkInputParams(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Compression *arg1 = (daal::data_management::interface1::Compression *) 0 ;
  daal::byte *arg2 = (daal::byte *) 0 ;
  size_t arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compression > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compression > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int i2 = 1 ;
  int is_new_object2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Compression_checkInputParams",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Compression_checkInputParams" "', argument " "1"" of type '" "daal::data_management::interface1::Compression *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compression > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compression > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compression * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compression > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compression * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Compression_checkInputParams" "', argument " "1"" of type '" "daal::data_management::interface1::Compression *""'"); 
  }
  {
    array2 = (FORCE_INPLACE == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UBYTE)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UBYTE, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (unsigned char*) array_data(array2);
    arg3 = (size_t) array_size(array2,0);
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->checkInputParams(arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_Compression_checkOutputParams(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Compression *arg1 = (daal::data_management::interface1::Compression *) 0 ;
  daal::byte *arg2 = (daal::byte *) 0 ;
  size_t arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compression > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compression > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int i2 = 1 ;
  int is_new_object2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Compression_checkOutputParams",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Compression_checkOutputParams" "', argument " "1"" of type '" "daal::data_management::interface1::Compression *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compression > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compression > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compression * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compression > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compression * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Compression_checkOutputParams" "', argument " "1"" of type '" "daal::data_management::interface1::Compression *""'"); 
  }
  {
    array2 = (FORCE_INPLACE == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UBYTE)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UBYTE, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (unsigned char*) array_data(array2);
    arg3 = (size_t) array_size(array2,0);
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->checkOutputParams(arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *Compression_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_delete_CompressorImpl(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CompressorImpl *arg1 = (daal::data_management::interface1::CompressorImpl *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CompressorImpl > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CompressorImpl > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_CompressorImpl",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_CompressorImpl" "', argument " "1"" of type '" "daal::data_management::interface1::CompressorImpl *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressorImpl > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressorImpl > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CompressorImpl * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressorImpl > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CompressorImpl * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_CompressorImpl" "', argument " "1"" of type '" "daal::data_management::interface1::CompressorImpl *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *CompressorImpl_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_delete_DecompressorImpl(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DecompressorImpl *arg1 = (daal::data_management::interface1::DecompressorImpl *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DecompressorImpl > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DecompressorImpl > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_DecompressorImpl",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_DecompressorImpl" "', argument " "1"" of type '" "daal::data_management::interface1::DecompressorImpl *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DecompressorImpl > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DecompressorImpl > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DecompressorImpl * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DecompressorImpl > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DecompressorImpl * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_DecompressorImpl" "', argument " "1"" of type '" "daal::data_management::interface1::DecompressorImpl *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *DecompressorImpl_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_CompressionStream__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CompressorImpl *arg1 = (daal::data_management::interface1::CompressorImpl *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CompressorImpl > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CompressorImpl > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::data_management::interface1::CompressionStream *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:new_CompressionStream",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_CompressionStream" "', argument " "1"" of type '" "daal::data_management::interface1::CompressorImpl *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressorImpl > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressorImpl > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CompressorImpl * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressorImpl > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CompressorImpl * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_CompressionStream" "', argument " "1"" of type '" "daal::data_management::interface1::CompressorImpl *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "new_CompressionStream" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::CompressionStream *)new daal::data_management::interface1::CompressionStream(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::CompressionStream > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::CompressionStream >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionStream_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_CompressionStream__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CompressorImpl *arg1 = (daal::data_management::interface1::CompressorImpl *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CompressorImpl > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CompressorImpl > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::CompressionStream *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:new_CompressionStream",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_CompressionStream" "', argument " "1"" of type '" "daal::data_management::interface1::CompressorImpl *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressorImpl > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressorImpl > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CompressorImpl * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressorImpl > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CompressorImpl * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_CompressionStream" "', argument " "1"" of type '" "daal::data_management::interface1::CompressorImpl *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::CompressionStream *)new daal::data_management::interface1::CompressionStream(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::CompressionStream > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::CompressionStream >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionStream_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_CompressionStream(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_CompressionStream__SWIG_1(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_new_CompressionStream__SWIG_0(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'new_CompressionStream'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::CompressionStream::CompressionStream(daal::data_management::interface1::CompressorImpl *,size_t)\n"
    "    daal::data_management::interface1::CompressionStream::CompressionStream(daal::data_management::interface1::CompressorImpl *)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_CompressionStream(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CompressionStream *arg1 = (daal::data_management::interface1::CompressionStream *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CompressionStream > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CompressionStream > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_CompressionStream",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionStream_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_CompressionStream" "', argument " "1"" of type '" "daal::data_management::interface1::CompressionStream *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressionStream > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressionStream > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CompressionStream * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressionStream > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CompressionStream * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_CompressionStream" "', argument " "1"" of type '" "daal::data_management::interface1::CompressionStream *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CompressionStream___lshift__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CompressionStream *arg1 = (daal::data_management::interface1::CompressionStream *) 0 ;
  daal::data_management::interface1::DataBlock arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CompressionStream > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CompressionStream > *smartarg1 = 0 ;
  void *argp2 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:CompressionStream___lshift__",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionStream_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CompressionStream___lshift__" "', argument " "1"" of type '" "daal::data_management::interface1::CompressionStream *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressionStream > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressionStream > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CompressionStream * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressionStream > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CompressionStream * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CompressionStream___lshift__" "', argument " "1"" of type '" "daal::data_management::interface1::CompressionStream *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CompressionStream___lshift__" "', argument " "2"" of type '" "daal::data_management::interface1::DataBlock""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CompressionStream___lshift__" "', argument " "2"" of type '" "daal::data_management::interface1::DataBlock""'");
    } else {
      arg2 = *(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataBlock > * >(argp2)->get());
      if (newmem & SWIG_CAST_NEW_MEMORY) delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataBlock > * >(argp2);
    }
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->operator <<(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CompressionStream_getCompressedBlocksCollection(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CompressionStream *arg1 = (daal::data_management::interface1::CompressionStream *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CompressionStream > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CompressionStream > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::DataBlockCollectionPtr result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:CompressionStream_getCompressedBlocksCollection",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionStream_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CompressionStream_getCompressedBlocksCollection" "', argument " "1"" of type '" "daal::data_management::interface1::CompressionStream *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressionStream > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressionStream > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CompressionStream * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressionStream > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CompressionStream * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CompressionStream_getCompressedBlocksCollection" "', argument " "1"" of type '" "daal::data_management::interface1::CompressionStream *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getCompressedBlocksCollection();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::services::interface1::Collection< daal::services::SharedPtr< daal::data_management::interface1::DataBlock > > > *smartresult = result ? new daal::services::SharedPtr<  daal::services::interface1::Collection< daal::services::SharedPtr< daal::data_management::interface1::DataBlock > > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CompressionStream_getCompressedDataSize(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CompressionStream *arg1 = (daal::data_management::interface1::CompressionStream *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CompressionStream > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CompressionStream > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:CompressionStream_getCompressedDataSize",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionStream_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CompressionStream_getCompressedDataSize" "', argument " "1"" of type '" "daal::data_management::interface1::CompressionStream *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressionStream > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressionStream > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CompressionStream * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressionStream > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CompressionStream * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CompressionStream_getCompressedDataSize" "', argument " "1"" of type '" "daal::data_management::interface1::CompressionStream *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getCompressedDataSize();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CompressionStream_copyCompressedArray__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CompressionStream *arg1 = (daal::data_management::interface1::CompressionStream *) 0 ;
  daal::byte *arg2 = (daal::byte *) 0 ;
  size_t arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CompressionStream > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CompressionStream > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int i2 = 1 ;
  int is_new_object2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:CompressionStream_copyCompressedArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionStream_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CompressionStream_copyCompressedArray" "', argument " "1"" of type '" "daal::data_management::interface1::CompressionStream *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressionStream > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressionStream > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CompressionStream * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressionStream > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CompressionStream * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CompressionStream_copyCompressedArray" "', argument " "1"" of type '" "daal::data_management::interface1::CompressionStream *""'"); 
  }
  {
    array2 = (FORCE_INPLACE == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UBYTE)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UBYTE, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (unsigned char*) array_data(array2);
    arg3 = (size_t) array_size(array2,0);
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->copyCompressedArray(arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_CompressionStream_copyCompressedArray__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CompressionStream *arg1 = (daal::data_management::interface1::CompressionStream *) 0 ;
  daal::data_management::interface1::DataBlock *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CompressionStream > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CompressionStream > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataBlock > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:CompressionStream_copyCompressedArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionStream_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CompressionStream_copyCompressedArray" "', argument " "1"" of type '" "daal::data_management::interface1::CompressionStream *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressionStream > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressionStream > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CompressionStream * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressionStream > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CompressionStream * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CompressionStream_copyCompressedArray" "', argument " "1"" of type '" "daal::data_management::interface1::CompressionStream *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CompressionStream_copyCompressedArray" "', argument " "2"" of type '" "daal::data_management::interface1::DataBlock &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CompressionStream_copyCompressedArray" "', argument " "2"" of type '" "daal::data_management::interface1::DataBlock &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataBlock > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataBlock > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::DataBlock * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::DataBlock * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataBlock > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CompressionStream_copyCompressedArray" "', argument " "2"" of type '" "daal::data_management::interface1::DataBlock &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->copyCompressedArray(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CompressionStream_copyCompressedArray(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionStream_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_CompressionStream_copyCompressedArray__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionStream_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = (FORCE_INPLACE == FORCE_INPLACE
          ? (is_array(argv[1]) && PyArray_EquivTypenums(array_type(argv[1]), NPY_UBYTE))
          :(is_array(argv[1]) || PySequence_Check(argv[1])));
      }
      if (_v) {
        if (argc <= 2) {
          return _wrap_CompressionStream_copyCompressedArray__SWIG_0(self, args);
        }
        return _wrap_CompressionStream_copyCompressedArray__SWIG_0(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'CompressionStream_copyCompressedArray'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::CompressionStream::copyCompressedArray(daal::byte *,size_t)\n"
    "    daal::data_management::interface1::CompressionStream::copyCompressedArray(daal::data_management::interface1::DataBlock &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_CompressionStream_push_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CompressionStream *arg1 = (daal::data_management::interface1::CompressionStream *) 0 ;
  daal::byte *arg2 = (daal::byte *) 0 ;
  size_t arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CompressionStream > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CompressionStream > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int i2 = 1 ;
  int is_new_object2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:CompressionStream_push_back",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionStream_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CompressionStream_push_back" "', argument " "1"" of type '" "daal::data_management::interface1::CompressionStream *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressionStream > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressionStream > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CompressionStream * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressionStream > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CompressionStream * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CompressionStream_push_back" "', argument " "1"" of type '" "daal::data_management::interface1::CompressionStream *""'"); 
  }
  {
    array2 = (FORCE_INPLACE == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UBYTE)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UBYTE, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (unsigned char*) array_data(array2);
    arg3 = (size_t) array_size(array2,0);
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        daal_data_management_interface1_CompressionStream_push_back(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *CompressionStream_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionStream_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_DecompressionStream__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DecompressorImpl *arg1 = (daal::data_management::interface1::DecompressorImpl *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DecompressorImpl > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DecompressorImpl > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::data_management::interface1::DecompressionStream *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:new_DecompressionStream",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_DecompressionStream" "', argument " "1"" of type '" "daal::data_management::interface1::DecompressorImpl *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DecompressorImpl > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DecompressorImpl > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DecompressorImpl * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DecompressorImpl > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DecompressorImpl * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_DecompressionStream" "', argument " "1"" of type '" "daal::data_management::interface1::DecompressorImpl *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "new_DecompressionStream" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::DecompressionStream *)new daal::data_management::interface1::DecompressionStream(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::DecompressionStream > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::DecompressionStream >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressionStream_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_DecompressionStream__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DecompressorImpl *arg1 = (daal::data_management::interface1::DecompressorImpl *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DecompressorImpl > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DecompressorImpl > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::DecompressionStream *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:new_DecompressionStream",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_DecompressionStream" "', argument " "1"" of type '" "daal::data_management::interface1::DecompressorImpl *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DecompressorImpl > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DecompressorImpl > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DecompressorImpl * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DecompressorImpl > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DecompressorImpl * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_DecompressionStream" "', argument " "1"" of type '" "daal::data_management::interface1::DecompressorImpl *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::DecompressionStream *)new daal::data_management::interface1::DecompressionStream(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::DecompressionStream > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::DecompressionStream >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressionStream_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_DecompressionStream(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_DecompressionStream__SWIG_1(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_new_DecompressionStream__SWIG_0(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'new_DecompressionStream'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::DecompressionStream::DecompressionStream(daal::data_management::interface1::DecompressorImpl *,size_t)\n"
    "    daal::data_management::interface1::DecompressionStream::DecompressionStream(daal::data_management::interface1::DecompressorImpl *)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_DecompressionStream(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DecompressionStream *arg1 = (daal::data_management::interface1::DecompressionStream *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DecompressionStream > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DecompressionStream > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_DecompressionStream",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressionStream_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_DecompressionStream" "', argument " "1"" of type '" "daal::data_management::interface1::DecompressionStream *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DecompressionStream > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DecompressionStream > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DecompressionStream * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DecompressionStream > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DecompressionStream * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_DecompressionStream" "', argument " "1"" of type '" "daal::data_management::interface1::DecompressionStream *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DecompressionStream___lshift__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DecompressionStream *arg1 = (daal::data_management::interface1::DecompressionStream *) 0 ;
  daal::data_management::interface1::DataBlock arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DecompressionStream > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DecompressionStream > *smartarg1 = 0 ;
  void *argp2 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DecompressionStream___lshift__",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressionStream_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DecompressionStream___lshift__" "', argument " "1"" of type '" "daal::data_management::interface1::DecompressionStream *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DecompressionStream > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DecompressionStream > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DecompressionStream * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DecompressionStream > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DecompressionStream * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DecompressionStream___lshift__" "', argument " "1"" of type '" "daal::data_management::interface1::DecompressionStream *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DecompressionStream___lshift__" "', argument " "2"" of type '" "daal::data_management::interface1::DataBlock""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "DecompressionStream___lshift__" "', argument " "2"" of type '" "daal::data_management::interface1::DataBlock""'");
    } else {
      arg2 = *(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataBlock > * >(argp2)->get());
      if (newmem & SWIG_CAST_NEW_MEMORY) delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataBlock > * >(argp2);
    }
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->operator <<(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DecompressionStream_getDecompressedBlocksCollection(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DecompressionStream *arg1 = (daal::data_management::interface1::DecompressionStream *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DecompressionStream > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DecompressionStream > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::DataBlockCollectionPtr result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DecompressionStream_getDecompressedBlocksCollection",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressionStream_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DecompressionStream_getDecompressedBlocksCollection" "', argument " "1"" of type '" "daal::data_management::interface1::DecompressionStream *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DecompressionStream > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DecompressionStream > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DecompressionStream * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DecompressionStream > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DecompressionStream * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DecompressionStream_getDecompressedBlocksCollection" "', argument " "1"" of type '" "daal::data_management::interface1::DecompressionStream *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getDecompressedBlocksCollection();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::services::interface1::Collection< daal::services::SharedPtr< daal::data_management::interface1::DataBlock > > > *smartresult = result ? new daal::services::SharedPtr<  daal::services::interface1::Collection< daal::services::SharedPtr< daal::data_management::interface1::DataBlock > > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DecompressionStream_getDecompressedDataSize(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DecompressionStream *arg1 = (daal::data_management::interface1::DecompressionStream *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DecompressionStream > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DecompressionStream > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DecompressionStream_getDecompressedDataSize",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressionStream_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DecompressionStream_getDecompressedDataSize" "', argument " "1"" of type '" "daal::data_management::interface1::DecompressionStream *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DecompressionStream > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DecompressionStream > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DecompressionStream * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DecompressionStream > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DecompressionStream * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DecompressionStream_getDecompressedDataSize" "', argument " "1"" of type '" "daal::data_management::interface1::DecompressionStream *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getDecompressedDataSize();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DecompressionStream_copyDecompressedArray__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DecompressionStream *arg1 = (daal::data_management::interface1::DecompressionStream *) 0 ;
  daal::byte *arg2 = (daal::byte *) 0 ;
  size_t arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DecompressionStream > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DecompressionStream > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int i2 = 1 ;
  int is_new_object2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DecompressionStream_copyDecompressedArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressionStream_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DecompressionStream_copyDecompressedArray" "', argument " "1"" of type '" "daal::data_management::interface1::DecompressionStream *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DecompressionStream > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DecompressionStream > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DecompressionStream * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DecompressionStream > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DecompressionStream * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DecompressionStream_copyDecompressedArray" "', argument " "1"" of type '" "daal::data_management::interface1::DecompressionStream *""'"); 
  }
  {
    array2 = (FORCE_INPLACE == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UBYTE)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UBYTE, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (unsigned char*) array_data(array2);
    arg3 = (size_t) array_size(array2,0);
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->copyDecompressedArray(arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_DecompressionStream_copyDecompressedArray__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DecompressionStream *arg1 = (daal::data_management::interface1::DecompressionStream *) 0 ;
  daal::data_management::interface1::DataBlock *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DecompressionStream > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DecompressionStream > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataBlock > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DecompressionStream_copyDecompressedArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressionStream_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DecompressionStream_copyDecompressedArray" "', argument " "1"" of type '" "daal::data_management::interface1::DecompressionStream *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DecompressionStream > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DecompressionStream > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DecompressionStream * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DecompressionStream > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DecompressionStream * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DecompressionStream_copyDecompressedArray" "', argument " "1"" of type '" "daal::data_management::interface1::DecompressionStream *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DecompressionStream_copyDecompressedArray" "', argument " "2"" of type '" "daal::data_management::interface1::DataBlock &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "DecompressionStream_copyDecompressedArray" "', argument " "2"" of type '" "daal::data_management::interface1::DataBlock &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataBlock > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataBlock > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::DataBlock * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::DataBlock * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataBlock > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DecompressionStream_copyDecompressedArray" "', argument " "2"" of type '" "daal::data_management::interface1::DataBlock &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->copyDecompressedArray(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DecompressionStream_copyDecompressedArray(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressionStream_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_DecompressionStream_copyDecompressedArray__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressionStream_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = (FORCE_INPLACE == FORCE_INPLACE
          ? (is_array(argv[1]) && PyArray_EquivTypenums(array_type(argv[1]), NPY_UBYTE))
          :(is_array(argv[1]) || PySequence_Check(argv[1])));
      }
      if (_v) {
        if (argc <= 2) {
          return _wrap_DecompressionStream_copyDecompressedArray__SWIG_0(self, args);
        }
        return _wrap_DecompressionStream_copyDecompressedArray__SWIG_0(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'DecompressionStream_copyDecompressedArray'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::DecompressionStream::copyDecompressedArray(daal::byte *,size_t)\n"
    "    daal::data_management::interface1::DecompressionStream::copyDecompressedArray(daal::data_management::interface1::DataBlock &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_DecompressionStream_push_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DecompressionStream *arg1 = (daal::data_management::interface1::DecompressionStream *) 0 ;
  daal::byte *arg2 = (daal::byte *) 0 ;
  size_t arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DecompressionStream > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DecompressionStream > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int i2 = 1 ;
  int is_new_object2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DecompressionStream_push_back",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressionStream_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DecompressionStream_push_back" "', argument " "1"" of type '" "daal::data_management::interface1::DecompressionStream *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DecompressionStream > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DecompressionStream > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DecompressionStream * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DecompressionStream > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DecompressionStream * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DecompressionStream_push_back" "', argument " "1"" of type '" "daal::data_management::interface1::DecompressionStream *""'"); 
  }
  {
    array2 = (FORCE_INPLACE == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UBYTE)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UBYTE, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (unsigned char*) array_data(array2);
    arg3 = (size_t) array_size(array2,0);
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        daal_data_management_interface1_DecompressionStream_push_back(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *DecompressionStream_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressionStream_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_Bzip2CompressionParameter__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::CompressionLevel arg1 ;
  int val1 ;
  int ecode1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::Bzip2CompressionParameter *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:new_Bzip2CompressionParameter",&obj0)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_Bzip2CompressionParameter" "', argument " "1"" of type '" "daal::data_management::CompressionLevel""'");
  } 
  arg1 = static_cast< daal::data_management::CompressionLevel >(val1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::Bzip2CompressionParameter *)new daal::data_management::interface1::Bzip2CompressionParameter(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_daal__data_management__interface1__Bzip2CompressionParameter, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_Bzip2CompressionParameter__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Bzip2CompressionParameter *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_Bzip2CompressionParameter")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::Bzip2CompressionParameter *)new daal::data_management::interface1::Bzip2CompressionParameter();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_daal__data_management__interface1__Bzip2CompressionParameter, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_Bzip2CompressionParameter(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[2];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 1) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_new_Bzip2CompressionParameter__SWIG_1(self, args);
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_new_Bzip2CompressionParameter__SWIG_0(self, args);
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'new_Bzip2CompressionParameter'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::Bzip2CompressionParameter::Bzip2CompressionParameter(daal::data_management::CompressionLevel)\n"
    "    daal::data_management::interface1::Bzip2CompressionParameter::Bzip2CompressionParameter()\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_Bzip2CompressionParameter(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Bzip2CompressionParameter *arg1 = (daal::data_management::interface1::Bzip2CompressionParameter *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_Bzip2CompressionParameter",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__interface1__Bzip2CompressionParameter, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Bzip2CompressionParameter" "', argument " "1"" of type '" "daal::data_management::interface1::Bzip2CompressionParameter *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::interface1::Bzip2CompressionParameter * >(argp1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete arg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Bzip2CompressionParameter_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__data_management__interface1__Bzip2CompressionParameter, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_LzoCompressionParameter__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::data_management::interface1::LzoCompressionParameter *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:new_LzoCompressionParameter",&obj0,&obj1)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_LzoCompressionParameter" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "new_LzoCompressionParameter" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::LzoCompressionParameter *)new daal::data_management::interface1::LzoCompressionParameter(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_daal__data_management__interface1__LzoCompressionParameter, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_LzoCompressionParameter__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t val1 ;
  int ecode1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::LzoCompressionParameter *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:new_LzoCompressionParameter",&obj0)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_LzoCompressionParameter" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::LzoCompressionParameter *)new daal::data_management::interface1::LzoCompressionParameter(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_daal__data_management__interface1__LzoCompressionParameter, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_LzoCompressionParameter__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::LzoCompressionParameter *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_LzoCompressionParameter")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::LzoCompressionParameter *)new daal::data_management::interface1::LzoCompressionParameter();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_daal__data_management__interface1__LzoCompressionParameter, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_LzoCompressionParameter(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_new_LzoCompressionParameter__SWIG_2(self, args);
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_new_LzoCompressionParameter__SWIG_1(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_new_LzoCompressionParameter__SWIG_0(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'new_LzoCompressionParameter'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::LzoCompressionParameter::LzoCompressionParameter(size_t,size_t)\n"
    "    daal::data_management::interface1::LzoCompressionParameter::LzoCompressionParameter(size_t)\n"
    "    daal::data_management::interface1::LzoCompressionParameter::LzoCompressionParameter()\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_LzoCompressionParameter(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::LzoCompressionParameter *arg1 = (daal::data_management::interface1::LzoCompressionParameter *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_LzoCompressionParameter",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__interface1__LzoCompressionParameter, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_LzoCompressionParameter" "', argument " "1"" of type '" "daal::data_management::interface1::LzoCompressionParameter *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::interface1::LzoCompressionParameter * >(argp1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete arg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_LzoCompressionParameter_preHeadBytes_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::LzoCompressionParameter *arg1 = (daal::data_management::interface1::LzoCompressionParameter *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:LzoCompressionParameter_preHeadBytes_set",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__interface1__LzoCompressionParameter, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "LzoCompressionParameter_preHeadBytes_set" "', argument " "1"" of type '" "daal::data_management::interface1::LzoCompressionParameter *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::interface1::LzoCompressionParameter * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "LzoCompressionParameter_preHeadBytes_set" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    if (arg1) (arg1)->preHeadBytes = arg2;
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_LzoCompressionParameter_preHeadBytes_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::LzoCompressionParameter *arg1 = (daal::data_management::interface1::LzoCompressionParameter *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:LzoCompressionParameter_preHeadBytes_get",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__interface1__LzoCompressionParameter, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "LzoCompressionParameter_preHeadBytes_get" "', argument " "1"" of type '" "daal::data_management::interface1::LzoCompressionParameter *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::interface1::LzoCompressionParameter * >(argp1);
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    result =  ((arg1)->preHeadBytes);
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_LzoCompressionParameter_postHeadBytes_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::LzoCompressionParameter *arg1 = (daal::data_management::interface1::LzoCompressionParameter *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:LzoCompressionParameter_postHeadBytes_set",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__interface1__LzoCompressionParameter, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "LzoCompressionParameter_postHeadBytes_set" "', argument " "1"" of type '" "daal::data_management::interface1::LzoCompressionParameter *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::interface1::LzoCompressionParameter * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "LzoCompressionParameter_postHeadBytes_set" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    if (arg1) (arg1)->postHeadBytes = arg2;
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_LzoCompressionParameter_postHeadBytes_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::LzoCompressionParameter *arg1 = (daal::data_management::interface1::LzoCompressionParameter *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:LzoCompressionParameter_postHeadBytes_get",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__interface1__LzoCompressionParameter, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "LzoCompressionParameter_postHeadBytes_get" "', argument " "1"" of type '" "daal::data_management::interface1::LzoCompressionParameter *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::interface1::LzoCompressionParameter * >(argp1);
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    result =  ((arg1)->postHeadBytes);
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *LzoCompressionParameter_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__data_management__interface1__LzoCompressionParameter, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_RleCompressionParameter__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  bool arg1 ;
  bool val1 ;
  int ecode1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::RleCompressionParameter *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:new_RleCompressionParameter",&obj0)) SWIG_fail;
  ecode1 = SWIG_AsVal_bool(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_RleCompressionParameter" "', argument " "1"" of type '" "bool""'");
  } 
  arg1 = static_cast< bool >(val1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::RleCompressionParameter *)new daal::data_management::interface1::RleCompressionParameter(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_daal__data_management__interface1__RleCompressionParameter, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_RleCompressionParameter__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::RleCompressionParameter *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_RleCompressionParameter")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::RleCompressionParameter *)new daal::data_management::interface1::RleCompressionParameter();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_daal__data_management__interface1__RleCompressionParameter, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_RleCompressionParameter(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[2];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 1) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_new_RleCompressionParameter__SWIG_1(self, args);
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_bool(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_new_RleCompressionParameter__SWIG_0(self, args);
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'new_RleCompressionParameter'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::RleCompressionParameter::RleCompressionParameter(bool)\n"
    "    daal::data_management::interface1::RleCompressionParameter::RleCompressionParameter()\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_RleCompressionParameter(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::RleCompressionParameter *arg1 = (daal::data_management::interface1::RleCompressionParameter *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_RleCompressionParameter",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__interface1__RleCompressionParameter, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_RleCompressionParameter" "', argument " "1"" of type '" "daal::data_management::interface1::RleCompressionParameter *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::interface1::RleCompressionParameter * >(argp1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete arg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RleCompressionParameter_isBlockHeader_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::RleCompressionParameter *arg1 = (daal::data_management::interface1::RleCompressionParameter *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:RleCompressionParameter_isBlockHeader_set",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__interface1__RleCompressionParameter, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RleCompressionParameter_isBlockHeader_set" "', argument " "1"" of type '" "daal::data_management::interface1::RleCompressionParameter *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::interface1::RleCompressionParameter * >(argp1);
  ecode2 = SWIG_AsVal_bool(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "RleCompressionParameter_isBlockHeader_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    if (arg1) (arg1)->isBlockHeader = arg2;
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RleCompressionParameter_isBlockHeader_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::RleCompressionParameter *arg1 = (daal::data_management::interface1::RleCompressionParameter *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:RleCompressionParameter_isBlockHeader_get",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__interface1__RleCompressionParameter, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RleCompressionParameter_isBlockHeader_get" "', argument " "1"" of type '" "daal::data_management::interface1::RleCompressionParameter *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::interface1::RleCompressionParameter * >(argp1);
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    result = (bool) ((arg1)->isBlockHeader);
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *RleCompressionParameter_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__data_management__interface1__RleCompressionParameter, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_ZlibCompressionParameter__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::CompressionLevel arg1 ;
  bool arg2 ;
  int val1 ;
  int ecode1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::data_management::interface1::ZlibCompressionParameter *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:new_ZlibCompressionParameter",&obj0,&obj1)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_ZlibCompressionParameter" "', argument " "1"" of type '" "daal::data_management::CompressionLevel""'");
  } 
  arg1 = static_cast< daal::data_management::CompressionLevel >(val1);
  ecode2 = SWIG_AsVal_bool(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "new_ZlibCompressionParameter" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::ZlibCompressionParameter *)new daal::data_management::interface1::ZlibCompressionParameter(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_daal__data_management__interface1__ZlibCompressionParameter, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_ZlibCompressionParameter__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::CompressionLevel arg1 ;
  int val1 ;
  int ecode1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::ZlibCompressionParameter *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:new_ZlibCompressionParameter",&obj0)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_ZlibCompressionParameter" "', argument " "1"" of type '" "daal::data_management::CompressionLevel""'");
  } 
  arg1 = static_cast< daal::data_management::CompressionLevel >(val1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::ZlibCompressionParameter *)new daal::data_management::interface1::ZlibCompressionParameter(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_daal__data_management__interface1__ZlibCompressionParameter, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_ZlibCompressionParameter__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::ZlibCompressionParameter *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_ZlibCompressionParameter")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::ZlibCompressionParameter *)new daal::data_management::interface1::ZlibCompressionParameter();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_daal__data_management__interface1__ZlibCompressionParameter, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_ZlibCompressionParameter(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_new_ZlibCompressionParameter__SWIG_2(self, args);
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_new_ZlibCompressionParameter__SWIG_1(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_bool(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_new_ZlibCompressionParameter__SWIG_0(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'new_ZlibCompressionParameter'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::ZlibCompressionParameter::ZlibCompressionParameter(daal::data_management::CompressionLevel,bool)\n"
    "    daal::data_management::interface1::ZlibCompressionParameter::ZlibCompressionParameter(daal::data_management::CompressionLevel)\n"
    "    daal::data_management::interface1::ZlibCompressionParameter::ZlibCompressionParameter()\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_ZlibCompressionParameter(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::ZlibCompressionParameter *arg1 = (daal::data_management::interface1::ZlibCompressionParameter *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_ZlibCompressionParameter",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__interface1__ZlibCompressionParameter, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_ZlibCompressionParameter" "', argument " "1"" of type '" "daal::data_management::interface1::ZlibCompressionParameter *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::interface1::ZlibCompressionParameter * >(argp1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete arg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ZlibCompressionParameter_gzHeader_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::ZlibCompressionParameter *arg1 = (daal::data_management::interface1::ZlibCompressionParameter *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:ZlibCompressionParameter_gzHeader_set",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__interface1__ZlibCompressionParameter, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ZlibCompressionParameter_gzHeader_set" "', argument " "1"" of type '" "daal::data_management::interface1::ZlibCompressionParameter *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::interface1::ZlibCompressionParameter * >(argp1);
  ecode2 = SWIG_AsVal_bool(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ZlibCompressionParameter_gzHeader_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    if (arg1) (arg1)->gzHeader = arg2;
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ZlibCompressionParameter_gzHeader_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::ZlibCompressionParameter *arg1 = (daal::data_management::interface1::ZlibCompressionParameter *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:ZlibCompressionParameter_gzHeader_get",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__interface1__ZlibCompressionParameter, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ZlibCompressionParameter_gzHeader_get" "', argument " "1"" of type '" "daal::data_management::interface1::ZlibCompressionParameter *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::interface1::ZlibCompressionParameter * >(argp1);
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    result = (bool) ((arg1)->gzHeader);
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *ZlibCompressionParameter_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__data_management__interface1__ZlibCompressionParameter, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *readOnly_swigconstant(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *module;
  PyObject *d;
  if (!PyArg_ParseTuple(args,(char*)"O:swigconstant", &module)) return NULL;
  d = PyModule_GetDict(module);
  if (!d) return NULL;
  SWIG_Python_SetConstant(d, "readOnly",SWIG_From_int(static_cast< int >(daal::data_management::readOnly)));
  return SWIG_Py_Void();
}


SWIGINTERN PyObject *writeOnly_swigconstant(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *module;
  PyObject *d;
  if (!PyArg_ParseTuple(args,(char*)"O:swigconstant", &module)) return NULL;
  d = PyModule_GetDict(module);
  if (!d) return NULL;
  SWIG_Python_SetConstant(d, "writeOnly",SWIG_From_int(static_cast< int >(daal::data_management::writeOnly)));
  return SWIG_Py_Void();
}


SWIGINTERN PyObject *readWrite_swigconstant(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *module;
  PyObject *d;
  if (!PyArg_ParseTuple(args,(char*)"O:swigconstant", &module)) return NULL;
  d = PyModule_GetDict(module);
  if (!d) return NULL;
  SWIG_Python_SetConstant(d, "readWrite",SWIG_From_int(static_cast< int >(daal::data_management::readWrite)));
  return SWIG_Py_Void();
}


SWIGINTERN PyObject *_wrap_delete_DataArchiveIface(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataArchiveIface *arg1 = (daal::data_management::interface1::DataArchiveIface *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchiveIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchiveIface > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_DataArchiveIface",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_DataArchiveIface" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchiveIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchiveIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchiveIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_DataArchiveIface" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchiveIface *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataArchiveIface_write(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataArchiveIface *arg1 = (daal::data_management::interface1::DataArchiveIface *) 0 ;
  daal::byte *arg2 = (daal::byte *) 0 ;
  size_t arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchiveIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchiveIface > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int i2 = 1 ;
  int is_new_object2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DataArchiveIface_write",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataArchiveIface_write" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchiveIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchiveIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchiveIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataArchiveIface_write" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchiveIface *""'"); 
  }
  {
    array2 = (FORCE_INPLACE == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UBYTE)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UBYTE, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (unsigned char*) array_data(array2);
    arg3 = (size_t) array_size(array2,0);
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->write(arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataArchiveIface_read(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataArchiveIface *arg1 = (daal::data_management::interface1::DataArchiveIface *) 0 ;
  daal::byte *arg2 = (daal::byte *) 0 ;
  size_t arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchiveIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchiveIface > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int i2 = 1 ;
  int is_new_object2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DataArchiveIface_read",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataArchiveIface_read" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchiveIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchiveIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchiveIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataArchiveIface_read" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchiveIface *""'"); 
  }
  {
    array2 = (FORCE_INPLACE == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UBYTE)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UBYTE, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (unsigned char*) array_data(array2);
    arg3 = (size_t) array_size(array2,0);
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->read(arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataArchiveIface_getSizeOfArchive(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataArchiveIface *arg1 = (daal::data_management::interface1::DataArchiveIface *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchiveIface const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchiveIface const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataArchiveIface_getSizeOfArchive",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataArchiveIface_getSizeOfArchive" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchiveIface const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataArchiveIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataArchiveIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchiveIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataArchiveIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchiveIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataArchiveIface_getSizeOfArchive" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchiveIface const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::DataArchiveIface const *)arg1)->getSizeOfArchive();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataArchiveIface_getArchiveAsString(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataArchiveIface *arg1 = (daal::data_management::interface1::DataArchiveIface *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchiveIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchiveIface > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  std::string result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataArchiveIface_getArchiveAsString",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataArchiveIface_getArchiveAsString" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchiveIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchiveIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchiveIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataArchiveIface_getArchiveAsString" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchiveIface *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getArchiveAsString();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_std_string(static_cast< std::string >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataArchiveIface_copyArchiveToArray(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataArchiveIface *arg1 = (daal::data_management::interface1::DataArchiveIface *) 0 ;
  daal::byte *arg2 = (daal::byte *) 0 ;
  size_t arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchiveIface const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchiveIface const > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int i2 = 1 ;
  int is_new_object2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DataArchiveIface_copyArchiveToArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataArchiveIface_copyArchiveToArray" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchiveIface const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataArchiveIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataArchiveIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchiveIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataArchiveIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchiveIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataArchiveIface_copyArchiveToArray" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchiveIface const *""'"); 
  }
  {
    array2 = (FORCE_INPLACE == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UBYTE)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UBYTE, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (unsigned char*) array_data(array2);
    arg3 = (size_t) array_size(array2,0);
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::DataArchiveIface const *)arg1)->copyArchiveToArray(arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataArchiveIface_setMajorVersion(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataArchiveIface *arg1 = (daal::data_management::interface1::DataArchiveIface *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchiveIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchiveIface > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DataArchiveIface_setMajorVersion",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataArchiveIface_setMajorVersion" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchiveIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchiveIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchiveIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataArchiveIface_setMajorVersion" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchiveIface *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "DataArchiveIface_setMajorVersion" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->setMajorVersion(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataArchiveIface_setMinorVersion(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataArchiveIface *arg1 = (daal::data_management::interface1::DataArchiveIface *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchiveIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchiveIface > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DataArchiveIface_setMinorVersion",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataArchiveIface_setMinorVersion" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchiveIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchiveIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchiveIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataArchiveIface_setMinorVersion" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchiveIface *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "DataArchiveIface_setMinorVersion" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->setMinorVersion(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataArchiveIface_setUpdateVersion(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataArchiveIface *arg1 = (daal::data_management::interface1::DataArchiveIface *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchiveIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchiveIface > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DataArchiveIface_setUpdateVersion",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataArchiveIface_setUpdateVersion" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchiveIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchiveIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchiveIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataArchiveIface_setUpdateVersion" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchiveIface *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "DataArchiveIface_setUpdateVersion" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->setUpdateVersion(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataArchiveIface_getMajorVersion(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataArchiveIface *arg1 = (daal::data_management::interface1::DataArchiveIface *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchiveIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchiveIface > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataArchiveIface_getMajorVersion",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataArchiveIface_getMajorVersion" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchiveIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchiveIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchiveIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataArchiveIface_getMajorVersion" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchiveIface *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)(arg1)->getMajorVersion();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataArchiveIface_getMinorVersion(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataArchiveIface *arg1 = (daal::data_management::interface1::DataArchiveIface *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchiveIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchiveIface > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataArchiveIface_getMinorVersion",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataArchiveIface_getMinorVersion" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchiveIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchiveIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchiveIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataArchiveIface_getMinorVersion" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchiveIface *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)(arg1)->getMinorVersion();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataArchiveIface_getUpdateVersion(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataArchiveIface *arg1 = (daal::data_management::interface1::DataArchiveIface *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchiveIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchiveIface > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataArchiveIface_getUpdateVersion",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataArchiveIface_getUpdateVersion" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchiveIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchiveIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchiveIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataArchiveIface_getUpdateVersion" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchiveIface *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)(arg1)->getUpdateVersion();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *DataArchiveIface_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_delete_DataArchiveImpl(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataArchiveImpl *arg1 = (daal::data_management::interface1::DataArchiveImpl *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchiveImpl > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchiveImpl > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_DataArchiveImpl",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveImpl_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_DataArchiveImpl" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchiveImpl *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveImpl > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveImpl > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchiveImpl * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveImpl > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchiveImpl * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_DataArchiveImpl" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchiveImpl *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataArchiveImpl_setMajorVersion(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataArchiveImpl *arg1 = (daal::data_management::interface1::DataArchiveImpl *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchiveImpl > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchiveImpl > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DataArchiveImpl_setMajorVersion",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveImpl_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataArchiveImpl_setMajorVersion" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchiveImpl *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveImpl > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveImpl > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchiveImpl * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveImpl > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchiveImpl * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataArchiveImpl_setMajorVersion" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchiveImpl *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "DataArchiveImpl_setMajorVersion" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->setMajorVersion(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataArchiveImpl_setMinorVersion(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataArchiveImpl *arg1 = (daal::data_management::interface1::DataArchiveImpl *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchiveImpl > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchiveImpl > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DataArchiveImpl_setMinorVersion",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveImpl_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataArchiveImpl_setMinorVersion" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchiveImpl *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveImpl > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveImpl > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchiveImpl * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveImpl > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchiveImpl * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataArchiveImpl_setMinorVersion" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchiveImpl *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "DataArchiveImpl_setMinorVersion" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->setMinorVersion(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataArchiveImpl_setUpdateVersion(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataArchiveImpl *arg1 = (daal::data_management::interface1::DataArchiveImpl *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchiveImpl > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchiveImpl > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DataArchiveImpl_setUpdateVersion",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveImpl_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataArchiveImpl_setUpdateVersion" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchiveImpl *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveImpl > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveImpl > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchiveImpl * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveImpl > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchiveImpl * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataArchiveImpl_setUpdateVersion" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchiveImpl *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "DataArchiveImpl_setUpdateVersion" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->setUpdateVersion(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataArchiveImpl_getMajorVersion(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataArchiveImpl *arg1 = (daal::data_management::interface1::DataArchiveImpl *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchiveImpl > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchiveImpl > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataArchiveImpl_getMajorVersion",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveImpl_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataArchiveImpl_getMajorVersion" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchiveImpl *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveImpl > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveImpl > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchiveImpl * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveImpl > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchiveImpl * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataArchiveImpl_getMajorVersion" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchiveImpl *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)(arg1)->getMajorVersion();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataArchiveImpl_getMinorVersion(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataArchiveImpl *arg1 = (daal::data_management::interface1::DataArchiveImpl *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchiveImpl > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchiveImpl > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataArchiveImpl_getMinorVersion",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveImpl_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataArchiveImpl_getMinorVersion" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchiveImpl *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveImpl > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveImpl > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchiveImpl * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveImpl > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchiveImpl * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataArchiveImpl_getMinorVersion" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchiveImpl *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)(arg1)->getMinorVersion();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataArchiveImpl_getUpdateVersion(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataArchiveImpl *arg1 = (daal::data_management::interface1::DataArchiveImpl *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchiveImpl > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchiveImpl > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataArchiveImpl_getUpdateVersion",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveImpl_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataArchiveImpl_getUpdateVersion" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchiveImpl *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveImpl > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveImpl > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchiveImpl * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveImpl > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchiveImpl * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataArchiveImpl_getUpdateVersion" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchiveImpl *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)(arg1)->getUpdateVersion();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *DataArchiveImpl_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveImpl_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_DataArchive__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataArchive *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_DataArchive")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::DataArchive *)new daal::data_management::interface1::DataArchive();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::DataArchive > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::DataArchive >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchive_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_DataArchive__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataArchive *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchive const > tempshared1 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::DataArchive *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:new_DataArchive",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchive_t,  0 , &newmem);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_DataArchive" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchive const &""'"); 
    }
    if (!argp1) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_DataArchive" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchive const &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataArchive > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchive * >(tempshared1.get());
    } else {
      arg1 = const_cast< daal::data_management::interface1::DataArchive * >(reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataArchive > * >(argp1)->get());
    }
    if(!arg1) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_DataArchive" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchive const &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::DataArchive *)new daal::data_management::interface1::DataArchive((daal::data_management::interface1::DataArchive const &)*arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::DataArchive > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::DataArchive >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchive_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_DataArchive__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::byte *arg1 = (daal::byte *) 0 ;
  size_t arg2 ;
  PyArrayObject *array1 = NULL ;
  int i1 = 1 ;
  int is_new_object1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::DataArchive *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:new_DataArchive",&obj0)) SWIG_fail;
  {
    array1 = (FORCE_INPLACE == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj0, NPY_UBYTE)
      :obj_to_array_contiguous_allow_conversion(obj0, NPY_UBYTE, &is_new_object1));
    if (!array1 || !require_dimensions(array1, 1) || !require_contiguous(array1) || !require_native(array1)) SWIG_fail;
    arg1 = (unsigned char*) array_data(array1);
    arg2 = (size_t) array_size(array1,0);
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::DataArchive *)new daal::data_management::interface1::DataArchive(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::DataArchive > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::DataArchive >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchive_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object1 && array1) {
      Py_DECREF(array1);
    }
  }
  return resultobj;
fail:
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object1 && array1) {
      Py_DECREF(array1);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_DataArchive(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[2];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 1) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_new_DataArchive__SWIG_0(self, args);
  }
  if (argc == 1) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchive_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_DataArchive__SWIG_1(self, args);
    }
  }
  if (argc == 1) {
    int _v;
    {
      _v = (FORCE_INPLACE == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_UBYTE))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      if (argc <= 1) {
        return _wrap_new_DataArchive__SWIG_2(self, args);
      }
      return _wrap_new_DataArchive__SWIG_2(self, args);
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'new_DataArchive'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::DataArchive::DataArchive()\n"
    "    daal::data_management::interface1::DataArchive::DataArchive(daal::data_management::interface1::DataArchive const &)\n"
    "    daal::data_management::interface1::DataArchive::DataArchive(daal::byte *,size_t)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_DataArchive(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataArchive *arg1 = (daal::data_management::interface1::DataArchive *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchive > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchive > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_DataArchive",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchive_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_DataArchive" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchive *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchive > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchive * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchive * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_DataArchive" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchive *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataArchive_write(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataArchive *arg1 = (daal::data_management::interface1::DataArchive *) 0 ;
  daal::byte *arg2 = (daal::byte *) 0 ;
  size_t arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchive > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchive > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int i2 = 1 ;
  int is_new_object2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DataArchive_write",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchive_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataArchive_write" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchive *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchive > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchive * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchive * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataArchive_write" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchive *""'"); 
  }
  {
    array2 = (FORCE_INPLACE == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UBYTE)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UBYTE, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (unsigned char*) array_data(array2);
    arg3 = (size_t) array_size(array2,0);
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->write(arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataArchive_read(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataArchive *arg1 = (daal::data_management::interface1::DataArchive *) 0 ;
  daal::byte *arg2 = (daal::byte *) 0 ;
  size_t arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchive > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchive > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int i2 = 1 ;
  int is_new_object2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DataArchive_read",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchive_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataArchive_read" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchive *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchive > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchive * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchive * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataArchive_read" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchive *""'"); 
  }
  {
    array2 = (FORCE_INPLACE == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UBYTE)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UBYTE, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (unsigned char*) array_data(array2);
    arg3 = (size_t) array_size(array2,0);
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->read(arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataArchive_getSizeOfArchive(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataArchive *arg1 = (daal::data_management::interface1::DataArchive *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchive const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchive const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataArchive_getSizeOfArchive",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchive_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataArchive_getSizeOfArchive" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchive const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataArchive > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchive * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchive * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataArchive_getSizeOfArchive" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchive const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::DataArchive const *)arg1)->getSizeOfArchive();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataArchive_getArchiveAsString(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataArchive *arg1 = (daal::data_management::interface1::DataArchive *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchive > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchive > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  std::string result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataArchive_getArchiveAsString",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchive_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataArchive_getArchiveAsString" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchive *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchive > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchive * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchive * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataArchive_getArchiveAsString" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchive *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getArchiveAsString();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_std_string(static_cast< std::string >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataArchive_copyArchiveToArray(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataArchive *arg1 = (daal::data_management::interface1::DataArchive *) 0 ;
  daal::byte *arg2 = (daal::byte *) 0 ;
  size_t arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchive const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchive const > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int i2 = 1 ;
  int is_new_object2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DataArchive_copyArchiveToArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchive_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataArchive_copyArchiveToArray" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchive const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataArchive > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchive * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchive * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataArchive_copyArchiveToArray" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchive const *""'"); 
  }
  {
    array2 = (FORCE_INPLACE == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UBYTE)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UBYTE, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (unsigned char*) array_data(array2);
    arg3 = (size_t) array_size(array2,0);
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::DataArchive const *)arg1)->copyArchiveToArray(arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataArchive_getArchiveAsArray(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataArchive *arg1 = (daal::data_management::interface1::DataArchive *) 0 ;
  daal::services::SharedPtr< daal::byte > *arg2 = (daal::services::SharedPtr< daal::byte > *) 0 ;
  size_t *arg3 = (size_t *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchive > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchive > *smartarg1 = 0 ;
  daal::services::SharedPtr< unsigned char > data_temp2 ;
  size_t dim_temp2 ;
  PyObject * obj0 = 0 ;
  
  {
    arg2 = &data_temp2;
    arg3 = &dim_temp2;
  }
  if (!PyArg_ParseTuple(args,(char *)"O:DataArchive_getArchiveAsArray",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchive_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataArchive_getArchiveAsArray" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchive *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchive > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchive * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchive * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataArchive_getArchiveAsArray" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchive *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        daal_data_management_interface1_DataArchive_getArchiveAsArray_(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    npy_intp dims[1] = {
      static_cast<npy_intp>(*arg3) 
    }; // Intel/FS static-cast
    PyObject* obj = PyArray_SimpleNewFromData(1, dims, NPY_UBYTE, (void*)(arg2->get()));
    if (!obj) SWIG_fail;
    set_sp_base((PyArrayObject*)obj, *arg2);
    resultobj = SWIG_Python_AppendOutput(resultobj,obj);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *DataArchive_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchive_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_CompressedDataArchive(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::CompressorImpl *arg1 = (daal::data_management::CompressorImpl *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CompressorImpl > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CompressorImpl > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::CompressedDataArchive *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:new_CompressedDataArchive",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_CompressedDataArchive" "', argument " "1"" of type '" "daal::data_management::CompressorImpl *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressorImpl > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressorImpl > * >(argp1);
      arg1 = const_cast< daal::data_management::CompressorImpl * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressorImpl > * >(argp1);
      arg1 = const_cast< daal::data_management::CompressorImpl * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_CompressedDataArchive" "', argument " "1"" of type '" "daal::data_management::CompressorImpl *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::CompressedDataArchive *)new daal::data_management::interface1::CompressedDataArchive(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::CompressedDataArchive > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::CompressedDataArchive >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressedDataArchive_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_CompressedDataArchive(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CompressedDataArchive *arg1 = (daal::data_management::interface1::CompressedDataArchive *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CompressedDataArchive > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CompressedDataArchive > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_CompressedDataArchive",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressedDataArchive_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_CompressedDataArchive" "', argument " "1"" of type '" "daal::data_management::interface1::CompressedDataArchive *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressedDataArchive > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressedDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CompressedDataArchive * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressedDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CompressedDataArchive * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_CompressedDataArchive" "', argument " "1"" of type '" "daal::data_management::interface1::CompressedDataArchive *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CompressedDataArchive_write(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CompressedDataArchive *arg1 = (daal::data_management::interface1::CompressedDataArchive *) 0 ;
  daal::byte *arg2 = (daal::byte *) 0 ;
  size_t arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CompressedDataArchive > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CompressedDataArchive > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int i2 = 1 ;
  int is_new_object2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:CompressedDataArchive_write",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressedDataArchive_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CompressedDataArchive_write" "', argument " "1"" of type '" "daal::data_management::interface1::CompressedDataArchive *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressedDataArchive > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressedDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CompressedDataArchive * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressedDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CompressedDataArchive * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CompressedDataArchive_write" "', argument " "1"" of type '" "daal::data_management::interface1::CompressedDataArchive *""'"); 
  }
  {
    array2 = (FORCE_INPLACE == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UBYTE)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UBYTE, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (unsigned char*) array_data(array2);
    arg3 = (size_t) array_size(array2,0);
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->write(arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_CompressedDataArchive_read(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CompressedDataArchive *arg1 = (daal::data_management::interface1::CompressedDataArchive *) 0 ;
  daal::byte *arg2 = (daal::byte *) 0 ;
  size_t arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CompressedDataArchive > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CompressedDataArchive > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int i2 = 1 ;
  int is_new_object2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:CompressedDataArchive_read",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressedDataArchive_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CompressedDataArchive_read" "', argument " "1"" of type '" "daal::data_management::interface1::CompressedDataArchive *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressedDataArchive > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressedDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CompressedDataArchive * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressedDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CompressedDataArchive * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CompressedDataArchive_read" "', argument " "1"" of type '" "daal::data_management::interface1::CompressedDataArchive *""'"); 
  }
  {
    array2 = (FORCE_INPLACE == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UBYTE)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UBYTE, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (unsigned char*) array_data(array2);
    arg3 = (size_t) array_size(array2,0);
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->read(arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_CompressedDataArchive_getSizeOfArchive(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CompressedDataArchive *arg1 = (daal::data_management::interface1::CompressedDataArchive *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CompressedDataArchive const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CompressedDataArchive const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:CompressedDataArchive_getSizeOfArchive",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressedDataArchive_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CompressedDataArchive_getSizeOfArchive" "', argument " "1"" of type '" "daal::data_management::interface1::CompressedDataArchive const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CompressedDataArchive > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CompressedDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CompressedDataArchive * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CompressedDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CompressedDataArchive * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CompressedDataArchive_getSizeOfArchive" "', argument " "1"" of type '" "daal::data_management::interface1::CompressedDataArchive const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::CompressedDataArchive const *)arg1)->getSizeOfArchive();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CompressedDataArchive_getArchiveAsString(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CompressedDataArchive *arg1 = (daal::data_management::interface1::CompressedDataArchive *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CompressedDataArchive > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CompressedDataArchive > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  std::string result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:CompressedDataArchive_getArchiveAsString",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressedDataArchive_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CompressedDataArchive_getArchiveAsString" "', argument " "1"" of type '" "daal::data_management::interface1::CompressedDataArchive *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressedDataArchive > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressedDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CompressedDataArchive * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressedDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CompressedDataArchive * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CompressedDataArchive_getArchiveAsString" "', argument " "1"" of type '" "daal::data_management::interface1::CompressedDataArchive *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getArchiveAsString();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_std_string(static_cast< std::string >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CompressedDataArchive_copyArchiveToArray(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CompressedDataArchive *arg1 = (daal::data_management::interface1::CompressedDataArchive *) 0 ;
  daal::byte *arg2 = (daal::byte *) 0 ;
  size_t arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CompressedDataArchive const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CompressedDataArchive const > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int i2 = 1 ;
  int is_new_object2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:CompressedDataArchive_copyArchiveToArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressedDataArchive_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CompressedDataArchive_copyArchiveToArray" "', argument " "1"" of type '" "daal::data_management::interface1::CompressedDataArchive const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CompressedDataArchive > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CompressedDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CompressedDataArchive * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CompressedDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CompressedDataArchive * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CompressedDataArchive_copyArchiveToArray" "', argument " "1"" of type '" "daal::data_management::interface1::CompressedDataArchive const *""'"); 
  }
  {
    array2 = (FORCE_INPLACE == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UBYTE)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UBYTE, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (unsigned char*) array_data(array2);
    arg3 = (size_t) array_size(array2,0);
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::CompressedDataArchive const *)arg1)->copyArchiveToArray(arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *CompressedDataArchive_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressedDataArchive_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_DecompressedDataArchive(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::DecompressorImpl *arg1 = (daal::data_management::DecompressorImpl *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DecompressorImpl > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DecompressorImpl > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::DecompressedDataArchive *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:new_DecompressedDataArchive",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_DecompressedDataArchive" "', argument " "1"" of type '" "daal::data_management::DecompressorImpl *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DecompressorImpl > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DecompressorImpl > * >(argp1);
      arg1 = const_cast< daal::data_management::DecompressorImpl * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DecompressorImpl > * >(argp1);
      arg1 = const_cast< daal::data_management::DecompressorImpl * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_DecompressedDataArchive" "', argument " "1"" of type '" "daal::data_management::DecompressorImpl *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::DecompressedDataArchive *)new daal::data_management::interface1::DecompressedDataArchive(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::DecompressedDataArchive > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::DecompressedDataArchive >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressedDataArchive_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_DecompressedDataArchive(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DecompressedDataArchive *arg1 = (daal::data_management::interface1::DecompressedDataArchive *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DecompressedDataArchive > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DecompressedDataArchive > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_DecompressedDataArchive",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressedDataArchive_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_DecompressedDataArchive" "', argument " "1"" of type '" "daal::data_management::interface1::DecompressedDataArchive *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DecompressedDataArchive > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DecompressedDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DecompressedDataArchive * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DecompressedDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DecompressedDataArchive * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_DecompressedDataArchive" "', argument " "1"" of type '" "daal::data_management::interface1::DecompressedDataArchive *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DecompressedDataArchive_write(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DecompressedDataArchive *arg1 = (daal::data_management::interface1::DecompressedDataArchive *) 0 ;
  daal::byte *arg2 = (daal::byte *) 0 ;
  size_t arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DecompressedDataArchive > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DecompressedDataArchive > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int i2 = 1 ;
  int is_new_object2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DecompressedDataArchive_write",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressedDataArchive_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DecompressedDataArchive_write" "', argument " "1"" of type '" "daal::data_management::interface1::DecompressedDataArchive *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DecompressedDataArchive > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DecompressedDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DecompressedDataArchive * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DecompressedDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DecompressedDataArchive * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DecompressedDataArchive_write" "', argument " "1"" of type '" "daal::data_management::interface1::DecompressedDataArchive *""'"); 
  }
  {
    array2 = (FORCE_INPLACE == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UBYTE)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UBYTE, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (unsigned char*) array_data(array2);
    arg3 = (size_t) array_size(array2,0);
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->write(arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_DecompressedDataArchive_read(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DecompressedDataArchive *arg1 = (daal::data_management::interface1::DecompressedDataArchive *) 0 ;
  daal::byte *arg2 = (daal::byte *) 0 ;
  size_t arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DecompressedDataArchive > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DecompressedDataArchive > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int i2 = 1 ;
  int is_new_object2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DecompressedDataArchive_read",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressedDataArchive_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DecompressedDataArchive_read" "', argument " "1"" of type '" "daal::data_management::interface1::DecompressedDataArchive *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DecompressedDataArchive > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DecompressedDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DecompressedDataArchive * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DecompressedDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DecompressedDataArchive * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DecompressedDataArchive_read" "', argument " "1"" of type '" "daal::data_management::interface1::DecompressedDataArchive *""'"); 
  }
  {
    array2 = (FORCE_INPLACE == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UBYTE)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UBYTE, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (unsigned char*) array_data(array2);
    arg3 = (size_t) array_size(array2,0);
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->read(arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_DecompressedDataArchive_getSizeOfArchive(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DecompressedDataArchive *arg1 = (daal::data_management::interface1::DecompressedDataArchive *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DecompressedDataArchive const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DecompressedDataArchive const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DecompressedDataArchive_getSizeOfArchive",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressedDataArchive_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DecompressedDataArchive_getSizeOfArchive" "', argument " "1"" of type '" "daal::data_management::interface1::DecompressedDataArchive const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DecompressedDataArchive > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DecompressedDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DecompressedDataArchive * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DecompressedDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DecompressedDataArchive * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DecompressedDataArchive_getSizeOfArchive" "', argument " "1"" of type '" "daal::data_management::interface1::DecompressedDataArchive const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::DecompressedDataArchive const *)arg1)->getSizeOfArchive();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DecompressedDataArchive_getArchiveAsString(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DecompressedDataArchive *arg1 = (daal::data_management::interface1::DecompressedDataArchive *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DecompressedDataArchive > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DecompressedDataArchive > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  std::string result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DecompressedDataArchive_getArchiveAsString",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressedDataArchive_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DecompressedDataArchive_getArchiveAsString" "', argument " "1"" of type '" "daal::data_management::interface1::DecompressedDataArchive *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DecompressedDataArchive > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DecompressedDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DecompressedDataArchive * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DecompressedDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DecompressedDataArchive * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DecompressedDataArchive_getArchiveAsString" "', argument " "1"" of type '" "daal::data_management::interface1::DecompressedDataArchive *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getArchiveAsString();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_std_string(static_cast< std::string >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DecompressedDataArchive_copyArchiveToArray(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DecompressedDataArchive *arg1 = (daal::data_management::interface1::DecompressedDataArchive *) 0 ;
  daal::byte *arg2 = (daal::byte *) 0 ;
  size_t arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DecompressedDataArchive const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DecompressedDataArchive const > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int i2 = 1 ;
  int is_new_object2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DecompressedDataArchive_copyArchiveToArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressedDataArchive_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DecompressedDataArchive_copyArchiveToArray" "', argument " "1"" of type '" "daal::data_management::interface1::DecompressedDataArchive const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DecompressedDataArchive > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DecompressedDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DecompressedDataArchive * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DecompressedDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DecompressedDataArchive * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DecompressedDataArchive_copyArchiveToArray" "', argument " "1"" of type '" "daal::data_management::interface1::DecompressedDataArchive const *""'"); 
  }
  {
    array2 = (FORCE_INPLACE == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UBYTE)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UBYTE, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (unsigned char*) array_data(array2);
    arg3 = (size_t) array_size(array2,0);
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::DecompressedDataArchive const *)arg1)->copyArchiveToArray(arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *DecompressedDataArchive_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressedDataArchive_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_InputDataArchive__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::InputDataArchive *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_InputDataArchive")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::InputDataArchive *)new daal::data_management::interface1::InputDataArchive();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::InputDataArchive > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::InputDataArchive >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__InputDataArchive_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_InputDataArchive__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataArchiveIface *arg1 = (daal::data_management::interface1::DataArchiveIface *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchiveIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchiveIface > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::InputDataArchive *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:new_InputDataArchive",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_InputDataArchive" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchiveIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchiveIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchiveIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_InputDataArchive" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchiveIface *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::InputDataArchive *)new daal::data_management::interface1::InputDataArchive(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::InputDataArchive > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::InputDataArchive >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__InputDataArchive_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_InputDataArchive__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::CompressorImpl *arg1 = (daal::data_management::CompressorImpl *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CompressorImpl > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CompressorImpl > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::InputDataArchive *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:new_InputDataArchive",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_InputDataArchive" "', argument " "1"" of type '" "daal::data_management::CompressorImpl *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressorImpl > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressorImpl > * >(argp1);
      arg1 = const_cast< daal::data_management::CompressorImpl * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CompressorImpl > * >(argp1);
      arg1 = const_cast< daal::data_management::CompressorImpl * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_InputDataArchive" "', argument " "1"" of type '" "daal::data_management::CompressorImpl *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::InputDataArchive *)new daal::data_management::interface1::InputDataArchive(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::InputDataArchive > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::InputDataArchive >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__InputDataArchive_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_InputDataArchive(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[2];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 1) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_new_InputDataArchive__SWIG_0(self, args);
  }
  if (argc == 1) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_InputDataArchive__SWIG_1(self, args);
    }
  }
  if (argc == 1) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_InputDataArchive__SWIG_2(self, args);
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'new_InputDataArchive'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::InputDataArchive::InputDataArchive()\n"
    "    daal::data_management::interface1::InputDataArchive::InputDataArchive(daal::data_management::interface1::DataArchiveIface *)\n"
    "    daal::data_management::interface1::InputDataArchive::InputDataArchive(daal::data_management::CompressorImpl *)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_InputDataArchive(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::InputDataArchive *arg1 = (daal::data_management::interface1::InputDataArchive *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::InputDataArchive > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::InputDataArchive > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_InputDataArchive",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__InputDataArchive_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_InputDataArchive" "', argument " "1"" of type '" "daal::data_management::interface1::InputDataArchive *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::InputDataArchive > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::InputDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::InputDataArchive * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::InputDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::InputDataArchive * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_InputDataArchive" "', argument " "1"" of type '" "daal::data_management::interface1::InputDataArchive *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_InputDataArchive_archiveHeader(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::InputDataArchive *arg1 = (daal::data_management::interface1::InputDataArchive *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::InputDataArchive > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::InputDataArchive > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:InputDataArchive_archiveHeader",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__InputDataArchive_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "InputDataArchive_archiveHeader" "', argument " "1"" of type '" "daal::data_management::interface1::InputDataArchive *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::InputDataArchive > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::InputDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::InputDataArchive * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::InputDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::InputDataArchive * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "InputDataArchive_archiveHeader" "', argument " "1"" of type '" "daal::data_management::interface1::InputDataArchive *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->archiveHeader();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_InputDataArchive_archiveFooter(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::InputDataArchive *arg1 = (daal::data_management::interface1::InputDataArchive *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::InputDataArchive > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::InputDataArchive > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:InputDataArchive_archiveFooter",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__InputDataArchive_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "InputDataArchive_archiveFooter" "', argument " "1"" of type '" "daal::data_management::interface1::InputDataArchive *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::InputDataArchive > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::InputDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::InputDataArchive * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::InputDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::InputDataArchive * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "InputDataArchive_archiveFooter" "', argument " "1"" of type '" "daal::data_management::interface1::InputDataArchive *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->archiveFooter();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_InputDataArchive_segmentHeader__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::InputDataArchive *arg1 = (daal::data_management::interface1::InputDataArchive *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::InputDataArchive > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::InputDataArchive > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:InputDataArchive_segmentHeader",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__InputDataArchive_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "InputDataArchive_segmentHeader" "', argument " "1"" of type '" "daal::data_management::interface1::InputDataArchive *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::InputDataArchive > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::InputDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::InputDataArchive * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::InputDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::InputDataArchive * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "InputDataArchive_segmentHeader" "', argument " "1"" of type '" "daal::data_management::interface1::InputDataArchive *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "InputDataArchive_segmentHeader" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->segmentHeader(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_InputDataArchive_segmentHeader__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::InputDataArchive *arg1 = (daal::data_management::interface1::InputDataArchive *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::InputDataArchive > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::InputDataArchive > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:InputDataArchive_segmentHeader",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__InputDataArchive_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "InputDataArchive_segmentHeader" "', argument " "1"" of type '" "daal::data_management::interface1::InputDataArchive *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::InputDataArchive > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::InputDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::InputDataArchive * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::InputDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::InputDataArchive * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "InputDataArchive_segmentHeader" "', argument " "1"" of type '" "daal::data_management::interface1::InputDataArchive *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->segmentHeader();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_InputDataArchive_segmentHeader(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__InputDataArchive_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_InputDataArchive_segmentHeader__SWIG_1(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__InputDataArchive_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_InputDataArchive_segmentHeader__SWIG_0(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'InputDataArchive_segmentHeader'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::InputDataArchive::segmentHeader(int)\n"
    "    daal::data_management::interface1::InputDataArchive::segmentHeader()\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_InputDataArchive_segmentFooter(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::InputDataArchive *arg1 = (daal::data_management::interface1::InputDataArchive *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::InputDataArchive > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::InputDataArchive > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:InputDataArchive_segmentFooter",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__InputDataArchive_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "InputDataArchive_segmentFooter" "', argument " "1"" of type '" "daal::data_management::interface1::InputDataArchive *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::InputDataArchive > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::InputDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::InputDataArchive * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::InputDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::InputDataArchive * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "InputDataArchive_segmentFooter" "', argument " "1"" of type '" "daal::data_management::interface1::InputDataArchive *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->segmentFooter();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_InputDataArchive_setSingleObj(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::InputDataArchive *arg1 = (daal::data_management::interface1::InputDataArchive *) 0 ;
  daal::data_management::interface1::SerializationIface **arg2 = (daal::data_management::interface1::SerializationIface **) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::InputDataArchive > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::InputDataArchive > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:InputDataArchive_setSingleObj",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__InputDataArchive_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "InputDataArchive_setSingleObj" "', argument " "1"" of type '" "daal::data_management::interface1::InputDataArchive *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::InputDataArchive > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::InputDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::InputDataArchive * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::InputDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::InputDataArchive * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "InputDataArchive_setSingleObj" "', argument " "1"" of type '" "daal::data_management::interface1::InputDataArchive *""'"); 
  }
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_p_daal__data_management__interface1__SerializationIface, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "InputDataArchive_setSingleObj" "', argument " "2"" of type '" "daal::data_management::interface1::SerializationIface **""'"); 
  }
  arg2 = reinterpret_cast< daal::data_management::interface1::SerializationIface ** >(argp2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->setSingleObj(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_InputDataArchive_getSizeOfArchive(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::InputDataArchive *arg1 = (daal::data_management::interface1::InputDataArchive *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::InputDataArchive > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::InputDataArchive > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:InputDataArchive_getSizeOfArchive",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__InputDataArchive_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "InputDataArchive_getSizeOfArchive" "', argument " "1"" of type '" "daal::data_management::interface1::InputDataArchive *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::InputDataArchive > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::InputDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::InputDataArchive * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::InputDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::InputDataArchive * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "InputDataArchive_getSizeOfArchive" "', argument " "1"" of type '" "daal::data_management::interface1::InputDataArchive *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getSizeOfArchive();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_InputDataArchive_getArchiveAsString(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::InputDataArchive *arg1 = (daal::data_management::interface1::InputDataArchive *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::InputDataArchive > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::InputDataArchive > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  std::string result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:InputDataArchive_getArchiveAsString",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__InputDataArchive_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "InputDataArchive_getArchiveAsString" "', argument " "1"" of type '" "daal::data_management::interface1::InputDataArchive *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::InputDataArchive > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::InputDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::InputDataArchive * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::InputDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::InputDataArchive * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "InputDataArchive_getArchiveAsString" "', argument " "1"" of type '" "daal::data_management::interface1::InputDataArchive *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getArchiveAsString();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_std_string(static_cast< std::string >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_InputDataArchive_copyArchiveToArray(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::InputDataArchive *arg1 = (daal::data_management::interface1::InputDataArchive *) 0 ;
  daal::byte *arg2 = (daal::byte *) 0 ;
  size_t arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::InputDataArchive > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::InputDataArchive > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int i2 = 1 ;
  int is_new_object2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:InputDataArchive_copyArchiveToArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__InputDataArchive_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "InputDataArchive_copyArchiveToArray" "', argument " "1"" of type '" "daal::data_management::interface1::InputDataArchive *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::InputDataArchive > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::InputDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::InputDataArchive * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::InputDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::InputDataArchive * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "InputDataArchive_copyArchiveToArray" "', argument " "1"" of type '" "daal::data_management::interface1::InputDataArchive *""'"); 
  }
  {
    array2 = (FORCE_INPLACE == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UBYTE)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UBYTE, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (unsigned char*) array_data(array2);
    arg3 = (size_t) array_size(array2,0);
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->copyArchiveToArray(arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_InputDataArchive_getDataArchive(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::InputDataArchive *arg1 = (daal::data_management::interface1::InputDataArchive *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::InputDataArchive > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::InputDataArchive > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::DataArchive *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:InputDataArchive_getDataArchive",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__InputDataArchive_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "InputDataArchive_getDataArchive" "', argument " "1"" of type '" "daal::data_management::interface1::InputDataArchive *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::InputDataArchive > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::InputDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::InputDataArchive * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::InputDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::InputDataArchive * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "InputDataArchive_getDataArchive" "', argument " "1"" of type '" "daal::data_management::interface1::InputDataArchive *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::DataArchive *) &(arg1)->getDataArchive();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr< const daal::data_management::interface1::DataArchive > *smartresult = new daal::services::SharedPtr< const daal::data_management::interface1::DataArchive >(result SWIG_NO_NULL_DELETER_0);
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchive_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_InputDataArchive_getArchiveAsArray(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::InputDataArchive *arg1 = (daal::data_management::interface1::InputDataArchive *) 0 ;
  daal::services::SharedPtr< daal::byte > *arg2 = (daal::services::SharedPtr< daal::byte > *) 0 ;
  size_t *arg3 = (size_t *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::InputDataArchive > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::InputDataArchive > *smartarg1 = 0 ;
  daal::services::SharedPtr< unsigned char > data_temp2 ;
  size_t dim_temp2 ;
  PyObject * obj0 = 0 ;
  
  {
    arg2 = &data_temp2;
    arg3 = &dim_temp2;
  }
  if (!PyArg_ParseTuple(args,(char *)"O:InputDataArchive_getArchiveAsArray",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__InputDataArchive_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "InputDataArchive_getArchiveAsArray" "', argument " "1"" of type '" "daal::data_management::interface1::InputDataArchive *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::InputDataArchive > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::InputDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::InputDataArchive * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::InputDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::InputDataArchive * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "InputDataArchive_getArchiveAsArray" "', argument " "1"" of type '" "daal::data_management::interface1::InputDataArchive *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        daal_data_management_interface1_InputDataArchive_getArchiveAsArray_(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    npy_intp dims[1] = {
      static_cast<npy_intp>(*arg3) 
    }; // Intel/FS static-cast
    PyObject* obj = PyArray_SimpleNewFromData(1, dims, NPY_UBYTE, (void*)(arg2->get()));
    if (!obj) SWIG_fail;
    set_sp_base((PyArrayObject*)obj, *arg2);
    resultobj = SWIG_Python_AppendOutput(resultobj,obj);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *InputDataArchive_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__InputDataArchive_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_OutputDataArchive__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::InputDataArchive *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::InputDataArchive > tempshared1 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::OutputDataArchive *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:new_OutputDataArchive",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__InputDataArchive_t,  0 , &newmem);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_OutputDataArchive" "', argument " "1"" of type '" "daal::data_management::interface1::InputDataArchive &""'"); 
    }
    if (!argp1) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_OutputDataArchive" "', argument " "1"" of type '" "daal::data_management::interface1::InputDataArchive &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::InputDataArchive > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::InputDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::InputDataArchive * >(tempshared1.get());
    } else {
      arg1 = const_cast< daal::data_management::interface1::InputDataArchive * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::InputDataArchive > * >(argp1)->get());
    }
    if(!arg1) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_OutputDataArchive" "', argument " "1"" of type '" "daal::data_management::interface1::InputDataArchive &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::OutputDataArchive *)new daal::data_management::interface1::OutputDataArchive(*arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::OutputDataArchive > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::OutputDataArchive >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__OutputDataArchive_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_OutputDataArchive__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataArchiveIface *arg1 = (daal::data_management::interface1::DataArchiveIface *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchiveIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataArchiveIface > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::OutputDataArchive *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:new_OutputDataArchive",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_OutputDataArchive" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchiveIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchiveIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataArchiveIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataArchiveIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_OutputDataArchive" "', argument " "1"" of type '" "daal::data_management::interface1::DataArchiveIface *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::OutputDataArchive *)new daal::data_management::interface1::OutputDataArchive(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::OutputDataArchive > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::OutputDataArchive >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__OutputDataArchive_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_OutputDataArchive__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::byte *arg1 = (daal::byte *) 0 ;
  size_t arg2 ;
  PyArrayObject *array1 = NULL ;
  int i1 = 1 ;
  int is_new_object1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::OutputDataArchive *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:new_OutputDataArchive",&obj0)) SWIG_fail;
  {
    array1 = (FORCE_INPLACE == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj0, NPY_UBYTE)
      :obj_to_array_contiguous_allow_conversion(obj0, NPY_UBYTE, &is_new_object1));
    if (!array1 || !require_dimensions(array1, 1) || !require_contiguous(array1) || !require_native(array1)) SWIG_fail;
    arg1 = (unsigned char*) array_data(array1);
    arg2 = (size_t) array_size(array1,0);
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::OutputDataArchive *)new daal::data_management::interface1::OutputDataArchive(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::OutputDataArchive > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::OutputDataArchive >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__OutputDataArchive_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object1 && array1) {
      Py_DECREF(array1);
    }
  }
  return resultobj;
fail:
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object1 && array1) {
      Py_DECREF(array1);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_OutputDataArchive__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::DecompressorImpl *arg1 = (daal::data_management::DecompressorImpl *) 0 ;
  daal::byte *arg2 = (daal::byte *) 0 ;
  size_t arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DecompressorImpl > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DecompressorImpl > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int i2 = 1 ;
  int is_new_object2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::data_management::interface1::OutputDataArchive *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:new_OutputDataArchive",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_OutputDataArchive" "', argument " "1"" of type '" "daal::data_management::DecompressorImpl *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DecompressorImpl > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DecompressorImpl > * >(argp1);
      arg1 = const_cast< daal::data_management::DecompressorImpl * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DecompressorImpl > * >(argp1);
      arg1 = const_cast< daal::data_management::DecompressorImpl * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_OutputDataArchive" "', argument " "1"" of type '" "daal::data_management::DecompressorImpl *""'"); 
  }
  {
    array2 = (FORCE_INPLACE == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UBYTE)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UBYTE, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (unsigned char*) array_data(array2);
    arg3 = (size_t) array_size(array2,0);
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::OutputDataArchive *)new daal::data_management::interface1::OutputDataArchive(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::OutputDataArchive > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::OutputDataArchive >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__OutputDataArchive_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_OutputDataArchive(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__InputDataArchive_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_OutputDataArchive__SWIG_0(self, args);
    }
  }
  if (argc == 1) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_OutputDataArchive__SWIG_1(self, args);
    }
  }
  if (argc == 1) {
    int _v;
    {
      _v = (FORCE_INPLACE == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_UBYTE))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      if (argc <= 1) {
        return _wrap_new_OutputDataArchive__SWIG_2(self, args);
      }
      return _wrap_new_OutputDataArchive__SWIG_2(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = (FORCE_INPLACE == FORCE_INPLACE
          ? (is_array(argv[1]) && PyArray_EquivTypenums(array_type(argv[1]), NPY_UBYTE))
          :(is_array(argv[1]) || PySequence_Check(argv[1])));
      }
      if (_v) {
        if (argc <= 2) {
          return _wrap_new_OutputDataArchive__SWIG_3(self, args);
        }
        return _wrap_new_OutputDataArchive__SWIG_3(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'new_OutputDataArchive'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::OutputDataArchive::OutputDataArchive(daal::data_management::interface1::InputDataArchive &)\n"
    "    daal::data_management::interface1::OutputDataArchive::OutputDataArchive(daal::data_management::interface1::DataArchiveIface *)\n"
    "    daal::data_management::interface1::OutputDataArchive::OutputDataArchive(daal::byte *,size_t)\n"
    "    daal::data_management::interface1::OutputDataArchive::OutputDataArchive(daal::data_management::DecompressorImpl *,daal::byte *,size_t)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_OutputDataArchive(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::OutputDataArchive *arg1 = (daal::data_management::interface1::OutputDataArchive *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::OutputDataArchive > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::OutputDataArchive > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_OutputDataArchive",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__OutputDataArchive_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_OutputDataArchive" "', argument " "1"" of type '" "daal::data_management::interface1::OutputDataArchive *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::OutputDataArchive > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::OutputDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::OutputDataArchive * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::OutputDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::OutputDataArchive * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_OutputDataArchive" "', argument " "1"" of type '" "daal::data_management::interface1::OutputDataArchive *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OutputDataArchive_archiveHeader(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::OutputDataArchive *arg1 = (daal::data_management::interface1::OutputDataArchive *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::OutputDataArchive const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::OutputDataArchive const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:OutputDataArchive_archiveHeader",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__OutputDataArchive_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OutputDataArchive_archiveHeader" "', argument " "1"" of type '" "daal::data_management::interface1::OutputDataArchive const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::OutputDataArchive > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::OutputDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::OutputDataArchive * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::OutputDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::OutputDataArchive * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OutputDataArchive_archiveHeader" "', argument " "1"" of type '" "daal::data_management::interface1::OutputDataArchive const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        ((daal::data_management::interface1::OutputDataArchive const *)arg1)->archiveHeader();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OutputDataArchive_archiveFooter(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::OutputDataArchive *arg1 = (daal::data_management::interface1::OutputDataArchive *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::OutputDataArchive const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::OutputDataArchive const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:OutputDataArchive_archiveFooter",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__OutputDataArchive_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OutputDataArchive_archiveFooter" "', argument " "1"" of type '" "daal::data_management::interface1::OutputDataArchive const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::OutputDataArchive > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::OutputDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::OutputDataArchive * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::OutputDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::OutputDataArchive * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OutputDataArchive_archiveFooter" "', argument " "1"" of type '" "daal::data_management::interface1::OutputDataArchive const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        ((daal::data_management::interface1::OutputDataArchive const *)arg1)->archiveFooter();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OutputDataArchive_segmentHeader(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::OutputDataArchive *arg1 = (daal::data_management::interface1::OutputDataArchive *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::OutputDataArchive const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::OutputDataArchive const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:OutputDataArchive_segmentHeader",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__OutputDataArchive_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OutputDataArchive_segmentHeader" "', argument " "1"" of type '" "daal::data_management::interface1::OutputDataArchive const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::OutputDataArchive > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::OutputDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::OutputDataArchive * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::OutputDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::OutputDataArchive * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OutputDataArchive_segmentHeader" "', argument " "1"" of type '" "daal::data_management::interface1::OutputDataArchive const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)((daal::data_management::interface1::OutputDataArchive const *)arg1)->segmentHeader();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OutputDataArchive_segmentFooter(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::OutputDataArchive *arg1 = (daal::data_management::interface1::OutputDataArchive *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::OutputDataArchive const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::OutputDataArchive const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:OutputDataArchive_segmentFooter",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__OutputDataArchive_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OutputDataArchive_segmentFooter" "', argument " "1"" of type '" "daal::data_management::interface1::OutputDataArchive const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::OutputDataArchive > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::OutputDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::OutputDataArchive * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::OutputDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::OutputDataArchive * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OutputDataArchive_segmentFooter" "', argument " "1"" of type '" "daal::data_management::interface1::OutputDataArchive const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        ((daal::data_management::interface1::OutputDataArchive const *)arg1)->segmentFooter();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OutputDataArchive_setSingleObj(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::OutputDataArchive *arg1 = (daal::data_management::interface1::OutputDataArchive *) 0 ;
  daal::data_management::interface1::SerializationIface **arg2 = (daal::data_management::interface1::SerializationIface **) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::OutputDataArchive const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::OutputDataArchive const > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:OutputDataArchive_setSingleObj",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__OutputDataArchive_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OutputDataArchive_setSingleObj" "', argument " "1"" of type '" "daal::data_management::interface1::OutputDataArchive const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::OutputDataArchive > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::OutputDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::OutputDataArchive * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::OutputDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::OutputDataArchive * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OutputDataArchive_setSingleObj" "', argument " "1"" of type '" "daal::data_management::interface1::OutputDataArchive const *""'"); 
  }
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_p_daal__data_management__interface1__SerializationIface, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OutputDataArchive_setSingleObj" "', argument " "2"" of type '" "daal::data_management::interface1::SerializationIface **""'"); 
  }
  arg2 = reinterpret_cast< daal::data_management::interface1::SerializationIface ** >(argp2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        ((daal::data_management::interface1::OutputDataArchive const *)arg1)->setSingleObj(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OutputDataArchive_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::OutputDataArchive *arg1 = (daal::data_management::interface1::OutputDataArchive *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::OutputDataArchive const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::OutputDataArchive const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SerializationIface > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:OutputDataArchive_get",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__OutputDataArchive_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OutputDataArchive_get" "', argument " "1"" of type '" "daal::data_management::interface1::OutputDataArchive const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::OutputDataArchive > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::OutputDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::OutputDataArchive * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::OutputDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::OutputDataArchive * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OutputDataArchive_get" "', argument " "1"" of type '" "daal::data_management::interface1::OutputDataArchive const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::OutputDataArchive const *)arg1)->getAsSharedPtr();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::SerializationIface > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::SerializationIface >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OutputDataArchive_getMajorVersion(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::OutputDataArchive *arg1 = (daal::data_management::interface1::OutputDataArchive *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::OutputDataArchive const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::OutputDataArchive const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:OutputDataArchive_getMajorVersion",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__OutputDataArchive_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OutputDataArchive_getMajorVersion" "', argument " "1"" of type '" "daal::data_management::interface1::OutputDataArchive const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::OutputDataArchive > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::OutputDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::OutputDataArchive * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::OutputDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::OutputDataArchive * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OutputDataArchive_getMajorVersion" "', argument " "1"" of type '" "daal::data_management::interface1::OutputDataArchive const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)((daal::data_management::interface1::OutputDataArchive const *)arg1)->getMajorVersion();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OutputDataArchive_getMinorVersion(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::OutputDataArchive *arg1 = (daal::data_management::interface1::OutputDataArchive *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::OutputDataArchive const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::OutputDataArchive const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:OutputDataArchive_getMinorVersion",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__OutputDataArchive_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OutputDataArchive_getMinorVersion" "', argument " "1"" of type '" "daal::data_management::interface1::OutputDataArchive const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::OutputDataArchive > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::OutputDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::OutputDataArchive * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::OutputDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::OutputDataArchive * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OutputDataArchive_getMinorVersion" "', argument " "1"" of type '" "daal::data_management::interface1::OutputDataArchive const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)((daal::data_management::interface1::OutputDataArchive const *)arg1)->getMinorVersion();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OutputDataArchive_getUpdateVersion(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::OutputDataArchive *arg1 = (daal::data_management::interface1::OutputDataArchive *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::OutputDataArchive const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::OutputDataArchive const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:OutputDataArchive_getUpdateVersion",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__OutputDataArchive_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OutputDataArchive_getUpdateVersion" "', argument " "1"" of type '" "daal::data_management::interface1::OutputDataArchive const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::OutputDataArchive > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::OutputDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::OutputDataArchive * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::OutputDataArchive > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::OutputDataArchive * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OutputDataArchive_getUpdateVersion" "', argument " "1"" of type '" "daal::data_management::interface1::OutputDataArchive const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)((daal::data_management::interface1::OutputDataArchive const *)arg1)->getUpdateVersion();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *OutputDataArchive_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__OutputDataArchive_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_DataCollection_serializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)":DataCollection_serializationTag")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)daal::data_management::interface1::DataCollection::serializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataCollection_getSerializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataCollection *arg1 = (daal::data_management::interface1::DataCollection *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataCollection const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataCollection const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataCollection_getSerializationTag",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataCollection_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataCollection_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::DataCollection const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataCollection > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataCollection > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataCollection * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataCollection > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataCollection * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataCollection_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::DataCollection const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)((daal::data_management::interface1::DataCollection const *)arg1)->getSerializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_DataCollection__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataCollection *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_DataCollection")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::DataCollection *)new daal::data_management::interface1::DataCollection();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::DataCollection > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::DataCollection >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataCollection_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_DataCollection__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataCollection *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataCollection const > tempshared1 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::DataCollection *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:new_DataCollection",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataCollection_t,  0 , &newmem);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_DataCollection" "', argument " "1"" of type '" "daal::data_management::interface1::DataCollection const &""'"); 
    }
    if (!argp1) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_DataCollection" "', argument " "1"" of type '" "daal::data_management::interface1::DataCollection const &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataCollection > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataCollection > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataCollection * >(tempshared1.get());
    } else {
      arg1 = const_cast< daal::data_management::interface1::DataCollection * >(reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataCollection > * >(argp1)->get());
    }
    if(!arg1) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_DataCollection" "', argument " "1"" of type '" "daal::data_management::interface1::DataCollection const &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::DataCollection *)new daal::data_management::interface1::DataCollection((daal::data_management::interface1::DataCollection const &)*arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::DataCollection > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::DataCollection >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataCollection_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_DataCollection__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t val1 ;
  int ecode1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::DataCollection *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:new_DataCollection",&obj0)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_DataCollection" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::DataCollection *)new daal::data_management::interface1::DataCollection(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::DataCollection > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::DataCollection >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataCollection_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_DataCollection(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[2];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 1) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_new_DataCollection__SWIG_0(self, args);
  }
  if (argc == 1) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataCollection_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_DataCollection__SWIG_1(self, args);
    }
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_new_DataCollection__SWIG_2(self, args);
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'new_DataCollection'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::DataCollection::DataCollection()\n"
    "    daal::data_management::interface1::DataCollection::DataCollection(daal::data_management::interface1::DataCollection const &)\n"
    "    daal::data_management::interface1::DataCollection::DataCollection(size_t)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_DataCollection(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataCollection *arg1 = (daal::data_management::interface1::DataCollection *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataCollection > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataCollection > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_DataCollection",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataCollection_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_DataCollection" "', argument " "1"" of type '" "daal::data_management::interface1::DataCollection *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataCollection > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataCollection > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataCollection * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataCollection > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataCollection * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_DataCollection" "', argument " "1"" of type '" "daal::data_management::interface1::DataCollection *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataCollection_get__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataCollection *arg1 = (daal::data_management::interface1::DataCollection *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataCollection > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataCollection > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::data_management::interface1::SerializationIfacePtr *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DataCollection_get",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataCollection_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataCollection_get" "', argument " "1"" of type '" "daal::data_management::interface1::DataCollection *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataCollection > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataCollection > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataCollection * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataCollection > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataCollection * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataCollection_get" "', argument " "1"" of type '" "daal::data_management::interface1::DataCollection *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "DataCollection_get" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::SerializationIfacePtr *) &(arg1)->get(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::SerializationIface > *smartresult = *result ? new daal::services::SharedPtr<  daal::data_management::interface1::SerializationIface >(*result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataCollection_get__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataCollection *arg1 = (daal::data_management::interface1::DataCollection *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataCollection const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataCollection const > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::data_management::interface1::SerializationIfacePtr *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DataCollection_get",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataCollection_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataCollection_get" "', argument " "1"" of type '" "daal::data_management::interface1::DataCollection const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataCollection > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataCollection > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataCollection * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataCollection > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataCollection * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataCollection_get" "', argument " "1"" of type '" "daal::data_management::interface1::DataCollection const *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "DataCollection_get" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::SerializationIfacePtr *) &((daal::data_management::interface1::DataCollection const *)arg1)->get(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::SerializationIface > *smartresult = *result ? new daal::services::SharedPtr<  daal::data_management::interface1::SerializationIface >(*result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataCollection_get(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataCollection_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_DataCollection_get__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataCollection_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_DataCollection_get__SWIG_1(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'DataCollection_get'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::DataCollection::get(size_t)\n"
    "    daal::data_management::interface1::DataCollection::get(size_t) const\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_DataCollection_push_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataCollection *arg1 = (daal::data_management::interface1::DataCollection *) 0 ;
  daal::data_management::interface1::SerializationIfacePtr *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataCollection > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataCollection > *smartarg1 = 0 ;
  void *argp2 ;
  int res2 = 0 ;
  daal::data_management::interface1::SerializationIfacePtr tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::data_management::interface1::DataCollection *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DataCollection_push_back",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataCollection_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataCollection_push_back" "', argument " "1"" of type '" "daal::data_management::interface1::DataCollection *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataCollection > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataCollection > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataCollection * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataCollection > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataCollection * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataCollection_push_back" "', argument " "1"" of type '" "daal::data_management::interface1::DataCollection *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DataCollection_push_back" "', argument " "2"" of type '" "daal::data_management::interface1::SerializationIfacePtr const &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      if (argp2) tempshared2 = *reinterpret_cast< daal::data_management::interface1::SerializationIfacePtr * >(argp2);
      delete reinterpret_cast< daal::data_management::interface1::SerializationIfacePtr * >(argp2);
      arg2 = &tempshared2;
    } else {
      arg2 = (argp2) ? reinterpret_cast< daal::data_management::interface1::SerializationIfacePtr * >(argp2) : &tempshared2;
    }
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::DataCollection *) &(arg1)->push_back((daal::data_management::interface1::SerializationIfacePtr const &)*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::DataCollection > *smartresult = new daal::services::SharedPtr<  daal::data_management::interface1::DataCollection >(result SWIG_NO_NULL_DELETER_0);
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataCollection_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataCollection___lshift__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataCollection *arg1 = (daal::data_management::interface1::DataCollection *) 0 ;
  daal::data_management::interface1::SerializationIfacePtr *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataCollection > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataCollection > *smartarg1 = 0 ;
  void *argp2 ;
  int res2 = 0 ;
  daal::data_management::interface1::SerializationIfacePtr tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::data_management::interface1::DataCollection *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DataCollection___lshift__",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataCollection_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataCollection___lshift__" "', argument " "1"" of type '" "daal::data_management::interface1::DataCollection *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataCollection > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataCollection > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataCollection * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataCollection > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataCollection * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataCollection___lshift__" "', argument " "1"" of type '" "daal::data_management::interface1::DataCollection *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DataCollection___lshift__" "', argument " "2"" of type '" "daal::data_management::interface1::SerializationIfacePtr const &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      if (argp2) tempshared2 = *reinterpret_cast< daal::data_management::interface1::SerializationIfacePtr * >(argp2);
      delete reinterpret_cast< daal::data_management::interface1::SerializationIfacePtr * >(argp2);
      arg2 = &tempshared2;
    } else {
      arg2 = (argp2) ? reinterpret_cast< daal::data_management::interface1::SerializationIfacePtr * >(argp2) : &tempshared2;
    }
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::DataCollection *) &(arg1)->operator <<((daal::data_management::interface1::SerializationIfacePtr const &)*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::DataCollection > *smartresult = new daal::services::SharedPtr<  daal::data_management::interface1::DataCollection >(result SWIG_NO_NULL_DELETER_0);
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataCollection_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataCollection_size(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataCollection *arg1 = (daal::data_management::interface1::DataCollection *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataCollection const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataCollection const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataCollection_size",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataCollection_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataCollection_size" "', argument " "1"" of type '" "daal::data_management::interface1::DataCollection const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataCollection > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataCollection > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataCollection * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataCollection > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataCollection * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataCollection_size" "', argument " "1"" of type '" "daal::data_management::interface1::DataCollection const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::DataCollection const *)arg1)->size();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataCollection_clear(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataCollection *arg1 = (daal::data_management::interface1::DataCollection *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataCollection > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataCollection > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataCollection_clear",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataCollection_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataCollection_clear" "', argument " "1"" of type '" "daal::data_management::interface1::DataCollection *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataCollection > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataCollection > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataCollection * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataCollection > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataCollection * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataCollection_clear" "', argument " "1"" of type '" "daal::data_management::interface1::DataCollection *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->clear();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataCollection_erase(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataCollection *arg1 = (daal::data_management::interface1::DataCollection *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataCollection > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataCollection > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DataCollection_erase",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataCollection_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataCollection_erase" "', argument " "1"" of type '" "daal::data_management::interface1::DataCollection *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataCollection > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataCollection > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataCollection * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataCollection > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataCollection * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataCollection_erase" "', argument " "1"" of type '" "daal::data_management::interface1::DataCollection *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "DataCollection_erase" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->erase(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataCollection_resize(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataCollection *arg1 = (daal::data_management::interface1::DataCollection *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataCollection > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataCollection > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DataCollection_resize",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataCollection_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataCollection_resize" "', argument " "1"" of type '" "daal::data_management::interface1::DataCollection *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataCollection > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataCollection > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataCollection * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataCollection > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataCollection * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataCollection_resize" "', argument " "1"" of type '" "daal::data_management::interface1::DataCollection *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "DataCollection_resize" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (bool)(arg1)->resize(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataCollection___getitem__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataCollection *arg1 = (daal::data_management::interface1::DataCollection *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataCollection > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataCollection > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::data_management::interface1::SerializationIfacePtr *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DataCollection___getitem__",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataCollection_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataCollection___getitem__" "', argument " "1"" of type '" "daal::data_management::interface1::DataCollection *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataCollection > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataCollection > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataCollection * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataCollection > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataCollection * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataCollection___getitem__" "', argument " "1"" of type '" "daal::data_management::interface1::DataCollection *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "DataCollection___getitem__" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::SerializationIfacePtr *) &daal_data_management_interface1_DataCollection___getitem__(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::SerializationIface > *smartresult = *result ? new daal::services::SharedPtr<  daal::data_management::interface1::SerializationIface >(*result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataCollection___setitem__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataCollection *arg1 = (daal::data_management::interface1::DataCollection *) 0 ;
  size_t arg2 ;
  daal::data_management::interface1::SerializationIfacePtr *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataCollection > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataCollection > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 ;
  int res3 = 0 ;
  daal::data_management::interface1::SerializationIfacePtr tempshared3 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::data_management::interface1::SerializationIfacePtr *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:DataCollection___setitem__",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataCollection_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataCollection___setitem__" "', argument " "1"" of type '" "daal::data_management::interface1::DataCollection *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataCollection > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataCollection > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataCollection * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataCollection > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataCollection * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataCollection___setitem__" "', argument " "1"" of type '" "daal::data_management::interface1::DataCollection *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "DataCollection___setitem__" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t,  0 , &newmem);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "DataCollection___setitem__" "', argument " "3"" of type '" "daal::data_management::interface1::SerializationIfacePtr &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      if (argp3) tempshared3 = *reinterpret_cast< daal::data_management::interface1::SerializationIfacePtr * >(argp3);
      delete reinterpret_cast< daal::data_management::interface1::SerializationIfacePtr * >(argp3);
      arg3 = &tempshared3;
    } else {
      arg3 = (argp3) ? reinterpret_cast< daal::data_management::interface1::SerializationIfacePtr * >(argp3) : &tempshared3;
    }
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::SerializationIfacePtr *) &daal_data_management_interface1_DataCollection___setitem__(arg1,arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::SerializationIface > *smartresult = *result ? new daal::services::SharedPtr<  daal::data_management::interface1::SerializationIface >(*result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *DataCollection_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataCollection_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_NumericTableFeature_indexType_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTableFeature *arg1 = (daal::data_management::interface1::NumericTableFeature *) 0 ;
  daal::data_management::features::IndexNumType arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableFeature > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableFeature > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:NumericTableFeature_indexType_set",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableFeature_indexType_set" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableFeature *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableFeature * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableFeature * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableFeature_indexType_set" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableFeature *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "NumericTableFeature_indexType_set" "', argument " "2"" of type '" "daal::data_management::features::IndexNumType""'");
  } 
  arg2 = static_cast< daal::data_management::features::IndexNumType >(val2);
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    if (arg1) (arg1)->indexType = arg2;
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTableFeature_indexType_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTableFeature *arg1 = (daal::data_management::interface1::NumericTableFeature *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableFeature > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableFeature > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::features::IndexNumType result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:NumericTableFeature_indexType_get",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableFeature_indexType_get" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableFeature *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableFeature * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableFeature * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableFeature_indexType_get" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableFeature *""'"); 
  }
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    result = (daal::data_management::features::IndexNumType) ((arg1)->indexType);
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTableFeature_pmmlType_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTableFeature *arg1 = (daal::data_management::interface1::NumericTableFeature *) 0 ;
  daal::data_management::features::PMMLNumType arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableFeature > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableFeature > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:NumericTableFeature_pmmlType_set",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableFeature_pmmlType_set" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableFeature *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableFeature * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableFeature * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableFeature_pmmlType_set" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableFeature *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "NumericTableFeature_pmmlType_set" "', argument " "2"" of type '" "daal::data_management::features::PMMLNumType""'");
  } 
  arg2 = static_cast< daal::data_management::features::PMMLNumType >(val2);
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    if (arg1) (arg1)->pmmlType = arg2;
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTableFeature_pmmlType_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTableFeature *arg1 = (daal::data_management::interface1::NumericTableFeature *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableFeature > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableFeature > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::features::PMMLNumType result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:NumericTableFeature_pmmlType_get",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableFeature_pmmlType_get" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableFeature *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableFeature * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableFeature * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableFeature_pmmlType_get" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableFeature *""'"); 
  }
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    result = (daal::data_management::features::PMMLNumType) ((arg1)->pmmlType);
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTableFeature_featureType_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTableFeature *arg1 = (daal::data_management::interface1::NumericTableFeature *) 0 ;
  daal::data_management::features::FeatureType arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableFeature > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableFeature > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:NumericTableFeature_featureType_set",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableFeature_featureType_set" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableFeature *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableFeature * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableFeature * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableFeature_featureType_set" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableFeature *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "NumericTableFeature_featureType_set" "', argument " "2"" of type '" "daal::data_management::features::FeatureType""'");
  } 
  arg2 = static_cast< daal::data_management::features::FeatureType >(val2);
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    if (arg1) (arg1)->featureType = arg2;
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTableFeature_featureType_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTableFeature *arg1 = (daal::data_management::interface1::NumericTableFeature *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableFeature > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableFeature > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::features::FeatureType result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:NumericTableFeature_featureType_get",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableFeature_featureType_get" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableFeature *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableFeature * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableFeature * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableFeature_featureType_get" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableFeature *""'"); 
  }
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    result = (daal::data_management::features::FeatureType) ((arg1)->featureType);
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTableFeature_typeSize_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTableFeature *arg1 = (daal::data_management::interface1::NumericTableFeature *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableFeature > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableFeature > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:NumericTableFeature_typeSize_set",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableFeature_typeSize_set" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableFeature *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableFeature * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableFeature * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableFeature_typeSize_set" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableFeature *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "NumericTableFeature_typeSize_set" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    if (arg1) (arg1)->typeSize = arg2;
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTableFeature_typeSize_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTableFeature *arg1 = (daal::data_management::interface1::NumericTableFeature *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableFeature > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableFeature > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:NumericTableFeature_typeSize_get",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableFeature_typeSize_get" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableFeature *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableFeature * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableFeature * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableFeature_typeSize_get" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableFeature *""'"); 
  }
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    result =  ((arg1)->typeSize);
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTableFeature_categoryNumber_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTableFeature *arg1 = (daal::data_management::interface1::NumericTableFeature *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableFeature > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableFeature > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:NumericTableFeature_categoryNumber_set",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableFeature_categoryNumber_set" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableFeature *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableFeature * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableFeature * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableFeature_categoryNumber_set" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableFeature *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "NumericTableFeature_categoryNumber_set" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    if (arg1) (arg1)->categoryNumber = arg2;
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTableFeature_categoryNumber_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTableFeature *arg1 = (daal::data_management::interface1::NumericTableFeature *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableFeature > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableFeature > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:NumericTableFeature_categoryNumber_get",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableFeature_categoryNumber_get" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableFeature *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableFeature * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableFeature * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableFeature_categoryNumber_get" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableFeature *""'"); 
  }
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    result =  ((arg1)->categoryNumber);
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_NumericTableFeature(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTableFeature *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_NumericTableFeature")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::NumericTableFeature *)new daal::data_management::interface1::NumericTableFeature();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_NumericTableFeature(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTableFeature *arg1 = (daal::data_management::interface1::NumericTableFeature *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableFeature > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableFeature > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_NumericTableFeature",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_NumericTableFeature" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableFeature *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableFeature * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableFeature * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_NumericTableFeature" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableFeature *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTableFeature_getSerializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTableFeature *arg1 = (daal::data_management::interface1::NumericTableFeature *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableFeature const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableFeature const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:NumericTableFeature_getSerializationTag",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableFeature_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableFeature const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTableFeature > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTableFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableFeature * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTableFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableFeature * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableFeature_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableFeature const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)((daal::data_management::interface1::NumericTableFeature const *)arg1)->getSerializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTableFeature_getIndexType(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTableFeature *arg1 = (daal::data_management::interface1::NumericTableFeature *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableFeature const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableFeature const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::features::IndexNumType result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:NumericTableFeature_getIndexType",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableFeature_getIndexType" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableFeature const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTableFeature > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTableFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableFeature * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTableFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableFeature * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableFeature_getIndexType" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableFeature const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::features::IndexNumType)((daal::data_management::interface1::NumericTableFeature const *)arg1)->getIndexType();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTableFeature_setType_Float64(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTableFeature *arg1 = (daal::data_management::interface1::NumericTableFeature *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableFeature > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableFeature > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:NumericTableFeature_setType_Float64",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableFeature_setType_Float64" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableFeature *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableFeature * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableFeature * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableFeature_setType_Float64" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableFeature *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->SWIGTEMPLATEDISAMBIGUATOR setType< double >();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTableFeature_setType_Float32(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTableFeature *arg1 = (daal::data_management::interface1::NumericTableFeature *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableFeature > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableFeature > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:NumericTableFeature_setType_Float32",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableFeature_setType_Float32" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableFeature *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableFeature * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableFeature * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableFeature_setType_Float32" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableFeature *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->SWIGTEMPLATEDISAMBIGUATOR setType< float >();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTableFeature_setType_Intc(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTableFeature *arg1 = (daal::data_management::interface1::NumericTableFeature *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableFeature > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableFeature > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:NumericTableFeature_setType_Intc",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableFeature_setType_Intc" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableFeature *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableFeature * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableFeature * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableFeature_setType_Intc" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableFeature *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->SWIGTEMPLATEDISAMBIGUATOR setType< int >();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *NumericTableFeature_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_DictionaryIface(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_DictionaryIface")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::DictionaryIface *)new daal::data_management::interface1::DictionaryIface();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::DictionaryIface > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::DictionaryIface >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryIface_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_DictionaryIface(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface *arg1 = (daal::data_management::interface1::DictionaryIface *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DictionaryIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DictionaryIface > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_DictionaryIface",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_DictionaryIface" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DictionaryIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DictionaryIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DictionaryIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DictionaryIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DictionaryIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_DictionaryIface" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *DictionaryIface_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryIface_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_CategoricalFeatureDictionary(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CategoricalFeatureDictionary *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_CategoricalFeatureDictionary")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::CategoricalFeatureDictionary *)new daal::data_management::interface1::CategoricalFeatureDictionary();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_daal__data_management__interface1__CategoricalFeatureDictionary, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_CategoricalFeatureDictionary(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CategoricalFeatureDictionary *arg1 = (daal::data_management::interface1::CategoricalFeatureDictionary *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_CategoricalFeatureDictionary",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__interface1__CategoricalFeatureDictionary, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_CategoricalFeatureDictionary" "', argument " "1"" of type '" "daal::data_management::interface1::CategoricalFeatureDictionary *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::interface1::CategoricalFeatureDictionary * >(argp1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete arg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *CategoricalFeatureDictionary_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__data_management__interface1__CategoricalFeatureDictionary, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_DataSourceFeature_ntFeature_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSourceFeature *arg1 = (daal::data_management::interface1::DataSourceFeature *) 0 ;
  daal::data_management::interface1::NumericTableFeature *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableFeature const > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DataSourceFeature_ntFeature_set",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceFeature_ntFeature_set" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceFeature *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceFeature * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceFeature * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceFeature_ntFeature_set" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceFeature *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DataSourceFeature_ntFeature_set" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTableFeature const &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "DataSourceFeature_ntFeature_set" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTableFeature const &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTableFeature > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTableFeature > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::NumericTableFeature * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::NumericTableFeature * >(reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTableFeature > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DataSourceFeature_ntFeature_set" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTableFeature const &""'"); 
  }
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    if (arg1) (arg1)->ntFeature = *arg2;
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceFeature_ntFeature_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSourceFeature *arg1 = (daal::data_management::interface1::DataSourceFeature *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::NumericTableFeature *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataSourceFeature_ntFeature_get",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceFeature_ntFeature_get" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceFeature *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceFeature * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceFeature * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceFeature_ntFeature_get" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceFeature *""'"); 
  }
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    result = (daal::data_management::interface1::NumericTableFeature *) & ((arg1)->ntFeature);
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  {
    daal::services::SharedPtr< const daal::data_management::interface1::NumericTableFeature > *smartresult = new daal::services::SharedPtr< const daal::data_management::interface1::NumericTableFeature >(result SWIG_NO_NULL_DELETER_0);
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceFeature_name_length_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSourceFeature *arg1 = (daal::data_management::interface1::DataSourceFeature *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DataSourceFeature_name_length_set",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceFeature_name_length_set" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceFeature *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceFeature * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceFeature * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceFeature_name_length_set" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceFeature *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "DataSourceFeature_name_length_set" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    if (arg1) (arg1)->name_length = arg2;
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceFeature_name_length_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSourceFeature *arg1 = (daal::data_management::interface1::DataSourceFeature *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataSourceFeature_name_length_get",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceFeature_name_length_get" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceFeature *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceFeature * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceFeature * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceFeature_name_length_get" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceFeature *""'"); 
  }
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    result =  ((arg1)->name_length);
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceFeature_name_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSourceFeature *arg1 = (daal::data_management::interface1::DataSourceFeature *) 0 ;
  char *arg2 = (char *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature > *smartarg1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DataSourceFeature_name_set",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceFeature_name_set" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceFeature *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceFeature * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceFeature * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceFeature_name_set" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceFeature *""'"); 
  }
  res2 = SWIG_AsCharPtrAndSize(obj1, &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DataSourceFeature_name_set" "', argument " "2"" of type '" "char *""'");
  }
  arg2 = reinterpret_cast< char * >(buf2);
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    if (arg1->name) delete[] arg1->name;
    if (arg2) {
      size_t size = strlen(reinterpret_cast< const char * >(arg2)) + 1;
      arg1->name = (char *)reinterpret_cast< char* >(memcpy((new char[size]), reinterpret_cast< const char * >(arg2), sizeof(char)*(size)));
    } else {
      arg1->name = 0;
    }
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceFeature_name_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSourceFeature *arg1 = (daal::data_management::interface1::DataSourceFeature *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  char *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataSourceFeature_name_get",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceFeature_name_get" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceFeature *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceFeature * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceFeature * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceFeature_name_get" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceFeature *""'"); 
  }
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    result = (char *) ((arg1)->name);
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_FromCharPtr((const char *)result);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceFeature_cat_dict_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSourceFeature *arg1 = (daal::data_management::interface1::DataSourceFeature *) 0 ;
  daal::data_management::interface1::CategoricalFeatureDictionary *arg2 = (daal::data_management::interface1::CategoricalFeatureDictionary *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DataSourceFeature_cat_dict_set",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceFeature_cat_dict_set" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceFeature *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceFeature * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceFeature * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceFeature_cat_dict_set" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceFeature *""'"); 
  }
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_daal__data_management__interface1__CategoricalFeatureDictionary, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DataSourceFeature_cat_dict_set" "', argument " "2"" of type '" "daal::data_management::interface1::CategoricalFeatureDictionary *""'"); 
  }
  arg2 = reinterpret_cast< daal::data_management::interface1::CategoricalFeatureDictionary * >(argp2);
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    if (arg1) (arg1)->cat_dict = arg2;
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceFeature_cat_dict_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSourceFeature *arg1 = (daal::data_management::interface1::DataSourceFeature *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::CategoricalFeatureDictionary *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataSourceFeature_cat_dict_get",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceFeature_cat_dict_get" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceFeature *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceFeature * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceFeature * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceFeature_cat_dict_get" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceFeature *""'"); 
  }
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    result = (daal::data_management::interface1::CategoricalFeatureDictionary *) ((arg1)->cat_dict);
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_daal__data_management__interface1__CategoricalFeatureDictionary, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_DataSourceFeature__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSourceFeature *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_DataSourceFeature")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::DataSourceFeature *)new daal::data_management::interface1::DataSourceFeature();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_DataSourceFeature__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSourceFeature *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature const > tempshared1 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::DataSourceFeature *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:new_DataSourceFeature",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t,  0 , &newmem);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_DataSourceFeature" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceFeature const &""'"); 
    }
    if (!argp1) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_DataSourceFeature" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceFeature const &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataSourceFeature > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataSourceFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceFeature * >(tempshared1.get());
    } else {
      arg1 = const_cast< daal::data_management::interface1::DataSourceFeature * >(reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataSourceFeature > * >(argp1)->get());
    }
    if(!arg1) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_DataSourceFeature" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceFeature const &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::DataSourceFeature *)new daal::data_management::interface1::DataSourceFeature((daal::data_management::interface1::DataSourceFeature const &)*arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_DataSourceFeature(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[2];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 1) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_new_DataSourceFeature__SWIG_0(self, args);
  }
  if (argc == 1) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_DataSourceFeature__SWIG_1(self, args);
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'new_DataSourceFeature'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::DataSourceFeature::DataSourceFeature()\n"
    "    daal::data_management::interface1::DataSourceFeature::DataSourceFeature(daal::data_management::interface1::DataSourceFeature const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_DataSourceFeature(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSourceFeature *arg1 = (daal::data_management::interface1::DataSourceFeature *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_DataSourceFeature",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_DataSourceFeature" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceFeature *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceFeature * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceFeature * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_DataSourceFeature" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceFeature *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceFeature_getFeatureName(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSourceFeature *arg1 = (daal::data_management::interface1::DataSourceFeature *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::String result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataSourceFeature_getFeatureName",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceFeature_getFeatureName" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceFeature const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataSourceFeature > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataSourceFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceFeature * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataSourceFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceFeature * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceFeature_getFeatureName" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceFeature const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::DataSourceFeature const *)arg1)->getFeatureName();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::String(static_cast< const daal::services::String& >(result))), SWIGTYPE_p_daal__services__String, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceFeature_getCategoricalDictionary(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSourceFeature *arg1 = (daal::data_management::interface1::DataSourceFeature *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::CategoricalFeatureDictionary *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataSourceFeature_getCategoricalDictionary",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceFeature_getCategoricalDictionary" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceFeature *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceFeature * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceFeature * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceFeature_getCategoricalDictionary" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceFeature *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::CategoricalFeatureDictionary *)(arg1)->getCategoricalDictionary();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_daal__data_management__interface1__CategoricalFeatureDictionary, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceFeature_setCategoricalDictionary(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSourceFeature *arg1 = (daal::data_management::interface1::DataSourceFeature *) 0 ;
  daal::data_management::interface1::CategoricalFeatureDictionaryPtr *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DataSourceFeature_setCategoricalDictionary",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceFeature_setCategoricalDictionary" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceFeature *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceFeature * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceFeature * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceFeature_setCategoricalDictionary" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceFeature *""'"); 
  }
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CategoricalFeatureDictionary_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DataSourceFeature_setCategoricalDictionary" "', argument " "2"" of type '" "daal::data_management::interface1::CategoricalFeatureDictionaryPtr const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "DataSourceFeature_setCategoricalDictionary" "', argument " "2"" of type '" "daal::data_management::interface1::CategoricalFeatureDictionaryPtr const &""'"); 
  }
  arg2 = reinterpret_cast< daal::data_management::interface1::CategoricalFeatureDictionaryPtr * >(argp2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->setCategoricalDictionary((daal::data_management::interface1::CategoricalFeatureDictionaryPtr const &)*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceFeature_setFeatureName(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSourceFeature *arg1 = (daal::data_management::interface1::DataSourceFeature *) 0 ;
  daal::services::String *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DataSourceFeature_setFeatureName",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceFeature_setFeatureName" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceFeature *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceFeature * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceFeature * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceFeature_setFeatureName" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceFeature *""'"); 
  }
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_daal__services__String,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DataSourceFeature_setFeatureName" "', argument " "2"" of type '" "daal::services::String const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "DataSourceFeature_setFeatureName" "', argument " "2"" of type '" "daal::services::String const &""'"); 
  }
  arg2 = reinterpret_cast< daal::services::String * >(argp2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->setFeatureName((daal::services::String const &)*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceFeature_getSerializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSourceFeature *arg1 = (daal::data_management::interface1::DataSourceFeature *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataSourceFeature_getSerializationTag",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceFeature_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceFeature const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataSourceFeature > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataSourceFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceFeature * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataSourceFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceFeature * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceFeature_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceFeature const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)((daal::data_management::interface1::DataSourceFeature const *)arg1)->getSerializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceFeature_getIndexType(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSourceFeature *arg1 = (daal::data_management::interface1::DataSourceFeature *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::features::IndexNumType result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataSourceFeature_getIndexType",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceFeature_getIndexType" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceFeature const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataSourceFeature > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataSourceFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceFeature * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataSourceFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceFeature * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceFeature_getIndexType" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceFeature const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::features::IndexNumType)((daal::data_management::interface1::DataSourceFeature const *)arg1)->getIndexType();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceFeature_setType_Float64(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSourceFeature *arg1 = (daal::data_management::interface1::DataSourceFeature *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataSourceFeature_setType_Float64",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceFeature_setType_Float64" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceFeature *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceFeature * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceFeature * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceFeature_setType_Float64" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceFeature *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->SWIGTEMPLATEDISAMBIGUATOR setType< double >();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceFeature_setType_Float32(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSourceFeature *arg1 = (daal::data_management::interface1::DataSourceFeature *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataSourceFeature_setType_Float32",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceFeature_setType_Float32" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceFeature *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceFeature * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceFeature * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceFeature_setType_Float32" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceFeature *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->SWIGTEMPLATEDISAMBIGUATOR setType< float >();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceFeature_setType_Intc(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSourceFeature *arg1 = (daal::data_management::interface1::DataSourceFeature *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataSourceFeature_setType_Intc",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceFeature_setType_Intc" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceFeature *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceFeature * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceFeature * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceFeature_setType_Intc" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceFeature *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->SWIGTEMPLATEDISAMBIGUATOR setType< int >();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *DataSourceFeature_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_delete_NumericTableIface(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTableIface *arg1 = (daal::data_management::interface1::NumericTableIface *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_NumericTableIface",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_NumericTableIface" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_NumericTableIface" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableIface *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTableIface_setDictionary(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTableIface *arg1 = (daal::data_management::interface1::NumericTableIface *) 0 ;
  daal::data_management::interface1::NumericTableDictionary *arg2 = (daal::data_management::interface1::NumericTableDictionary *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > > tempshared2 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > > *smartarg2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:NumericTableIface_setDictionary",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableIface_setDictionary" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableIface_setDictionary" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableIface *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res2) || !argp2) && obj1 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "NumericTableIface_setDictionary" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTableDictionary *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::NumericTableDictionary * >(tempshared2.get());
    } else {
      smartarg2 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::NumericTableDictionary * >((smartarg2 ? smartarg2->get() : 0));
    }
    if(!arg2 && obj1 != Py_None) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "NumericTableIface_setDictionary" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTableDictionary *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->setDictionary(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTableIface_getDictionary(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTableIface *arg1 = (daal::data_management::interface1::NumericTableIface *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::NumericTableDictionary *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:NumericTableIface_getDictionary",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableIface_getDictionary" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableIface const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableIface_getDictionary" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableIface const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::NumericTableDictionary *)((daal::data_management::interface1::NumericTableIface const *)arg1)->getDictionary();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > >(result SWIG_NO_NULL_DELETER_0) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t, 0 | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTableIface_resetDictionary(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTableIface *arg1 = (daal::data_management::interface1::NumericTableIface *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:NumericTableIface_resetDictionary",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableIface_resetDictionary" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableIface_resetDictionary" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableIface *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->resetDictionary();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTableIface_getFeatureType(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTableIface *arg1 = (daal::data_management::interface1::NumericTableIface *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface const > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::data_management::features::FeatureType result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:NumericTableIface_getFeatureType",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableIface_getFeatureType" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableIface const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableIface_getFeatureType" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableIface const *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "NumericTableIface_getFeatureType" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::features::FeatureType)((daal::data_management::interface1::NumericTableIface const *)arg1)->getFeatureType(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTableIface_getNumberOfCategories(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTableIface *arg1 = (daal::data_management::interface1::NumericTableIface *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface const > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:NumericTableIface_getNumberOfCategories",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableIface_getNumberOfCategories" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableIface const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableIface_getNumberOfCategories" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableIface const *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "NumericTableIface_getNumberOfCategories" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::NumericTableIface const *)arg1)->getNumberOfCategories(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTableIface_getDataLayout(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTableIface *arg1 = (daal::data_management::interface1::NumericTableIface *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::NumericTableIface::StorageLayout result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:NumericTableIface_getDataLayout",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableIface_getDataLayout" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableIface const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableIface_getDataLayout" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableIface const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::NumericTableIface::StorageLayout)((daal::data_management::interface1::NumericTableIface const *)arg1)->getDataLayout();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTableIface_resize(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTableIface *arg1 = (daal::data_management::interface1::NumericTableIface *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:NumericTableIface_resize",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableIface_resize" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableIface_resize" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableIface *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "NumericTableIface_resize" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->resize(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTableIface_setNumberOfColumns(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTableIface *arg1 = (daal::data_management::interface1::NumericTableIface *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:NumericTableIface_setNumberOfColumns",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableIface_setNumberOfColumns" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableIface_setNumberOfColumns" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableIface *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "NumericTableIface_setNumberOfColumns" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->setNumberOfColumns(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTableIface_setNumberOfRows(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTableIface *arg1 = (daal::data_management::interface1::NumericTableIface *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:NumericTableIface_setNumberOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableIface_setNumberOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableIface_setNumberOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableIface *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "NumericTableIface_setNumberOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->setNumberOfRows(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTableIface_allocateDataMemory__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTableIface *arg1 = (daal::data_management::interface1::NumericTableIface *) 0 ;
  daal::MemType arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:NumericTableIface_allocateDataMemory",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableIface_allocateDataMemory" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableIface_allocateDataMemory" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableIface *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "NumericTableIface_allocateDataMemory" "', argument " "2"" of type '" "daal::MemType""'");
  } 
  arg2 = static_cast< daal::MemType >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->allocateDataMemory(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTableIface_allocateDataMemory__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTableIface *arg1 = (daal::data_management::interface1::NumericTableIface *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:NumericTableIface_allocateDataMemory",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableIface_allocateDataMemory" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableIface_allocateDataMemory" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableIface *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->allocateDataMemory();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTableIface_allocateDataMemory(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_NumericTableIface_allocateDataMemory__SWIG_1(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_NumericTableIface_allocateDataMemory__SWIG_0(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'NumericTableIface_allocateDataMemory'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::NumericTableIface::allocateDataMemory(daal::MemType)\n"
    "    daal::data_management::interface1::NumericTableIface::allocateDataMemory()\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_NumericTableIface_freeDataMemory(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTableIface *arg1 = (daal::data_management::interface1::NumericTableIface *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:NumericTableIface_freeDataMemory",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableIface_freeDataMemory" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableIface_freeDataMemory" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableIface *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->freeDataMemory();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTableIface_allocateBasicStatistics(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTableIface *arg1 = (daal::data_management::interface1::NumericTableIface *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:NumericTableIface_allocateBasicStatistics",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableIface_allocateBasicStatistics" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableIface_allocateBasicStatistics" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableIface *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->allocateBasicStatistics();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTableIface_check__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTableIface *arg1 = (daal::data_management::interface1::NumericTableIface *) 0 ;
  char *arg2 = (char *) 0 ;
  bool arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface const > *smartarg1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  bool val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:NumericTableIface_check",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableIface_check" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableIface const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableIface_check" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableIface const *""'"); 
  }
  res2 = SWIG_AsCharPtrAndSize(obj1, &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "NumericTableIface_check" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = reinterpret_cast< char * >(buf2);
  ecode3 = SWIG_AsVal_bool(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "NumericTableIface_check" "', argument " "3"" of type '" "bool""'");
  } 
  arg3 = static_cast< bool >(val3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::NumericTableIface const *)arg1)->check((char const *)arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTableIface_check__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTableIface *arg1 = (daal::data_management::interface1::NumericTableIface *) 0 ;
  char *arg2 = (char *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface const > *smartarg1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:NumericTableIface_check",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableIface_check" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableIface const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableIface_check" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableIface const *""'"); 
  }
  res2 = SWIG_AsCharPtrAndSize(obj1, &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "NumericTableIface_check" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = reinterpret_cast< char * >(buf2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::NumericTableIface const *)arg1)->check((char const *)arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTableIface_check(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[4];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 3) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_AsCharPtrAndSize(argv[1], 0, NULL, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_NumericTableIface_check__SWIG_1(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_AsCharPtrAndSize(argv[1], 0, NULL, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_bool(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_NumericTableIface_check__SWIG_0(self, args);
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'NumericTableIface_check'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::NumericTableIface::check(char const *,bool) const\n"
    "    daal::data_management::interface1::NumericTableIface::check(char const *) const\n");
  return 0;
}


SWIGINTERN PyObject *NumericTableIface_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN int Swig_var_packed_mask_set(PyObject *) {
  SWIG_Error(SWIG_AttributeError,"Variable packed_mask is read-only.");
  return 1;
}


SWIGINTERN PyObject *Swig_var_packed_mask_get(void) {
  PyObject *pyobj = 0;
  
  pyobj = SWIG_From_int(static_cast< int >(daal::data_management::packed_mask));
  return pyobj;
}


SWIGINTERN PyObject *_wrap_delete_DenseNumericTableIface(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DenseNumericTableIface *arg1 = (daal::data_management::interface1::DenseNumericTableIface *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_DenseNumericTableIface",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_DenseNumericTableIface" "', argument " "1"" of type '" "daal::data_management::interface1::DenseNumericTableIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseNumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseNumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_DenseNumericTableIface" "', argument " "1"" of type '" "daal::data_management::interface1::DenseNumericTableIface *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DenseNumericTableIface_getBlockOfRows__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DenseNumericTableIface *arg1 = (daal::data_management::interface1::DenseNumericTableIface *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:DenseNumericTableIface_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseNumericTableIface_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::DenseNumericTableIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseNumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseNumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseNumericTableIface_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::DenseNumericTableIface *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "DenseNumericTableIface_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "DenseNumericTableIface_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "DenseNumericTableIface_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "DenseNumericTableIface_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "DenseNumericTableIface_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "DenseNumericTableIface_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DenseNumericTableIface_getBlockOfRows__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DenseNumericTableIface *arg1 = (daal::data_management::interface1::DenseNumericTableIface *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:DenseNumericTableIface_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseNumericTableIface_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::DenseNumericTableIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseNumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseNumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseNumericTableIface_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::DenseNumericTableIface *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "DenseNumericTableIface_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "DenseNumericTableIface_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "DenseNumericTableIface_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "DenseNumericTableIface_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "DenseNumericTableIface_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "DenseNumericTableIface_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DenseNumericTableIface_getBlockOfRows__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DenseNumericTableIface *arg1 = (daal::data_management::interface1::DenseNumericTableIface *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:DenseNumericTableIface_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseNumericTableIface_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::DenseNumericTableIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseNumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseNumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseNumericTableIface_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::DenseNumericTableIface *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "DenseNumericTableIface_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "DenseNumericTableIface_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "DenseNumericTableIface_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "DenseNumericTableIface_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "DenseNumericTableIface_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "DenseNumericTableIface_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DenseNumericTableIface_getBlockOfRows(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[6];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 5) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_DenseNumericTableIface_getBlockOfRows__SWIG_0(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_DenseNumericTableIface_getBlockOfRows__SWIG_1(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_DenseNumericTableIface_getBlockOfRows__SWIG_2(self, args);
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'DenseNumericTableIface_getBlockOfRows'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::DenseNumericTableIface::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::DenseNumericTableIface::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::DenseNumericTableIface::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_DenseNumericTableIface_releaseBlockOfRows__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DenseNumericTableIface *arg1 = (daal::data_management::interface1::DenseNumericTableIface *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DenseNumericTableIface_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseNumericTableIface_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::DenseNumericTableIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseNumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseNumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseNumericTableIface_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::DenseNumericTableIface *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DenseNumericTableIface_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "DenseNumericTableIface_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DenseNumericTableIface_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DenseNumericTableIface_releaseBlockOfRows__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DenseNumericTableIface *arg1 = (daal::data_management::interface1::DenseNumericTableIface *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DenseNumericTableIface_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseNumericTableIface_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::DenseNumericTableIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseNumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseNumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseNumericTableIface_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::DenseNumericTableIface *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DenseNumericTableIface_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "DenseNumericTableIface_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DenseNumericTableIface_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DenseNumericTableIface_releaseBlockOfRows__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DenseNumericTableIface *arg1 = (daal::data_management::interface1::DenseNumericTableIface *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DenseNumericTableIface_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseNumericTableIface_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::DenseNumericTableIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseNumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseNumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseNumericTableIface_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::DenseNumericTableIface *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DenseNumericTableIface_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "DenseNumericTableIface_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DenseNumericTableIface_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DenseNumericTableIface_releaseBlockOfRows(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_DenseNumericTableIface_releaseBlockOfRows__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_DenseNumericTableIface_releaseBlockOfRows__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_DenseNumericTableIface_releaseBlockOfRows__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'DenseNumericTableIface_releaseBlockOfRows'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::DenseNumericTableIface::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::DenseNumericTableIface::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::DenseNumericTableIface::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_DenseNumericTableIface_getBlockOfColumnValues__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DenseNumericTableIface *arg1 = (daal::data_management::interface1::DenseNumericTableIface *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:DenseNumericTableIface_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseNumericTableIface_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::DenseNumericTableIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseNumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseNumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseNumericTableIface_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::DenseNumericTableIface *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "DenseNumericTableIface_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "DenseNumericTableIface_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "DenseNumericTableIface_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "DenseNumericTableIface_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "DenseNumericTableIface_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "DenseNumericTableIface_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "DenseNumericTableIface_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DenseNumericTableIface_getBlockOfColumnValues__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DenseNumericTableIface *arg1 = (daal::data_management::interface1::DenseNumericTableIface *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:DenseNumericTableIface_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseNumericTableIface_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::DenseNumericTableIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseNumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseNumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseNumericTableIface_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::DenseNumericTableIface *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "DenseNumericTableIface_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "DenseNumericTableIface_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "DenseNumericTableIface_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "DenseNumericTableIface_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "DenseNumericTableIface_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "DenseNumericTableIface_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "DenseNumericTableIface_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DenseNumericTableIface_getBlockOfColumnValues__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DenseNumericTableIface *arg1 = (daal::data_management::interface1::DenseNumericTableIface *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:DenseNumericTableIface_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseNumericTableIface_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::DenseNumericTableIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseNumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseNumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseNumericTableIface_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::DenseNumericTableIface *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "DenseNumericTableIface_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "DenseNumericTableIface_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "DenseNumericTableIface_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "DenseNumericTableIface_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "DenseNumericTableIface_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "DenseNumericTableIface_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "DenseNumericTableIface_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DenseNumericTableIface_getBlockOfColumnValues(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[7];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 6) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_DenseNumericTableIface_getBlockOfColumnValues__SWIG_0(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_DenseNumericTableIface_getBlockOfColumnValues__SWIG_1(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_DenseNumericTableIface_getBlockOfColumnValues__SWIG_2(self, args);
              }
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'DenseNumericTableIface_getBlockOfColumnValues'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::DenseNumericTableIface::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::DenseNumericTableIface::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::DenseNumericTableIface::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_DenseNumericTableIface_releaseBlockOfColumnValues__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DenseNumericTableIface *arg1 = (daal::data_management::interface1::DenseNumericTableIface *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DenseNumericTableIface_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseNumericTableIface_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::DenseNumericTableIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseNumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseNumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseNumericTableIface_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::DenseNumericTableIface *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DenseNumericTableIface_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "DenseNumericTableIface_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DenseNumericTableIface_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DenseNumericTableIface_releaseBlockOfColumnValues__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DenseNumericTableIface *arg1 = (daal::data_management::interface1::DenseNumericTableIface *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DenseNumericTableIface_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseNumericTableIface_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::DenseNumericTableIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseNumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseNumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseNumericTableIface_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::DenseNumericTableIface *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DenseNumericTableIface_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "DenseNumericTableIface_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DenseNumericTableIface_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DenseNumericTableIface_releaseBlockOfColumnValues__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DenseNumericTableIface *arg1 = (daal::data_management::interface1::DenseNumericTableIface *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DenseNumericTableIface_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseNumericTableIface_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::DenseNumericTableIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseNumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseNumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseNumericTableIface_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::DenseNumericTableIface *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DenseNumericTableIface_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "DenseNumericTableIface_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DenseNumericTableIface_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DenseNumericTableIface_releaseBlockOfColumnValues(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_DenseNumericTableIface_releaseBlockOfColumnValues__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_DenseNumericTableIface_releaseBlockOfColumnValues__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_DenseNumericTableIface_releaseBlockOfColumnValues__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'DenseNumericTableIface_releaseBlockOfColumnValues'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::DenseNumericTableIface::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::DenseNumericTableIface::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::DenseNumericTableIface::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_DenseNumericTableIface_getBlockOfRowsAsDouble(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DenseNumericTableIface *arg1 = (daal::data_management::interface1::DenseNumericTableIface *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::interface1::BlockDescriptor< double > **arg4 = (daal::data_management::interface1::BlockDescriptor< double > **) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  daal::data_management::BlockDescriptor< double > *data_temp4 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  {
    arg4 = &data_temp4;
  }
  if (!PyArg_ParseTuple(args,(char *)"OOO:DenseNumericTableIface_getBlockOfRowsAsDouble",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseNumericTableIface_getBlockOfRowsAsDouble" "', argument " "1"" of type '" "daal::data_management::interface1::DenseNumericTableIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseNumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseNumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseNumericTableIface_getBlockOfRowsAsDouble" "', argument " "1"" of type '" "daal::data_management::interface1::DenseNumericTableIface *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "DenseNumericTableIface_getBlockOfRowsAsDouble" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "DenseNumericTableIface_getBlockOfRowsAsDouble" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        daal_data_management_interface1_DenseNumericTableIface_getBlockOfRowsAsDouble(arg1,arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    npy_intp dims[2] = {
      static_cast<npy_intp>((*arg4)->getNumberOfRows()), static_cast<npy_intp>((*arg4)->getNumberOfColumns()) 
    };
    daal::services::SharedPtr< double > data_tmp((*arg4)->getBlockSharedPtr());
    PyObject* obj = PyArray_SimpleNewFromData(2, dims, NPY_DOUBLE, (void*)data_tmp.get());
    if (!obj) SWIG_fail;
    set_sp_base((PyArrayObject*)obj, data_tmp);
    resultobj = SWIG_Python_AppendOutput(resultobj, obj);
    // oooohhhh
    delete *arg4;
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DenseNumericTableIface_getBlockOfColumnValuesAsDouble(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DenseNumericTableIface *arg1 = (daal::data_management::interface1::DenseNumericTableIface *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::interface1::BlockDescriptor< double > **arg5 = (daal::data_management::interface1::BlockDescriptor< double > **) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  daal::data_management::BlockDescriptor< double > *data_temp5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  
  {
    arg5 = &data_temp5;
  }
  if (!PyArg_ParseTuple(args,(char *)"OOOO:DenseNumericTableIface_getBlockOfColumnValuesAsDouble",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseNumericTableIface_getBlockOfColumnValuesAsDouble" "', argument " "1"" of type '" "daal::data_management::interface1::DenseNumericTableIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseNumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseNumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseNumericTableIface_getBlockOfColumnValuesAsDouble" "', argument " "1"" of type '" "daal::data_management::interface1::DenseNumericTableIface *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "DenseNumericTableIface_getBlockOfColumnValuesAsDouble" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "DenseNumericTableIface_getBlockOfColumnValuesAsDouble" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "DenseNumericTableIface_getBlockOfColumnValuesAsDouble" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        daal_data_management_interface1_DenseNumericTableIface_getBlockOfColumnValuesAsDouble(arg1,arg2,arg3,arg4,arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    npy_intp dims[2] = {
      static_cast<npy_intp>((*arg5)->getNumberOfRows()), static_cast<npy_intp>((*arg5)->getNumberOfColumns()) 
    };
    daal::services::SharedPtr< double > data_tmp((*arg5)->getBlockSharedPtr());
    PyObject* obj = PyArray_SimpleNewFromData(2, dims, NPY_DOUBLE, (void*)data_tmp.get());
    if (!obj) SWIG_fail;
    set_sp_base((PyArrayObject*)obj, data_tmp);
    resultobj = SWIG_Python_AppendOutput(resultobj, obj);
    // oooohhhh
    delete *arg5;
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DenseNumericTableIface_getBlockOfRowsAsFloat(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DenseNumericTableIface *arg1 = (daal::data_management::interface1::DenseNumericTableIface *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::interface1::BlockDescriptor< float > **arg4 = (daal::data_management::interface1::BlockDescriptor< float > **) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  daal::data_management::BlockDescriptor< float > *data_temp4 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  {
    arg4 = &data_temp4;
  }
  if (!PyArg_ParseTuple(args,(char *)"OOO:DenseNumericTableIface_getBlockOfRowsAsFloat",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseNumericTableIface_getBlockOfRowsAsFloat" "', argument " "1"" of type '" "daal::data_management::interface1::DenseNumericTableIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseNumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseNumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseNumericTableIface_getBlockOfRowsAsFloat" "', argument " "1"" of type '" "daal::data_management::interface1::DenseNumericTableIface *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "DenseNumericTableIface_getBlockOfRowsAsFloat" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "DenseNumericTableIface_getBlockOfRowsAsFloat" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        daal_data_management_interface1_DenseNumericTableIface_getBlockOfRowsAsFloat(arg1,arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    npy_intp dims[2] = {
      static_cast<npy_intp>((*arg4)->getNumberOfRows()), static_cast<npy_intp>((*arg4)->getNumberOfColumns()) 
    };
    daal::services::SharedPtr< float > data_tmp((*arg4)->getBlockSharedPtr());
    PyObject* obj = PyArray_SimpleNewFromData(2, dims, NPY_FLOAT, (void*)data_tmp.get());
    if (!obj) SWIG_fail;
    set_sp_base((PyArrayObject*)obj, data_tmp);
    resultobj = SWIG_Python_AppendOutput(resultobj, obj);
    // oooohhhh
    delete *arg4;
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DenseNumericTableIface_getBlockOfColumnValuesAsFloat(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DenseNumericTableIface *arg1 = (daal::data_management::interface1::DenseNumericTableIface *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::interface1::BlockDescriptor< float > **arg5 = (daal::data_management::interface1::BlockDescriptor< float > **) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  daal::data_management::BlockDescriptor< float > *data_temp5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  
  {
    arg5 = &data_temp5;
  }
  if (!PyArg_ParseTuple(args,(char *)"OOOO:DenseNumericTableIface_getBlockOfColumnValuesAsFloat",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseNumericTableIface_getBlockOfColumnValuesAsFloat" "', argument " "1"" of type '" "daal::data_management::interface1::DenseNumericTableIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseNumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseNumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseNumericTableIface_getBlockOfColumnValuesAsFloat" "', argument " "1"" of type '" "daal::data_management::interface1::DenseNumericTableIface *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "DenseNumericTableIface_getBlockOfColumnValuesAsFloat" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "DenseNumericTableIface_getBlockOfColumnValuesAsFloat" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "DenseNumericTableIface_getBlockOfColumnValuesAsFloat" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        daal_data_management_interface1_DenseNumericTableIface_getBlockOfColumnValuesAsFloat(arg1,arg2,arg3,arg4,arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    npy_intp dims[2] = {
      static_cast<npy_intp>((*arg5)->getNumberOfRows()), static_cast<npy_intp>((*arg5)->getNumberOfColumns()) 
    };
    daal::services::SharedPtr< float > data_tmp((*arg5)->getBlockSharedPtr());
    PyObject* obj = PyArray_SimpleNewFromData(2, dims, NPY_FLOAT, (void*)data_tmp.get());
    if (!obj) SWIG_fail;
    set_sp_base((PyArrayObject*)obj, data_tmp);
    resultobj = SWIG_Python_AppendOutput(resultobj, obj);
    // oooohhhh
    delete *arg5;
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DenseNumericTableIface_getBlockOfRowsAsInt(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DenseNumericTableIface *arg1 = (daal::data_management::interface1::DenseNumericTableIface *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::interface1::BlockDescriptor< int > **arg4 = (daal::data_management::interface1::BlockDescriptor< int > **) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  daal::data_management::BlockDescriptor< int > *data_temp4 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  {
    arg4 = &data_temp4;
  }
  if (!PyArg_ParseTuple(args,(char *)"OOO:DenseNumericTableIface_getBlockOfRowsAsInt",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseNumericTableIface_getBlockOfRowsAsInt" "', argument " "1"" of type '" "daal::data_management::interface1::DenseNumericTableIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseNumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseNumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseNumericTableIface_getBlockOfRowsAsInt" "', argument " "1"" of type '" "daal::data_management::interface1::DenseNumericTableIface *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "DenseNumericTableIface_getBlockOfRowsAsInt" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "DenseNumericTableIface_getBlockOfRowsAsInt" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        daal_data_management_interface1_DenseNumericTableIface_getBlockOfRowsAsInt(arg1,arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    npy_intp dims[2] = {
      static_cast<npy_intp>((*arg4)->getNumberOfRows()), static_cast<npy_intp>((*arg4)->getNumberOfColumns()) 
    };
    daal::services::SharedPtr< int > data_tmp((*arg4)->getBlockSharedPtr());
    PyObject* obj = PyArray_SimpleNewFromData(2, dims, NPY_INT, (void*)data_tmp.get());
    if (!obj) SWIG_fail;
    set_sp_base((PyArrayObject*)obj, data_tmp);
    resultobj = SWIG_Python_AppendOutput(resultobj, obj);
    // oooohhhh
    delete *arg4;
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DenseNumericTableIface_getBlockOfColumnValuesAsInt(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DenseNumericTableIface *arg1 = (daal::data_management::interface1::DenseNumericTableIface *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::interface1::BlockDescriptor< int > **arg5 = (daal::data_management::interface1::BlockDescriptor< int > **) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  daal::data_management::BlockDescriptor< int > *data_temp5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  
  {
    arg5 = &data_temp5;
  }
  if (!PyArg_ParseTuple(args,(char *)"OOOO:DenseNumericTableIface_getBlockOfColumnValuesAsInt",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseNumericTableIface_getBlockOfColumnValuesAsInt" "', argument " "1"" of type '" "daal::data_management::interface1::DenseNumericTableIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseNumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseNumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseNumericTableIface_getBlockOfColumnValuesAsInt" "', argument " "1"" of type '" "daal::data_management::interface1::DenseNumericTableIface *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "DenseNumericTableIface_getBlockOfColumnValuesAsInt" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "DenseNumericTableIface_getBlockOfColumnValuesAsInt" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "DenseNumericTableIface_getBlockOfColumnValuesAsInt" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        daal_data_management_interface1_DenseNumericTableIface_getBlockOfColumnValuesAsInt(arg1,arg2,arg3,arg4,arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    npy_intp dims[2] = {
      static_cast<npy_intp>((*arg5)->getNumberOfRows()), static_cast<npy_intp>((*arg5)->getNumberOfColumns()) 
    };
    daal::services::SharedPtr< int > data_tmp((*arg5)->getBlockSharedPtr());
    PyObject* obj = PyArray_SimpleNewFromData(2, dims, NPY_INT, (void*)data_tmp.get());
    if (!obj) SWIG_fail;
    set_sp_base((PyArrayObject*)obj, data_tmp);
    resultobj = SWIG_Python_AppendOutput(resultobj, obj);
    // oooohhhh
    delete *arg5;
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *DenseNumericTableIface_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_delete_NumericTable(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTable *arg1 = (daal::data_management::interface1::NumericTable *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_NumericTable",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_NumericTable" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_NumericTable" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTable_setDictionary(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTable *arg1 = (daal::data_management::interface1::NumericTable *) 0 ;
  daal::data_management::interface1::NumericTableDictionary *arg2 = (daal::data_management::interface1::NumericTableDictionary *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > > tempshared2 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > > *smartarg2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:NumericTable_setDictionary",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_setDictionary" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_setDictionary" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res2) || !argp2) && obj1 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "NumericTable_setDictionary" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTableDictionary *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::NumericTableDictionary * >(tempshared2.get());
    } else {
      smartarg2 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::NumericTableDictionary * >((smartarg2 ? smartarg2->get() : 0));
    }
    if(!arg2 && obj1 != Py_None) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "NumericTable_setDictionary" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTableDictionary *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->setDictionary(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTable_getDictionary(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTable *arg1 = (daal::data_management::interface1::NumericTable *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::NumericTableDictionary *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:NumericTable_getDictionary",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_getDictionary" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_getDictionary" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::NumericTableDictionary *)((daal::data_management::interface1::NumericTable const *)arg1)->getDictionary();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > >(result SWIG_NO_NULL_DELETER_0) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t, 0 | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTable_resetDictionary(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTable *arg1 = (daal::data_management::interface1::NumericTable *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:NumericTable_resetDictionary",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_resetDictionary" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_resetDictionary" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->resetDictionary();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTable_resize(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTable *arg1 = (daal::data_management::interface1::NumericTable *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:NumericTable_resize",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_resize" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_resize" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "NumericTable_resize" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->resize(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTable_getNumberOfColumns(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTable *arg1 = (daal::data_management::interface1::NumericTable *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:NumericTable_getNumberOfColumns",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_getNumberOfColumns" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_getNumberOfColumns" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::NumericTable const *)arg1)->getNumberOfColumns();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTable_getNumberOfRows(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTable *arg1 = (daal::data_management::interface1::NumericTable *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:NumericTable_getNumberOfRows",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_getNumberOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_getNumberOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::NumericTable const *)arg1)->getNumberOfRows();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTable_setNumberOfColumns(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTable *arg1 = (daal::data_management::interface1::NumericTable *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:NumericTable_setNumberOfColumns",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_setNumberOfColumns" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_setNumberOfColumns" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "NumericTable_setNumberOfColumns" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->setNumberOfColumns(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTable_setNumberOfRows(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTable *arg1 = (daal::data_management::interface1::NumericTable *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:NumericTable_setNumberOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_setNumberOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_setNumberOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "NumericTable_setNumberOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->setNumberOfRows(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTable_allocateDataMemory__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTable *arg1 = (daal::data_management::interface1::NumericTable *) 0 ;
  daal::MemType arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:NumericTable_allocateDataMemory",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_allocateDataMemory" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_allocateDataMemory" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "NumericTable_allocateDataMemory" "', argument " "2"" of type '" "daal::MemType""'");
  } 
  arg2 = static_cast< daal::MemType >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->allocateDataMemory(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTable_allocateDataMemory__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTable *arg1 = (daal::data_management::interface1::NumericTable *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:NumericTable_allocateDataMemory",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_allocateDataMemory" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_allocateDataMemory" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->allocateDataMemory();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTable_allocateDataMemory(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_NumericTable_allocateDataMemory__SWIG_1(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_NumericTable_allocateDataMemory__SWIG_0(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'NumericTable_allocateDataMemory'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::NumericTable::allocateDataMemory(daal::MemType)\n"
    "    daal::data_management::interface1::NumericTable::allocateDataMemory()\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_NumericTable_freeDataMemory(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTable *arg1 = (daal::data_management::interface1::NumericTable *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:NumericTable_freeDataMemory",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_freeDataMemory" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_freeDataMemory" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->freeDataMemory();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTable_getDataLayout(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTable *arg1 = (daal::data_management::interface1::NumericTable *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::NumericTableIface::StorageLayout result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:NumericTable_getDataLayout",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_getDataLayout" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_getDataLayout" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::NumericTableIface::StorageLayout)((daal::data_management::interface1::NumericTable const *)arg1)->getDataLayout();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTable_getFeatureType(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTable *arg1 = (daal::data_management::interface1::NumericTable *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable const > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::data_management::features::FeatureType result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:NumericTable_getFeatureType",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_getFeatureType" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_getFeatureType" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable const *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "NumericTable_getFeatureType" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::features::FeatureType)((daal::data_management::interface1::NumericTable const *)arg1)->getFeatureType(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTable_getNumberOfCategories(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTable *arg1 = (daal::data_management::interface1::NumericTable *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable const > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:NumericTable_getNumberOfCategories",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_getNumberOfCategories" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_getNumberOfCategories" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable const *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "NumericTable_getNumberOfCategories" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::NumericTable const *)arg1)->getNumberOfCategories(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTable_getDataMemoryStatus(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTable *arg1 = (daal::data_management::interface1::NumericTable *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::NumericTableIface::MemoryStatus result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:NumericTable_getDataMemoryStatus",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_getDataMemoryStatus" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_getDataMemoryStatus" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::NumericTableIface::MemoryStatus)((daal::data_management::interface1::NumericTable const *)arg1)->getDataMemoryStatus();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTable_isNormalized(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTable *arg1 = (daal::data_management::interface1::NumericTable *) 0 ;
  daal::data_management::interface1::NumericTableIface::NormalizationType arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable const > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:NumericTable_isNormalized",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_isNormalized" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_isNormalized" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable const *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "NumericTable_isNormalized" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTableIface::NormalizationType""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTableIface::NormalizationType >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (bool)((daal::data_management::interface1::NumericTable const *)arg1)->isNormalized(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTable_setNormalizationFlag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTable *arg1 = (daal::data_management::interface1::NumericTable *) 0 ;
  daal::data_management::interface1::NumericTableIface::NormalizationType arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::data_management::interface1::NumericTableIface::NormalizationType result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:NumericTable_setNormalizationFlag",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_setNormalizationFlag" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_setNormalizationFlag" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "NumericTable_setNormalizationFlag" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTableIface::NormalizationType""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTableIface::NormalizationType >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::NumericTableIface::NormalizationType)(arg1)->setNormalizationFlag(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTable_allocateBasicStatistics(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTable *arg1 = (daal::data_management::interface1::NumericTable *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:NumericTable_allocateBasicStatistics",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_allocateBasicStatistics" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_allocateBasicStatistics" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->allocateBasicStatistics();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTable_check__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTable *arg1 = (daal::data_management::interface1::NumericTable *) 0 ;
  char *arg2 = (char *) 0 ;
  bool arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable const > *smartarg1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  bool val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:NumericTable_check",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_check" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_check" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable const *""'"); 
  }
  res2 = SWIG_AsCharPtrAndSize(obj1, &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "NumericTable_check" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = reinterpret_cast< char * >(buf2);
  ecode3 = SWIG_AsVal_bool(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "NumericTable_check" "', argument " "3"" of type '" "bool""'");
  } 
  arg3 = static_cast< bool >(val3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::NumericTable const *)arg1)->check((char const *)arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTable_check__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTable *arg1 = (daal::data_management::interface1::NumericTable *) 0 ;
  char *arg2 = (char *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable const > *smartarg1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:NumericTable_check",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_check" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_check" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable const *""'"); 
  }
  res2 = SWIG_AsCharPtrAndSize(obj1, &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "NumericTable_check" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = reinterpret_cast< char * >(buf2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::NumericTable const *)arg1)->check((char const *)arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTable_check(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[4];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 3) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_AsCharPtrAndSize(argv[1], 0, NULL, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_NumericTable_check__SWIG_1(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_AsCharPtrAndSize(argv[1], 0, NULL, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_bool(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_NumericTable_check__SWIG_0(self, args);
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'NumericTable_check'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::NumericTable::check(char const *,bool) const\n"
    "    daal::data_management::interface1::NumericTable::check(char const *) const\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_NumericTable_assign__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTable *arg1 = (daal::data_management::interface1::NumericTable *) 0 ;
  float arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > *smartarg1 = 0 ;
  float val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:NumericTable_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_assign" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_assign" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
  }
  ecode2 = SWIG_AsVal_float(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "NumericTable_assign" "', argument " "2"" of type '" "float""'");
  } 
  arg2 = static_cast< float >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTable_assign__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTable *arg1 = (daal::data_management::interface1::NumericTable *) 0 ;
  double arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > *smartarg1 = 0 ;
  double val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:NumericTable_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_assign" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_assign" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
  }
  ecode2 = SWIG_AsVal_double(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "NumericTable_assign" "', argument " "2"" of type '" "double""'");
  } 
  arg2 = static_cast< double >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTable_assign__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTable *arg1 = (daal::data_management::interface1::NumericTable *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:NumericTable_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_assign" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_assign" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "NumericTable_assign" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTable_assign(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_NumericTable_assign__SWIG_2(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_float(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_NumericTable_assign__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_double(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_NumericTable_assign__SWIG_1(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'NumericTable_assign'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::NumericTable::assign(float)\n"
    "    daal::data_management::interface1::NumericTable::assign(double)\n"
    "    daal::data_management::interface1::NumericTable::assign(int)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_NumericTable_basicStatistics_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTable *arg1 = (daal::data_management::interface1::NumericTable *) 0 ;
  daal::data_management::interface1::NumericTable::BasicStatisticsDataCollection *arg2 = (daal::data_management::interface1::NumericTable::BasicStatisticsDataCollection *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:NumericTable_basicStatistics_set",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_basicStatistics_set" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_basicStatistics_set" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
  }
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_daal__data_management__interface1__NumericTable__BasicStatisticsDataCollection, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "NumericTable_basicStatistics_set" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTable::BasicStatisticsDataCollection *""'"); 
  }
  arg2 = reinterpret_cast< daal::data_management::interface1::NumericTable::BasicStatisticsDataCollection * >(argp2);
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    if (arg1) (arg1)->basicStatistics = *arg2;
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTable_basicStatistics_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTable *arg1 = (daal::data_management::interface1::NumericTable *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::NumericTable::BasicStatisticsDataCollection *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:NumericTable_basicStatistics_get",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_basicStatistics_get" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_basicStatistics_get" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
  }
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    result = (daal::data_management::interface1::NumericTable::BasicStatisticsDataCollection *)& ((arg1)->basicStatistics);
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_daal__data_management__interface1__NumericTable__BasicStatisticsDataCollection, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTable_getValue_Float64__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTable *arg1 = (daal::data_management::interface1::NumericTable *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable const > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  double result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:NumericTable_getValue_Float64",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_getValue_Float64" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_getValue_Float64" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable const *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "NumericTable_getValue_Float64" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "NumericTable_getValue_Float64" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (double)((daal::data_management::interface1::NumericTable const *)arg1)->SWIGTEMPLATEDISAMBIGUATOR getValue< double >(arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_double(static_cast< double >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTable_getValue_Float64__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTable *arg1 = (daal::data_management::interface1::NumericTable *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::services::Status *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable const > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  double result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:NumericTable_getValue_Float64",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_getValue_Float64" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_getValue_Float64" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable const *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "NumericTable_getValue_Float64" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "NumericTable_getValue_Float64" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  res4 = SWIG_ConvertPtr(obj3, &argp4, SWIGTYPE_p_daal__services__interface1__Status,  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "NumericTable_getValue_Float64" "', argument " "4"" of type '" "daal::services::Status &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "NumericTable_getValue_Float64" "', argument " "4"" of type '" "daal::services::Status &""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (double)((daal::data_management::interface1::NumericTable const *)arg1)->SWIGTEMPLATEDISAMBIGUATOR getValue< double >(arg2,arg3,*arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_double(static_cast< double >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTable_getValue_Float64(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[5];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 4) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_NumericTable_getValue_Float64__SWIG_0(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_NumericTable_getValue_Float64__SWIG_1(self, args);
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'NumericTable_getValue_Float64'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::NumericTable::getValue< double >(size_t,size_t) const\n"
    "    daal::data_management::interface1::NumericTable::getValue< double >(size_t,size_t,daal::services::Status &) const\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_NumericTable_getValue_Float32__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTable *arg1 = (daal::data_management::interface1::NumericTable *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable const > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  float result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:NumericTable_getValue_Float32",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_getValue_Float32" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_getValue_Float32" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable const *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "NumericTable_getValue_Float32" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "NumericTable_getValue_Float32" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (float)((daal::data_management::interface1::NumericTable const *)arg1)->SWIGTEMPLATEDISAMBIGUATOR getValue< float >(arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_float(static_cast< float >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTable_getValue_Float32__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTable *arg1 = (daal::data_management::interface1::NumericTable *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::services::Status *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable const > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  float result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:NumericTable_getValue_Float32",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_getValue_Float32" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_getValue_Float32" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable const *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "NumericTable_getValue_Float32" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "NumericTable_getValue_Float32" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  res4 = SWIG_ConvertPtr(obj3, &argp4, SWIGTYPE_p_daal__services__interface1__Status,  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "NumericTable_getValue_Float32" "', argument " "4"" of type '" "daal::services::Status &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "NumericTable_getValue_Float32" "', argument " "4"" of type '" "daal::services::Status &""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (float)((daal::data_management::interface1::NumericTable const *)arg1)->SWIGTEMPLATEDISAMBIGUATOR getValue< float >(arg2,arg3,*arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_float(static_cast< float >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTable_getValue_Float32(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[5];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 4) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_NumericTable_getValue_Float32__SWIG_0(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_NumericTable_getValue_Float32__SWIG_1(self, args);
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'NumericTable_getValue_Float32'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::NumericTable::getValue< float >(size_t,size_t) const\n"
    "    daal::data_management::interface1::NumericTable::getValue< float >(size_t,size_t,daal::services::Status &) const\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_NumericTable_getValue_Intc__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTable *arg1 = (daal::data_management::interface1::NumericTable *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable const > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:NumericTable_getValue_Intc",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_getValue_Intc" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_getValue_Intc" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable const *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "NumericTable_getValue_Intc" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "NumericTable_getValue_Intc" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)((daal::data_management::interface1::NumericTable const *)arg1)->SWIGTEMPLATEDISAMBIGUATOR getValue< int >(arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTable_getValue_Intc__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTable *arg1 = (daal::data_management::interface1::NumericTable *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::services::Status *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable const > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:NumericTable_getValue_Intc",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_getValue_Intc" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTable_getValue_Intc" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable const *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "NumericTable_getValue_Intc" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "NumericTable_getValue_Intc" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  res4 = SWIG_ConvertPtr(obj3, &argp4, SWIGTYPE_p_daal__services__interface1__Status,  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "NumericTable_getValue_Intc" "', argument " "4"" of type '" "daal::services::Status &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "NumericTable_getValue_Intc" "', argument " "4"" of type '" "daal::services::Status &""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)((daal::data_management::interface1::NumericTable const *)arg1)->SWIGTEMPLATEDISAMBIGUATOR getValue< int >(arg2,arg3,*arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTable_getValue_Intc(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[5];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 4) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_NumericTable_getValue_Intc__SWIG_0(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_NumericTable_getValue_Intc__SWIG_1(self, args);
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'NumericTable_getValue_Intc'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::NumericTable::getValue< int >(size_t,size_t) const\n"
    "    daal::data_management::interface1::NumericTable::getValue< int >(size_t,size_t,daal::services::Status &) const\n");
  return 0;
}


SWIGINTERN PyObject *NumericTable_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_BasicStatisticsDataCollection(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTable::BasicStatisticsDataCollection *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_BasicStatisticsDataCollection")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::NumericTable::BasicStatisticsDataCollection *)new daal::data_management::interface1::NumericTable::BasicStatisticsDataCollection();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_daal__data_management__interface1__NumericTable__BasicStatisticsDataCollection, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BasicStatisticsDataCollection_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTable::BasicStatisticsDataCollection *arg1 = (daal::data_management::interface1::NumericTable::BasicStatisticsDataCollection *) 0 ;
  daal::data_management::interface1::NumericTableIface::BasicStatisticsId arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:BasicStatisticsDataCollection_get",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__interface1__NumericTable__BasicStatisticsDataCollection, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BasicStatisticsDataCollection_get" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable::BasicStatisticsDataCollection *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::interface1::NumericTable::BasicStatisticsDataCollection * >(argp1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "BasicStatisticsDataCollection_get" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTableIface::BasicStatisticsId""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTableIface::BasicStatisticsId >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->get(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::NumericTable >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BasicStatisticsDataCollection_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTable::BasicStatisticsDataCollection *arg1 = (daal::data_management::interface1::NumericTable::BasicStatisticsDataCollection *) 0 ;
  daal::data_management::interface1::NumericTableIface::BasicStatisticsId arg2 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 ;
  int res3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > tempshared3 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:BasicStatisticsDataCollection_set",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__interface1__NumericTable__BasicStatisticsDataCollection, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BasicStatisticsDataCollection_set" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable::BasicStatisticsDataCollection *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::interface1::NumericTable::BasicStatisticsDataCollection * >(argp1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "BasicStatisticsDataCollection_set" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTableIface::BasicStatisticsId""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTableIface::BasicStatisticsId >(val2);
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t,  0 , &newmem);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "BasicStatisticsDataCollection_set" "', argument " "3"" of type '" "daal::services::SharedPtr< daal::data_management::interface1::NumericTable > const &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      if (argp3) tempshared3 = *reinterpret_cast< daal::services::SharedPtr< daal::data_management::interface1::NumericTable > * >(argp3);
      delete reinterpret_cast< daal::services::SharedPtr< daal::data_management::interface1::NumericTable > * >(argp3);
      arg3 = &tempshared3;
    } else {
      arg3 = (argp3) ? reinterpret_cast< daal::services::SharedPtr< daal::data_management::interface1::NumericTable > * >(argp3) : &tempshared3;
    }
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->set(arg2,(daal::services::SharedPtr< daal::data_management::interface1::NumericTable > const &)*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_BasicStatisticsDataCollection(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTable::BasicStatisticsDataCollection *arg1 = (daal::data_management::interface1::NumericTable::BasicStatisticsDataCollection *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_BasicStatisticsDataCollection",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__interface1__NumericTable__BasicStatisticsDataCollection, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_BasicStatisticsDataCollection" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTable::BasicStatisticsDataCollection *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::interface1::NumericTable::BasicStatisticsDataCollection * >(argp1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete arg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *BasicStatisticsDataCollection_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__data_management__interface1__NumericTable__BasicStatisticsDataCollection, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_checkNumericTable__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::NumericTable *arg1 = (daal::data_management::NumericTable *) 0 ;
  char *arg2 = (char *) 0 ;
  int arg3 ;
  int arg4 ;
  size_t arg5 ;
  size_t arg6 ;
  bool arg7 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable const > *smartarg1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  int val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  size_t val5 ;
  int ecode5 = 0 ;
  size_t val6 ;
  int ecode6 = 0 ;
  bool val7 ;
  int ecode7 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  PyObject * obj6 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOOO:checkNumericTable",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5,&obj6)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "checkNumericTable" "', argument " "1"" of type '" "daal::data_management::NumericTable const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::NumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::NumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "checkNumericTable" "', argument " "1"" of type '" "daal::data_management::NumericTable const *""'"); 
  }
  res2 = SWIG_AsCharPtrAndSize(obj1, &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "checkNumericTable" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = reinterpret_cast< char * >(buf2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "checkNumericTable" "', argument " "3"" of type '" "int""'");
  } 
  arg3 = static_cast< int >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "checkNumericTable" "', argument " "4"" of type '" "int""'");
  } 
  arg4 = static_cast< int >(val4);
  ecode5 = SWIG_AsVal_size_t(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "checkNumericTable" "', argument " "5"" of type '" "size_t""'");
  } 
  arg5 = static_cast< size_t >(val5);
  ecode6 = SWIG_AsVal_size_t(obj5, &val6);
  if (!SWIG_IsOK(ecode6)) {
    SWIG_exception_fail(SWIG_ArgError(ecode6), "in method '" "checkNumericTable" "', argument " "6"" of type '" "size_t""'");
  } 
  arg6 = static_cast< size_t >(val6);
  ecode7 = SWIG_AsVal_bool(obj6, &val7);
  if (!SWIG_IsOK(ecode7)) {
    SWIG_exception_fail(SWIG_ArgError(ecode7), "in method '" "checkNumericTable" "', argument " "7"" of type '" "bool""'");
  } 
  arg7 = static_cast< bool >(val7);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::checkNumericTable((daal::data_management::interface1::NumericTable const *)arg1,(char const *)arg2,arg3,arg4,arg5,arg6,arg7);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_checkNumericTable__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::NumericTable *arg1 = (daal::data_management::NumericTable *) 0 ;
  char *arg2 = (char *) 0 ;
  int arg3 ;
  int arg4 ;
  size_t arg5 ;
  size_t arg6 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable const > *smartarg1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  int val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  size_t val5 ;
  int ecode5 = 0 ;
  size_t val6 ;
  int ecode6 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:checkNumericTable",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "checkNumericTable" "', argument " "1"" of type '" "daal::data_management::NumericTable const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::NumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::NumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "checkNumericTable" "', argument " "1"" of type '" "daal::data_management::NumericTable const *""'"); 
  }
  res2 = SWIG_AsCharPtrAndSize(obj1, &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "checkNumericTable" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = reinterpret_cast< char * >(buf2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "checkNumericTable" "', argument " "3"" of type '" "int""'");
  } 
  arg3 = static_cast< int >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "checkNumericTable" "', argument " "4"" of type '" "int""'");
  } 
  arg4 = static_cast< int >(val4);
  ecode5 = SWIG_AsVal_size_t(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "checkNumericTable" "', argument " "5"" of type '" "size_t""'");
  } 
  arg5 = static_cast< size_t >(val5);
  ecode6 = SWIG_AsVal_size_t(obj5, &val6);
  if (!SWIG_IsOK(ecode6)) {
    SWIG_exception_fail(SWIG_ArgError(ecode6), "in method '" "checkNumericTable" "', argument " "6"" of type '" "size_t""'");
  } 
  arg6 = static_cast< size_t >(val6);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::checkNumericTable((daal::data_management::interface1::NumericTable const *)arg1,(char const *)arg2,arg3,arg4,arg5,arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_checkNumericTable__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::NumericTable *arg1 = (daal::data_management::NumericTable *) 0 ;
  char *arg2 = (char *) 0 ;
  int arg3 ;
  int arg4 ;
  size_t arg5 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable const > *smartarg1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  int val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  size_t val5 ;
  int ecode5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:checkNumericTable",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "checkNumericTable" "', argument " "1"" of type '" "daal::data_management::NumericTable const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::NumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::NumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "checkNumericTable" "', argument " "1"" of type '" "daal::data_management::NumericTable const *""'"); 
  }
  res2 = SWIG_AsCharPtrAndSize(obj1, &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "checkNumericTable" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = reinterpret_cast< char * >(buf2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "checkNumericTable" "', argument " "3"" of type '" "int""'");
  } 
  arg3 = static_cast< int >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "checkNumericTable" "', argument " "4"" of type '" "int""'");
  } 
  arg4 = static_cast< int >(val4);
  ecode5 = SWIG_AsVal_size_t(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "checkNumericTable" "', argument " "5"" of type '" "size_t""'");
  } 
  arg5 = static_cast< size_t >(val5);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::checkNumericTable((daal::data_management::interface1::NumericTable const *)arg1,(char const *)arg2,arg3,arg4,arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_checkNumericTable__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::NumericTable *arg1 = (daal::data_management::NumericTable *) 0 ;
  char *arg2 = (char *) 0 ;
  int arg3 ;
  int arg4 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable const > *smartarg1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  int val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:checkNumericTable",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "checkNumericTable" "', argument " "1"" of type '" "daal::data_management::NumericTable const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::NumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::NumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "checkNumericTable" "', argument " "1"" of type '" "daal::data_management::NumericTable const *""'"); 
  }
  res2 = SWIG_AsCharPtrAndSize(obj1, &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "checkNumericTable" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = reinterpret_cast< char * >(buf2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "checkNumericTable" "', argument " "3"" of type '" "int""'");
  } 
  arg3 = static_cast< int >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "checkNumericTable" "', argument " "4"" of type '" "int""'");
  } 
  arg4 = static_cast< int >(val4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::checkNumericTable((daal::data_management::interface1::NumericTable const *)arg1,(char const *)arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_checkNumericTable__SWIG_4(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::NumericTable *arg1 = (daal::data_management::NumericTable *) 0 ;
  char *arg2 = (char *) 0 ;
  int arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable const > *smartarg1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  int val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:checkNumericTable",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "checkNumericTable" "', argument " "1"" of type '" "daal::data_management::NumericTable const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::NumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::NumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "checkNumericTable" "', argument " "1"" of type '" "daal::data_management::NumericTable const *""'"); 
  }
  res2 = SWIG_AsCharPtrAndSize(obj1, &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "checkNumericTable" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = reinterpret_cast< char * >(buf2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "checkNumericTable" "', argument " "3"" of type '" "int""'");
  } 
  arg3 = static_cast< int >(val3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::checkNumericTable((daal::data_management::interface1::NumericTable const *)arg1,(char const *)arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_checkNumericTable__SWIG_5(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::NumericTable *arg1 = (daal::data_management::NumericTable *) 0 ;
  char *arg2 = (char *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable const > *smartarg1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:checkNumericTable",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "checkNumericTable" "', argument " "1"" of type '" "daal::data_management::NumericTable const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::NumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::NumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "checkNumericTable" "', argument " "1"" of type '" "daal::data_management::NumericTable const *""'"); 
  }
  res2 = SWIG_AsCharPtrAndSize(obj1, &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "checkNumericTable" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = reinterpret_cast< char * >(buf2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::checkNumericTable((daal::data_management::interface1::NumericTable const *)arg1,(char const *)arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_checkNumericTable(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[8];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 7) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_AsCharPtrAndSize(argv[1], 0, NULL, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_checkNumericTable__SWIG_5(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_AsCharPtrAndSize(argv[1], 0, NULL, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_checkNumericTable__SWIG_4(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_AsCharPtrAndSize(argv[1], 0, NULL, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            return _wrap_checkNumericTable__SWIG_3(self, args);
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_AsCharPtrAndSize(argv[1], 0, NULL, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_size_t(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              return _wrap_checkNumericTable__SWIG_2(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_AsCharPtrAndSize(argv[1], 0, NULL, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_size_t(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              {
                int res = SWIG_AsVal_size_t(argv[5], NULL);
                _v = SWIG_CheckState(res);
              }
              if (_v) {
                return _wrap_checkNumericTable__SWIG_1(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 7) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_AsCharPtrAndSize(argv[1], 0, NULL, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_size_t(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              {
                int res = SWIG_AsVal_size_t(argv[5], NULL);
                _v = SWIG_CheckState(res);
              }
              if (_v) {
                {
                  int res = SWIG_AsVal_bool(argv[6], NULL);
                  _v = SWIG_CheckState(res);
                }
                if (_v) {
                  return _wrap_checkNumericTable__SWIG_0(self, args);
                }
              }
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'checkNumericTable'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::checkNumericTable(daal::data_management::NumericTable const *,char const *,int const,int const,size_t,size_t,bool)\n"
    "    daal::data_management::checkNumericTable(daal::data_management::NumericTable const *,char const *,int const,int const,size_t,size_t)\n"
    "    daal::data_management::checkNumericTable(daal::data_management::NumericTable const *,char const *,int const,int const,size_t)\n"
    "    daal::data_management::checkNumericTable(daal::data_management::NumericTable const *,char const *,int const,int const)\n"
    "    daal::data_management::checkNumericTable(daal::data_management::NumericTable const *,char const *,int const)\n"
    "    daal::data_management::checkNumericTable(daal::data_management::NumericTable const *,char const *)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_TensorIface(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::TensorIface *arg1 = (daal::data_management::interface1::TensorIface *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorIface > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_TensorIface",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_TensorIface" "', argument " "1"" of type '" "daal::data_management::interface1::TensorIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::TensorIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::TensorIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::TensorIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_TensorIface" "', argument " "1"" of type '" "daal::data_management::interface1::TensorIface *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TensorIface_setDimensions__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::TensorIface *arg1 = (daal::data_management::interface1::TensorIface *) 0 ;
  size_t arg2 ;
  size_t *arg3 = (size_t *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorIface > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:TensorIface_setDimensions",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TensorIface_setDimensions" "', argument " "1"" of type '" "daal::data_management::interface1::TensorIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::TensorIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::TensorIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::TensorIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TensorIface_setDimensions" "', argument " "1"" of type '" "daal::data_management::interface1::TensorIface *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "TensorIface_setDimensions" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_size_t, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "TensorIface_setDimensions" "', argument " "3"" of type '" "size_t const *""'"); 
  }
  arg3 = reinterpret_cast< size_t * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->setDimensions(arg2,(size_t const *)arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TensorIface_setDimensions__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::TensorIface *arg1 = (daal::data_management::interface1::TensorIface *) 0 ;
  daal::services::Collection< size_t > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorIface > *smartarg1 = 0 ;
  daal::services::Collection< size_t > *col_szt2 = NULL ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:TensorIface_setDimensions",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TensorIface_setDimensions" "', argument " "1"" of type '" "daal::data_management::interface1::TensorIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::TensorIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::TensorIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::TensorIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TensorIface_setDimensions" "', argument " "1"" of type '" "daal::data_management::interface1::TensorIface *""'"); 
  }
  {
    Py_ssize_t n = PySequence_Length(obj1);
    if( n == 0 ) SWIG_fail;
    col_szt2 = new daal::services::Collection<size_t>(n);
    for( Py_ssize_t i=0; i<n; ++i ) {
      PyObject * o = PySequence_GetItem(obj1, i);
      size_t tmp = PyInt_AsSsize_t(o);
      if(PyErr_Occurred()) {
        PyErr_Format(PyExc_TypeError, "Sequence of integer values required");
        SWIG_fail;
      }
      (*col_szt2)[i] = tmp;
    }
    arg2 = col_szt2;
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->setDimensions((daal::services::Collection< size_t > const &)*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  {
    if( col_szt2 ) delete col_szt2;
  }
  return resultobj;
fail:
  {
    if( col_szt2 ) delete col_szt2;
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_TensorIface_setDimensions(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[4];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 3) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorIface_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySequence_Check(argv[1]);
      }
      if (_v) {
        return _wrap_TensorIface_setDimensions__SWIG_1(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorIface_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_size_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_TensorIface_setDimensions__SWIG_0(self, args);
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'TensorIface_setDimensions'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::TensorIface::setDimensions(size_t,size_t const *)\n"
    "    daal::data_management::interface1::TensorIface::setDimensions(daal::services::Collection< size_t > const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_TensorIface_allocateDataMemory__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::TensorIface *arg1 = (daal::data_management::interface1::TensorIface *) 0 ;
  daal::MemType arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorIface > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:TensorIface_allocateDataMemory",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TensorIface_allocateDataMemory" "', argument " "1"" of type '" "daal::data_management::interface1::TensorIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::TensorIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::TensorIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::TensorIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TensorIface_allocateDataMemory" "', argument " "1"" of type '" "daal::data_management::interface1::TensorIface *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "TensorIface_allocateDataMemory" "', argument " "2"" of type '" "daal::MemType""'");
  } 
  arg2 = static_cast< daal::MemType >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->allocateDataMemory(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TensorIface_allocateDataMemory__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::TensorIface *arg1 = (daal::data_management::interface1::TensorIface *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorIface > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:TensorIface_allocateDataMemory",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TensorIface_allocateDataMemory" "', argument " "1"" of type '" "daal::data_management::interface1::TensorIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::TensorIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::TensorIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::TensorIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TensorIface_allocateDataMemory" "', argument " "1"" of type '" "daal::data_management::interface1::TensorIface *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->allocateDataMemory();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TensorIface_allocateDataMemory(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorIface_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_TensorIface_allocateDataMemory__SWIG_1(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorIface_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_TensorIface_allocateDataMemory__SWIG_0(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'TensorIface_allocateDataMemory'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::TensorIface::allocateDataMemory(daal::MemType)\n"
    "    daal::data_management::interface1::TensorIface::allocateDataMemory()\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_TensorIface_freeDataMemory(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::TensorIface *arg1 = (daal::data_management::interface1::TensorIface *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorIface > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:TensorIface_freeDataMemory",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TensorIface_freeDataMemory" "', argument " "1"" of type '" "daal::data_management::interface1::TensorIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::TensorIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::TensorIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::TensorIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TensorIface_freeDataMemory" "', argument " "1"" of type '" "daal::data_management::interface1::TensorIface *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->freeDataMemory();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TensorIface_resize(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::TensorIface *arg1 = (daal::data_management::interface1::TensorIface *) 0 ;
  daal::services::Collection< size_t > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorIface > *smartarg1 = 0 ;
  daal::services::Collection< size_t > *col_szt2 = NULL ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:TensorIface_resize",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TensorIface_resize" "', argument " "1"" of type '" "daal::data_management::interface1::TensorIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::TensorIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::TensorIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::TensorIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TensorIface_resize" "', argument " "1"" of type '" "daal::data_management::interface1::TensorIface *""'"); 
  }
  {
    Py_ssize_t n = PySequence_Length(obj1);
    if( n == 0 ) SWIG_fail;
    col_szt2 = new daal::services::Collection<size_t>(n);
    for( Py_ssize_t i=0; i<n; ++i ) {
      PyObject * o = PySequence_GetItem(obj1, i);
      size_t tmp = PyInt_AsSsize_t(o);
      if(PyErr_Occurred()) {
        PyErr_Format(PyExc_TypeError, "Sequence of integer values required");
        SWIG_fail;
      }
      (*col_szt2)[i] = tmp;
    }
    arg2 = col_szt2;
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->resize((daal::services::Collection< size_t > const &)*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  {
    if( col_szt2 ) delete col_szt2;
  }
  return resultobj;
fail:
  {
    if( col_szt2 ) delete col_szt2;
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_TensorIface_check(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::TensorIface *arg1 = (daal::data_management::interface1::TensorIface *) 0 ;
  char *arg2 = (char *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorIface const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorIface const > *smartarg1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:TensorIface_check",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TensorIface_check" "', argument " "1"" of type '" "daal::data_management::interface1::TensorIface const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TensorIface_check" "', argument " "1"" of type '" "daal::data_management::interface1::TensorIface const *""'"); 
  }
  res2 = SWIG_AsCharPtrAndSize(obj1, &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TensorIface_check" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = reinterpret_cast< char * >(buf2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::TensorIface const *)arg1)->check((char const *)arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_TensorIface_getSampleTensor(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::TensorIface *arg1 = (daal::data_management::interface1::TensorIface *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorIface > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::data_management::interface1::TensorPtr result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:TensorIface_getSampleTensor",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TensorIface_getSampleTensor" "', argument " "1"" of type '" "daal::data_management::interface1::TensorIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::TensorIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::TensorIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::TensorIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TensorIface_getSampleTensor" "', argument " "1"" of type '" "daal::data_management::interface1::TensorIface *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "TensorIface_getSampleTensor" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getSampleTensor(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Tensor > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Tensor >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *TensorIface_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorIface_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_delete_TensorLayoutIface(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::TensorLayoutIface *arg1 = (daal::data_management::interface1::TensorLayoutIface *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorLayoutIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorLayoutIface > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_TensorLayoutIface",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayoutIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_TensorLayoutIface" "', argument " "1"" of type '" "daal::data_management::interface1::TensorLayoutIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::TensorLayoutIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::TensorLayoutIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorLayoutIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::TensorLayoutIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorLayoutIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_TensorLayoutIface" "', argument " "1"" of type '" "daal::data_management::interface1::TensorLayoutIface *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TensorLayoutIface_shuffleDimensions(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::TensorLayoutIface *arg1 = (daal::data_management::interface1::TensorLayoutIface *) 0 ;
  daal::services::Collection< size_t > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorLayoutIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorLayoutIface > *smartarg1 = 0 ;
  daal::services::Collection< size_t > *col_szt2 = NULL ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:TensorLayoutIface_shuffleDimensions",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayoutIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TensorLayoutIface_shuffleDimensions" "', argument " "1"" of type '" "daal::data_management::interface1::TensorLayoutIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::TensorLayoutIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::TensorLayoutIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorLayoutIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::TensorLayoutIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorLayoutIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TensorLayoutIface_shuffleDimensions" "', argument " "1"" of type '" "daal::data_management::interface1::TensorLayoutIface *""'"); 
  }
  {
    Py_ssize_t n = PySequence_Length(obj1);
    if( n == 0 ) SWIG_fail;
    col_szt2 = new daal::services::Collection<size_t>(n);
    for( Py_ssize_t i=0; i<n; ++i ) {
      PyObject * o = PySequence_GetItem(obj1, i);
      size_t tmp = PyInt_AsSsize_t(o);
      if(PyErr_Occurred()) {
        PyErr_Format(PyExc_TypeError, "Sequence of integer values required");
        SWIG_fail;
      }
      (*col_szt2)[i] = tmp;
    }
    arg2 = col_szt2;
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->shuffleDimensions((daal::services::Collection< size_t > const &)*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  {
    if( col_szt2 ) delete col_szt2;
  }
  return resultobj;
fail:
  {
    if( col_szt2 ) delete col_szt2;
  }
  return NULL;
}


SWIGINTERN PyObject *TensorLayoutIface_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayoutIface_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_delete_TensorLayout(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::TensorLayout *arg1 = (daal::data_management::interface1::TensorLayout *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorLayout > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorLayout > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_TensorLayout",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayout_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_TensorLayout" "', argument " "1"" of type '" "daal::data_management::interface1::TensorLayout *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::TensorLayout > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::TensorLayout > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorLayout * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::TensorLayout > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorLayout * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_TensorLayout" "', argument " "1"" of type '" "daal::data_management::interface1::TensorLayout *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TensorLayout_getDimensions(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::TensorLayout *arg1 = (daal::data_management::interface1::TensorLayout *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorLayout const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorLayout const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::Collection< size_t > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:TensorLayout_getDimensions",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayout_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TensorLayout_getDimensions" "', argument " "1"" of type '" "daal::data_management::interface1::TensorLayout const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorLayout > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorLayout > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorLayout * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorLayout > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorLayout * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TensorLayout_getDimensions" "', argument " "1"" of type '" "daal::data_management::interface1::TensorLayout const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::services::Collection< size_t > *) &((daal::data_management::interface1::TensorLayout const *)arg1)->getDimensions();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    size_t n = result->size();
    resultobj = PyList_New(n);
    for( size_t i = 0; i < n; ++i ) {
      PyObject * tmp = PyLong_FromSsize_t((*result)[i]);
      if( tmp == NULL || PyList_SetItem(resultobj, i, tmp) ) {
        PyErr_Format(PyExc_TypeError, "Could not fill sequence from Collection.");
        SWIG_fail;
      }
    }
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *TensorLayout_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayout_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_TensorOffsetLayout__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::TensorOffsetLayout *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout const > tempshared1 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::TensorOffsetLayout *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:new_TensorOffsetLayout",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t,  0 , &newmem);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_TensorOffsetLayout" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (!argp1) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_TensorOffsetLayout" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(tempshared1.get());
    } else {
      arg1 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1)->get());
    }
    if(!arg1) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_TensorOffsetLayout" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::TensorOffsetLayout *)new daal::data_management::interface1::TensorOffsetLayout((daal::data_management::interface1::TensorOffsetLayout const &)*arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::TensorOffsetLayout > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::TensorOffsetLayout >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_TensorOffsetLayout__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::Collection< size_t > *arg1 = 0 ;
  daal::services::Collection< size_t > *col_szt1 = NULL ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::TensorOffsetLayout *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:new_TensorOffsetLayout",&obj0)) SWIG_fail;
  {
    Py_ssize_t n = PySequence_Length(obj0);
    if( n == 0 ) SWIG_fail;
    col_szt1 = new daal::services::Collection<size_t>(n);
    for( Py_ssize_t i=0; i<n; ++i ) {
      PyObject * o = PySequence_GetItem(obj0, i);
      size_t tmp = PyInt_AsSsize_t(o);
      if(PyErr_Occurred()) {
        PyErr_Format(PyExc_TypeError, "Sequence of integer values required");
        SWIG_fail;
      }
      (*col_szt1)[i] = tmp;
    }
    arg1 = col_szt1;
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::TensorOffsetLayout *)new daal::data_management::interface1::TensorOffsetLayout((daal::services::Collection< size_t > const &)*arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::TensorOffsetLayout > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::TensorOffsetLayout >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  {
    if( col_szt1 ) delete col_szt1;
  }
  return resultobj;
fail:
  {
    if( col_szt1 ) delete col_szt1;
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_TensorOffsetLayout__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::Collection< size_t > *arg1 = 0 ;
  daal::services::Collection< size_t > *arg2 = 0 ;
  daal::services::Collection< size_t > *arg3 = 0 ;
  daal::services::Collection< size_t > *col_szt1 = NULL ;
  daal::services::Collection< size_t > *col_szt2 = NULL ;
  daal::services::Collection< size_t > *col_szt3 = NULL ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::data_management::interface1::TensorOffsetLayout *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:new_TensorOffsetLayout",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    Py_ssize_t n = PySequence_Length(obj0);
    if( n == 0 ) SWIG_fail;
    col_szt1 = new daal::services::Collection<size_t>(n);
    for( Py_ssize_t i=0; i<n; ++i ) {
      PyObject * o = PySequence_GetItem(obj0, i);
      size_t tmp = PyInt_AsSsize_t(o);
      if(PyErr_Occurred()) {
        PyErr_Format(PyExc_TypeError, "Sequence of integer values required");
        SWIG_fail;
      }
      (*col_szt1)[i] = tmp;
    }
    arg1 = col_szt1;
  }
  {
    Py_ssize_t n = PySequence_Length(obj1);
    if( n == 0 ) SWIG_fail;
    col_szt2 = new daal::services::Collection<size_t>(n);
    for( Py_ssize_t i=0; i<n; ++i ) {
      PyObject * o = PySequence_GetItem(obj1, i);
      size_t tmp = PyInt_AsSsize_t(o);
      if(PyErr_Occurred()) {
        PyErr_Format(PyExc_TypeError, "Sequence of integer values required");
        SWIG_fail;
      }
      (*col_szt2)[i] = tmp;
    }
    arg2 = col_szt2;
  }
  {
    Py_ssize_t n = PySequence_Length(obj2);
    if( n == 0 ) SWIG_fail;
    col_szt3 = new daal::services::Collection<size_t>(n);
    for( Py_ssize_t i=0; i<n; ++i ) {
      PyObject * o = PySequence_GetItem(obj2, i);
      size_t tmp = PyInt_AsSsize_t(o);
      if(PyErr_Occurred()) {
        PyErr_Format(PyExc_TypeError, "Sequence of integer values required");
        SWIG_fail;
      }
      (*col_szt3)[i] = tmp;
    }
    arg3 = col_szt3;
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::TensorOffsetLayout *)new daal::data_management::interface1::TensorOffsetLayout((daal::services::Collection< size_t > const &)*arg1,(daal::services::Collection< size_t > const &)*arg2,(daal::services::Collection< size_t > const &)*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::TensorOffsetLayout > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::TensorOffsetLayout >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  {
    if( col_szt1 ) delete col_szt1;
  }
  {
    if( col_szt2 ) delete col_szt2;
  }
  {
    if( col_szt3 ) delete col_szt3;
  }
  return resultobj;
fail:
  {
    if( col_szt1 ) delete col_szt1;
  }
  {
    if( col_szt2 ) delete col_szt2;
  }
  {
    if( col_szt3 ) delete col_szt3;
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_TensorOffsetLayout(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[4];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 3) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_TensorOffsetLayout__SWIG_0(self, args);
    }
  }
  if (argc == 1) {
    int _v;
    {
      _v = PySequence_Check(argv[0]);
    }
    if (_v) {
      return _wrap_new_TensorOffsetLayout__SWIG_1(self, args);
    }
  }
  if (argc == 3) {
    int _v;
    {
      _v = PySequence_Check(argv[0]);
    }
    if (_v) {
      {
        _v = PySequence_Check(argv[1]);
      }
      if (_v) {
        {
          _v = PySequence_Check(argv[2]);
        }
        if (_v) {
          return _wrap_new_TensorOffsetLayout__SWIG_2(self, args);
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'new_TensorOffsetLayout'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::TensorOffsetLayout::TensorOffsetLayout(daal::data_management::interface1::TensorOffsetLayout const &)\n"
    "    daal::data_management::interface1::TensorOffsetLayout::TensorOffsetLayout(daal::services::Collection< size_t > const &)\n"
    "    daal::data_management::interface1::TensorOffsetLayout::TensorOffsetLayout(daal::services::Collection< size_t > const &,daal::services::Collection< size_t > const &,daal::services::Collection< size_t > const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_TensorOffsetLayout(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::TensorOffsetLayout *arg1 = (daal::data_management::interface1::TensorOffsetLayout *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_TensorOffsetLayout",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_TensorOffsetLayout" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_TensorOffsetLayout" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TensorOffsetLayout_getOffsets(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::TensorOffsetLayout *arg1 = (daal::data_management::interface1::TensorOffsetLayout *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::Collection< size_t > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:TensorOffsetLayout_getOffsets",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TensorOffsetLayout_getOffsets" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TensorOffsetLayout_getOffsets" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::services::Collection< size_t > *) &((daal::data_management::interface1::TensorOffsetLayout const *)arg1)->getOffsets();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    size_t n = result->size();
    resultobj = PyList_New(n);
    for( size_t i = 0; i < n; ++i ) {
      PyObject * tmp = PyLong_FromSsize_t((*result)[i]);
      if( tmp == NULL || PyList_SetItem(resultobj, i, tmp) ) {
        PyErr_Format(PyExc_TypeError, "Could not fill sequence from Collection.");
        SWIG_fail;
      }
    }
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TensorOffsetLayout_getIndices(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::TensorOffsetLayout *arg1 = (daal::data_management::interface1::TensorOffsetLayout *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::Collection< size_t > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:TensorOffsetLayout_getIndices",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TensorOffsetLayout_getIndices" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TensorOffsetLayout_getIndices" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::services::Collection< size_t > *) &((daal::data_management::interface1::TensorOffsetLayout const *)arg1)->getIndices();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    size_t n = result->size();
    resultobj = PyList_New(n);
    for( size_t i = 0; i < n; ++i ) {
      PyObject * tmp = PyLong_FromSsize_t((*result)[i]);
      if( tmp == NULL || PyList_SetItem(resultobj, i, tmp) ) {
        PyErr_Format(PyExc_TypeError, "Could not fill sequence from Collection.");
        SWIG_fail;
      }
    }
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TensorOffsetLayout_isLayout(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::TensorOffsetLayout *arg1 = (daal::data_management::interface1::TensorOffsetLayout *) 0 ;
  daal::data_management::interface1::TensorOffsetLayout *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout const > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout const > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:TensorOffsetLayout_isLayout",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TensorOffsetLayout_isLayout" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TensorOffsetLayout_isLayout" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TensorOffsetLayout_isLayout" "', argument " "2"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "TensorOffsetLayout_isLayout" "', argument " "2"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TensorOffsetLayout_isLayout" "', argument " "2"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (bool)((daal::data_management::interface1::TensorOffsetLayout const *)arg1)->isLayout((daal::data_management::interface1::TensorOffsetLayout const &)*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TensorOffsetLayout_isDefaultLayout(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::TensorOffsetLayout *arg1 = (daal::data_management::interface1::TensorOffsetLayout *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:TensorOffsetLayout_isDefaultLayout",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TensorOffsetLayout_isDefaultLayout" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TensorOffsetLayout_isDefaultLayout" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (bool)((daal::data_management::interface1::TensorOffsetLayout const *)arg1)->isDefaultLayout();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TensorOffsetLayout_isRawLayout(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::TensorOffsetLayout *arg1 = (daal::data_management::interface1::TensorOffsetLayout *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:TensorOffsetLayout_isRawLayout",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TensorOffsetLayout_isRawLayout" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TensorOffsetLayout_isRawLayout" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (bool)((daal::data_management::interface1::TensorOffsetLayout const *)arg1)->isRawLayout();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TensorOffsetLayout_shuffleDimensions(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::TensorOffsetLayout *arg1 = (daal::data_management::interface1::TensorOffsetLayout *) 0 ;
  daal::services::Collection< size_t > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout > *smartarg1 = 0 ;
  daal::services::Collection< size_t > *col_szt2 = NULL ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:TensorOffsetLayout_shuffleDimensions",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TensorOffsetLayout_shuffleDimensions" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TensorOffsetLayout_shuffleDimensions" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout *""'"); 
  }
  {
    Py_ssize_t n = PySequence_Length(obj1);
    if( n == 0 ) SWIG_fail;
    col_szt2 = new daal::services::Collection<size_t>(n);
    for( Py_ssize_t i=0; i<n; ++i ) {
      PyObject * o = PySequence_GetItem(obj1, i);
      size_t tmp = PyInt_AsSsize_t(o);
      if(PyErr_Occurred()) {
        PyErr_Format(PyExc_TypeError, "Sequence of integer values required");
        SWIG_fail;
      }
      (*col_szt2)[i] = tmp;
    }
    arg2 = col_szt2;
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->shuffleDimensions((daal::services::Collection< size_t > const &)*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  {
    if( col_szt2 ) delete col_szt2;
  }
  return resultobj;
fail:
  {
    if( col_szt2 ) delete col_szt2;
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_TensorOffsetLayout_sortOffsets(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::TensorOffsetLayout *arg1 = (daal::data_management::interface1::TensorOffsetLayout *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:TensorOffsetLayout_sortOffsets",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TensorOffsetLayout_sortOffsets" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TensorOffsetLayout_sortOffsets" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->sortOffsets();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TensorOffsetLayout_getSerializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::TensorOffsetLayout *arg1 = (daal::data_management::interface1::TensorOffsetLayout *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:TensorOffsetLayout_getSerializationTag",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TensorOffsetLayout_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TensorOffsetLayout_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)((daal::data_management::interface1::TensorOffsetLayout const *)arg1)->getSerializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *TensorOffsetLayout_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_delete_DenseTensorIface(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DenseTensorIface *arg1 = (daal::data_management::interface1::DenseTensorIface *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseTensorIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseTensorIface > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_DenseTensorIface",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_DenseTensorIface" "', argument " "1"" of type '" "daal::data_management::interface1::DenseTensorIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseTensorIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseTensorIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseTensorIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseTensorIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseTensorIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_DenseTensorIface" "', argument " "1"" of type '" "daal::data_management::interface1::DenseTensorIface *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DenseTensorIface_getSubtensorEx__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DenseTensorIface *arg1 = (daal::data_management::interface1::DenseTensorIface *) 0 ;
  size_t arg2 ;
  size_t *arg3 = (size_t *) 0 ;
  size_t arg4 ;
  size_t arg5 ;
  daal::data_management::ReadWriteMode arg6 ;
  daal::data_management::interface1::SubtensorDescriptor< double > *arg7 = 0 ;
  daal::data_management::interface1::TensorOffsetLayout *arg8 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseTensorIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseTensorIface > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int is_new_object2 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  size_t val5 ;
  int ecode5 = 0 ;
  int val6 ;
  int ecode6 = 0 ;
  void *argp7 = 0 ;
  int res7 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< double > > tempshared7 ;
  void *argp8 = 0 ;
  int res8 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout const > tempshared8 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  PyObject * obj6 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOOO:DenseTensorIface_getSubtensorEx",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5,&obj6)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseTensorIface_getSubtensorEx" "', argument " "1"" of type '" "daal::data_management::interface1::DenseTensorIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseTensorIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseTensorIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseTensorIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseTensorIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseTensorIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseTensorIface_getSubtensorEx" "', argument " "1"" of type '" "daal::data_management::interface1::DenseTensorIface *""'"); 
  }
  {
    array2 = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UINT64)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UINT64, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (size_t) array_size(array2,0);
    arg3 = (size_t*) array_data(array2);
  }
  ecode4 = SWIG_AsVal_size_t(obj2, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "DenseTensorIface_getSubtensorEx" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_size_t(obj3, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "DenseTensorIface_getSubtensorEx" "', argument " "5"" of type '" "size_t""'");
  } 
  arg5 = static_cast< size_t >(val5);
  ecode6 = SWIG_AsVal_int(obj4, &val6);
  if (!SWIG_IsOK(ecode6)) {
    SWIG_exception_fail(SWIG_ArgError(ecode6), "in method '" "DenseTensorIface_getSubtensorEx" "', argument " "6"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg6 = static_cast< daal::data_management::ReadWriteMode >(val6);
  {
    int newmem = 0;
    res7 = SWIG_ConvertPtrAndOwn(obj5, &argp7, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res7)) {
      SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "DenseTensorIface_getSubtensorEx" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > &""'"); 
    }
    if (!argp7) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "DenseTensorIface_getSubtensorEx" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared7 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp7);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp7);
      arg7 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >(tempshared7.get());
    } else {
      arg7 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp7)->get());
    }
    if(!arg7) SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "DenseTensorIface_getSubtensorEx" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > &""'"); 
  }
  {
    int newmem = 0;
    res8 = SWIG_ConvertPtrAndOwn(obj6, &argp8, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t,  0 , &newmem);
    if (!SWIG_IsOK(res8)) {
      SWIG_exception_fail(SWIG_ArgError(res8), "in method '" "DenseTensorIface_getSubtensorEx" "', argument " "8"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (!argp8) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "DenseTensorIface_getSubtensorEx" "', argument " "8"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared8 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp8);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp8);
      arg8 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(tempshared8.get());
    } else {
      arg8 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp8)->get());
    }
    if(!arg8) SWIG_exception_fail(SWIG_ArgError(res8), "in method '" "DenseTensorIface_getSubtensorEx" "', argument " "8"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getSubtensorEx(arg2,(size_t const *)arg3,arg4,arg5,arg6,*arg7,(daal::data_management::interface1::TensorOffsetLayout const &)*arg8);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  {
    if(ALLOW_CONVERSION != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(ALLOW_CONVERSION != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_DenseTensorIface_getSubtensorEx__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DenseTensorIface *arg1 = (daal::data_management::interface1::DenseTensorIface *) 0 ;
  size_t arg2 ;
  size_t *arg3 = (size_t *) 0 ;
  size_t arg4 ;
  size_t arg5 ;
  daal::data_management::ReadWriteMode arg6 ;
  daal::data_management::interface1::SubtensorDescriptor< float > *arg7 = 0 ;
  daal::data_management::interface1::TensorOffsetLayout *arg8 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseTensorIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseTensorIface > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int is_new_object2 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  size_t val5 ;
  int ecode5 = 0 ;
  int val6 ;
  int ecode6 = 0 ;
  void *argp7 = 0 ;
  int res7 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< float > > tempshared7 ;
  void *argp8 = 0 ;
  int res8 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout const > tempshared8 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  PyObject * obj6 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOOO:DenseTensorIface_getSubtensorEx",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5,&obj6)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseTensorIface_getSubtensorEx" "', argument " "1"" of type '" "daal::data_management::interface1::DenseTensorIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseTensorIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseTensorIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseTensorIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseTensorIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseTensorIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseTensorIface_getSubtensorEx" "', argument " "1"" of type '" "daal::data_management::interface1::DenseTensorIface *""'"); 
  }
  {
    array2 = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UINT64)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UINT64, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (size_t) array_size(array2,0);
    arg3 = (size_t*) array_data(array2);
  }
  ecode4 = SWIG_AsVal_size_t(obj2, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "DenseTensorIface_getSubtensorEx" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_size_t(obj3, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "DenseTensorIface_getSubtensorEx" "', argument " "5"" of type '" "size_t""'");
  } 
  arg5 = static_cast< size_t >(val5);
  ecode6 = SWIG_AsVal_int(obj4, &val6);
  if (!SWIG_IsOK(ecode6)) {
    SWIG_exception_fail(SWIG_ArgError(ecode6), "in method '" "DenseTensorIface_getSubtensorEx" "', argument " "6"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg6 = static_cast< daal::data_management::ReadWriteMode >(val6);
  {
    int newmem = 0;
    res7 = SWIG_ConvertPtrAndOwn(obj5, &argp7, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res7)) {
      SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "DenseTensorIface_getSubtensorEx" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > &""'"); 
    }
    if (!argp7) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "DenseTensorIface_getSubtensorEx" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared7 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp7);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp7);
      arg7 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >(tempshared7.get());
    } else {
      arg7 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp7)->get());
    }
    if(!arg7) SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "DenseTensorIface_getSubtensorEx" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > &""'"); 
  }
  {
    int newmem = 0;
    res8 = SWIG_ConvertPtrAndOwn(obj6, &argp8, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t,  0 , &newmem);
    if (!SWIG_IsOK(res8)) {
      SWIG_exception_fail(SWIG_ArgError(res8), "in method '" "DenseTensorIface_getSubtensorEx" "', argument " "8"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (!argp8) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "DenseTensorIface_getSubtensorEx" "', argument " "8"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared8 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp8);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp8);
      arg8 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(tempshared8.get());
    } else {
      arg8 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp8)->get());
    }
    if(!arg8) SWIG_exception_fail(SWIG_ArgError(res8), "in method '" "DenseTensorIface_getSubtensorEx" "', argument " "8"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getSubtensorEx(arg2,(size_t const *)arg3,arg4,arg5,arg6,*arg7,(daal::data_management::interface1::TensorOffsetLayout const &)*arg8);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  {
    if(ALLOW_CONVERSION != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(ALLOW_CONVERSION != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_DenseTensorIface_getSubtensorEx__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DenseTensorIface *arg1 = (daal::data_management::interface1::DenseTensorIface *) 0 ;
  size_t arg2 ;
  size_t *arg3 = (size_t *) 0 ;
  size_t arg4 ;
  size_t arg5 ;
  daal::data_management::ReadWriteMode arg6 ;
  daal::data_management::interface1::SubtensorDescriptor< int > *arg7 = 0 ;
  daal::data_management::interface1::TensorOffsetLayout *arg8 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseTensorIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseTensorIface > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int is_new_object2 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  size_t val5 ;
  int ecode5 = 0 ;
  int val6 ;
  int ecode6 = 0 ;
  void *argp7 = 0 ;
  int res7 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< int > > tempshared7 ;
  void *argp8 = 0 ;
  int res8 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout const > tempshared8 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  PyObject * obj6 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOOO:DenseTensorIface_getSubtensorEx",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5,&obj6)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseTensorIface_getSubtensorEx" "', argument " "1"" of type '" "daal::data_management::interface1::DenseTensorIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseTensorIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseTensorIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseTensorIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseTensorIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseTensorIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseTensorIface_getSubtensorEx" "', argument " "1"" of type '" "daal::data_management::interface1::DenseTensorIface *""'"); 
  }
  {
    array2 = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UINT64)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UINT64, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (size_t) array_size(array2,0);
    arg3 = (size_t*) array_data(array2);
  }
  ecode4 = SWIG_AsVal_size_t(obj2, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "DenseTensorIface_getSubtensorEx" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_size_t(obj3, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "DenseTensorIface_getSubtensorEx" "', argument " "5"" of type '" "size_t""'");
  } 
  arg5 = static_cast< size_t >(val5);
  ecode6 = SWIG_AsVal_int(obj4, &val6);
  if (!SWIG_IsOK(ecode6)) {
    SWIG_exception_fail(SWIG_ArgError(ecode6), "in method '" "DenseTensorIface_getSubtensorEx" "', argument " "6"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg6 = static_cast< daal::data_management::ReadWriteMode >(val6);
  {
    int newmem = 0;
    res7 = SWIG_ConvertPtrAndOwn(obj5, &argp7, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res7)) {
      SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "DenseTensorIface_getSubtensorEx" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > &""'"); 
    }
    if (!argp7) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "DenseTensorIface_getSubtensorEx" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared7 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp7);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp7);
      arg7 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >(tempshared7.get());
    } else {
      arg7 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp7)->get());
    }
    if(!arg7) SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "DenseTensorIface_getSubtensorEx" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > &""'"); 
  }
  {
    int newmem = 0;
    res8 = SWIG_ConvertPtrAndOwn(obj6, &argp8, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t,  0 , &newmem);
    if (!SWIG_IsOK(res8)) {
      SWIG_exception_fail(SWIG_ArgError(res8), "in method '" "DenseTensorIface_getSubtensorEx" "', argument " "8"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (!argp8) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "DenseTensorIface_getSubtensorEx" "', argument " "8"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared8 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp8);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp8);
      arg8 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(tempshared8.get());
    } else {
      arg8 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp8)->get());
    }
    if(!arg8) SWIG_exception_fail(SWIG_ArgError(res8), "in method '" "DenseTensorIface_getSubtensorEx" "', argument " "8"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getSubtensorEx(arg2,(size_t const *)arg3,arg4,arg5,arg6,*arg7,(daal::data_management::interface1::TensorOffsetLayout const &)*arg8);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  {
    if(ALLOW_CONVERSION != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(ALLOW_CONVERSION != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_DenseTensorIface_getSubtensorEx(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[8];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 7) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 7) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = (ALLOW_CONVERSION == FORCE_INPLACE
          ? (is_array(argv[1]) && PyArray_EquivTypenums(array_type(argv[1]), NPY_UINT64))
          :(is_array(argv[1]) || PySequence_Check(argv[1])));
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                int res = SWIG_ConvertPtr(argv[6], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, 0);
                _v = SWIG_CheckState(res);
                if (_v) {
                  return _wrap_DenseTensorIface_getSubtensorEx__SWIG_0(self, args);
                }
              }
            }
          }
        }
      }
    }
  }
  if (argc == 7) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = (ALLOW_CONVERSION == FORCE_INPLACE
          ? (is_array(argv[1]) && PyArray_EquivTypenums(array_type(argv[1]), NPY_UINT64))
          :(is_array(argv[1]) || PySequence_Check(argv[1])));
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                int res = SWIG_ConvertPtr(argv[6], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, 0);
                _v = SWIG_CheckState(res);
                if (_v) {
                  return _wrap_DenseTensorIface_getSubtensorEx__SWIG_1(self, args);
                }
              }
            }
          }
        }
      }
    }
  }
  if (argc == 7) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = (ALLOW_CONVERSION == FORCE_INPLACE
          ? (is_array(argv[1]) && PyArray_EquivTypenums(array_type(argv[1]), NPY_UINT64))
          :(is_array(argv[1]) || PySequence_Check(argv[1])));
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                int res = SWIG_ConvertPtr(argv[6], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, 0);
                _v = SWIG_CheckState(res);
                if (_v) {
                  return _wrap_DenseTensorIface_getSubtensorEx__SWIG_2(self, args);
                }
              }
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'DenseTensorIface_getSubtensorEx'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::DenseTensorIface::getSubtensorEx(size_t,size_t const *,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::SubtensorDescriptor< double > &,daal::data_management::interface1::TensorOffsetLayout const &)\n"
    "    daal::data_management::interface1::DenseTensorIface::getSubtensorEx(size_t,size_t const *,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::SubtensorDescriptor< float > &,daal::data_management::interface1::TensorOffsetLayout const &)\n"
    "    daal::data_management::interface1::DenseTensorIface::getSubtensorEx(size_t,size_t const *,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::SubtensorDescriptor< int > &,daal::data_management::interface1::TensorOffsetLayout const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_DenseTensorIface_releaseSubtensor__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DenseTensorIface *arg1 = (daal::data_management::interface1::DenseTensorIface *) 0 ;
  daal::data_management::interface1::SubtensorDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseTensorIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseTensorIface > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DenseTensorIface_releaseSubtensor",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseTensorIface_releaseSubtensor" "', argument " "1"" of type '" "daal::data_management::interface1::DenseTensorIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseTensorIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseTensorIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseTensorIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseTensorIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseTensorIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseTensorIface_releaseSubtensor" "', argument " "1"" of type '" "daal::data_management::interface1::DenseTensorIface *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DenseTensorIface_releaseSubtensor" "', argument " "2"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "DenseTensorIface_releaseSubtensor" "', argument " "2"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DenseTensorIface_releaseSubtensor" "', argument " "2"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseSubtensor(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DenseTensorIface_releaseSubtensor__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DenseTensorIface *arg1 = (daal::data_management::interface1::DenseTensorIface *) 0 ;
  daal::data_management::interface1::SubtensorDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseTensorIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseTensorIface > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DenseTensorIface_releaseSubtensor",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseTensorIface_releaseSubtensor" "', argument " "1"" of type '" "daal::data_management::interface1::DenseTensorIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseTensorIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseTensorIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseTensorIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseTensorIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseTensorIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseTensorIface_releaseSubtensor" "', argument " "1"" of type '" "daal::data_management::interface1::DenseTensorIface *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DenseTensorIface_releaseSubtensor" "', argument " "2"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "DenseTensorIface_releaseSubtensor" "', argument " "2"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DenseTensorIface_releaseSubtensor" "', argument " "2"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseSubtensor(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DenseTensorIface_releaseSubtensor__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DenseTensorIface *arg1 = (daal::data_management::interface1::DenseTensorIface *) 0 ;
  daal::data_management::interface1::SubtensorDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseTensorIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseTensorIface > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DenseTensorIface_releaseSubtensor",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseTensorIface_releaseSubtensor" "', argument " "1"" of type '" "daal::data_management::interface1::DenseTensorIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseTensorIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseTensorIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseTensorIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseTensorIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseTensorIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseTensorIface_releaseSubtensor" "', argument " "1"" of type '" "daal::data_management::interface1::DenseTensorIface *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DenseTensorIface_releaseSubtensor" "', argument " "2"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "DenseTensorIface_releaseSubtensor" "', argument " "2"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DenseTensorIface_releaseSubtensor" "', argument " "2"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseSubtensor(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DenseTensorIface_releaseSubtensor(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_DenseTensorIface_releaseSubtensor__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_DenseTensorIface_releaseSubtensor__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_DenseTensorIface_releaseSubtensor__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'DenseTensorIface_releaseSubtensor'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::DenseTensorIface::releaseSubtensor(daal::data_management::interface1::SubtensorDescriptor< double > &)\n"
    "    daal::data_management::interface1::DenseTensorIface::releaseSubtensor(daal::data_management::interface1::SubtensorDescriptor< float > &)\n"
    "    daal::data_management::interface1::DenseTensorIface::releaseSubtensor(daal::data_management::interface1::SubtensorDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_DenseTensorIface_getSubtensor__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DenseTensorIface *arg1 = (daal::data_management::interface1::DenseTensorIface *) 0 ;
  size_t arg2 ;
  size_t *arg3 = (size_t *) 0 ;
  size_t arg4 ;
  size_t arg5 ;
  daal::data_management::ReadWriteMode arg6 ;
  daal::data_management::interface1::SubtensorDescriptor< double > *arg7 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseTensorIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseTensorIface > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int is_new_object2 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  size_t val5 ;
  int ecode5 = 0 ;
  int val6 ;
  int ecode6 = 0 ;
  void *argp7 = 0 ;
  int res7 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< double > > tempshared7 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:DenseTensorIface_getSubtensor",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseTensorIface_getSubtensor" "', argument " "1"" of type '" "daal::data_management::interface1::DenseTensorIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseTensorIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseTensorIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseTensorIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseTensorIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseTensorIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseTensorIface_getSubtensor" "', argument " "1"" of type '" "daal::data_management::interface1::DenseTensorIface *""'"); 
  }
  {
    array2 = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UINT64)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UINT64, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (size_t) array_size(array2,0);
    arg3 = (size_t*) array_data(array2);
  }
  ecode4 = SWIG_AsVal_size_t(obj2, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "DenseTensorIface_getSubtensor" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_size_t(obj3, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "DenseTensorIface_getSubtensor" "', argument " "5"" of type '" "size_t""'");
  } 
  arg5 = static_cast< size_t >(val5);
  ecode6 = SWIG_AsVal_int(obj4, &val6);
  if (!SWIG_IsOK(ecode6)) {
    SWIG_exception_fail(SWIG_ArgError(ecode6), "in method '" "DenseTensorIface_getSubtensor" "', argument " "6"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg6 = static_cast< daal::data_management::ReadWriteMode >(val6);
  {
    int newmem = 0;
    res7 = SWIG_ConvertPtrAndOwn(obj5, &argp7, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res7)) {
      SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "DenseTensorIface_getSubtensor" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > &""'"); 
    }
    if (!argp7) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "DenseTensorIface_getSubtensor" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared7 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp7);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp7);
      arg7 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >(tempshared7.get());
    } else {
      arg7 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp7)->get());
    }
    if(!arg7) SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "DenseTensorIface_getSubtensor" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getSubtensor(arg2,(size_t const *)arg3,arg4,arg5,arg6,*arg7);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  {
    if(ALLOW_CONVERSION != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(ALLOW_CONVERSION != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_DenseTensorIface_getSubtensor__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DenseTensorIface *arg1 = (daal::data_management::interface1::DenseTensorIface *) 0 ;
  size_t arg2 ;
  size_t *arg3 = (size_t *) 0 ;
  size_t arg4 ;
  size_t arg5 ;
  daal::data_management::ReadWriteMode arg6 ;
  daal::data_management::interface1::SubtensorDescriptor< float > *arg7 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseTensorIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseTensorIface > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int is_new_object2 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  size_t val5 ;
  int ecode5 = 0 ;
  int val6 ;
  int ecode6 = 0 ;
  void *argp7 = 0 ;
  int res7 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< float > > tempshared7 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:DenseTensorIface_getSubtensor",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseTensorIface_getSubtensor" "', argument " "1"" of type '" "daal::data_management::interface1::DenseTensorIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseTensorIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseTensorIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseTensorIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseTensorIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseTensorIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseTensorIface_getSubtensor" "', argument " "1"" of type '" "daal::data_management::interface1::DenseTensorIface *""'"); 
  }
  {
    array2 = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UINT64)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UINT64, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (size_t) array_size(array2,0);
    arg3 = (size_t*) array_data(array2);
  }
  ecode4 = SWIG_AsVal_size_t(obj2, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "DenseTensorIface_getSubtensor" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_size_t(obj3, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "DenseTensorIface_getSubtensor" "', argument " "5"" of type '" "size_t""'");
  } 
  arg5 = static_cast< size_t >(val5);
  ecode6 = SWIG_AsVal_int(obj4, &val6);
  if (!SWIG_IsOK(ecode6)) {
    SWIG_exception_fail(SWIG_ArgError(ecode6), "in method '" "DenseTensorIface_getSubtensor" "', argument " "6"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg6 = static_cast< daal::data_management::ReadWriteMode >(val6);
  {
    int newmem = 0;
    res7 = SWIG_ConvertPtrAndOwn(obj5, &argp7, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res7)) {
      SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "DenseTensorIface_getSubtensor" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > &""'"); 
    }
    if (!argp7) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "DenseTensorIface_getSubtensor" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared7 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp7);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp7);
      arg7 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >(tempshared7.get());
    } else {
      arg7 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp7)->get());
    }
    if(!arg7) SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "DenseTensorIface_getSubtensor" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getSubtensor(arg2,(size_t const *)arg3,arg4,arg5,arg6,*arg7);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  {
    if(ALLOW_CONVERSION != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(ALLOW_CONVERSION != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_DenseTensorIface_getSubtensor__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DenseTensorIface *arg1 = (daal::data_management::interface1::DenseTensorIface *) 0 ;
  size_t arg2 ;
  size_t *arg3 = (size_t *) 0 ;
  size_t arg4 ;
  size_t arg5 ;
  daal::data_management::ReadWriteMode arg6 ;
  daal::data_management::interface1::SubtensorDescriptor< int > *arg7 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseTensorIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseTensorIface > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int is_new_object2 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  size_t val5 ;
  int ecode5 = 0 ;
  int val6 ;
  int ecode6 = 0 ;
  void *argp7 = 0 ;
  int res7 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< int > > tempshared7 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:DenseTensorIface_getSubtensor",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseTensorIface_getSubtensor" "', argument " "1"" of type '" "daal::data_management::interface1::DenseTensorIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseTensorIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseTensorIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseTensorIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DenseTensorIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseTensorIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseTensorIface_getSubtensor" "', argument " "1"" of type '" "daal::data_management::interface1::DenseTensorIface *""'"); 
  }
  {
    array2 = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UINT64)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UINT64, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (size_t) array_size(array2,0);
    arg3 = (size_t*) array_data(array2);
  }
  ecode4 = SWIG_AsVal_size_t(obj2, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "DenseTensorIface_getSubtensor" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_size_t(obj3, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "DenseTensorIface_getSubtensor" "', argument " "5"" of type '" "size_t""'");
  } 
  arg5 = static_cast< size_t >(val5);
  ecode6 = SWIG_AsVal_int(obj4, &val6);
  if (!SWIG_IsOK(ecode6)) {
    SWIG_exception_fail(SWIG_ArgError(ecode6), "in method '" "DenseTensorIface_getSubtensor" "', argument " "6"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg6 = static_cast< daal::data_management::ReadWriteMode >(val6);
  {
    int newmem = 0;
    res7 = SWIG_ConvertPtrAndOwn(obj5, &argp7, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res7)) {
      SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "DenseTensorIface_getSubtensor" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > &""'"); 
    }
    if (!argp7) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "DenseTensorIface_getSubtensor" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared7 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp7);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp7);
      arg7 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >(tempshared7.get());
    } else {
      arg7 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp7)->get());
    }
    if(!arg7) SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "DenseTensorIface_getSubtensor" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getSubtensor(arg2,(size_t const *)arg3,arg4,arg5,arg6,*arg7);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  {
    if(ALLOW_CONVERSION != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(ALLOW_CONVERSION != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_DenseTensorIface_getSubtensor(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[7];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 6) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = (ALLOW_CONVERSION == FORCE_INPLACE
          ? (is_array(argv[1]) && PyArray_EquivTypenums(array_type(argv[1]), NPY_UINT64))
          :(is_array(argv[1]) || PySequence_Check(argv[1])));
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_DenseTensorIface_getSubtensor__SWIG_0(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = (ALLOW_CONVERSION == FORCE_INPLACE
          ? (is_array(argv[1]) && PyArray_EquivTypenums(array_type(argv[1]), NPY_UINT64))
          :(is_array(argv[1]) || PySequence_Check(argv[1])));
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_DenseTensorIface_getSubtensor__SWIG_1(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = (ALLOW_CONVERSION == FORCE_INPLACE
          ? (is_array(argv[1]) && PyArray_EquivTypenums(array_type(argv[1]), NPY_UINT64))
          :(is_array(argv[1]) || PySequence_Check(argv[1])));
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_DenseTensorIface_getSubtensor__SWIG_2(self, args);
              }
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'DenseTensorIface_getSubtensor'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::DenseTensorIface::getSubtensor(size_t,size_t const *,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::SubtensorDescriptor< double > &)\n"
    "    daal::data_management::interface1::DenseTensorIface::getSubtensor(size_t,size_t const *,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::SubtensorDescriptor< float > &)\n"
    "    daal::data_management::interface1::DenseTensorIface::getSubtensor(size_t,size_t const *,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::SubtensorDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_DenseTensorIface_createDefaultSubtensorLayout(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DenseTensorIface *arg1 = (daal::data_management::interface1::DenseTensorIface *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseTensorIface const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseTensorIface const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  SwigValueWrapper< daal::data_management::interface1::TensorOffsetLayout > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DenseTensorIface_createDefaultSubtensorLayout",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseTensorIface_createDefaultSubtensorLayout" "', argument " "1"" of type '" "daal::data_management::interface1::DenseTensorIface const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DenseTensorIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DenseTensorIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseTensorIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DenseTensorIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseTensorIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseTensorIface_createDefaultSubtensorLayout" "', argument " "1"" of type '" "daal::data_management::interface1::DenseTensorIface const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::DenseTensorIface const *)arg1)->createDefaultSubtensorLayout();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::TensorOffsetLayout > *smartresult = new daal::services::SharedPtr<  daal::data_management::interface1::TensorOffsetLayout >(new daal::data_management::interface1::TensorOffsetLayout((daal::data_management::interface1::TensorOffsetLayout &)result));
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DenseTensorIface_createRawSubtensorLayout(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DenseTensorIface *arg1 = (daal::data_management::interface1::DenseTensorIface *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseTensorIface const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DenseTensorIface const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  SwigValueWrapper< daal::data_management::interface1::TensorOffsetLayout > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DenseTensorIface_createRawSubtensorLayout",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseTensorIface_createRawSubtensorLayout" "', argument " "1"" of type '" "daal::data_management::interface1::DenseTensorIface const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DenseTensorIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DenseTensorIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseTensorIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DenseTensorIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DenseTensorIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DenseTensorIface_createRawSubtensorLayout" "', argument " "1"" of type '" "daal::data_management::interface1::DenseTensorIface const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::DenseTensorIface const *)arg1)->createRawSubtensorLayout();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::TensorOffsetLayout > *smartresult = new daal::services::SharedPtr<  daal::data_management::interface1::TensorOffsetLayout >(new daal::data_management::interface1::TensorOffsetLayout((daal::data_management::interface1::TensorOffsetLayout &)result));
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *DenseTensorIface_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_delete_Tensor(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Tensor *arg1 = (daal::data_management::interface1::Tensor *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Tensor > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Tensor > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_Tensor",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Tensor" "', argument " "1"" of type '" "daal::data_management::interface1::Tensor *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Tensor > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Tensor > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Tensor * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Tensor > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Tensor * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Tensor" "', argument " "1"" of type '" "daal::data_management::interface1::Tensor *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Tensor_getDataMemoryStatus(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Tensor *arg1 = (daal::data_management::interface1::Tensor *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Tensor const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Tensor const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::TensorIface::MemoryStatus result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Tensor_getDataMemoryStatus",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Tensor_getDataMemoryStatus" "', argument " "1"" of type '" "daal::data_management::interface1::Tensor const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Tensor > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Tensor > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Tensor * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Tensor > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Tensor * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Tensor_getDataMemoryStatus" "', argument " "1"" of type '" "daal::data_management::interface1::Tensor const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::TensorIface::MemoryStatus)((daal::data_management::interface1::Tensor const *)arg1)->getDataMemoryStatus();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Tensor_getNumberOfDimensions(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Tensor *arg1 = (daal::data_management::interface1::Tensor *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Tensor const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Tensor const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Tensor_getNumberOfDimensions",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Tensor_getNumberOfDimensions" "', argument " "1"" of type '" "daal::data_management::interface1::Tensor const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Tensor > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Tensor > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Tensor * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Tensor > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Tensor * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Tensor_getNumberOfDimensions" "', argument " "1"" of type '" "daal::data_management::interface1::Tensor const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::Tensor const *)arg1)->getNumberOfDimensions();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Tensor_getDimensionSize(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Tensor *arg1 = (daal::data_management::interface1::Tensor *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Tensor const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Tensor const > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Tensor_getDimensionSize",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Tensor_getDimensionSize" "', argument " "1"" of type '" "daal::data_management::interface1::Tensor const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Tensor > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Tensor > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Tensor * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Tensor > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Tensor * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Tensor_getDimensionSize" "', argument " "1"" of type '" "daal::data_management::interface1::Tensor const *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Tensor_getDimensionSize" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::Tensor const *)arg1)->getDimensionSize(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Tensor_getDimensions(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Tensor *arg1 = (daal::data_management::interface1::Tensor *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Tensor const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Tensor const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::Collection< size_t > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Tensor_getDimensions",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Tensor_getDimensions" "', argument " "1"" of type '" "daal::data_management::interface1::Tensor const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Tensor > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Tensor > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Tensor * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Tensor > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Tensor * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Tensor_getDimensions" "', argument " "1"" of type '" "daal::data_management::interface1::Tensor const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::services::Collection< size_t > *) &((daal::data_management::interface1::Tensor const *)arg1)->getDimensions();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    size_t n = result->size();
    resultobj = PyList_New(n);
    for( size_t i = 0; i < n; ++i ) {
      PyObject * tmp = PyLong_FromSsize_t((*result)[i]);
      if( tmp == NULL || PyList_SetItem(resultobj, i, tmp) ) {
        PyErr_Format(PyExc_TypeError, "Could not fill sequence from Collection.");
        SWIG_fail;
      }
    }
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Tensor_getSize__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Tensor *arg1 = (daal::data_management::interface1::Tensor *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Tensor const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Tensor const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Tensor_getSize",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Tensor_getSize" "', argument " "1"" of type '" "daal::data_management::interface1::Tensor const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Tensor > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Tensor > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Tensor * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Tensor > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Tensor * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Tensor_getSize" "', argument " "1"" of type '" "daal::data_management::interface1::Tensor const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::Tensor const *)arg1)->getSize();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Tensor_getSize__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Tensor *arg1 = (daal::data_management::interface1::Tensor *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Tensor const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Tensor const > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Tensor_getSize",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Tensor_getSize" "', argument " "1"" of type '" "daal::data_management::interface1::Tensor const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Tensor > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Tensor > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Tensor * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Tensor > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Tensor * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Tensor_getSize" "', argument " "1"" of type '" "daal::data_management::interface1::Tensor const *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Tensor_getSize" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Tensor_getSize" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::Tensor const *)arg1)->getSize(arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Tensor_getSize(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[4];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 3) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_Tensor_getSize__SWIG_0(self, args);
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_Tensor_getSize__SWIG_1(self, args);
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Tensor_getSize'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::Tensor::getSize() const\n"
    "    daal::data_management::interface1::Tensor::getSize(size_t,size_t) const\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Tensor_check(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Tensor *arg1 = (daal::data_management::interface1::Tensor *) 0 ;
  char *arg2 = (char *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Tensor const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Tensor const > *smartarg1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Tensor_check",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Tensor_check" "', argument " "1"" of type '" "daal::data_management::interface1::Tensor const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Tensor > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Tensor > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Tensor * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Tensor > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Tensor * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Tensor_check" "', argument " "1"" of type '" "daal::data_management::interface1::Tensor const *""'"); 
  }
  res2 = SWIG_AsCharPtrAndSize(obj1, &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Tensor_check" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = reinterpret_cast< char * >(buf2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::Tensor const *)arg1)->check((char const *)arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Tensor_getLayoutPtr(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Tensor *arg1 = (daal::data_management::interface1::Tensor *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Tensor const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Tensor const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::TensorLayout *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Tensor_getLayoutPtr",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Tensor_getLayoutPtr" "', argument " "1"" of type '" "daal::data_management::interface1::Tensor const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Tensor > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Tensor > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Tensor * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Tensor > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Tensor * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Tensor_getLayoutPtr" "', argument " "1"" of type '" "daal::data_management::interface1::Tensor const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::TensorLayout *)((daal::data_management::interface1::Tensor const *)arg1)->getLayoutPtr();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr< const daal::data_management::interface1::TensorLayout > *smartresult = result ? new daal::services::SharedPtr< const daal::data_management::interface1::TensorLayout >(result SWIG_NO_NULL_DELETER_0) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayout_t, 0 | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Tensor_allocateDataMemory__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Tensor *arg1 = (daal::data_management::interface1::Tensor *) 0 ;
  daal::MemType arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Tensor > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Tensor > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Tensor_allocateDataMemory",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Tensor_allocateDataMemory" "', argument " "1"" of type '" "daal::data_management::interface1::Tensor *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Tensor > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Tensor > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Tensor * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Tensor > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Tensor * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Tensor_allocateDataMemory" "', argument " "1"" of type '" "daal::data_management::interface1::Tensor *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Tensor_allocateDataMemory" "', argument " "2"" of type '" "daal::MemType""'");
  } 
  arg2 = static_cast< daal::MemType >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->allocateDataMemory(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Tensor_allocateDataMemory__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Tensor *arg1 = (daal::data_management::interface1::Tensor *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Tensor > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Tensor > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Tensor_allocateDataMemory",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Tensor_allocateDataMemory" "', argument " "1"" of type '" "daal::data_management::interface1::Tensor *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Tensor > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Tensor > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Tensor * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Tensor > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Tensor * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Tensor_allocateDataMemory" "', argument " "1"" of type '" "daal::data_management::interface1::Tensor *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->allocateDataMemory();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Tensor_allocateDataMemory(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_Tensor_allocateDataMemory__SWIG_1(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_Tensor_allocateDataMemory__SWIG_0(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Tensor_allocateDataMemory'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::Tensor::allocateDataMemory(daal::MemType)\n"
    "    daal::data_management::interface1::Tensor::allocateDataMemory()\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Tensor_freeDataMemory(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Tensor *arg1 = (daal::data_management::interface1::Tensor *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Tensor > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Tensor > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Tensor_freeDataMemory",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Tensor_freeDataMemory" "', argument " "1"" of type '" "daal::data_management::interface1::Tensor *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Tensor > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Tensor > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Tensor * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Tensor > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Tensor * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Tensor_freeDataMemory" "', argument " "1"" of type '" "daal::data_management::interface1::Tensor *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->freeDataMemory();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Tensor_resize(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Tensor *arg1 = (daal::data_management::interface1::Tensor *) 0 ;
  daal::services::Collection< size_t > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Tensor > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Tensor > *smartarg1 = 0 ;
  daal::services::Collection< size_t > *col_szt2 = NULL ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Tensor_resize",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Tensor_resize" "', argument " "1"" of type '" "daal::data_management::interface1::Tensor *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Tensor > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Tensor > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Tensor * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Tensor > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Tensor * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Tensor_resize" "', argument " "1"" of type '" "daal::data_management::interface1::Tensor *""'"); 
  }
  {
    Py_ssize_t n = PySequence_Length(obj1);
    if( n == 0 ) SWIG_fail;
    col_szt2 = new daal::services::Collection<size_t>(n);
    for( Py_ssize_t i=0; i<n; ++i ) {
      PyObject * o = PySequence_GetItem(obj1, i);
      size_t tmp = PyInt_AsSsize_t(o);
      if(PyErr_Occurred()) {
        PyErr_Format(PyExc_TypeError, "Sequence of integer values required");
        SWIG_fail;
      }
      (*col_szt2)[i] = tmp;
    }
    arg2 = col_szt2;
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->resize((daal::services::Collection< size_t > const &)*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  {
    if( col_szt2 ) delete col_szt2;
  }
  return resultobj;
fail:
  {
    if( col_szt2 ) delete col_szt2;
  }
  return NULL;
}


SWIGINTERN PyObject *Tensor_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_checkTensor__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::Tensor *arg1 = (daal::data_management::Tensor *) 0 ;
  char *arg2 = (char *) 0 ;
  daal::services::Collection< size_t > *arg3 = (daal::services::Collection< size_t > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Tensor const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Tensor const > *smartarg1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:checkTensor",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "checkTensor" "', argument " "1"" of type '" "daal::data_management::Tensor const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Tensor > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Tensor > * >(argp1);
      arg1 = const_cast< daal::data_management::Tensor * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Tensor > * >(argp1);
      arg1 = const_cast< daal::data_management::Tensor * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "checkTensor" "', argument " "1"" of type '" "daal::data_management::Tensor const *""'"); 
  }
  res2 = SWIG_AsCharPtrAndSize(obj1, &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "checkTensor" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = reinterpret_cast< char * >(buf2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_daal__services__CollectionT_size_t_t, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "checkTensor" "', argument " "3"" of type '" "daal::services::Collection< size_t > const *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Collection< size_t > * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::checkTensor((daal::data_management::interface1::Tensor const *)arg1,(char const *)arg2,(daal::services::Collection< size_t > const *)arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_checkTensor__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::Tensor *arg1 = (daal::data_management::Tensor *) 0 ;
  char *arg2 = (char *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Tensor const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Tensor const > *smartarg1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:checkTensor",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "checkTensor" "', argument " "1"" of type '" "daal::data_management::Tensor const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Tensor > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Tensor > * >(argp1);
      arg1 = const_cast< daal::data_management::Tensor * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Tensor > * >(argp1);
      arg1 = const_cast< daal::data_management::Tensor * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "checkTensor" "', argument " "1"" of type '" "daal::data_management::Tensor const *""'"); 
  }
  res2 = SWIG_AsCharPtrAndSize(obj1, &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "checkTensor" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = reinterpret_cast< char * >(buf2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::checkTensor((daal::data_management::interface1::Tensor const *)arg1,(char const *)arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_checkTensor(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[4];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 3) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_AsCharPtrAndSize(argv[1], 0, NULL, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_checkTensor__SWIG_1(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_AsCharPtrAndSize(argv[1], 0, NULL, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__CollectionT_size_t_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_checkTensor__SWIG_0(self, args);
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'checkTensor'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::checkTensor(daal::data_management::Tensor const *,char const *,daal::services::Collection< size_t > const *)\n"
    "    daal::data_management::checkTensor(daal::data_management::Tensor const *,char const *)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_new_AOSNumericTable(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  PyArrayObject *arg1 = (PyArrayObject *) 0 ;
  PyObject *ary1 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::NpyAOSNumericTable *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:new_AOSNumericTable",&obj0)) SWIG_fail;
  {
    arg1 = obj_to_array_no_conversion(obj0, NPY_NOTYPE);
    if (!arg1 || !require_dimensions(arg1,1) || !require_contiguous(arg1) || !require_native(arg1)) {
      SWIG_fail;
    }
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::NpyAOSNumericTable *)new daal::data_management::interface1::NpyAOSNumericTable(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_AOSNumericTable(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NpyAOSNumericTable *arg1 = (daal::data_management::interface1::NpyAOSNumericTable *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NpyAOSNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NpyAOSNumericTable > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_AOSNumericTable",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_AOSNumericTable" "', argument " "1"" of type '" "daal::data_management::interface1::NpyAOSNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NpyAOSNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NpyAOSNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_AOSNumericTable" "', argument " "1"" of type '" "daal::data_management::interface1::NpyAOSNumericTable *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AOSNumericTable_getSerializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NpyAOSNumericTable *arg1 = (daal::data_management::interface1::NpyAOSNumericTable *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NpyAOSNumericTable const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NpyAOSNumericTable const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:AOSNumericTable_getSerializationTag",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AOSNumericTable_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::NpyAOSNumericTable const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NpyAOSNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NpyAOSNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AOSNumericTable_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::NpyAOSNumericTable const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)((daal::data_management::interface1::NpyAOSNumericTable const *)arg1)->getSerializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AOSNumericTable_getBlockOfRows__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NpyAOSNumericTable *arg1 = (daal::data_management::interface1::NpyAOSNumericTable *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NpyAOSNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NpyAOSNumericTable > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:AOSNumericTable_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AOSNumericTable_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::NpyAOSNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NpyAOSNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NpyAOSNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AOSNumericTable_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::NpyAOSNumericTable *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AOSNumericTable_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "AOSNumericTable_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "AOSNumericTable_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "AOSNumericTable_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AOSNumericTable_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "AOSNumericTable_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AOSNumericTable_getBlockOfRows__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NpyAOSNumericTable *arg1 = (daal::data_management::interface1::NpyAOSNumericTable *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NpyAOSNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NpyAOSNumericTable > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:AOSNumericTable_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AOSNumericTable_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::NpyAOSNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NpyAOSNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NpyAOSNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AOSNumericTable_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::NpyAOSNumericTable *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AOSNumericTable_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "AOSNumericTable_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "AOSNumericTable_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "AOSNumericTable_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AOSNumericTable_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "AOSNumericTable_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AOSNumericTable_getBlockOfRows__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NpyAOSNumericTable *arg1 = (daal::data_management::interface1::NpyAOSNumericTable *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NpyAOSNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NpyAOSNumericTable > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:AOSNumericTable_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AOSNumericTable_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::NpyAOSNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NpyAOSNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NpyAOSNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AOSNumericTable_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::NpyAOSNumericTable *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AOSNumericTable_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "AOSNumericTable_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "AOSNumericTable_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "AOSNumericTable_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AOSNumericTable_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "AOSNumericTable_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AOSNumericTable_getBlockOfRows(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[6];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 5) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_AOSNumericTable_getBlockOfRows__SWIG_0(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_AOSNumericTable_getBlockOfRows__SWIG_1(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_AOSNumericTable_getBlockOfRows__SWIG_2(self, args);
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'AOSNumericTable_getBlockOfRows'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::NpyAOSNumericTable::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::NpyAOSNumericTable::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::NpyAOSNumericTable::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AOSNumericTable_releaseBlockOfRows__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NpyAOSNumericTable *arg1 = (daal::data_management::interface1::NpyAOSNumericTable *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NpyAOSNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NpyAOSNumericTable > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:AOSNumericTable_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AOSNumericTable_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::NpyAOSNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NpyAOSNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NpyAOSNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AOSNumericTable_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::NpyAOSNumericTable *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AOSNumericTable_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AOSNumericTable_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AOSNumericTable_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AOSNumericTable_releaseBlockOfRows__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NpyAOSNumericTable *arg1 = (daal::data_management::interface1::NpyAOSNumericTable *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NpyAOSNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NpyAOSNumericTable > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:AOSNumericTable_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AOSNumericTable_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::NpyAOSNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NpyAOSNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NpyAOSNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AOSNumericTable_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::NpyAOSNumericTable *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AOSNumericTable_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AOSNumericTable_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AOSNumericTable_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AOSNumericTable_releaseBlockOfRows__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NpyAOSNumericTable *arg1 = (daal::data_management::interface1::NpyAOSNumericTable *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NpyAOSNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NpyAOSNumericTable > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:AOSNumericTable_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AOSNumericTable_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::NpyAOSNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NpyAOSNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NpyAOSNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AOSNumericTable_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::NpyAOSNumericTable *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AOSNumericTable_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AOSNumericTable_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AOSNumericTable_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AOSNumericTable_releaseBlockOfRows(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_AOSNumericTable_releaseBlockOfRows__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_AOSNumericTable_releaseBlockOfRows__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_AOSNumericTable_releaseBlockOfRows__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'AOSNumericTable_releaseBlockOfRows'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::NpyAOSNumericTable::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::NpyAOSNumericTable::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::NpyAOSNumericTable::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AOSNumericTable_getBlockOfColumnValues__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NpyAOSNumericTable *arg1 = (daal::data_management::interface1::NpyAOSNumericTable *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NpyAOSNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NpyAOSNumericTable > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:AOSNumericTable_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AOSNumericTable_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::NpyAOSNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NpyAOSNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NpyAOSNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AOSNumericTable_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::NpyAOSNumericTable *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AOSNumericTable_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "AOSNumericTable_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "AOSNumericTable_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "AOSNumericTable_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "AOSNumericTable_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AOSNumericTable_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "AOSNumericTable_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AOSNumericTable_getBlockOfColumnValues__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NpyAOSNumericTable *arg1 = (daal::data_management::interface1::NpyAOSNumericTable *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NpyAOSNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NpyAOSNumericTable > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:AOSNumericTable_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AOSNumericTable_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::NpyAOSNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NpyAOSNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NpyAOSNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AOSNumericTable_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::NpyAOSNumericTable *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AOSNumericTable_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "AOSNumericTable_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "AOSNumericTable_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "AOSNumericTable_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "AOSNumericTable_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AOSNumericTable_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "AOSNumericTable_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AOSNumericTable_getBlockOfColumnValues__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NpyAOSNumericTable *arg1 = (daal::data_management::interface1::NpyAOSNumericTable *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NpyAOSNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NpyAOSNumericTable > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:AOSNumericTable_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AOSNumericTable_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::NpyAOSNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NpyAOSNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NpyAOSNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AOSNumericTable_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::NpyAOSNumericTable *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AOSNumericTable_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "AOSNumericTable_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "AOSNumericTable_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "AOSNumericTable_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "AOSNumericTable_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AOSNumericTable_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "AOSNumericTable_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AOSNumericTable_getBlockOfColumnValues(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[7];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 6) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_AOSNumericTable_getBlockOfColumnValues__SWIG_0(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_AOSNumericTable_getBlockOfColumnValues__SWIG_1(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_AOSNumericTable_getBlockOfColumnValues__SWIG_2(self, args);
              }
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'AOSNumericTable_getBlockOfColumnValues'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::NpyAOSNumericTable::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::NpyAOSNumericTable::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::NpyAOSNumericTable::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AOSNumericTable_releaseBlockOfColumnValues__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NpyAOSNumericTable *arg1 = (daal::data_management::interface1::NpyAOSNumericTable *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NpyAOSNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NpyAOSNumericTable > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:AOSNumericTable_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AOSNumericTable_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::NpyAOSNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NpyAOSNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NpyAOSNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AOSNumericTable_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::NpyAOSNumericTable *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AOSNumericTable_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AOSNumericTable_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AOSNumericTable_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AOSNumericTable_releaseBlockOfColumnValues__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NpyAOSNumericTable *arg1 = (daal::data_management::interface1::NpyAOSNumericTable *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NpyAOSNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NpyAOSNumericTable > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:AOSNumericTable_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AOSNumericTable_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::NpyAOSNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NpyAOSNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NpyAOSNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AOSNumericTable_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::NpyAOSNumericTable *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AOSNumericTable_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AOSNumericTable_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AOSNumericTable_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AOSNumericTable_releaseBlockOfColumnValues__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NpyAOSNumericTable *arg1 = (daal::data_management::interface1::NpyAOSNumericTable *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NpyAOSNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NpyAOSNumericTable > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:AOSNumericTable_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AOSNumericTable_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::NpyAOSNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NpyAOSNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NpyAOSNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AOSNumericTable_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::NpyAOSNumericTable *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AOSNumericTable_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AOSNumericTable_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AOSNumericTable_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AOSNumericTable_releaseBlockOfColumnValues(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_AOSNumericTable_releaseBlockOfColumnValues__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_AOSNumericTable_releaseBlockOfColumnValues__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_AOSNumericTable_releaseBlockOfColumnValues__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'AOSNumericTable_releaseBlockOfColumnValues'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::NpyAOSNumericTable::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::NpyAOSNumericTable::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::NpyAOSNumericTable::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AOSNumericTable_allocateDataMemory__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NpyAOSNumericTable *arg1 = (daal::data_management::interface1::NpyAOSNumericTable *) 0 ;
  daal::MemType arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NpyAOSNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NpyAOSNumericTable > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:AOSNumericTable_allocateDataMemory",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AOSNumericTable_allocateDataMemory" "', argument " "1"" of type '" "daal::data_management::interface1::NpyAOSNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NpyAOSNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NpyAOSNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AOSNumericTable_allocateDataMemory" "', argument " "1"" of type '" "daal::data_management::interface1::NpyAOSNumericTable *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AOSNumericTable_allocateDataMemory" "', argument " "2"" of type '" "daal::MemType""'");
  } 
  arg2 = static_cast< daal::MemType >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->allocateDataMemory(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AOSNumericTable_allocateDataMemory__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NpyAOSNumericTable *arg1 = (daal::data_management::interface1::NpyAOSNumericTable *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NpyAOSNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NpyAOSNumericTable > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:AOSNumericTable_allocateDataMemory",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AOSNumericTable_allocateDataMemory" "', argument " "1"" of type '" "daal::data_management::interface1::NpyAOSNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NpyAOSNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NpyAOSNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AOSNumericTable_allocateDataMemory" "', argument " "1"" of type '" "daal::data_management::interface1::NpyAOSNumericTable *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->allocateDataMemory();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AOSNumericTable_allocateDataMemory(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_AOSNumericTable_allocateDataMemory__SWIG_1(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_AOSNumericTable_allocateDataMemory__SWIG_0(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'AOSNumericTable_allocateDataMemory'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::NpyAOSNumericTable::allocateDataMemory(daal::MemType)\n"
    "    daal::data_management::interface1::NpyAOSNumericTable::allocateDataMemory()\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AOSNumericTable_freeDataMemory(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NpyAOSNumericTable *arg1 = (daal::data_management::interface1::NpyAOSNumericTable *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NpyAOSNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::NpyAOSNumericTable > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:AOSNumericTable_freeDataMemory",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AOSNumericTable_freeDataMemory" "', argument " "1"" of type '" "daal::data_management::interface1::NpyAOSNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NpyAOSNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NpyAOSNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NpyAOSNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AOSNumericTable_freeDataMemory" "', argument " "1"" of type '" "daal::data_management::interface1::NpyAOSNumericTable *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->freeDataMemory();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *AOSNumericTable_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_SOANumericTable_serializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)":SOANumericTable_serializationTag")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)daal::data_management::interface1::SOANumericTable::serializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SOANumericTable_getSerializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SOANumericTable *arg1 = (daal::data_management::interface1::SOANumericTable *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SOANumericTable const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SOANumericTable const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:SOANumericTable_getSerializationTag",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SOANumericTable_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::SOANumericTable const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SOANumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SOANumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SOANumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SOANumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SOANumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SOANumericTable_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::SOANumericTable const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)((daal::data_management::interface1::SOANumericTable const *)arg1)->getSerializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_SOANumericTable__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg3 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  int val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::data_management::interface1::SOANumericTable *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:new_SOANumericTable",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_SOANumericTable" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "new_SOANumericTable" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "new_SOANumericTable" "', argument " "3"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg3 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::SOANumericTable *)new daal::data_management::interface1::SOANumericTable(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_SOANumericTable__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::data_management::interface1::SOANumericTable *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:new_SOANumericTable",&obj0,&obj1)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_SOANumericTable" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "new_SOANumericTable" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::SOANumericTable *)new daal::data_management::interface1::SOANumericTable(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_SOANumericTable__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t val1 ;
  int ecode1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::SOANumericTable *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:new_SOANumericTable",&obj0)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_SOANumericTable" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::SOANumericTable *)new daal::data_management::interface1::SOANumericTable(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_SOANumericTable__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SOANumericTable *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_SOANumericTable")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::SOANumericTable *)new daal::data_management::interface1::SOANumericTable();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_SOANumericTable__SWIG_4(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTableDictionary *arg1 = (daal::data_management::interface1::NumericTableDictionary *) 0 ;
  size_t arg2 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  int val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::data_management::interface1::SOANumericTable *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:new_SOANumericTable",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_SOANumericTable" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableDictionary *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableDictionary * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableDictionary * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_SOANumericTable" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableDictionary *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "new_SOANumericTable" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "new_SOANumericTable" "', argument " "3"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg3 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::SOANumericTable *)new daal::data_management::interface1::SOANumericTable(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_SOANumericTable__SWIG_5(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTableDictionary *arg1 = (daal::data_management::interface1::NumericTableDictionary *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::data_management::interface1::SOANumericTable *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:new_SOANumericTable",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_SOANumericTable" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableDictionary *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableDictionary * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::NumericTableDictionary * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_SOANumericTable" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableDictionary *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "new_SOANumericTable" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::SOANumericTable *)new daal::data_management::interface1::SOANumericTable(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_SOANumericTable__SWIG_6(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTableDictionaryPtr arg1 ;
  size_t arg2 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg3 ;
  void *argp1 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  int val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::data_management::interface1::SOANumericTable *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:new_SOANumericTable",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_SOANumericTable" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableDictionaryPtr""'"); 
    }
    if (argp1) arg1 = *(reinterpret_cast< daal::data_management::interface1::NumericTableDictionaryPtr * >(argp1));
    if (newmem & SWIG_CAST_NEW_MEMORY) delete reinterpret_cast< daal::data_management::interface1::NumericTableDictionaryPtr * >(argp1);
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "new_SOANumericTable" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "new_SOANumericTable" "', argument " "3"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg3 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::SOANumericTable *)new daal::data_management::interface1::SOANumericTable(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_SOANumericTable__SWIG_7(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTableDictionaryPtr arg1 ;
  size_t arg2 ;
  void *argp1 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::data_management::interface1::SOANumericTable *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:new_SOANumericTable",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_SOANumericTable" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableDictionaryPtr""'"); 
    }
    if (argp1) arg1 = *(reinterpret_cast< daal::data_management::interface1::NumericTableDictionaryPtr * >(argp1));
    if (newmem & SWIG_CAST_NEW_MEMORY) delete reinterpret_cast< daal::data_management::interface1::NumericTableDictionaryPtr * >(argp1);
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "new_SOANumericTable" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::SOANumericTable *)new daal::data_management::interface1::SOANumericTable(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_SOANumericTable(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[4];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 3) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_new_SOANumericTable__SWIG_3(self, args);
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_new_SOANumericTable__SWIG_2(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_new_SOANumericTable__SWIG_5(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_new_SOANumericTable__SWIG_7(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_new_SOANumericTable__SWIG_1(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_new_SOANumericTable__SWIG_6(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_new_SOANumericTable__SWIG_4(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_new_SOANumericTable__SWIG_0(self, args);
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'new_SOANumericTable'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::SOANumericTable::SOANumericTable(size_t,size_t,daal::data_management::interface1::DictionaryIface::FeaturesEqual)\n"
    "    daal::data_management::interface1::SOANumericTable::SOANumericTable(size_t,size_t)\n"
    "    daal::data_management::interface1::SOANumericTable::SOANumericTable(size_t)\n"
    "    daal::data_management::interface1::SOANumericTable::SOANumericTable()\n"
    "    daal::data_management::interface1::SOANumericTable::SOANumericTable(daal::data_management::interface1::NumericTableDictionary *,size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag)\n"
    "    daal::data_management::interface1::SOANumericTable::SOANumericTable(daal::data_management::interface1::NumericTableDictionary *,size_t)\n"
    "    daal::data_management::interface1::SOANumericTable::SOANumericTable(daal::data_management::interface1::NumericTableDictionaryPtr,size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag)\n"
    "    daal::data_management::interface1::SOANumericTable::SOANumericTable(daal::data_management::interface1::NumericTableDictionaryPtr,size_t)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_SOANumericTable(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SOANumericTable *arg1 = (daal::data_management::interface1::SOANumericTable *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SOANumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SOANumericTable > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_SOANumericTable",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_SOANumericTable" "', argument " "1"" of type '" "daal::data_management::interface1::SOANumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SOANumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SOANumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_SOANumericTable" "', argument " "1"" of type '" "daal::data_management::interface1::SOANumericTable *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SOANumericTable_getBlockOfRows__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SOANumericTable *arg1 = (daal::data_management::interface1::SOANumericTable *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SOANumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SOANumericTable > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:SOANumericTable_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SOANumericTable_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::SOANumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SOANumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SOANumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SOANumericTable_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::SOANumericTable *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SOANumericTable_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "SOANumericTable_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "SOANumericTable_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "SOANumericTable_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SOANumericTable_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "SOANumericTable_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SOANumericTable_getBlockOfRows__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SOANumericTable *arg1 = (daal::data_management::interface1::SOANumericTable *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SOANumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SOANumericTable > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:SOANumericTable_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SOANumericTable_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::SOANumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SOANumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SOANumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SOANumericTable_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::SOANumericTable *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SOANumericTable_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "SOANumericTable_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "SOANumericTable_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "SOANumericTable_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SOANumericTable_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "SOANumericTable_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SOANumericTable_getBlockOfRows__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SOANumericTable *arg1 = (daal::data_management::interface1::SOANumericTable *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SOANumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SOANumericTable > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:SOANumericTable_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SOANumericTable_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::SOANumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SOANumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SOANumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SOANumericTable_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::SOANumericTable *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SOANumericTable_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "SOANumericTable_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "SOANumericTable_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "SOANumericTable_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SOANumericTable_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "SOANumericTable_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SOANumericTable_getBlockOfRows(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[6];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 5) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_SOANumericTable_getBlockOfRows__SWIG_0(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_SOANumericTable_getBlockOfRows__SWIG_1(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_SOANumericTable_getBlockOfRows__SWIG_2(self, args);
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'SOANumericTable_getBlockOfRows'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::SOANumericTable::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::SOANumericTable::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::SOANumericTable::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_SOANumericTable_releaseBlockOfRows__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SOANumericTable *arg1 = (daal::data_management::interface1::SOANumericTable *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SOANumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SOANumericTable > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:SOANumericTable_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SOANumericTable_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::SOANumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SOANumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SOANumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SOANumericTable_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::SOANumericTable *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SOANumericTable_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SOANumericTable_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SOANumericTable_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SOANumericTable_releaseBlockOfRows__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SOANumericTable *arg1 = (daal::data_management::interface1::SOANumericTable *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SOANumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SOANumericTable > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:SOANumericTable_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SOANumericTable_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::SOANumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SOANumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SOANumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SOANumericTable_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::SOANumericTable *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SOANumericTable_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SOANumericTable_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SOANumericTable_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SOANumericTable_releaseBlockOfRows__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SOANumericTable *arg1 = (daal::data_management::interface1::SOANumericTable *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SOANumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SOANumericTable > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:SOANumericTable_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SOANumericTable_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::SOANumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SOANumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SOANumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SOANumericTable_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::SOANumericTable *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SOANumericTable_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SOANumericTable_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SOANumericTable_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SOANumericTable_releaseBlockOfRows(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_SOANumericTable_releaseBlockOfRows__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_SOANumericTable_releaseBlockOfRows__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_SOANumericTable_releaseBlockOfRows__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'SOANumericTable_releaseBlockOfRows'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::SOANumericTable::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::SOANumericTable::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::SOANumericTable::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_SOANumericTable_getBlockOfColumnValues__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SOANumericTable *arg1 = (daal::data_management::interface1::SOANumericTable *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SOANumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SOANumericTable > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:SOANumericTable_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SOANumericTable_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::SOANumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SOANumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SOANumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SOANumericTable_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::SOANumericTable *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SOANumericTable_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "SOANumericTable_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "SOANumericTable_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "SOANumericTable_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "SOANumericTable_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SOANumericTable_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "SOANumericTable_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SOANumericTable_getBlockOfColumnValues__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SOANumericTable *arg1 = (daal::data_management::interface1::SOANumericTable *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SOANumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SOANumericTable > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:SOANumericTable_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SOANumericTable_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::SOANumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SOANumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SOANumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SOANumericTable_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::SOANumericTable *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SOANumericTable_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "SOANumericTable_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "SOANumericTable_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "SOANumericTable_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "SOANumericTable_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SOANumericTable_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "SOANumericTable_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SOANumericTable_getBlockOfColumnValues__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SOANumericTable *arg1 = (daal::data_management::interface1::SOANumericTable *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SOANumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SOANumericTable > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:SOANumericTable_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SOANumericTable_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::SOANumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SOANumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SOANumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SOANumericTable_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::SOANumericTable *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SOANumericTable_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "SOANumericTable_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "SOANumericTable_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "SOANumericTable_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "SOANumericTable_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SOANumericTable_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "SOANumericTable_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SOANumericTable_getBlockOfColumnValues(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[7];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 6) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_SOANumericTable_getBlockOfColumnValues__SWIG_0(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_SOANumericTable_getBlockOfColumnValues__SWIG_1(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_SOANumericTable_getBlockOfColumnValues__SWIG_2(self, args);
              }
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'SOANumericTable_getBlockOfColumnValues'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::SOANumericTable::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::SOANumericTable::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::SOANumericTable::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_SOANumericTable_releaseBlockOfColumnValues__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SOANumericTable *arg1 = (daal::data_management::interface1::SOANumericTable *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SOANumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SOANumericTable > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:SOANumericTable_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SOANumericTable_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::SOANumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SOANumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SOANumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SOANumericTable_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::SOANumericTable *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SOANumericTable_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SOANumericTable_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SOANumericTable_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SOANumericTable_releaseBlockOfColumnValues__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SOANumericTable *arg1 = (daal::data_management::interface1::SOANumericTable *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SOANumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SOANumericTable > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:SOANumericTable_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SOANumericTable_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::SOANumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SOANumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SOANumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SOANumericTable_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::SOANumericTable *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SOANumericTable_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SOANumericTable_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SOANumericTable_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SOANumericTable_releaseBlockOfColumnValues__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SOANumericTable *arg1 = (daal::data_management::interface1::SOANumericTable *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SOANumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SOANumericTable > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:SOANumericTable_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SOANumericTable_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::SOANumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SOANumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SOANumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SOANumericTable_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::SOANumericTable *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SOANumericTable_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SOANumericTable_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SOANumericTable_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SOANumericTable_releaseBlockOfColumnValues(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_SOANumericTable_releaseBlockOfColumnValues__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_SOANumericTable_releaseBlockOfColumnValues__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_SOANumericTable_releaseBlockOfColumnValues__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'SOANumericTable_releaseBlockOfColumnValues'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::SOANumericTable::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::SOANumericTable::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::SOANumericTable::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_SOANumericTable_setDictionary(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SOANumericTable *arg1 = (daal::data_management::interface1::SOANumericTable *) 0 ;
  daal::data_management::interface1::NumericTableDictionary *arg2 = (daal::data_management::interface1::NumericTableDictionary *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SOANumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SOANumericTable > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > > tempshared2 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > > *smartarg2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:SOANumericTable_setDictionary",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SOANumericTable_setDictionary" "', argument " "1"" of type '" "daal::data_management::interface1::SOANumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SOANumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SOANumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SOANumericTable_setDictionary" "', argument " "1"" of type '" "daal::data_management::interface1::SOANumericTable *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res2) || !argp2) && obj1 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SOANumericTable_setDictionary" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTableDictionary *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::NumericTableDictionary * >(tempshared2.get());
    } else {
      smartarg2 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::NumericTableDictionary * >((smartarg2 ? smartarg2->get() : 0));
    }
    if(!arg2 && obj1 != Py_None) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SOANumericTable_setDictionary" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTableDictionary *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->setDictionary(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SOANumericTable_setArray(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SOANumericTable *arg1 = (daal::data_management::interface1::SOANumericTable *) 0 ;
  PyArrayObject *arg2 = (PyArrayObject *) 0 ;
  size_t arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SOANumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SOANumericTable > *smartarg1 = 0 ;
  PyObject *ary2 ;
  size_t val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:SOANumericTable_setArray",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SOANumericTable_setArray" "', argument " "1"" of type '" "daal::data_management::interface1::SOANumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SOANumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SOANumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SOANumericTable_setArray" "', argument " "1"" of type '" "daal::data_management::interface1::SOANumericTable *""'"); 
  }
  {
    arg2 = obj_to_array_no_conversion(obj1, NPY_NOTYPE);
    if (!arg2 || !require_dimensions(arg2,1) || !require_contiguous(arg2) || !require_native(arg2)) {
      SWIG_fail;
    }
  }
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "SOANumericTable_setArray" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        daal_data_management_interface1_SOANumericTable_setArray(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SOANumericTable_getArray(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SOANumericTable *arg1 = (daal::data_management::interface1::SOANumericTable *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SOANumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SOANumericTable > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:SOANumericTable_getArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SOANumericTable_getArray" "', argument " "1"" of type '" "daal::data_management::interface1::SOANumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SOANumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SOANumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SOANumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SOANumericTable_getArray" "', argument " "1"" of type '" "daal::data_management::interface1::SOANumericTable *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SOANumericTable_getArray" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (PyObject *)daal_data_management_interface1_SOANumericTable_getArray(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = result;
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *SOANumericTable_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_delete_CSRNumericTableIface(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRNumericTableIface *arg1 = (daal::data_management::interface1::CSRNumericTableIface *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTableIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTableIface > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_CSRNumericTableIface",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_CSRNumericTableIface" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTableIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_CSRNumericTableIface" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTableIface *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRNumericTableIface_getDataSize(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRNumericTableIface *arg1 = (daal::data_management::interface1::CSRNumericTableIface *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTableIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTableIface > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:CSRNumericTableIface_getDataSize",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTableIface_getDataSize" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTableIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTableIface_getDataSize" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTableIface *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getDataSize();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRNumericTableIface_getSparseBlock__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRNumericTableIface *arg1 = (daal::data_management::interface1::CSRNumericTableIface *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::CSRBlockDescriptor< double > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTableIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTableIface > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< double > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:CSRNumericTableIface_getSparseBlock",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTableIface_getSparseBlock" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTableIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTableIface_getSparseBlock" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTableIface *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CSRNumericTableIface_getSparseBlock" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "CSRNumericTableIface_getSparseBlock" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "CSRNumericTableIface_getSparseBlock" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "CSRNumericTableIface_getSparseBlock" "', argument " "5"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< double > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CSRNumericTableIface_getSparseBlock" "', argument " "5"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< double > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "CSRNumericTableIface_getSparseBlock" "', argument " "5"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getSparseBlock(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRNumericTableIface_getSparseBlock__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRNumericTableIface *arg1 = (daal::data_management::interface1::CSRNumericTableIface *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::CSRBlockDescriptor< float > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTableIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTableIface > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< float > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:CSRNumericTableIface_getSparseBlock",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTableIface_getSparseBlock" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTableIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTableIface_getSparseBlock" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTableIface *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CSRNumericTableIface_getSparseBlock" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "CSRNumericTableIface_getSparseBlock" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "CSRNumericTableIface_getSparseBlock" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "CSRNumericTableIface_getSparseBlock" "', argument " "5"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< float > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CSRNumericTableIface_getSparseBlock" "', argument " "5"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< float > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "CSRNumericTableIface_getSparseBlock" "', argument " "5"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getSparseBlock(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRNumericTableIface_getSparseBlock__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRNumericTableIface *arg1 = (daal::data_management::interface1::CSRNumericTableIface *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::CSRBlockDescriptor< int > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTableIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTableIface > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< int > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:CSRNumericTableIface_getSparseBlock",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTableIface_getSparseBlock" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTableIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTableIface_getSparseBlock" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTableIface *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CSRNumericTableIface_getSparseBlock" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "CSRNumericTableIface_getSparseBlock" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "CSRNumericTableIface_getSparseBlock" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "CSRNumericTableIface_getSparseBlock" "', argument " "5"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< int > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CSRNumericTableIface_getSparseBlock" "', argument " "5"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< int > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "CSRNumericTableIface_getSparseBlock" "', argument " "5"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getSparseBlock(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRNumericTableIface_getSparseBlock(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[6];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 5) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTableIface_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_double_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_CSRNumericTableIface_getSparseBlock__SWIG_0(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTableIface_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_float_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_CSRNumericTableIface_getSparseBlock__SWIG_1(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTableIface_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_int_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_CSRNumericTableIface_getSparseBlock__SWIG_2(self, args);
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'CSRNumericTableIface_getSparseBlock'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::CSRNumericTableIface::getSparseBlock(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::CSRBlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::CSRNumericTableIface::getSparseBlock(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::CSRBlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::CSRNumericTableIface::getSparseBlock(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::CSRBlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_CSRNumericTableIface_releaseSparseBlock__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRNumericTableIface *arg1 = (daal::data_management::interface1::CSRNumericTableIface *) 0 ;
  daal::data_management::interface1::CSRBlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTableIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTableIface > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:CSRNumericTableIface_releaseSparseBlock",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTableIface_releaseSparseBlock" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTableIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTableIface_releaseSparseBlock" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTableIface *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CSRNumericTableIface_releaseSparseBlock" "', argument " "2"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CSRNumericTableIface_releaseSparseBlock" "', argument " "2"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CSRNumericTableIface_releaseSparseBlock" "', argument " "2"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseSparseBlock(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRNumericTableIface_releaseSparseBlock__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRNumericTableIface *arg1 = (daal::data_management::interface1::CSRNumericTableIface *) 0 ;
  daal::data_management::interface1::CSRBlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTableIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTableIface > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:CSRNumericTableIface_releaseSparseBlock",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTableIface_releaseSparseBlock" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTableIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTableIface_releaseSparseBlock" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTableIface *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CSRNumericTableIface_releaseSparseBlock" "', argument " "2"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CSRNumericTableIface_releaseSparseBlock" "', argument " "2"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CSRNumericTableIface_releaseSparseBlock" "', argument " "2"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseSparseBlock(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRNumericTableIface_releaseSparseBlock__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRNumericTableIface *arg1 = (daal::data_management::interface1::CSRNumericTableIface *) 0 ;
  daal::data_management::interface1::CSRBlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTableIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTableIface > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:CSRNumericTableIface_releaseSparseBlock",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTableIface_releaseSparseBlock" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTableIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTableIface_releaseSparseBlock" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTableIface *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CSRNumericTableIface_releaseSparseBlock" "', argument " "2"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CSRNumericTableIface_releaseSparseBlock" "', argument " "2"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CSRNumericTableIface_releaseSparseBlock" "', argument " "2"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseSparseBlock(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRNumericTableIface_releaseSparseBlock(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTableIface_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_CSRNumericTableIface_releaseSparseBlock__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTableIface_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_CSRNumericTableIface_releaseSparseBlock__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTableIface_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_CSRNumericTableIface_releaseSparseBlock__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'CSRNumericTableIface_releaseSparseBlock'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::CSRNumericTableIface::releaseSparseBlock(daal::data_management::interface1::CSRBlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::CSRNumericTableIface::releaseSparseBlock(daal::data_management::interface1::CSRBlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::CSRNumericTableIface::releaseSparseBlock(daal::data_management::interface1::CSRBlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *CSRNumericTableIface_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTableIface_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_CSRNumericTable_serializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)":CSRNumericTable_serializationTag")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)daal::data_management::interface1::CSRNumericTable::serializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRNumericTable_getSerializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRNumericTable *arg1 = (daal::data_management::interface1::CSRNumericTable *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:CSRNumericTable_getSerializationTag",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)((daal::data_management::interface1::CSRNumericTable const *)arg1)->getSerializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_CSRNumericTable__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRNumericTable *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_CSRNumericTable")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::CSRNumericTable *)new daal::data_management::interface1::CSRNumericTable();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_CSRNumericTable(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRNumericTable *arg1 = (daal::data_management::interface1::CSRNumericTable *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_CSRNumericTable",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_CSRNumericTable" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_CSRNumericTable" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRNumericTable_resize(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRNumericTable *arg1 = (daal::data_management::interface1::CSRNumericTable *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:CSRNumericTable_resize",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_resize" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_resize" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CSRNumericTable_resize" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->resize(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRNumericTable_getBlockOfRows__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRNumericTable *arg1 = (daal::data_management::interface1::CSRNumericTable *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:CSRNumericTable_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CSRNumericTable_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "CSRNumericTable_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "CSRNumericTable_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "CSRNumericTable_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CSRNumericTable_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "CSRNumericTable_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRNumericTable_getBlockOfRows__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRNumericTable *arg1 = (daal::data_management::interface1::CSRNumericTable *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:CSRNumericTable_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CSRNumericTable_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "CSRNumericTable_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "CSRNumericTable_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "CSRNumericTable_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CSRNumericTable_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "CSRNumericTable_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRNumericTable_getBlockOfRows__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRNumericTable *arg1 = (daal::data_management::interface1::CSRNumericTable *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:CSRNumericTable_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CSRNumericTable_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "CSRNumericTable_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "CSRNumericTable_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "CSRNumericTable_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CSRNumericTable_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "CSRNumericTable_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRNumericTable_getBlockOfRows(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[6];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 5) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_CSRNumericTable_getBlockOfRows__SWIG_0(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_CSRNumericTable_getBlockOfRows__SWIG_1(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_CSRNumericTable_getBlockOfRows__SWIG_2(self, args);
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'CSRNumericTable_getBlockOfRows'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::CSRNumericTable::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::CSRNumericTable::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::CSRNumericTable::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_CSRNumericTable_releaseBlockOfRows__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRNumericTable *arg1 = (daal::data_management::interface1::CSRNumericTable *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:CSRNumericTable_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CSRNumericTable_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CSRNumericTable_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CSRNumericTable_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRNumericTable_releaseBlockOfRows__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRNumericTable *arg1 = (daal::data_management::interface1::CSRNumericTable *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:CSRNumericTable_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CSRNumericTable_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CSRNumericTable_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CSRNumericTable_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRNumericTable_releaseBlockOfRows__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRNumericTable *arg1 = (daal::data_management::interface1::CSRNumericTable *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:CSRNumericTable_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CSRNumericTable_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CSRNumericTable_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CSRNumericTable_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRNumericTable_releaseBlockOfRows(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_CSRNumericTable_releaseBlockOfRows__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_CSRNumericTable_releaseBlockOfRows__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_CSRNumericTable_releaseBlockOfRows__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'CSRNumericTable_releaseBlockOfRows'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::CSRNumericTable::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::CSRNumericTable::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::CSRNumericTable::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_CSRNumericTable_getBlockOfColumnValues__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRNumericTable *arg1 = (daal::data_management::interface1::CSRNumericTable *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:CSRNumericTable_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CSRNumericTable_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "CSRNumericTable_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "CSRNumericTable_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "CSRNumericTable_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "CSRNumericTable_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CSRNumericTable_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "CSRNumericTable_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRNumericTable_getBlockOfColumnValues__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRNumericTable *arg1 = (daal::data_management::interface1::CSRNumericTable *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:CSRNumericTable_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CSRNumericTable_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "CSRNumericTable_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "CSRNumericTable_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "CSRNumericTable_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "CSRNumericTable_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CSRNumericTable_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "CSRNumericTable_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRNumericTable_getBlockOfColumnValues__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRNumericTable *arg1 = (daal::data_management::interface1::CSRNumericTable *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:CSRNumericTable_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CSRNumericTable_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "CSRNumericTable_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "CSRNumericTable_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "CSRNumericTable_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "CSRNumericTable_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CSRNumericTable_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "CSRNumericTable_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRNumericTable_getBlockOfColumnValues(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[7];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 6) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_CSRNumericTable_getBlockOfColumnValues__SWIG_0(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_CSRNumericTable_getBlockOfColumnValues__SWIG_1(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_CSRNumericTable_getBlockOfColumnValues__SWIG_2(self, args);
              }
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'CSRNumericTable_getBlockOfColumnValues'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::CSRNumericTable::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::CSRNumericTable::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::CSRNumericTable::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_CSRNumericTable_releaseBlockOfColumnValues__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRNumericTable *arg1 = (daal::data_management::interface1::CSRNumericTable *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:CSRNumericTable_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CSRNumericTable_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CSRNumericTable_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CSRNumericTable_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRNumericTable_releaseBlockOfColumnValues__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRNumericTable *arg1 = (daal::data_management::interface1::CSRNumericTable *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:CSRNumericTable_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CSRNumericTable_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CSRNumericTable_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CSRNumericTable_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRNumericTable_releaseBlockOfColumnValues__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRNumericTable *arg1 = (daal::data_management::interface1::CSRNumericTable *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:CSRNumericTable_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CSRNumericTable_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CSRNumericTable_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CSRNumericTable_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRNumericTable_releaseBlockOfColumnValues(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_CSRNumericTable_releaseBlockOfColumnValues__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_CSRNumericTable_releaseBlockOfColumnValues__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_CSRNumericTable_releaseBlockOfColumnValues__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'CSRNumericTable_releaseBlockOfColumnValues'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::CSRNumericTable::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::CSRNumericTable::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::CSRNumericTable::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_CSRNumericTable_getSparseBlock__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRNumericTable *arg1 = (daal::data_management::interface1::CSRNumericTable *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::CSRBlockDescriptor< double > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< double > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:CSRNumericTable_getSparseBlock",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_getSparseBlock" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_getSparseBlock" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CSRNumericTable_getSparseBlock" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "CSRNumericTable_getSparseBlock" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "CSRNumericTable_getSparseBlock" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "CSRNumericTable_getSparseBlock" "', argument " "5"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< double > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CSRNumericTable_getSparseBlock" "', argument " "5"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< double > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "CSRNumericTable_getSparseBlock" "', argument " "5"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getSparseBlock(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRNumericTable_getSparseBlock__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRNumericTable *arg1 = (daal::data_management::interface1::CSRNumericTable *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::CSRBlockDescriptor< float > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< float > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:CSRNumericTable_getSparseBlock",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_getSparseBlock" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_getSparseBlock" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CSRNumericTable_getSparseBlock" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "CSRNumericTable_getSparseBlock" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "CSRNumericTable_getSparseBlock" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "CSRNumericTable_getSparseBlock" "', argument " "5"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< float > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CSRNumericTable_getSparseBlock" "', argument " "5"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< float > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "CSRNumericTable_getSparseBlock" "', argument " "5"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getSparseBlock(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRNumericTable_getSparseBlock__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRNumericTable *arg1 = (daal::data_management::interface1::CSRNumericTable *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::CSRBlockDescriptor< int > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< int > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:CSRNumericTable_getSparseBlock",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_getSparseBlock" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_getSparseBlock" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CSRNumericTable_getSparseBlock" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "CSRNumericTable_getSparseBlock" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "CSRNumericTable_getSparseBlock" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "CSRNumericTable_getSparseBlock" "', argument " "5"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< int > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CSRNumericTable_getSparseBlock" "', argument " "5"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< int > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "CSRNumericTable_getSparseBlock" "', argument " "5"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getSparseBlock(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRNumericTable_getSparseBlock(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[6];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 5) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_double_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_CSRNumericTable_getSparseBlock__SWIG_0(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_float_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_CSRNumericTable_getSparseBlock__SWIG_1(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_int_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_CSRNumericTable_getSparseBlock__SWIG_2(self, args);
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'CSRNumericTable_getSparseBlock'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::CSRNumericTable::getSparseBlock(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::CSRBlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::CSRNumericTable::getSparseBlock(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::CSRBlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::CSRNumericTable::getSparseBlock(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::CSRBlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_CSRNumericTable_releaseSparseBlock__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRNumericTable *arg1 = (daal::data_management::interface1::CSRNumericTable *) 0 ;
  daal::data_management::interface1::CSRBlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:CSRNumericTable_releaseSparseBlock",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_releaseSparseBlock" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_releaseSparseBlock" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CSRNumericTable_releaseSparseBlock" "', argument " "2"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CSRNumericTable_releaseSparseBlock" "', argument " "2"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CSRNumericTable_releaseSparseBlock" "', argument " "2"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseSparseBlock(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRNumericTable_releaseSparseBlock__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRNumericTable *arg1 = (daal::data_management::interface1::CSRNumericTable *) 0 ;
  daal::data_management::interface1::CSRBlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:CSRNumericTable_releaseSparseBlock",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_releaseSparseBlock" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_releaseSparseBlock" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CSRNumericTable_releaseSparseBlock" "', argument " "2"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CSRNumericTable_releaseSparseBlock" "', argument " "2"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CSRNumericTable_releaseSparseBlock" "', argument " "2"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseSparseBlock(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRNumericTable_releaseSparseBlock__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRNumericTable *arg1 = (daal::data_management::interface1::CSRNumericTable *) 0 ;
  daal::data_management::interface1::CSRBlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:CSRNumericTable_releaseSparseBlock",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_releaseSparseBlock" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_releaseSparseBlock" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CSRNumericTable_releaseSparseBlock" "', argument " "2"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CSRNumericTable_releaseSparseBlock" "', argument " "2"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CSRNumericTable_releaseSparseBlock" "', argument " "2"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseSparseBlock(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRNumericTable_releaseSparseBlock(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_CSRNumericTable_releaseSparseBlock__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_CSRNumericTable_releaseSparseBlock__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_CSRNumericTable_releaseSparseBlock__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'CSRNumericTable_releaseSparseBlock'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::CSRNumericTable::releaseSparseBlock(daal::data_management::interface1::CSRBlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::CSRNumericTable::releaseSparseBlock(daal::data_management::interface1::CSRBlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::CSRNumericTable::releaseSparseBlock(daal::data_management::interface1::CSRBlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_CSRNumericTable_allocateDataMemory__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRNumericTable *arg1 = (daal::data_management::interface1::CSRNumericTable *) 0 ;
  size_t arg2 ;
  daal::MemType arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  int val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:CSRNumericTable_allocateDataMemory",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_allocateDataMemory" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_allocateDataMemory" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CSRNumericTable_allocateDataMemory" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "CSRNumericTable_allocateDataMemory" "', argument " "3"" of type '" "daal::MemType""'");
  } 
  arg3 = static_cast< daal::MemType >(val3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->allocateDataMemory(arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRNumericTable_allocateDataMemory__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRNumericTable *arg1 = (daal::data_management::interface1::CSRNumericTable *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:CSRNumericTable_allocateDataMemory",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_allocateDataMemory" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_allocateDataMemory" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CSRNumericTable_allocateDataMemory" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->allocateDataMemory(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRNumericTable_allocateDataMemory(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[4];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 3) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_CSRNumericTable_allocateDataMemory__SWIG_1(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_CSRNumericTable_allocateDataMemory__SWIG_0(self, args);
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'CSRNumericTable_allocateDataMemory'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::CSRNumericTable::allocateDataMemory(size_t,daal::MemType)\n"
    "    daal::data_management::interface1::CSRNumericTable::allocateDataMemory(size_t)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_CSRNumericTable_getCSRIndexing(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRNumericTable *arg1 = (daal::data_management::interface1::CSRNumericTable *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::CSRNumericTableIface::CSRIndexing result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:CSRNumericTable_getCSRIndexing",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_getCSRIndexing" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_getCSRIndexing" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::CSRNumericTableIface::CSRIndexing)((daal::data_management::interface1::CSRNumericTable const *)arg1)->getCSRIndexing();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRNumericTable_check__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRNumericTable *arg1 = (daal::data_management::interface1::CSRNumericTable *) 0 ;
  char *arg2 = (char *) 0 ;
  bool arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable const > *smartarg1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  bool val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:CSRNumericTable_check",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_check" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_check" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable const *""'"); 
  }
  res2 = SWIG_AsCharPtrAndSize(obj1, &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CSRNumericTable_check" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = reinterpret_cast< char * >(buf2);
  ecode3 = SWIG_AsVal_bool(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "CSRNumericTable_check" "', argument " "3"" of type '" "bool""'");
  } 
  arg3 = static_cast< bool >(val3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::CSRNumericTable const *)arg1)->check((char const *)arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRNumericTable_check__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRNumericTable *arg1 = (daal::data_management::interface1::CSRNumericTable *) 0 ;
  char *arg2 = (char *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable const > *smartarg1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:CSRNumericTable_check",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_check" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_check" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable const *""'"); 
  }
  res2 = SWIG_AsCharPtrAndSize(obj1, &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CSRNumericTable_check" "', argument " "2"" of type '" "char const *""'");
  }
  arg2 = reinterpret_cast< char * >(buf2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::CSRNumericTable const *)arg1)->check((char const *)arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRNumericTable_check(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[4];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 3) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_AsCharPtrAndSize(argv[1], 0, NULL, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_CSRNumericTable_check__SWIG_1(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_AsCharPtrAndSize(argv[1], 0, NULL, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_bool(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_CSRNumericTable_check__SWIG_0(self, args);
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'CSRNumericTable_check'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::CSRNumericTable::check(char const *,bool) const\n"
    "    daal::data_management::interface1::CSRNumericTable::check(char const *) const\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_CSRNumericTable_getDataSize(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRNumericTable *arg1 = (daal::data_management::interface1::CSRNumericTable *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:CSRNumericTable_getDataSize",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_getDataSize" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_getDataSize" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getDataSize();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_CSRNumericTable__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< double > *arg1 = 0 ;
  size_t arg2 ;
  daal::services::SharedPtr< size_t > *arg3 = 0 ;
  size_t arg4 ;
  daal::services::SharedPtr< size_t > *arg5 = 0 ;
  size_t arg6 ;
  size_t arg7 ;
  size_t arg8 ;
  daal::services::SharedPtr< double > r4p1 ;
  daal::services::SharedPtr< size_t > r4p3 ;
  daal::services::SharedPtr< size_t > r4p5 ;
  size_t val7 ;
  int ecode7 = 0 ;
  size_t val8 ;
  int ecode8 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::data_management::interface1::CSRNumericTable *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:new_CSRNumericTable",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int is_new_object = 0;
    PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj0, NPY_DOUBLE)
      :obj_to_array_contiguous_allow_conversion(obj0, NPY_DOUBLE, &is_new_object));
    if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p1 = daal::services::SharedPtr< double >((double*)array_data(array), NumpyDeleter(array));
    arg1 = &r4p1;
    arg2 = (size_t) array_size(array,0);
    // we need it increment the ref-count if we use the obj0 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj0) Py_INCREF(array);
  }
  {
    int is_new_object = 0;
    PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UINT64)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UINT64, &is_new_object));
    if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p3 = daal::services::SharedPtr< size_t >((size_t*)array_data(array), NumpyDeleter(array));
    arg3 = &r4p3;
    arg4 = (size_t) array_size(array,0);
    // we need it increment the ref-count if we use the obj1 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj1) Py_INCREF(array);
  }
  {
    int is_new_object = 0;
    PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj2, NPY_UINT64)
      :obj_to_array_contiguous_allow_conversion(obj2, NPY_UINT64, &is_new_object));
    if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p5 = daal::services::SharedPtr< size_t >((size_t*)array_data(array), NumpyDeleter(array));
    arg5 = &r4p5;
    arg6 = (size_t) array_size(array,0);
    // we need it increment the ref-count if we use the obj2 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj2) Py_INCREF(array);
  }
  ecode7 = SWIG_AsVal_size_t(obj3, &val7);
  if (!SWIG_IsOK(ecode7)) {
    SWIG_exception_fail(SWIG_ArgError(ecode7), "in method '" "new_CSRNumericTable" "', argument " "7"" of type '" "size_t""'");
  } 
  arg7 = static_cast< size_t >(val7);
  ecode8 = SWIG_AsVal_size_t(obj4, &val8);
  if (!SWIG_IsOK(ecode8)) {
    SWIG_exception_fail(SWIG_ArgError(ecode8), "in method '" "new_CSRNumericTable" "', argument " "8"" of type '" "size_t""'");
  } 
  arg8 = static_cast< size_t >(val8);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::CSRNumericTable *)new_daal_data_management_interface1_CSRNumericTable__SWIG_3((daal::services::SharedPtr< double > const &)*arg1,arg2,(daal::services::SharedPtr< size_t > const &)*arg3,arg4,(daal::services::SharedPtr< size_t > const &)*arg5,arg6,arg7,arg8);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRNumericTable_setArrays__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRNumericTable *arg1 = (daal::data_management::interface1::CSRNumericTable *) 0 ;
  daal::services::SharedPtr< double > *arg2 = 0 ;
  size_t arg3 ;
  daal::services::SharedPtr< size_t > *arg4 = 0 ;
  size_t arg5 ;
  daal::services::SharedPtr< size_t > *arg6 = 0 ;
  size_t arg7 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > *smartarg1 = 0 ;
  daal::services::SharedPtr< double > r4p2 ;
  daal::services::SharedPtr< size_t > r4p4 ;
  daal::services::SharedPtr< size_t > r4p6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:CSRNumericTable_setArrays",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_setArrays" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_setArrays" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
  }
  {
    int is_new_object = 0;
    PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_DOUBLE)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_DOUBLE, &is_new_object));
    if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p2 = daal::services::SharedPtr< double >((double*)array_data(array), NumpyDeleter(array));
    arg2 = &r4p2;
    arg3 = (size_t) array_size(array,0);
    // we need it increment the ref-count if we use the obj1 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj1) Py_INCREF(array);
  }
  {
    int is_new_object = 0;
    PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj2, NPY_UINT64)
      :obj_to_array_contiguous_allow_conversion(obj2, NPY_UINT64, &is_new_object));
    if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p4 = daal::services::SharedPtr< size_t >((size_t*)array_data(array), NumpyDeleter(array));
    arg4 = &r4p4;
    arg5 = (size_t) array_size(array,0);
    // we need it increment the ref-count if we use the obj2 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj2) Py_INCREF(array);
  }
  {
    int is_new_object = 0;
    PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj3, NPY_UINT64)
      :obj_to_array_contiguous_allow_conversion(obj3, NPY_UINT64, &is_new_object));
    if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p6 = daal::services::SharedPtr< size_t >((size_t*)array_data(array), NumpyDeleter(array));
    arg6 = &r4p6;
    arg7 = (size_t) array_size(array,0);
    // we need it increment the ref-count if we use the obj3 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj3) Py_INCREF(array);
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        daal_data_management_interface1_CSRNumericTable_setArrays__SWIG_2(arg1,(daal::services::SharedPtr< double > const &)*arg2,arg3,(daal::services::SharedPtr< size_t > const &)*arg4,arg5,(daal::services::SharedPtr< size_t > const &)*arg6,arg7);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_CSRNumericTable__SWIG_4(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< float > *arg1 = 0 ;
  size_t arg2 ;
  daal::services::SharedPtr< size_t > *arg3 = 0 ;
  size_t arg4 ;
  daal::services::SharedPtr< size_t > *arg5 = 0 ;
  size_t arg6 ;
  size_t arg7 ;
  size_t arg8 ;
  daal::services::SharedPtr< float > r4p1 ;
  daal::services::SharedPtr< size_t > r4p3 ;
  daal::services::SharedPtr< size_t > r4p5 ;
  size_t val7 ;
  int ecode7 = 0 ;
  size_t val8 ;
  int ecode8 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::data_management::interface1::CSRNumericTable *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:new_CSRNumericTable",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int is_new_object = 0;
    PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj0, NPY_FLOAT)
      :obj_to_array_contiguous_allow_conversion(obj0, NPY_FLOAT, &is_new_object));
    if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p1 = daal::services::SharedPtr< float >((float*)array_data(array), NumpyDeleter(array));
    arg1 = &r4p1;
    arg2 = (size_t) array_size(array,0);
    // we need it increment the ref-count if we use the obj0 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj0) Py_INCREF(array);
  }
  {
    int is_new_object = 0;
    PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UINT64)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UINT64, &is_new_object));
    if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p3 = daal::services::SharedPtr< size_t >((size_t*)array_data(array), NumpyDeleter(array));
    arg3 = &r4p3;
    arg4 = (size_t) array_size(array,0);
    // we need it increment the ref-count if we use the obj1 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj1) Py_INCREF(array);
  }
  {
    int is_new_object = 0;
    PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj2, NPY_UINT64)
      :obj_to_array_contiguous_allow_conversion(obj2, NPY_UINT64, &is_new_object));
    if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p5 = daal::services::SharedPtr< size_t >((size_t*)array_data(array), NumpyDeleter(array));
    arg5 = &r4p5;
    arg6 = (size_t) array_size(array,0);
    // we need it increment the ref-count if we use the obj2 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj2) Py_INCREF(array);
  }
  ecode7 = SWIG_AsVal_size_t(obj3, &val7);
  if (!SWIG_IsOK(ecode7)) {
    SWIG_exception_fail(SWIG_ArgError(ecode7), "in method '" "new_CSRNumericTable" "', argument " "7"" of type '" "size_t""'");
  } 
  arg7 = static_cast< size_t >(val7);
  ecode8 = SWIG_AsVal_size_t(obj4, &val8);
  if (!SWIG_IsOK(ecode8)) {
    SWIG_exception_fail(SWIG_ArgError(ecode8), "in method '" "new_CSRNumericTable" "', argument " "8"" of type '" "size_t""'");
  } 
  arg8 = static_cast< size_t >(val8);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::CSRNumericTable *)new_daal_data_management_interface1_CSRNumericTable__SWIG_4((daal::services::SharedPtr< float > const &)*arg1,arg2,(daal::services::SharedPtr< size_t > const &)*arg3,arg4,(daal::services::SharedPtr< size_t > const &)*arg5,arg6,arg7,arg8);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRNumericTable_setArrays__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRNumericTable *arg1 = (daal::data_management::interface1::CSRNumericTable *) 0 ;
  daal::services::SharedPtr< float > *arg2 = 0 ;
  size_t arg3 ;
  daal::services::SharedPtr< size_t > *arg4 = 0 ;
  size_t arg5 ;
  daal::services::SharedPtr< size_t > *arg6 = 0 ;
  size_t arg7 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > *smartarg1 = 0 ;
  daal::services::SharedPtr< float > r4p2 ;
  daal::services::SharedPtr< size_t > r4p4 ;
  daal::services::SharedPtr< size_t > r4p6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:CSRNumericTable_setArrays",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_setArrays" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_setArrays" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
  }
  {
    int is_new_object = 0;
    PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_FLOAT)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_FLOAT, &is_new_object));
    if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p2 = daal::services::SharedPtr< float >((float*)array_data(array), NumpyDeleter(array));
    arg2 = &r4p2;
    arg3 = (size_t) array_size(array,0);
    // we need it increment the ref-count if we use the obj1 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj1) Py_INCREF(array);
  }
  {
    int is_new_object = 0;
    PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj2, NPY_UINT64)
      :obj_to_array_contiguous_allow_conversion(obj2, NPY_UINT64, &is_new_object));
    if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p4 = daal::services::SharedPtr< size_t >((size_t*)array_data(array), NumpyDeleter(array));
    arg4 = &r4p4;
    arg5 = (size_t) array_size(array,0);
    // we need it increment the ref-count if we use the obj2 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj2) Py_INCREF(array);
  }
  {
    int is_new_object = 0;
    PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj3, NPY_UINT64)
      :obj_to_array_contiguous_allow_conversion(obj3, NPY_UINT64, &is_new_object));
    if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p6 = daal::services::SharedPtr< size_t >((size_t*)array_data(array), NumpyDeleter(array));
    arg6 = &r4p6;
    arg7 = (size_t) array_size(array,0);
    // we need it increment the ref-count if we use the obj3 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj3) Py_INCREF(array);
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        daal_data_management_interface1_CSRNumericTable_setArrays__SWIG_3(arg1,(daal::services::SharedPtr< float > const &)*arg2,arg3,(daal::services::SharedPtr< size_t > const &)*arg4,arg5,(daal::services::SharedPtr< size_t > const &)*arg6,arg7);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_CSRNumericTable__SWIG_5(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< int > *arg1 = 0 ;
  size_t arg2 ;
  daal::services::SharedPtr< size_t > *arg3 = 0 ;
  size_t arg4 ;
  daal::services::SharedPtr< size_t > *arg5 = 0 ;
  size_t arg6 ;
  size_t arg7 ;
  size_t arg8 ;
  daal::services::SharedPtr< int > r4p1 ;
  daal::services::SharedPtr< size_t > r4p3 ;
  daal::services::SharedPtr< size_t > r4p5 ;
  size_t val7 ;
  int ecode7 = 0 ;
  size_t val8 ;
  int ecode8 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::data_management::interface1::CSRNumericTable *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:new_CSRNumericTable",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int is_new_object = 0;
    PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj0, NPY_INT)
      :obj_to_array_contiguous_allow_conversion(obj0, NPY_INT, &is_new_object));
    if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p1 = daal::services::SharedPtr< int >((int*)array_data(array), NumpyDeleter(array));
    arg1 = &r4p1;
    arg2 = (size_t) array_size(array,0);
    // we need it increment the ref-count if we use the obj0 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj0) Py_INCREF(array);
  }
  {
    int is_new_object = 0;
    PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UINT64)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UINT64, &is_new_object));
    if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p3 = daal::services::SharedPtr< size_t >((size_t*)array_data(array), NumpyDeleter(array));
    arg3 = &r4p3;
    arg4 = (size_t) array_size(array,0);
    // we need it increment the ref-count if we use the obj1 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj1) Py_INCREF(array);
  }
  {
    int is_new_object = 0;
    PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj2, NPY_UINT64)
      :obj_to_array_contiguous_allow_conversion(obj2, NPY_UINT64, &is_new_object));
    if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p5 = daal::services::SharedPtr< size_t >((size_t*)array_data(array), NumpyDeleter(array));
    arg5 = &r4p5;
    arg6 = (size_t) array_size(array,0);
    // we need it increment the ref-count if we use the obj2 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj2) Py_INCREF(array);
  }
  ecode7 = SWIG_AsVal_size_t(obj3, &val7);
  if (!SWIG_IsOK(ecode7)) {
    SWIG_exception_fail(SWIG_ArgError(ecode7), "in method '" "new_CSRNumericTable" "', argument " "7"" of type '" "size_t""'");
  } 
  arg7 = static_cast< size_t >(val7);
  ecode8 = SWIG_AsVal_size_t(obj4, &val8);
  if (!SWIG_IsOK(ecode8)) {
    SWIG_exception_fail(SWIG_ArgError(ecode8), "in method '" "new_CSRNumericTable" "', argument " "8"" of type '" "size_t""'");
  } 
  arg8 = static_cast< size_t >(val8);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::CSRNumericTable *)new_daal_data_management_interface1_CSRNumericTable__SWIG_5((daal::services::SharedPtr< int > const &)*arg1,arg2,(daal::services::SharedPtr< size_t > const &)*arg3,arg4,(daal::services::SharedPtr< size_t > const &)*arg5,arg6,arg7,arg8);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_CSRNumericTable(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[6];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 5) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_new_CSRNumericTable__SWIG_0(self, args);
  }
  if (argc == 5) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_DOUBLE))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      {
        _v = (ALLOW_CONVERSION == FORCE_INPLACE
          ? (is_array(argv[1]) && PyArray_EquivTypenums(array_type(argv[1]), NPY_UINT64))
          :(is_array(argv[1]) || PySequence_Check(argv[1])));
      }
      if (_v) {
        {
          _v = (ALLOW_CONVERSION == FORCE_INPLACE
            ? (is_array(argv[2]) && PyArray_EquivTypenums(array_type(argv[2]), NPY_UINT64))
            :(is_array(argv[2]) || PySequence_Check(argv[2])));
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_size_t(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              return _wrap_new_CSRNumericTable__SWIG_3(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_FLOAT))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      {
        _v = (ALLOW_CONVERSION == FORCE_INPLACE
          ? (is_array(argv[1]) && PyArray_EquivTypenums(array_type(argv[1]), NPY_UINT64))
          :(is_array(argv[1]) || PySequence_Check(argv[1])));
      }
      if (_v) {
        {
          _v = (ALLOW_CONVERSION == FORCE_INPLACE
            ? (is_array(argv[2]) && PyArray_EquivTypenums(array_type(argv[2]), NPY_UINT64))
            :(is_array(argv[2]) || PySequence_Check(argv[2])));
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_size_t(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              return _wrap_new_CSRNumericTable__SWIG_4(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_INT))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      {
        _v = (ALLOW_CONVERSION == FORCE_INPLACE
          ? (is_array(argv[1]) && PyArray_EquivTypenums(array_type(argv[1]), NPY_UINT64))
          :(is_array(argv[1]) || PySequence_Check(argv[1])));
      }
      if (_v) {
        {
          _v = (ALLOW_CONVERSION == FORCE_INPLACE
            ? (is_array(argv[2]) && PyArray_EquivTypenums(array_type(argv[2]), NPY_UINT64))
            :(is_array(argv[2]) || PySequence_Check(argv[2])));
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_size_t(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              return _wrap_new_CSRNumericTable__SWIG_5(self, args);
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'new_CSRNumericTable'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::CSRNumericTable::CSRNumericTable()\n"
    "    daal::data_management::interface1::CSRNumericTable::CSRNumericTable(daal::services::SharedPtr< double > const &,size_t,daal::services::SharedPtr< size_t > const &,size_t,daal::services::SharedPtr< size_t > const &,size_t,size_t,size_t)\n"
    "    daal::data_management::interface1::CSRNumericTable::CSRNumericTable(daal::services::SharedPtr< float > const &,size_t,daal::services::SharedPtr< size_t > const &,size_t,daal::services::SharedPtr< size_t > const &,size_t,size_t,size_t)\n"
    "    daal::data_management::interface1::CSRNumericTable::CSRNumericTable(daal::services::SharedPtr< int > const &,size_t,daal::services::SharedPtr< size_t > const &,size_t,daal::services::SharedPtr< size_t > const &,size_t,size_t,size_t)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_CSRNumericTable_setArrays__SWIG_4(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRNumericTable *arg1 = (daal::data_management::interface1::CSRNumericTable *) 0 ;
  daal::services::SharedPtr< int > *arg2 = 0 ;
  size_t arg3 ;
  daal::services::SharedPtr< size_t > *arg4 = 0 ;
  size_t arg5 ;
  daal::services::SharedPtr< size_t > *arg6 = 0 ;
  size_t arg7 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > *smartarg1 = 0 ;
  daal::services::SharedPtr< int > r4p2 ;
  daal::services::SharedPtr< size_t > r4p4 ;
  daal::services::SharedPtr< size_t > r4p6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:CSRNumericTable_setArrays",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_setArrays" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_setArrays" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
  }
  {
    int is_new_object = 0;
    PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_INT)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_INT, &is_new_object));
    if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p2 = daal::services::SharedPtr< int >((int*)array_data(array), NumpyDeleter(array));
    arg2 = &r4p2;
    arg3 = (size_t) array_size(array,0);
    // we need it increment the ref-count if we use the obj1 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj1) Py_INCREF(array);
  }
  {
    int is_new_object = 0;
    PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj2, NPY_UINT64)
      :obj_to_array_contiguous_allow_conversion(obj2, NPY_UINT64, &is_new_object));
    if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p4 = daal::services::SharedPtr< size_t >((size_t*)array_data(array), NumpyDeleter(array));
    arg4 = &r4p4;
    arg5 = (size_t) array_size(array,0);
    // we need it increment the ref-count if we use the obj2 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj2) Py_INCREF(array);
  }
  {
    int is_new_object = 0;
    PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj3, NPY_UINT64)
      :obj_to_array_contiguous_allow_conversion(obj3, NPY_UINT64, &is_new_object));
    if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p6 = daal::services::SharedPtr< size_t >((size_t*)array_data(array), NumpyDeleter(array));
    arg6 = &r4p6;
    arg7 = (size_t) array_size(array,0);
    // we need it increment the ref-count if we use the obj3 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj3) Py_INCREF(array);
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        daal_data_management_interface1_CSRNumericTable_setArrays__SWIG_4(arg1,(daal::services::SharedPtr< int > const &)*arg2,arg3,(daal::services::SharedPtr< size_t > const &)*arg4,arg5,(daal::services::SharedPtr< size_t > const &)*arg6,arg7);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRNumericTable_setArrays(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[5];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 4) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 4) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = (ALLOW_CONVERSION == FORCE_INPLACE
          ? (is_array(argv[1]) && PyArray_EquivTypenums(array_type(argv[1]), NPY_DOUBLE))
          :(is_array(argv[1]) || PySequence_Check(argv[1])));
      }
      if (_v) {
        {
          _v = (ALLOW_CONVERSION == FORCE_INPLACE
            ? (is_array(argv[2]) && PyArray_EquivTypenums(array_type(argv[2]), NPY_UINT64))
            :(is_array(argv[2]) || PySequence_Check(argv[2])));
        }
        if (_v) {
          {
            _v = (ALLOW_CONVERSION == FORCE_INPLACE
              ? (is_array(argv[3]) && PyArray_EquivTypenums(array_type(argv[3]), NPY_UINT64))
              :(is_array(argv[3]) || PySequence_Check(argv[3])));
          }
          if (_v) {
            if (argc <= 4) {
              return _wrap_CSRNumericTable_setArrays__SWIG_2(self, args);
            }
            return _wrap_CSRNumericTable_setArrays__SWIG_2(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = (ALLOW_CONVERSION == FORCE_INPLACE
          ? (is_array(argv[1]) && PyArray_EquivTypenums(array_type(argv[1]), NPY_FLOAT))
          :(is_array(argv[1]) || PySequence_Check(argv[1])));
      }
      if (_v) {
        {
          _v = (ALLOW_CONVERSION == FORCE_INPLACE
            ? (is_array(argv[2]) && PyArray_EquivTypenums(array_type(argv[2]), NPY_UINT64))
            :(is_array(argv[2]) || PySequence_Check(argv[2])));
        }
        if (_v) {
          {
            _v = (ALLOW_CONVERSION == FORCE_INPLACE
              ? (is_array(argv[3]) && PyArray_EquivTypenums(array_type(argv[3]), NPY_UINT64))
              :(is_array(argv[3]) || PySequence_Check(argv[3])));
          }
          if (_v) {
            if (argc <= 4) {
              return _wrap_CSRNumericTable_setArrays__SWIG_3(self, args);
            }
            return _wrap_CSRNumericTable_setArrays__SWIG_3(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = (ALLOW_CONVERSION == FORCE_INPLACE
          ? (is_array(argv[1]) && PyArray_EquivTypenums(array_type(argv[1]), NPY_INT))
          :(is_array(argv[1]) || PySequence_Check(argv[1])));
      }
      if (_v) {
        {
          _v = (ALLOW_CONVERSION == FORCE_INPLACE
            ? (is_array(argv[2]) && PyArray_EquivTypenums(array_type(argv[2]), NPY_UINT64))
            :(is_array(argv[2]) || PySequence_Check(argv[2])));
        }
        if (_v) {
          {
            _v = (ALLOW_CONVERSION == FORCE_INPLACE
              ? (is_array(argv[3]) && PyArray_EquivTypenums(array_type(argv[3]), NPY_UINT64))
              :(is_array(argv[3]) || PySequence_Check(argv[3])));
          }
          if (_v) {
            if (argc <= 4) {
              return _wrap_CSRNumericTable_setArrays__SWIG_4(self, args);
            }
            return _wrap_CSRNumericTable_setArrays__SWIG_4(self, args);
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'CSRNumericTable_setArrays'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::CSRNumericTable::setArrays(daal::services::SharedPtr< double > const &,size_t,daal::services::SharedPtr< size_t > const &,size_t,daal::services::SharedPtr< size_t > const &,size_t)\n"
    "    daal::data_management::interface1::CSRNumericTable::setArrays(daal::services::SharedPtr< float > const &,size_t,daal::services::SharedPtr< size_t > const &,size_t,daal::services::SharedPtr< size_t > const &,size_t)\n"
    "    daal::data_management::interface1::CSRNumericTable::setArrays(daal::services::SharedPtr< int > const &,size_t,daal::services::SharedPtr< size_t > const &,size_t,daal::services::SharedPtr< size_t > const &,size_t)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_CSRNumericTable_getArrays(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRNumericTable *arg1 = (daal::data_management::interface1::CSRNumericTable *) 0 ;
  size_t *arg2 = (size_t *) 0 ;
  daal::services::SharedPtr< size_t > *arg3 = (daal::services::SharedPtr< size_t > *) 0 ;
  size_t *arg4 = (size_t *) 0 ;
  daal::services::SharedPtr< size_t > *arg5 = (daal::services::SharedPtr< size_t > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > *smartarg1 = 0 ;
  daal::services::SharedPtr< size_t > data_temp2 ;
  size_t dim_temp2 ;
  daal::services::SharedPtr< size_t > data_temp4 ;
  size_t dim_temp4 ;
  PyObject * obj0 = 0 ;
  PyObject *result = 0 ;
  
  {
    arg2 = &dim_temp2;
    arg3 = &data_temp2;
  }
  {
    arg4 = &dim_temp4;
    arg5 = &data_temp4;
  }
  if (!PyArg_ParseTuple(args,(char *)"O:CSRNumericTable_getArrays",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_getArrays" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRNumericTable_getArrays" "', argument " "1"" of type '" "daal::data_management::interface1::CSRNumericTable *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (PyObject *)daal_data_management_interface1_CSRNumericTable_getArrays(arg1,arg2,arg3,arg4,arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = result;
  {
    npy_intp dims[1] = {
      static_cast<npy_intp>(*arg2) 
    }; // Intel/FS static-cast
    PyObject* obj = PyArray_SimpleNewFromData(1, dims, NPY_UINT64, (void*)(arg3->get()));
    if (!obj) SWIG_fail;
    set_sp_base((PyArrayObject*)obj, *arg3);
    resultobj = SWIG_Python_AppendOutput(resultobj,obj);
  }
  {
    npy_intp dims[1] = {
      static_cast<npy_intp>(*arg4) 
    }; // Intel/FS static-cast
    PyObject* obj = PyArray_SimpleNewFromData(1, dims, NPY_UINT64, (void*)(arg5->get()));
    if (!obj) SWIG_fail;
    set_sp_base((PyArrayObject*)obj, *arg5);
    resultobj = SWIG_Python_AppendOutput(resultobj,obj);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *CSRNumericTable_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_MergedNumericTable_serializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)":MergedNumericTable_serializationTag")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)daal::data_management::interface1::MergedNumericTable::serializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MergedNumericTable_getSerializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::MergedNumericTable *arg1 = (daal::data_management::interface1::MergedNumericTable *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::MergedNumericTable const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::MergedNumericTable const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:MergedNumericTable_getSerializationTag",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MergedNumericTable_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::MergedNumericTable const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::MergedNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::MergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::MergedNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::MergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::MergedNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MergedNumericTable_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::MergedNumericTable const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)((daal::data_management::interface1::MergedNumericTable const *)arg1)->getSerializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_MergedNumericTable__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::MergedNumericTable *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_MergedNumericTable")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::MergedNumericTable *)new daal::data_management::interface1::MergedNumericTable();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_MergedNumericTable__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTablePtr arg1 ;
  void *argp1 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::MergedNumericTable *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:new_MergedNumericTable",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t,  0 , &newmem);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_MergedNumericTable" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTablePtr""'"); 
    }
    if (argp1) arg1 = *(reinterpret_cast< daal::data_management::interface1::NumericTablePtr * >(argp1));
    if (newmem & SWIG_CAST_NEW_MEMORY) delete reinterpret_cast< daal::data_management::interface1::NumericTablePtr * >(argp1);
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::MergedNumericTable *)new daal::data_management::interface1::MergedNumericTable(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_MergedNumericTable__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTablePtr arg1 ;
  daal::data_management::interface1::NumericTablePtr arg2 ;
  void *argp1 ;
  int res1 = 0 ;
  void *argp2 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::data_management::interface1::MergedNumericTable *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:new_MergedNumericTable",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t,  0 , &newmem);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_MergedNumericTable" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTablePtr""'"); 
    }
    if (argp1) arg1 = *(reinterpret_cast< daal::data_management::interface1::NumericTablePtr * >(argp1));
    if (newmem & SWIG_CAST_NEW_MEMORY) delete reinterpret_cast< daal::data_management::interface1::NumericTablePtr * >(argp1);
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "new_MergedNumericTable" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTablePtr""'"); 
    }
    if (argp2) arg2 = *(reinterpret_cast< daal::data_management::interface1::NumericTablePtr * >(argp2));
    if (newmem & SWIG_CAST_NEW_MEMORY) delete reinterpret_cast< daal::data_management::interface1::NumericTablePtr * >(argp2);
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::MergedNumericTable *)new daal::data_management::interface1::MergedNumericTable(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_MergedNumericTable(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_new_MergedNumericTable__SWIG_0(self, args);
  }
  if (argc == 1) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_MergedNumericTable__SWIG_1(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_new_MergedNumericTable__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'new_MergedNumericTable'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::MergedNumericTable::MergedNumericTable()\n"
    "    daal::data_management::interface1::MergedNumericTable::MergedNumericTable(daal::data_management::interface1::NumericTablePtr)\n"
    "    daal::data_management::interface1::MergedNumericTable::MergedNumericTable(daal::data_management::interface1::NumericTablePtr,daal::data_management::interface1::NumericTablePtr)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_MergedNumericTable_addNumericTable(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::MergedNumericTable *arg1 = (daal::data_management::interface1::MergedNumericTable *) 0 ;
  daal::data_management::interface1::NumericTablePtr arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::MergedNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::MergedNumericTable > *smartarg1 = 0 ;
  void *argp2 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:MergedNumericTable_addNumericTable",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MergedNumericTable_addNumericTable" "', argument " "1"" of type '" "daal::data_management::interface1::MergedNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::MergedNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::MergedNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MergedNumericTable_addNumericTable" "', argument " "1"" of type '" "daal::data_management::interface1::MergedNumericTable *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "MergedNumericTable_addNumericTable" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTablePtr""'"); 
    }
    if (argp2) arg2 = *(reinterpret_cast< daal::data_management::interface1::NumericTablePtr * >(argp2));
    if (newmem & SWIG_CAST_NEW_MEMORY) delete reinterpret_cast< daal::data_management::interface1::NumericTablePtr * >(argp2);
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->addNumericTable(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MergedNumericTable_resize(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::MergedNumericTable *arg1 = (daal::data_management::interface1::MergedNumericTable *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::MergedNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::MergedNumericTable > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:MergedNumericTable_resize",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MergedNumericTable_resize" "', argument " "1"" of type '" "daal::data_management::interface1::MergedNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::MergedNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::MergedNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MergedNumericTable_resize" "', argument " "1"" of type '" "daal::data_management::interface1::MergedNumericTable *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MergedNumericTable_resize" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->resize(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MergedNumericTable_getDataMemoryStatus(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::MergedNumericTable *arg1 = (daal::data_management::interface1::MergedNumericTable *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::MergedNumericTable const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::MergedNumericTable const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::NumericTableIface::MemoryStatus result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:MergedNumericTable_getDataMemoryStatus",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MergedNumericTable_getDataMemoryStatus" "', argument " "1"" of type '" "daal::data_management::interface1::MergedNumericTable const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::MergedNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::MergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::MergedNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::MergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::MergedNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MergedNumericTable_getDataMemoryStatus" "', argument " "1"" of type '" "daal::data_management::interface1::MergedNumericTable const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::NumericTableIface::MemoryStatus)((daal::data_management::interface1::MergedNumericTable const *)arg1)->getDataMemoryStatus();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MergedNumericTable_getBlockOfRows__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::MergedNumericTable *arg1 = (daal::data_management::interface1::MergedNumericTable *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::MergedNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::MergedNumericTable > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:MergedNumericTable_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MergedNumericTable_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::MergedNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::MergedNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::MergedNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MergedNumericTable_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::MergedNumericTable *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MergedNumericTable_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "MergedNumericTable_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "MergedNumericTable_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "MergedNumericTable_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "MergedNumericTable_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "MergedNumericTable_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MergedNumericTable_getBlockOfRows__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::MergedNumericTable *arg1 = (daal::data_management::interface1::MergedNumericTable *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::MergedNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::MergedNumericTable > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:MergedNumericTable_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MergedNumericTable_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::MergedNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::MergedNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::MergedNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MergedNumericTable_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::MergedNumericTable *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MergedNumericTable_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "MergedNumericTable_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "MergedNumericTable_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "MergedNumericTable_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "MergedNumericTable_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "MergedNumericTable_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MergedNumericTable_getBlockOfRows__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::MergedNumericTable *arg1 = (daal::data_management::interface1::MergedNumericTable *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::MergedNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::MergedNumericTable > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:MergedNumericTable_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MergedNumericTable_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::MergedNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::MergedNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::MergedNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MergedNumericTable_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::MergedNumericTable *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MergedNumericTable_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "MergedNumericTable_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "MergedNumericTable_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "MergedNumericTable_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "MergedNumericTable_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "MergedNumericTable_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MergedNumericTable_getBlockOfRows(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[6];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 5) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_MergedNumericTable_getBlockOfRows__SWIG_0(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_MergedNumericTable_getBlockOfRows__SWIG_1(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_MergedNumericTable_getBlockOfRows__SWIG_2(self, args);
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'MergedNumericTable_getBlockOfRows'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::MergedNumericTable::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::MergedNumericTable::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::MergedNumericTable::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_MergedNumericTable_releaseBlockOfRows__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::MergedNumericTable *arg1 = (daal::data_management::interface1::MergedNumericTable *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::MergedNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::MergedNumericTable > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:MergedNumericTable_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MergedNumericTable_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::MergedNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::MergedNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::MergedNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MergedNumericTable_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::MergedNumericTable *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "MergedNumericTable_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "MergedNumericTable_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "MergedNumericTable_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MergedNumericTable_releaseBlockOfRows__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::MergedNumericTable *arg1 = (daal::data_management::interface1::MergedNumericTable *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::MergedNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::MergedNumericTable > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:MergedNumericTable_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MergedNumericTable_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::MergedNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::MergedNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::MergedNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MergedNumericTable_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::MergedNumericTable *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "MergedNumericTable_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "MergedNumericTable_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "MergedNumericTable_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MergedNumericTable_releaseBlockOfRows__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::MergedNumericTable *arg1 = (daal::data_management::interface1::MergedNumericTable *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::MergedNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::MergedNumericTable > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:MergedNumericTable_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MergedNumericTable_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::MergedNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::MergedNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::MergedNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MergedNumericTable_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::MergedNumericTable *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "MergedNumericTable_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "MergedNumericTable_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "MergedNumericTable_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MergedNumericTable_releaseBlockOfRows(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_MergedNumericTable_releaseBlockOfRows__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_MergedNumericTable_releaseBlockOfRows__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_MergedNumericTable_releaseBlockOfRows__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'MergedNumericTable_releaseBlockOfRows'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::MergedNumericTable::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::MergedNumericTable::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::MergedNumericTable::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_MergedNumericTable_getBlockOfColumnValues__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::MergedNumericTable *arg1 = (daal::data_management::interface1::MergedNumericTable *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::MergedNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::MergedNumericTable > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:MergedNumericTable_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MergedNumericTable_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::MergedNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::MergedNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::MergedNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MergedNumericTable_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::MergedNumericTable *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MergedNumericTable_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "MergedNumericTable_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "MergedNumericTable_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "MergedNumericTable_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "MergedNumericTable_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "MergedNumericTable_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "MergedNumericTable_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MergedNumericTable_getBlockOfColumnValues__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::MergedNumericTable *arg1 = (daal::data_management::interface1::MergedNumericTable *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::MergedNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::MergedNumericTable > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:MergedNumericTable_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MergedNumericTable_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::MergedNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::MergedNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::MergedNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MergedNumericTable_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::MergedNumericTable *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MergedNumericTable_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "MergedNumericTable_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "MergedNumericTable_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "MergedNumericTable_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "MergedNumericTable_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "MergedNumericTable_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "MergedNumericTable_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MergedNumericTable_getBlockOfColumnValues__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::MergedNumericTable *arg1 = (daal::data_management::interface1::MergedNumericTable *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::MergedNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::MergedNumericTable > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:MergedNumericTable_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MergedNumericTable_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::MergedNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::MergedNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::MergedNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MergedNumericTable_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::MergedNumericTable *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MergedNumericTable_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "MergedNumericTable_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "MergedNumericTable_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "MergedNumericTable_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "MergedNumericTable_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "MergedNumericTable_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "MergedNumericTable_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MergedNumericTable_getBlockOfColumnValues(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[7];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 6) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_MergedNumericTable_getBlockOfColumnValues__SWIG_0(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_MergedNumericTable_getBlockOfColumnValues__SWIG_1(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_MergedNumericTable_getBlockOfColumnValues__SWIG_2(self, args);
              }
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'MergedNumericTable_getBlockOfColumnValues'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::MergedNumericTable::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::MergedNumericTable::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::MergedNumericTable::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_MergedNumericTable_releaseBlockOfColumnValues__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::MergedNumericTable *arg1 = (daal::data_management::interface1::MergedNumericTable *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::MergedNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::MergedNumericTable > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:MergedNumericTable_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MergedNumericTable_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::MergedNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::MergedNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::MergedNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MergedNumericTable_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::MergedNumericTable *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "MergedNumericTable_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "MergedNumericTable_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "MergedNumericTable_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MergedNumericTable_releaseBlockOfColumnValues__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::MergedNumericTable *arg1 = (daal::data_management::interface1::MergedNumericTable *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::MergedNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::MergedNumericTable > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:MergedNumericTable_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MergedNumericTable_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::MergedNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::MergedNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::MergedNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MergedNumericTable_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::MergedNumericTable *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "MergedNumericTable_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "MergedNumericTable_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "MergedNumericTable_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MergedNumericTable_releaseBlockOfColumnValues__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::MergedNumericTable *arg1 = (daal::data_management::interface1::MergedNumericTable *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::MergedNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::MergedNumericTable > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:MergedNumericTable_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MergedNumericTable_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::MergedNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::MergedNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::MergedNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MergedNumericTable_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::MergedNumericTable *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "MergedNumericTable_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "MergedNumericTable_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "MergedNumericTable_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MergedNumericTable_releaseBlockOfColumnValues(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_MergedNumericTable_releaseBlockOfColumnValues__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_MergedNumericTable_releaseBlockOfColumnValues__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_MergedNumericTable_releaseBlockOfColumnValues__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'MergedNumericTable_releaseBlockOfColumnValues'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::MergedNumericTable::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::MergedNumericTable::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::MergedNumericTable::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_MergedNumericTable_allocateBasicStatistics(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::MergedNumericTable *arg1 = (daal::data_management::interface1::MergedNumericTable *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::MergedNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::MergedNumericTable > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:MergedNumericTable_allocateBasicStatistics",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MergedNumericTable_allocateBasicStatistics" "', argument " "1"" of type '" "daal::data_management::interface1::MergedNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::MergedNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::MergedNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MergedNumericTable_allocateBasicStatistics" "', argument " "1"" of type '" "daal::data_management::interface1::MergedNumericTable *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->allocateBasicStatistics();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_MergedNumericTable(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::MergedNumericTable *arg1 = (daal::data_management::interface1::MergedNumericTable *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::MergedNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::MergedNumericTable > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_MergedNumericTable",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_MergedNumericTable" "', argument " "1"" of type '" "daal::data_management::interface1::MergedNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::MergedNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::MergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::MergedNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_MergedNumericTable" "', argument " "1"" of type '" "daal::data_management::interface1::MergedNumericTable *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *MergedNumericTable_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_RowMergedNumericTable_serializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)":RowMergedNumericTable_serializationTag")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)daal::data_management::interface1::RowMergedNumericTable::serializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RowMergedNumericTable_getSerializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::RowMergedNumericTable *arg1 = (daal::data_management::interface1::RowMergedNumericTable *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::RowMergedNumericTable const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::RowMergedNumericTable const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:RowMergedNumericTable_getSerializationTag",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RowMergedNumericTable_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::RowMergedNumericTable const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::RowMergedNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::RowMergedNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RowMergedNumericTable_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::RowMergedNumericTable const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)((daal::data_management::interface1::RowMergedNumericTable const *)arg1)->getSerializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_RowMergedNumericTable__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::RowMergedNumericTable *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_RowMergedNumericTable")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::RowMergedNumericTable *)new daal::data_management::interface1::RowMergedNumericTable();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::RowMergedNumericTable > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::RowMergedNumericTable >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_RowMergedNumericTable__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTablePtr arg1 ;
  void *argp1 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::RowMergedNumericTable *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:new_RowMergedNumericTable",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t,  0 , &newmem);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_RowMergedNumericTable" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTablePtr""'"); 
    }
    if (argp1) arg1 = *(reinterpret_cast< daal::data_management::interface1::NumericTablePtr * >(argp1));
    if (newmem & SWIG_CAST_NEW_MEMORY) delete reinterpret_cast< daal::data_management::interface1::NumericTablePtr * >(argp1);
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::RowMergedNumericTable *)new daal::data_management::interface1::RowMergedNumericTable(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::RowMergedNumericTable > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::RowMergedNumericTable >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_RowMergedNumericTable(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[2];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 1) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_new_RowMergedNumericTable__SWIG_0(self, args);
  }
  if (argc == 1) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_RowMergedNumericTable__SWIG_1(self, args);
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'new_RowMergedNumericTable'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::RowMergedNumericTable::RowMergedNumericTable()\n"
    "    daal::data_management::interface1::RowMergedNumericTable::RowMergedNumericTable(daal::data_management::interface1::NumericTablePtr)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_RowMergedNumericTable_addNumericTable(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::RowMergedNumericTable *arg1 = (daal::data_management::interface1::RowMergedNumericTable *) 0 ;
  daal::data_management::interface1::NumericTablePtr arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::RowMergedNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::RowMergedNumericTable > *smartarg1 = 0 ;
  void *argp2 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:RowMergedNumericTable_addNumericTable",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RowMergedNumericTable_addNumericTable" "', argument " "1"" of type '" "daal::data_management::interface1::RowMergedNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::RowMergedNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::RowMergedNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RowMergedNumericTable_addNumericTable" "', argument " "1"" of type '" "daal::data_management::interface1::RowMergedNumericTable *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "RowMergedNumericTable_addNumericTable" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTablePtr""'"); 
    }
    if (argp2) arg2 = *(reinterpret_cast< daal::data_management::interface1::NumericTablePtr * >(argp2));
    if (newmem & SWIG_CAST_NEW_MEMORY) delete reinterpret_cast< daal::data_management::interface1::NumericTablePtr * >(argp2);
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->addNumericTable(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RowMergedNumericTable_resize(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::RowMergedNumericTable *arg1 = (daal::data_management::interface1::RowMergedNumericTable *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::RowMergedNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::RowMergedNumericTable > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:RowMergedNumericTable_resize",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RowMergedNumericTable_resize" "', argument " "1"" of type '" "daal::data_management::interface1::RowMergedNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::RowMergedNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::RowMergedNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RowMergedNumericTable_resize" "', argument " "1"" of type '" "daal::data_management::interface1::RowMergedNumericTable *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "RowMergedNumericTable_resize" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->resize(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RowMergedNumericTable_getDataMemoryStatus(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::RowMergedNumericTable *arg1 = (daal::data_management::interface1::RowMergedNumericTable *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::RowMergedNumericTable const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::RowMergedNumericTable const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::NumericTableIface::MemoryStatus result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:RowMergedNumericTable_getDataMemoryStatus",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RowMergedNumericTable_getDataMemoryStatus" "', argument " "1"" of type '" "daal::data_management::interface1::RowMergedNumericTable const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::RowMergedNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::RowMergedNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RowMergedNumericTable_getDataMemoryStatus" "', argument " "1"" of type '" "daal::data_management::interface1::RowMergedNumericTable const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::NumericTableIface::MemoryStatus)((daal::data_management::interface1::RowMergedNumericTable const *)arg1)->getDataMemoryStatus();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RowMergedNumericTable_getBlockOfRows__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::RowMergedNumericTable *arg1 = (daal::data_management::interface1::RowMergedNumericTable *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::RowMergedNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::RowMergedNumericTable > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:RowMergedNumericTable_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RowMergedNumericTable_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::RowMergedNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::RowMergedNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::RowMergedNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RowMergedNumericTable_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::RowMergedNumericTable *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "RowMergedNumericTable_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "RowMergedNumericTable_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "RowMergedNumericTable_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "RowMergedNumericTable_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "RowMergedNumericTable_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "RowMergedNumericTable_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RowMergedNumericTable_getBlockOfRows__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::RowMergedNumericTable *arg1 = (daal::data_management::interface1::RowMergedNumericTable *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::RowMergedNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::RowMergedNumericTable > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:RowMergedNumericTable_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RowMergedNumericTable_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::RowMergedNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::RowMergedNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::RowMergedNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RowMergedNumericTable_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::RowMergedNumericTable *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "RowMergedNumericTable_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "RowMergedNumericTable_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "RowMergedNumericTable_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "RowMergedNumericTable_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "RowMergedNumericTable_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "RowMergedNumericTable_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RowMergedNumericTable_getBlockOfRows__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::RowMergedNumericTable *arg1 = (daal::data_management::interface1::RowMergedNumericTable *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::RowMergedNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::RowMergedNumericTable > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:RowMergedNumericTable_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RowMergedNumericTable_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::RowMergedNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::RowMergedNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::RowMergedNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RowMergedNumericTable_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::RowMergedNumericTable *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "RowMergedNumericTable_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "RowMergedNumericTable_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "RowMergedNumericTable_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "RowMergedNumericTable_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "RowMergedNumericTable_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "RowMergedNumericTable_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RowMergedNumericTable_getBlockOfRows(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[6];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 5) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_RowMergedNumericTable_getBlockOfRows__SWIG_0(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_RowMergedNumericTable_getBlockOfRows__SWIG_1(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_RowMergedNumericTable_getBlockOfRows__SWIG_2(self, args);
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'RowMergedNumericTable_getBlockOfRows'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::RowMergedNumericTable::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::RowMergedNumericTable::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::RowMergedNumericTable::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_RowMergedNumericTable_releaseBlockOfRows__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::RowMergedNumericTable *arg1 = (daal::data_management::interface1::RowMergedNumericTable *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::RowMergedNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::RowMergedNumericTable > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:RowMergedNumericTable_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RowMergedNumericTable_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::RowMergedNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::RowMergedNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::RowMergedNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RowMergedNumericTable_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::RowMergedNumericTable *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "RowMergedNumericTable_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "RowMergedNumericTable_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "RowMergedNumericTable_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RowMergedNumericTable_releaseBlockOfRows__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::RowMergedNumericTable *arg1 = (daal::data_management::interface1::RowMergedNumericTable *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::RowMergedNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::RowMergedNumericTable > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:RowMergedNumericTable_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RowMergedNumericTable_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::RowMergedNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::RowMergedNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::RowMergedNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RowMergedNumericTable_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::RowMergedNumericTable *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "RowMergedNumericTable_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "RowMergedNumericTable_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "RowMergedNumericTable_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RowMergedNumericTable_releaseBlockOfRows__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::RowMergedNumericTable *arg1 = (daal::data_management::interface1::RowMergedNumericTable *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::RowMergedNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::RowMergedNumericTable > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:RowMergedNumericTable_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RowMergedNumericTable_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::RowMergedNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::RowMergedNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::RowMergedNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RowMergedNumericTable_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::RowMergedNumericTable *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "RowMergedNumericTable_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "RowMergedNumericTable_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "RowMergedNumericTable_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RowMergedNumericTable_releaseBlockOfRows(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_RowMergedNumericTable_releaseBlockOfRows__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_RowMergedNumericTable_releaseBlockOfRows__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_RowMergedNumericTable_releaseBlockOfRows__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'RowMergedNumericTable_releaseBlockOfRows'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::RowMergedNumericTable::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::RowMergedNumericTable::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::RowMergedNumericTable::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_RowMergedNumericTable_getBlockOfColumnValues__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::RowMergedNumericTable *arg1 = (daal::data_management::interface1::RowMergedNumericTable *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::RowMergedNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::RowMergedNumericTable > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:RowMergedNumericTable_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RowMergedNumericTable_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::RowMergedNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::RowMergedNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::RowMergedNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RowMergedNumericTable_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::RowMergedNumericTable *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "RowMergedNumericTable_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "RowMergedNumericTable_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "RowMergedNumericTable_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "RowMergedNumericTable_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "RowMergedNumericTable_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "RowMergedNumericTable_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "RowMergedNumericTable_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RowMergedNumericTable_getBlockOfColumnValues__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::RowMergedNumericTable *arg1 = (daal::data_management::interface1::RowMergedNumericTable *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::RowMergedNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::RowMergedNumericTable > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:RowMergedNumericTable_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RowMergedNumericTable_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::RowMergedNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::RowMergedNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::RowMergedNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RowMergedNumericTable_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::RowMergedNumericTable *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "RowMergedNumericTable_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "RowMergedNumericTable_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "RowMergedNumericTable_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "RowMergedNumericTable_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "RowMergedNumericTable_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "RowMergedNumericTable_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "RowMergedNumericTable_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RowMergedNumericTable_getBlockOfColumnValues__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::RowMergedNumericTable *arg1 = (daal::data_management::interface1::RowMergedNumericTable *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::RowMergedNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::RowMergedNumericTable > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:RowMergedNumericTable_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RowMergedNumericTable_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::RowMergedNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::RowMergedNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::RowMergedNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RowMergedNumericTable_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::RowMergedNumericTable *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "RowMergedNumericTable_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "RowMergedNumericTable_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "RowMergedNumericTable_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "RowMergedNumericTable_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "RowMergedNumericTable_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "RowMergedNumericTable_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "RowMergedNumericTable_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RowMergedNumericTable_getBlockOfColumnValues(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[7];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 6) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_RowMergedNumericTable_getBlockOfColumnValues__SWIG_0(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_RowMergedNumericTable_getBlockOfColumnValues__SWIG_1(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_RowMergedNumericTable_getBlockOfColumnValues__SWIG_2(self, args);
              }
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'RowMergedNumericTable_getBlockOfColumnValues'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::RowMergedNumericTable::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::RowMergedNumericTable::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::RowMergedNumericTable::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_RowMergedNumericTable_releaseBlockOfColumnValues__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::RowMergedNumericTable *arg1 = (daal::data_management::interface1::RowMergedNumericTable *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::RowMergedNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::RowMergedNumericTable > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:RowMergedNumericTable_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RowMergedNumericTable_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::RowMergedNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::RowMergedNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::RowMergedNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RowMergedNumericTable_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::RowMergedNumericTable *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "RowMergedNumericTable_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "RowMergedNumericTable_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "RowMergedNumericTable_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RowMergedNumericTable_releaseBlockOfColumnValues__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::RowMergedNumericTable *arg1 = (daal::data_management::interface1::RowMergedNumericTable *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::RowMergedNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::RowMergedNumericTable > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:RowMergedNumericTable_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RowMergedNumericTable_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::RowMergedNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::RowMergedNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::RowMergedNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RowMergedNumericTable_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::RowMergedNumericTable *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "RowMergedNumericTable_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "RowMergedNumericTable_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "RowMergedNumericTable_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RowMergedNumericTable_releaseBlockOfColumnValues__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::RowMergedNumericTable *arg1 = (daal::data_management::interface1::RowMergedNumericTable *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::RowMergedNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::RowMergedNumericTable > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:RowMergedNumericTable_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RowMergedNumericTable_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::RowMergedNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::RowMergedNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::RowMergedNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RowMergedNumericTable_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::RowMergedNumericTable *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "RowMergedNumericTable_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "RowMergedNumericTable_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "RowMergedNumericTable_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RowMergedNumericTable_releaseBlockOfColumnValues(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_RowMergedNumericTable_releaseBlockOfColumnValues__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_RowMergedNumericTable_releaseBlockOfColumnValues__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_RowMergedNumericTable_releaseBlockOfColumnValues__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'RowMergedNumericTable_releaseBlockOfColumnValues'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::RowMergedNumericTable::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::RowMergedNumericTable::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::RowMergedNumericTable::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_RowMergedNumericTable(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::RowMergedNumericTable *arg1 = (daal::data_management::interface1::RowMergedNumericTable *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::RowMergedNumericTable > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::RowMergedNumericTable > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_RowMergedNumericTable",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_RowMergedNumericTable" "', argument " "1"" of type '" "daal::data_management::interface1::RowMergedNumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::RowMergedNumericTable * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::RowMergedNumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::RowMergedNumericTable * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_RowMergedNumericTable" "', argument " "1"" of type '" "daal::data_management::interface1::RowMergedNumericTable *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *RowMergedNumericTable_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_delete_PackedArrayNumericTableIface(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedArrayNumericTableIface *arg1 = (daal::data_management::interface1::PackedArrayNumericTableIface *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedArrayNumericTableIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedArrayNumericTableIface > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_PackedArrayNumericTableIface",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_PackedArrayNumericTableIface" "', argument " "1"" of type '" "daal::data_management::interface1::PackedArrayNumericTableIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedArrayNumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedArrayNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedArrayNumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedArrayNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedArrayNumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_PackedArrayNumericTableIface" "', argument " "1"" of type '" "daal::data_management::interface1::PackedArrayNumericTableIface *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedArrayNumericTableIface_getPackedArray__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedArrayNumericTableIface *arg1 = (daal::data_management::interface1::PackedArrayNumericTableIface *) 0 ;
  daal::data_management::ReadWriteMode arg2 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedArrayNumericTableIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedArrayNumericTableIface > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared3 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedArrayNumericTableIface_getPackedArray",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedArrayNumericTableIface_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedArrayNumericTableIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedArrayNumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedArrayNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedArrayNumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedArrayNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedArrayNumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedArrayNumericTableIface_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedArrayNumericTableIface *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedArrayNumericTableIface_getPackedArray" "', argument " "2"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg2 = static_cast< daal::data_management::ReadWriteMode >(val2);
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedArrayNumericTableIface_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedArrayNumericTableIface_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared3 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp3);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp3);
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared3.get());
    } else {
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp3)->get());
    }
    if(!arg3) SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedArrayNumericTableIface_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getPackedArray(arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedArrayNumericTableIface_getPackedArray__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedArrayNumericTableIface *arg1 = (daal::data_management::interface1::PackedArrayNumericTableIface *) 0 ;
  daal::data_management::ReadWriteMode arg2 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedArrayNumericTableIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedArrayNumericTableIface > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared3 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedArrayNumericTableIface_getPackedArray",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedArrayNumericTableIface_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedArrayNumericTableIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedArrayNumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedArrayNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedArrayNumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedArrayNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedArrayNumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedArrayNumericTableIface_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedArrayNumericTableIface *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedArrayNumericTableIface_getPackedArray" "', argument " "2"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg2 = static_cast< daal::data_management::ReadWriteMode >(val2);
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedArrayNumericTableIface_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedArrayNumericTableIface_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared3 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp3);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp3);
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared3.get());
    } else {
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp3)->get());
    }
    if(!arg3) SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedArrayNumericTableIface_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getPackedArray(arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedArrayNumericTableIface_getPackedArray__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedArrayNumericTableIface *arg1 = (daal::data_management::interface1::PackedArrayNumericTableIface *) 0 ;
  daal::data_management::ReadWriteMode arg2 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedArrayNumericTableIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedArrayNumericTableIface > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared3 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedArrayNumericTableIface_getPackedArray",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedArrayNumericTableIface_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedArrayNumericTableIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedArrayNumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedArrayNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedArrayNumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedArrayNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedArrayNumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedArrayNumericTableIface_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedArrayNumericTableIface *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedArrayNumericTableIface_getPackedArray" "', argument " "2"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg2 = static_cast< daal::data_management::ReadWriteMode >(val2);
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedArrayNumericTableIface_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedArrayNumericTableIface_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared3 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp3);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp3);
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared3.get());
    } else {
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp3)->get());
    }
    if(!arg3) SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedArrayNumericTableIface_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getPackedArray(arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedArrayNumericTableIface_getPackedArray(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[4];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 3) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedArrayNumericTableIface_getPackedArray__SWIG_0(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedArrayNumericTableIface_getPackedArray__SWIG_1(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedArrayNumericTableIface_getPackedArray__SWIG_2(self, args);
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedArrayNumericTableIface_getPackedArray'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedArrayNumericTableIface::getPackedArray(daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedArrayNumericTableIface::getPackedArray(daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedArrayNumericTableIface::getPackedArray(daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedArrayNumericTableIface_releasePackedArray__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedArrayNumericTableIface *arg1 = (daal::data_management::interface1::PackedArrayNumericTableIface *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedArrayNumericTableIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedArrayNumericTableIface > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedArrayNumericTableIface_releasePackedArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedArrayNumericTableIface_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedArrayNumericTableIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedArrayNumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedArrayNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedArrayNumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedArrayNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedArrayNumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedArrayNumericTableIface_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedArrayNumericTableIface *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedArrayNumericTableIface_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedArrayNumericTableIface_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedArrayNumericTableIface_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releasePackedArray(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedArrayNumericTableIface_releasePackedArray__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedArrayNumericTableIface *arg1 = (daal::data_management::interface1::PackedArrayNumericTableIface *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedArrayNumericTableIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedArrayNumericTableIface > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedArrayNumericTableIface_releasePackedArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedArrayNumericTableIface_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedArrayNumericTableIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedArrayNumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedArrayNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedArrayNumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedArrayNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedArrayNumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedArrayNumericTableIface_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedArrayNumericTableIface *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedArrayNumericTableIface_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedArrayNumericTableIface_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedArrayNumericTableIface_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releasePackedArray(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedArrayNumericTableIface_releasePackedArray__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedArrayNumericTableIface *arg1 = (daal::data_management::interface1::PackedArrayNumericTableIface *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedArrayNumericTableIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedArrayNumericTableIface > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedArrayNumericTableIface_releasePackedArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedArrayNumericTableIface_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedArrayNumericTableIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedArrayNumericTableIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedArrayNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedArrayNumericTableIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedArrayNumericTableIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedArrayNumericTableIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedArrayNumericTableIface_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedArrayNumericTableIface *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedArrayNumericTableIface_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedArrayNumericTableIface_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedArrayNumericTableIface_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releasePackedArray(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedArrayNumericTableIface_releasePackedArray(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedArrayNumericTableIface_releasePackedArray__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedArrayNumericTableIface_releasePackedArray__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedArrayNumericTableIface_releasePackedArray__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedArrayNumericTableIface_releasePackedArray'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedArrayNumericTableIface::releasePackedArray(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedArrayNumericTableIface::releasePackedArray(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedArrayNumericTableIface::releasePackedArray(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *PackedArrayNumericTableIface_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_DataSourceIface_getDictionary(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSourceIface *arg1 = (daal::data_management::interface1::DataSourceIface *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::DataSourceDictionary *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataSourceIface_getDictionary",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceIface_getDictionary" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceIface_getDictionary" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceIface *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::DataSourceDictionary *)(arg1)->getDictionary();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > >(result SWIG_NO_NULL_DELETER_0) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_t, 0 | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceIface_setDictionary(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSourceIface *arg1 = (daal::data_management::interface1::DataSourceIface *) 0 ;
  daal::data_management::interface1::DataSourceDictionary *arg2 = (daal::data_management::interface1::DataSourceDictionary *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > > tempshared2 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > > *smartarg2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DataSourceIface_setDictionary",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceIface_setDictionary" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceIface_setDictionary" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceIface *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res2) || !argp2) && obj1 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DataSourceIface_setDictionary" "', argument " "2"" of type '" "daal::data_management::interface1::DataSourceDictionary *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::DataSourceDictionary * >(tempshared2.get());
    } else {
      smartarg2 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::DataSourceDictionary * >((smartarg2 ? smartarg2->get() : 0));
    }
    if(!arg2 && obj1 != Py_None) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DataSourceIface_setDictionary" "', argument " "2"" of type '" "daal::data_management::interface1::DataSourceDictionary *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->setDictionary(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceIface_createDictionaryFromContext(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSourceIface *arg1 = (daal::data_management::interface1::DataSourceIface *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataSourceIface_createDictionaryFromContext",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceIface_createDictionaryFromContext" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceIface_createDictionaryFromContext" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceIface *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->createDictionaryFromContext();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceIface_getStatus(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSourceIface *arg1 = (daal::data_management::interface1::DataSourceIface *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::DataSourceIface::DataSourceStatus result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataSourceIface_getStatus",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceIface_getStatus" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceIface_getStatus" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceIface *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::DataSourceIface::DataSourceStatus)(arg1)->getStatus();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceIface_getNumberOfColumns(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSourceIface *arg1 = (daal::data_management::interface1::DataSourceIface *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataSourceIface_getNumberOfColumns",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceIface_getNumberOfColumns" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceIface_getNumberOfColumns" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceIface *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getNumberOfColumns();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceIface_getNumericTableNumberOfColumns(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSourceIface *arg1 = (daal::data_management::interface1::DataSourceIface *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataSourceIface_getNumericTableNumberOfColumns",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceIface_getNumericTableNumberOfColumns" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceIface_getNumericTableNumberOfColumns" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceIface *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getNumericTableNumberOfColumns();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceIface_getNumberOfAvailableRows(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSourceIface *arg1 = (daal::data_management::interface1::DataSourceIface *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataSourceIface_getNumberOfAvailableRows",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceIface_getNumberOfAvailableRows" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceIface_getNumberOfAvailableRows" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceIface *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getNumberOfAvailableRows();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceIface_allocateNumericTable(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSourceIface *arg1 = (daal::data_management::interface1::DataSourceIface *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataSourceIface_allocateNumericTable",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceIface_allocateNumericTable" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceIface_allocateNumericTable" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceIface *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->allocateNumericTable();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceIface_getNumericTable(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSourceIface *arg1 = (daal::data_management::interface1::DataSourceIface *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::NumericTablePtr result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataSourceIface_getNumericTable",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceIface_getNumericTable" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceIface_getNumericTable" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceIface *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getNumericTable();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::NumericTable >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceIface_freeNumericTable(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSourceIface *arg1 = (daal::data_management::interface1::DataSourceIface *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataSourceIface_freeNumericTable",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceIface_freeNumericTable" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceIface_freeNumericTable" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceIface *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->freeNumericTable();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceIface_loadDataBlock__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSourceIface *arg1 = (daal::data_management::interface1::DataSourceIface *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DataSourceIface_loadDataBlock",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceIface_loadDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceIface_loadDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceIface *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "DataSourceIface_loadDataBlock" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->loadDataBlock(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceIface_loadDataBlock__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSourceIface *arg1 = (daal::data_management::interface1::DataSourceIface *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:DataSourceIface_loadDataBlock",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceIface_loadDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceIface_loadDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceIface *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "DataSourceIface_loadDataBlock" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "DataSourceIface_loadDataBlock" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "DataSourceIface_loadDataBlock" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->loadDataBlock(arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceIface_loadDataBlock__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSourceIface *arg1 = (daal::data_management::interface1::DataSourceIface *) 0 ;
  size_t arg2 ;
  daal::data_management::interface1::NumericTable *arg3 = (daal::data_management::interface1::NumericTable *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > tempshared3 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > *smartarg3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:DataSourceIface_loadDataBlock",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceIface_loadDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceIface_loadDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceIface *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "DataSourceIface_loadDataBlock" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res3) || !argp3) && obj2 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "DataSourceIface_loadDataBlock" "', argument " "3"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared3 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp3);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp3);
      arg3 = const_cast< daal::data_management::interface1::NumericTable * >(tempshared3.get());
    } else {
      smartarg3 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp3);
      arg3 = const_cast< daal::data_management::interface1::NumericTable * >((smartarg3 ? smartarg3->get() : 0));
    }
    if(!arg3 && obj2 != Py_None) SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "DataSourceIface_loadDataBlock" "', argument " "3"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->loadDataBlock(arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceIface_loadDataBlock__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSourceIface *arg1 = (daal::data_management::interface1::DataSourceIface *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::interface1::NumericTable *arg5 = (daal::data_management::interface1::NumericTable *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > tempshared5 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > *smartarg5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:DataSourceIface_loadDataBlock",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceIface_loadDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceIface_loadDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceIface *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "DataSourceIface_loadDataBlock" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "DataSourceIface_loadDataBlock" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "DataSourceIface_loadDataBlock" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res5) || !argp5) && obj4 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "DataSourceIface_loadDataBlock" "', argument " "5"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::NumericTable * >(tempshared5.get());
    } else {
      smartarg5 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::NumericTable * >((smartarg5 ? smartarg5->get() : 0));
    }
    if(!arg5 && obj4 != Py_None) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "DataSourceIface_loadDataBlock" "', argument " "5"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->loadDataBlock(arg2,arg3,arg4,arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceIface_loadDataBlock__SWIG_4(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSourceIface *arg1 = (daal::data_management::interface1::DataSourceIface *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataSourceIface_loadDataBlock",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceIface_loadDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceIface_loadDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceIface *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->loadDataBlock();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceIface_loadDataBlock__SWIG_5(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSourceIface *arg1 = (daal::data_management::interface1::DataSourceIface *) 0 ;
  daal::data_management::interface1::NumericTable *arg2 = (daal::data_management::interface1::NumericTable *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > tempshared2 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > *smartarg2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DataSourceIface_loadDataBlock",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceIface_loadDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceIface_loadDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceIface *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res2) || !argp2) && obj1 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DataSourceIface_loadDataBlock" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::NumericTable * >(tempshared2.get());
    } else {
      smartarg2 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::NumericTable * >((smartarg2 ? smartarg2->get() : 0));
    }
    if(!arg2 && obj1 != Py_None) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DataSourceIface_loadDataBlock" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->loadDataBlock(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceIface_loadDataBlock(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[6];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 5) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_DataSourceIface_loadDataBlock__SWIG_4(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_DataSourceIface_loadDataBlock__SWIG_5(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_DataSourceIface_loadDataBlock__SWIG_0(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_DataSourceIface_loadDataBlock__SWIG_2(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            return _wrap_DataSourceIface_loadDataBlock__SWIG_1(self, args);
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_DataSourceIface_loadDataBlock__SWIG_3(self, args);
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'DataSourceIface_loadDataBlock'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::DataSourceIface::loadDataBlock(size_t)\n"
    "    daal::data_management::interface1::DataSourceIface::loadDataBlock(size_t,size_t,size_t)\n"
    "    daal::data_management::interface1::DataSourceIface::loadDataBlock(size_t,daal::data_management::interface1::NumericTable *)\n"
    "    daal::data_management::interface1::DataSourceIface::loadDataBlock(size_t,size_t,size_t,daal::data_management::interface1::NumericTable *)\n"
    "    daal::data_management::interface1::DataSourceIface::loadDataBlock()\n"
    "    daal::data_management::interface1::DataSourceIface::loadDataBlock(daal::data_management::interface1::NumericTable *)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_DataSourceIface(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSourceIface *arg1 = (daal::data_management::interface1::DataSourceIface *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_DataSourceIface",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_DataSourceIface" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceIface *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceIface * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceIface > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceIface * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_DataSourceIface" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceIface *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *DataSourceIface_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_delete_DataSource(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSource *arg1 = (daal::data_management::interface1::DataSource *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSource > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSource > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_DataSource",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_DataSource" "', argument " "1"" of type '" "daal::data_management::interface1::DataSource *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSource > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSource > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSource * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSource > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSource * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_DataSource" "', argument " "1"" of type '" "daal::data_management::interface1::DataSource *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSource_getDictionary(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSource *arg1 = (daal::data_management::interface1::DataSource *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSource > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSource > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::DataSourceDictionary *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataSource_getDictionary",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSource_getDictionary" "', argument " "1"" of type '" "daal::data_management::interface1::DataSource *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSource > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSource > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSource * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSource > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSource * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSource_getDictionary" "', argument " "1"" of type '" "daal::data_management::interface1::DataSource *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::DataSourceDictionary *)(arg1)->getDictionary();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > >(result SWIG_NO_NULL_DELETER_0) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_t, 0 | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSource_setDictionary(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSource *arg1 = (daal::data_management::interface1::DataSource *) 0 ;
  daal::data_management::interface1::DataSourceDictionary *arg2 = (daal::data_management::interface1::DataSourceDictionary *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSource > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSource > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > > tempshared2 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > > *smartarg2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DataSource_setDictionary",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSource_setDictionary" "', argument " "1"" of type '" "daal::data_management::interface1::DataSource *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSource > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSource > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSource * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSource > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSource * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSource_setDictionary" "', argument " "1"" of type '" "daal::data_management::interface1::DataSource *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res2) || !argp2) && obj1 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DataSource_setDictionary" "', argument " "2"" of type '" "daal::data_management::interface1::DataSourceDictionary *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::DataSourceDictionary * >(tempshared2.get());
    } else {
      smartarg2 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::DataSourceDictionary * >((smartarg2 ? smartarg2->get() : 0));
    }
    if(!arg2 && obj1 != Py_None) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DataSource_setDictionary" "', argument " "2"" of type '" "daal::data_management::interface1::DataSourceDictionary *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->setDictionary(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSource_createDictionaryFromContext(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSource *arg1 = (daal::data_management::interface1::DataSource *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSource > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSource > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataSource_createDictionaryFromContext",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSource_createDictionaryFromContext" "', argument " "1"" of type '" "daal::data_management::interface1::DataSource *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSource > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSource > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSource * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSource > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSource * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSource_createDictionaryFromContext" "', argument " "1"" of type '" "daal::data_management::interface1::DataSource *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->createDictionaryFromContext();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSource_loadDataBlock__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSource *arg1 = (daal::data_management::interface1::DataSource *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSource > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSource > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DataSource_loadDataBlock",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSource_loadDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::DataSource *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSource > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSource > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSource * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSource > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSource * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSource_loadDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::DataSource *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "DataSource_loadDataBlock" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->loadDataBlock(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSource_loadDataBlock__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSource *arg1 = (daal::data_management::interface1::DataSource *) 0 ;
  size_t arg2 ;
  daal::data_management::interface1::NumericTable *arg3 = (daal::data_management::interface1::NumericTable *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSource > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSource > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > tempshared3 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > *smartarg3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:DataSource_loadDataBlock",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSource_loadDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::DataSource *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSource > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSource > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSource * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSource > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSource * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSource_loadDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::DataSource *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "DataSource_loadDataBlock" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res3) || !argp3) && obj2 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "DataSource_loadDataBlock" "', argument " "3"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared3 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp3);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp3);
      arg3 = const_cast< daal::data_management::interface1::NumericTable * >(tempshared3.get());
    } else {
      smartarg3 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp3);
      arg3 = const_cast< daal::data_management::interface1::NumericTable * >((smartarg3 ? smartarg3->get() : 0));
    }
    if(!arg3 && obj2 != Py_None) SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "DataSource_loadDataBlock" "', argument " "3"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->loadDataBlock(arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSource_loadDataBlock__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSource *arg1 = (daal::data_management::interface1::DataSource *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSource > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSource > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:DataSource_loadDataBlock",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSource_loadDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::DataSource *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSource > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSource > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSource * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSource > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSource * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSource_loadDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::DataSource *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "DataSource_loadDataBlock" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "DataSource_loadDataBlock" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "DataSource_loadDataBlock" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->loadDataBlock(arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSource_loadDataBlock__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSource *arg1 = (daal::data_management::interface1::DataSource *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::interface1::NumericTable *arg5 = (daal::data_management::interface1::NumericTable *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSource > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSource > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > tempshared5 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > *smartarg5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:DataSource_loadDataBlock",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSource_loadDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::DataSource *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSource > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSource > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSource * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSource > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSource * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSource_loadDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::DataSource *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "DataSource_loadDataBlock" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "DataSource_loadDataBlock" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "DataSource_loadDataBlock" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res5) || !argp5) && obj4 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "DataSource_loadDataBlock" "', argument " "5"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::NumericTable * >(tempshared5.get());
    } else {
      smartarg5 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::NumericTable * >((smartarg5 ? smartarg5->get() : 0));
    }
    if(!arg5 && obj4 != Py_None) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "DataSource_loadDataBlock" "', argument " "5"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->loadDataBlock(arg2,arg3,arg4,arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSource_loadDataBlock__SWIG_4(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSource *arg1 = (daal::data_management::interface1::DataSource *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSource > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSource > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataSource_loadDataBlock",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSource_loadDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::DataSource *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSource > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSource > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSource * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSource > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSource * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSource_loadDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::DataSource *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->loadDataBlock();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSource_loadDataBlock__SWIG_5(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSource *arg1 = (daal::data_management::interface1::DataSource *) 0 ;
  daal::data_management::interface1::NumericTable *arg2 = (daal::data_management::interface1::NumericTable *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSource > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSource > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > tempshared2 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > *smartarg2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DataSource_loadDataBlock",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSource_loadDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::DataSource *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSource > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSource > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSource * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSource > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSource * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSource_loadDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::DataSource *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res2) || !argp2) && obj1 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DataSource_loadDataBlock" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::NumericTable * >(tempshared2.get());
    } else {
      smartarg2 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::NumericTable * >((smartarg2 ? smartarg2->get() : 0));
    }
    if(!arg2 && obj1 != Py_None) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DataSource_loadDataBlock" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->loadDataBlock(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSource_loadDataBlock(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[6];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 5) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_DataSource_loadDataBlock__SWIG_4(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_DataSource_loadDataBlock__SWIG_5(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_DataSource_loadDataBlock__SWIG_0(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_DataSource_loadDataBlock__SWIG_1(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            return _wrap_DataSource_loadDataBlock__SWIG_2(self, args);
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_DataSource_loadDataBlock__SWIG_3(self, args);
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'DataSource_loadDataBlock'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::DataSource::loadDataBlock(size_t)\n"
    "    daal::data_management::interface1::DataSource::loadDataBlock(size_t,daal::data_management::interface1::NumericTable *)\n"
    "    daal::data_management::interface1::DataSource::loadDataBlock(size_t,size_t,size_t)\n"
    "    daal::data_management::interface1::DataSource::loadDataBlock(size_t,size_t,size_t,daal::data_management::interface1::NumericTable *)\n"
    "    daal::data_management::interface1::DataSource::loadDataBlock()\n"
    "    daal::data_management::interface1::DataSource::loadDataBlock(daal::data_management::interface1::NumericTable *)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_DataSource_getNumericTable(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSource *arg1 = (daal::data_management::interface1::DataSource *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSource > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSource > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::NumericTablePtr result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataSource_getNumericTable",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSource_getNumericTable" "', argument " "1"" of type '" "daal::data_management::interface1::DataSource *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSource > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSource > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSource * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSource > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSource * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSource_getNumericTable" "', argument " "1"" of type '" "daal::data_management::interface1::DataSource *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getNumericTable();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::NumericTable >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSource_getNumberOfColumns(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSource *arg1 = (daal::data_management::interface1::DataSource *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSource > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSource > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataSource_getNumberOfColumns",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSource_getNumberOfColumns" "', argument " "1"" of type '" "daal::data_management::interface1::DataSource *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSource > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSource > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSource * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSource > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSource * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSource_getNumberOfColumns" "', argument " "1"" of type '" "daal::data_management::interface1::DataSource *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getNumberOfColumns();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSource_status(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSource *arg1 = (daal::data_management::interface1::DataSource *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSource const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSource const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataSource_status",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSource_status" "', argument " "1"" of type '" "daal::data_management::interface1::DataSource const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataSource > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataSource > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSource * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataSource > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSource * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSource_status" "', argument " "1"" of type '" "daal::data_management::interface1::DataSource const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::DataSource const *)arg1)->status();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSource_getNumericTableNumberOfColumns(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSource *arg1 = (daal::data_management::interface1::DataSource *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSource > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSource > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataSource_getNumericTableNumberOfColumns",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSource_getNumericTableNumberOfColumns" "', argument " "1"" of type '" "daal::data_management::interface1::DataSource *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSource > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSource > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSource * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSource > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSource * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSource_getNumericTableNumberOfColumns" "', argument " "1"" of type '" "daal::data_management::interface1::DataSource *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getNumericTableNumberOfColumns();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *DataSource_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_CsvDataSourceOptions_unite(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CsvDataSourceOptions::Value *arg1 = 0 ;
  daal::data_management::interface1::CsvDataSourceOptions::Value *arg2 = 0 ;
  int val1 ;
  int ecode1 ;
  daal::data_management::interface1::CsvDataSourceOptions::Value temp1 ;
  int val2 ;
  int ecode2 ;
  daal::data_management::interface1::CsvDataSourceOptions::Value temp2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::data_management::interface1::CsvDataSourceOptions::Value result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:CsvDataSourceOptions_unite",&obj0,&obj1)) SWIG_fail;
  ecode1 = SWIG_AsVal_int (obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "CsvDataSourceOptions_unite" "', argument " "1"" of type '" "daal::data_management::interface1::CsvDataSourceOptions::Value const &""'");
  } else {
    temp1 = static_cast< daal::data_management::interface1::CsvDataSourceOptions::Value >(val1);
    arg1 = &temp1;
  }
  ecode2 = SWIG_AsVal_int (obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CsvDataSourceOptions_unite" "', argument " "2"" of type '" "daal::data_management::interface1::CsvDataSourceOptions::Value const &""'");
  } else {
    temp2 = static_cast< daal::data_management::interface1::CsvDataSourceOptions::Value >(val2);
    arg2 = &temp2;
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::CsvDataSourceOptions::Value)daal::data_management::interface1::CsvDataSourceOptions::unite((enum daal::data_management::interface1::CsvDataSourceOptions::Value const &)*arg1,(enum daal::data_management::interface1::CsvDataSourceOptions::Value const &)*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_CsvDataSourceOptions__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CsvDataSourceOptions::Value arg1 ;
  int val1 ;
  int ecode1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::CsvDataSourceOptions *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:new_CsvDataSourceOptions",&obj0)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_CsvDataSourceOptions" "', argument " "1"" of type '" "daal::data_management::interface1::CsvDataSourceOptions::Value""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::CsvDataSourceOptions::Value >(val1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::CsvDataSourceOptions *)new daal::data_management::interface1::CsvDataSourceOptions(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_daal__data_management__interface1__CsvDataSourceOptions, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_CsvDataSourceOptions__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CsvDataSourceOptions *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_CsvDataSourceOptions")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::CsvDataSourceOptions *)new daal::data_management::interface1::CsvDataSourceOptions();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_daal__data_management__interface1__CsvDataSourceOptions, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_CsvDataSourceOptions(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[2];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 1) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_new_CsvDataSourceOptions__SWIG_1(self, args);
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_new_CsvDataSourceOptions__SWIG_0(self, args);
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'new_CsvDataSourceOptions'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::CsvDataSourceOptions::CsvDataSourceOptions(daal::data_management::interface1::CsvDataSourceOptions::Value)\n"
    "    daal::data_management::interface1::CsvDataSourceOptions::CsvDataSourceOptions()\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_CsvDataSourceOptions_getNumericTableAllocationFlag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CsvDataSourceOptions *arg1 = (daal::data_management::interface1::CsvDataSourceOptions *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::DataSource::NumericTableAllocationFlag result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:CsvDataSourceOptions_getNumericTableAllocationFlag",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__interface1__CsvDataSourceOptions, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CsvDataSourceOptions_getNumericTableAllocationFlag" "', argument " "1"" of type '" "daal::data_management::interface1::CsvDataSourceOptions const *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::interface1::CsvDataSourceOptions * >(argp1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::DataSource::NumericTableAllocationFlag)((daal::data_management::interface1::CsvDataSourceOptions const *)arg1)->getNumericTableAllocationFlag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CsvDataSourceOptions_getDictionaryCreationFlag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CsvDataSourceOptions *arg1 = (daal::data_management::interface1::CsvDataSourceOptions *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::DataSource::DictionaryCreationFlag result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:CsvDataSourceOptions_getDictionaryCreationFlag",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__interface1__CsvDataSourceOptions, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CsvDataSourceOptions_getDictionaryCreationFlag" "', argument " "1"" of type '" "daal::data_management::interface1::CsvDataSourceOptions const *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::interface1::CsvDataSourceOptions * >(argp1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::DataSource::DictionaryCreationFlag)((daal::data_management::interface1::CsvDataSourceOptions const *)arg1)->getDictionaryCreationFlag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CsvDataSourceOptions_getParseHeaderFlag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CsvDataSourceOptions *arg1 = (daal::data_management::interface1::CsvDataSourceOptions *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:CsvDataSourceOptions_getParseHeaderFlag",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__interface1__CsvDataSourceOptions, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CsvDataSourceOptions_getParseHeaderFlag" "', argument " "1"" of type '" "daal::data_management::interface1::CsvDataSourceOptions const *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::interface1::CsvDataSourceOptions * >(argp1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (bool)((daal::data_management::interface1::CsvDataSourceOptions const *)arg1)->getParseHeaderFlag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_CsvDataSourceOptions(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CsvDataSourceOptions *arg1 = (daal::data_management::interface1::CsvDataSourceOptions *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_CsvDataSourceOptions",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__interface1__CsvDataSourceOptions, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_CsvDataSourceOptions" "', argument " "1"" of type '" "daal::data_management::interface1::CsvDataSourceOptions *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::interface1::CsvDataSourceOptions * >(argp1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete arg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *CsvDataSourceOptions_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__data_management__interface1__CsvDataSourceOptions, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap___or__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::CsvDataSourceOptions::Value *arg1 = 0 ;
  daal::data_management::CsvDataSourceOptions::Value *arg2 = 0 ;
  int val1 ;
  int ecode1 ;
  daal::data_management::CsvDataSourceOptions::Value temp1 ;
  int val2 ;
  int ecode2 ;
  daal::data_management::CsvDataSourceOptions::Value temp2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::data_management::CsvDataSourceOptions::Value result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:__or__",&obj0,&obj1)) SWIG_fail;
  ecode1 = SWIG_AsVal_int (obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "__or__" "', argument " "1"" of type '" "daal::data_management::CsvDataSourceOptions::Value const &""'");
  } else {
    temp1 = static_cast< daal::data_management::CsvDataSourceOptions::Value >(val1);
    arg1 = &temp1;
  }
  ecode2 = SWIG_AsVal_int (obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "__or__" "', argument " "2"" of type '" "daal::data_management::CsvDataSourceOptions::Value const &""'");
  } else {
    temp2 = static_cast< daal::data_management::CsvDataSourceOptions::Value >(val2);
    arg2 = &temp2;
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::CsvDataSourceOptions::Value)daal::data_management::operator |((enum daal::data_management::interface1::CsvDataSourceOptions::Value const &)*arg1,(enum daal::data_management::interface1::CsvDataSourceOptions::Value const &)*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_FeatureAuxData__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::FeatureAuxData *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_FeatureAuxData")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::FeatureAuxData *)new daal::data_management::FeatureAuxData();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_daal__data_management__FeatureAuxData, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_FeatureAuxData__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::DataSourceFeature *arg2 = (daal::data_management::DataSourceFeature *) 0 ;
  daal::data_management::NumericTableFeature *arg3 = (daal::data_management::NumericTableFeature *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature > tempshared2 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature > *smartarg2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableFeature > tempshared3 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableFeature > *smartarg3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::data_management::FeatureAuxData *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:new_FeatureAuxData",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_FeatureAuxData" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res2) || !argp2) && obj1 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "new_FeatureAuxData" "', argument " "2"" of type '" "daal::data_management::DataSourceFeature *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp2);
      arg2 = const_cast< daal::data_management::DataSourceFeature * >(tempshared2.get());
    } else {
      smartarg2 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp2);
      arg2 = const_cast< daal::data_management::DataSourceFeature * >((smartarg2 ? smartarg2->get() : 0));
    }
    if(!arg2 && obj1 != Py_None) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "new_FeatureAuxData" "', argument " "2"" of type '" "daal::data_management::DataSourceFeature *""'"); 
  }
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res3) || !argp3) && obj2 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "new_FeatureAuxData" "', argument " "3"" of type '" "daal::data_management::NumericTableFeature *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared3 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp3);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp3);
      arg3 = const_cast< daal::data_management::NumericTableFeature * >(tempshared3.get());
    } else {
      smartarg3 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp3);
      arg3 = const_cast< daal::data_management::NumericTableFeature * >((smartarg3 ? smartarg3->get() : 0));
    }
    if(!arg3 && obj2 != Py_None) SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "new_FeatureAuxData" "', argument " "3"" of type '" "daal::data_management::NumericTableFeature *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::FeatureAuxData *)new daal::data_management::FeatureAuxData(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_daal__data_management__FeatureAuxData, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_FeatureAuxData(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[4];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 3) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_new_FeatureAuxData__SWIG_0(self, args);
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_new_FeatureAuxData__SWIG_1(self, args);
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'new_FeatureAuxData'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::FeatureAuxData::FeatureAuxData()\n"
    "    daal::data_management::FeatureAuxData::FeatureAuxData(size_t,daal::data_management::DataSourceFeature *,daal::data_management::NumericTableFeature *)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_FeatureAuxData_idx_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::FeatureAuxData *arg1 = (daal::data_management::FeatureAuxData *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:FeatureAuxData_idx_set",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__FeatureAuxData, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "FeatureAuxData_idx_set" "', argument " "1"" of type '" "daal::data_management::FeatureAuxData *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::FeatureAuxData * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "FeatureAuxData_idx_set" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    if (arg1) (arg1)->idx = arg2;
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_FeatureAuxData_idx_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::FeatureAuxData *arg1 = (daal::data_management::FeatureAuxData *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:FeatureAuxData_idx_get",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__FeatureAuxData, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "FeatureAuxData_idx_get" "', argument " "1"" of type '" "daal::data_management::FeatureAuxData *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::FeatureAuxData * >(argp1);
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    result =  ((arg1)->idx);
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_FeatureAuxData_wide_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::FeatureAuxData *arg1 = (daal::data_management::FeatureAuxData *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:FeatureAuxData_wide_set",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__FeatureAuxData, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "FeatureAuxData_wide_set" "', argument " "1"" of type '" "daal::data_management::FeatureAuxData *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::FeatureAuxData * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "FeatureAuxData_wide_set" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    if (arg1) (arg1)->wide = arg2;
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_FeatureAuxData_wide_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::FeatureAuxData *arg1 = (daal::data_management::FeatureAuxData *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:FeatureAuxData_wide_get",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__FeatureAuxData, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "FeatureAuxData_wide_get" "', argument " "1"" of type '" "daal::data_management::FeatureAuxData *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::FeatureAuxData * >(argp1);
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    result =  ((arg1)->wide);
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_FeatureAuxData_nCats_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::FeatureAuxData *arg1 = (daal::data_management::FeatureAuxData *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:FeatureAuxData_nCats_set",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__FeatureAuxData, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "FeatureAuxData_nCats_set" "', argument " "1"" of type '" "daal::data_management::FeatureAuxData *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::FeatureAuxData * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "FeatureAuxData_nCats_set" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    if (arg1) (arg1)->nCats = arg2;
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_FeatureAuxData_nCats_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::FeatureAuxData *arg1 = (daal::data_management::FeatureAuxData *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:FeatureAuxData_nCats_get",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__FeatureAuxData, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "FeatureAuxData_nCats_get" "', argument " "1"" of type '" "daal::data_management::FeatureAuxData *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::FeatureAuxData * >(argp1);
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    result =  ((arg1)->nCats);
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_FeatureAuxData_dsFeat_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::FeatureAuxData *arg1 = (daal::data_management::FeatureAuxData *) 0 ;
  daal::data_management::DataSourceFeature *arg2 = (daal::data_management::DataSourceFeature *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature > tempshared2 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature > *smartarg2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:FeatureAuxData_dsFeat_set",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__FeatureAuxData, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "FeatureAuxData_dsFeat_set" "', argument " "1"" of type '" "daal::data_management::FeatureAuxData *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::FeatureAuxData * >(argp1);
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res2) || !argp2) && obj1 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "FeatureAuxData_dsFeat_set" "', argument " "2"" of type '" "daal::data_management::DataSourceFeature *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp2);
      arg2 = const_cast< daal::data_management::DataSourceFeature * >(tempshared2.get());
    } else {
      smartarg2 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp2);
      arg2 = const_cast< daal::data_management::DataSourceFeature * >((smartarg2 ? smartarg2->get() : 0));
    }
    if(!arg2 && obj1 != Py_None) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "FeatureAuxData_dsFeat_set" "', argument " "2"" of type '" "daal::data_management::DataSourceFeature *""'"); 
  }
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    if (arg1) (arg1)->dsFeat = arg2;
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_FeatureAuxData_dsFeat_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::FeatureAuxData *arg1 = (daal::data_management::FeatureAuxData *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::DataSourceFeature *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:FeatureAuxData_dsFeat_get",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__FeatureAuxData, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "FeatureAuxData_dsFeat_get" "', argument " "1"" of type '" "daal::data_management::FeatureAuxData *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::FeatureAuxData * >(argp1);
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    result = (daal::data_management::DataSourceFeature *) ((arg1)->dsFeat);
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature >(result SWIG_NO_NULL_DELETER_0) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t, 0 | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_FeatureAuxData_ntFeat_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::FeatureAuxData *arg1 = (daal::data_management::FeatureAuxData *) 0 ;
  daal::data_management::NumericTableFeature *arg2 = (daal::data_management::NumericTableFeature *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableFeature > tempshared2 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableFeature > *smartarg2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:FeatureAuxData_ntFeat_set",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__FeatureAuxData, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "FeatureAuxData_ntFeat_set" "', argument " "1"" of type '" "daal::data_management::FeatureAuxData *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::FeatureAuxData * >(argp1);
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res2) || !argp2) && obj1 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "FeatureAuxData_ntFeat_set" "', argument " "2"" of type '" "daal::data_management::NumericTableFeature *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp2);
      arg2 = const_cast< daal::data_management::NumericTableFeature * >(tempshared2.get());
    } else {
      smartarg2 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp2);
      arg2 = const_cast< daal::data_management::NumericTableFeature * >((smartarg2 ? smartarg2->get() : 0));
    }
    if(!arg2 && obj1 != Py_None) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "FeatureAuxData_ntFeat_set" "', argument " "2"" of type '" "daal::data_management::NumericTableFeature *""'"); 
  }
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    if (arg1) (arg1)->ntFeat = arg2;
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_FeatureAuxData_ntFeat_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::FeatureAuxData *arg1 = (daal::data_management::FeatureAuxData *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::NumericTableFeature *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:FeatureAuxData_ntFeat_get",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__FeatureAuxData, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "FeatureAuxData_ntFeat_get" "', argument " "1"" of type '" "daal::data_management::FeatureAuxData *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::FeatureAuxData * >(argp1);
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    result = (daal::data_management::NumericTableFeature *) ((arg1)->ntFeat);
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature >(result SWIG_NO_NULL_DELETER_0) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_t, 0 | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_FeatureAuxData_buffer_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::FeatureAuxData *arg1 = (daal::data_management::FeatureAuxData *) 0 ;
  std::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:FeatureAuxData_buffer_set",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__FeatureAuxData, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "FeatureAuxData_buffer_set" "', argument " "1"" of type '" "daal::data_management::FeatureAuxData *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::FeatureAuxData * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(obj1, &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "FeatureAuxData_buffer_set" "', argument " "2"" of type '" "std::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "FeatureAuxData_buffer_set" "', argument " "2"" of type '" "std::string const &""'"); 
    }
    arg2 = ptr;
  }
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    if (arg1) (arg1)->buffer = *arg2;
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_FeatureAuxData_buffer_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::FeatureAuxData *arg1 = (daal::data_management::FeatureAuxData *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  std::string *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:FeatureAuxData_buffer_get",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__FeatureAuxData, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "FeatureAuxData_buffer_get" "', argument " "1"" of type '" "daal::data_management::FeatureAuxData *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::FeatureAuxData * >(argp1);
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    result = (std::string *) & ((arg1)->buffer);
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_FeatureAuxData(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::FeatureAuxData *arg1 = (daal::data_management::FeatureAuxData *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_FeatureAuxData",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__FeatureAuxData, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_FeatureAuxData" "', argument " "1"" of type '" "daal::data_management::FeatureAuxData *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::FeatureAuxData * >(argp1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete arg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *FeatureAuxData_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__data_management__FeatureAuxData, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_ModifierIface_apply(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::ModifierIface *arg1 = (daal::data_management::ModifierIface *) 0 ;
  daal::services::Collection< daal::data_management::functionT > *arg2 = 0 ;
  daal::services::Collection< daal::data_management::FeatureAuxData > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:ModifierIface_apply",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__ModifierIface, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ModifierIface_apply" "', argument " "1"" of type '" "daal::data_management::ModifierIface const *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::ModifierIface * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_daal__services__CollectionT_void_fpFfchar_const_p_daal__data_management__FeatureAuxData_R_double_pF_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "ModifierIface_apply" "', argument " "2"" of type '" "daal::services::Collection< daal::data_management::functionT > &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ModifierIface_apply" "', argument " "2"" of type '" "daal::services::Collection< daal::data_management::functionT > &""'"); 
  }
  arg2 = reinterpret_cast< daal::services::Collection< daal::data_management::functionT > * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_daal__services__CollectionT_daal__data_management__FeatureAuxData_t,  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "ModifierIface_apply" "', argument " "3"" of type '" "daal::services::Collection< daal::data_management::FeatureAuxData > &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ModifierIface_apply" "', argument " "3"" of type '" "daal::services::Collection< daal::data_management::FeatureAuxData > &""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Collection< daal::data_management::FeatureAuxData > * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        ((daal::data_management::ModifierIface const *)arg1)->apply(*arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_ModifierIface(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::ModifierIface *arg1 = (daal::data_management::ModifierIface *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_ModifierIface",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__ModifierIface, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_ModifierIface" "', argument " "1"" of type '" "daal::data_management::ModifierIface *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::ModifierIface * >(argp1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete arg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ModifierIface_contFunc(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  char *arg1 = (char *) 0 ;
  daal::data_management::FeatureAuxData *arg2 = 0 ;
  double *arg3 = (double *) 0 ;
  int res1 ;
  char *buf1 = 0 ;
  int alloc1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:ModifierIface_contFunc",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_AsCharPtrAndSize(obj0, &buf1, NULL, &alloc1);
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ModifierIface_contFunc" "', argument " "1"" of type '" "char const *""'");
  }
  arg1 = reinterpret_cast< char * >(buf1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_daal__data_management__FeatureAuxData,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "ModifierIface_contFunc" "', argument " "2"" of type '" "daal::data_management::FeatureAuxData &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ModifierIface_contFunc" "', argument " "2"" of type '" "daal::data_management::FeatureAuxData &""'"); 
  }
  arg2 = reinterpret_cast< daal::data_management::FeatureAuxData * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_double, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "ModifierIface_contFunc" "', argument " "3"" of type '" "double *""'"); 
  }
  arg3 = reinterpret_cast< double * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        daal::data_management::ModifierIface::contFunc((char const *)arg1,*arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  if (alloc1 == SWIG_NEWOBJ) delete[] buf1;
  return resultobj;
fail:
  if (alloc1 == SWIG_NEWOBJ) delete[] buf1;
  return NULL;
}


SWIGINTERN PyObject *_wrap_ModifierIface_catFunc(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  char *arg1 = (char *) 0 ;
  daal::data_management::FeatureAuxData *arg2 = 0 ;
  double *arg3 = (double *) 0 ;
  int res1 ;
  char *buf1 = 0 ;
  int alloc1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:ModifierIface_catFunc",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_AsCharPtrAndSize(obj0, &buf1, NULL, &alloc1);
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ModifierIface_catFunc" "', argument " "1"" of type '" "char const *""'");
  }
  arg1 = reinterpret_cast< char * >(buf1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_daal__data_management__FeatureAuxData,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "ModifierIface_catFunc" "', argument " "2"" of type '" "daal::data_management::FeatureAuxData &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ModifierIface_catFunc" "', argument " "2"" of type '" "daal::data_management::FeatureAuxData &""'"); 
  }
  arg2 = reinterpret_cast< daal::data_management::FeatureAuxData * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_double, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "ModifierIface_catFunc" "', argument " "3"" of type '" "double *""'"); 
  }
  arg3 = reinterpret_cast< double * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        daal::data_management::ModifierIface::catFunc((char const *)arg1,*arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  if (alloc1 == SWIG_NEWOBJ) delete[] buf1;
  return resultobj;
fail:
  if (alloc1 == SWIG_NEWOBJ) delete[] buf1;
  return NULL;
}


SWIGINTERN PyObject *_wrap_ModifierIface_nullFunc(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  char *arg1 = (char *) 0 ;
  daal::data_management::FeatureAuxData *arg2 = 0 ;
  double *arg3 = (double *) 0 ;
  int res1 ;
  char *buf1 = 0 ;
  int alloc1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:ModifierIface_nullFunc",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_AsCharPtrAndSize(obj0, &buf1, NULL, &alloc1);
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ModifierIface_nullFunc" "', argument " "1"" of type '" "char const *""'");
  }
  arg1 = reinterpret_cast< char * >(buf1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_daal__data_management__FeatureAuxData,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "ModifierIface_nullFunc" "', argument " "2"" of type '" "daal::data_management::FeatureAuxData &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ModifierIface_nullFunc" "', argument " "2"" of type '" "daal::data_management::FeatureAuxData &""'"); 
  }
  arg2 = reinterpret_cast< daal::data_management::FeatureAuxData * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_double, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "ModifierIface_nullFunc" "', argument " "3"" of type '" "double *""'"); 
  }
  arg3 = reinterpret_cast< double * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        daal::data_management::ModifierIface::nullFunc((char const *)arg1,*arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  if (alloc1 == SWIG_NEWOBJ) delete[] buf1;
  return resultobj;
fail:
  if (alloc1 == SWIG_NEWOBJ) delete[] buf1;
  return NULL;
}


SWIGINTERN PyObject *ModifierIface_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__data_management__ModifierIface, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_MakeCategorical(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t val1 ;
  int ecode1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::MakeCategorical *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:new_MakeCategorical",&obj0)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_MakeCategorical" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::MakeCategorical *)new daal::data_management::MakeCategorical(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_daal__data_management__MakeCategorical, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_MakeCategorical(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::MakeCategorical *arg1 = (daal::data_management::MakeCategorical *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_MakeCategorical",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__MakeCategorical, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_MakeCategorical" "', argument " "1"" of type '" "daal::data_management::MakeCategorical *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::MakeCategorical * >(argp1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete arg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MakeCategorical_apply(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::MakeCategorical *arg1 = (daal::data_management::MakeCategorical *) 0 ;
  daal::services::Collection< daal::data_management::functionT > *arg2 = 0 ;
  daal::services::Collection< daal::data_management::FeatureAuxData > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:MakeCategorical_apply",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__MakeCategorical, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MakeCategorical_apply" "', argument " "1"" of type '" "daal::data_management::MakeCategorical const *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::MakeCategorical * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_daal__services__CollectionT_void_fpFfchar_const_p_daal__data_management__FeatureAuxData_R_double_pF_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "MakeCategorical_apply" "', argument " "2"" of type '" "daal::services::Collection< daal::data_management::functionT > &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "MakeCategorical_apply" "', argument " "2"" of type '" "daal::services::Collection< daal::data_management::functionT > &""'"); 
  }
  arg2 = reinterpret_cast< daal::services::Collection< daal::data_management::functionT > * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_daal__services__CollectionT_daal__data_management__FeatureAuxData_t,  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "MakeCategorical_apply" "', argument " "3"" of type '" "daal::services::Collection< daal::data_management::FeatureAuxData > &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "MakeCategorical_apply" "', argument " "3"" of type '" "daal::services::Collection< daal::data_management::FeatureAuxData > &""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Collection< daal::data_management::FeatureAuxData > * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        ((daal::data_management::MakeCategorical const *)arg1)->apply(*arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *MakeCategorical_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__data_management__MakeCategorical, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_OneHotEncoder(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::data_management::OneHotEncoder *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:new_OneHotEncoder",&obj0,&obj1)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_OneHotEncoder" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "new_OneHotEncoder" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::OneHotEncoder *)new daal::data_management::OneHotEncoder(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_daal__data_management__OneHotEncoder, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_OneHotEncoder(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::OneHotEncoder *arg1 = (daal::data_management::OneHotEncoder *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_OneHotEncoder",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__OneHotEncoder, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_OneHotEncoder" "', argument " "1"" of type '" "daal::data_management::OneHotEncoder *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::OneHotEncoder * >(argp1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete arg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OneHotEncoder_apply(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::OneHotEncoder *arg1 = (daal::data_management::OneHotEncoder *) 0 ;
  daal::services::Collection< daal::data_management::functionT > *arg2 = 0 ;
  daal::services::Collection< daal::data_management::FeatureAuxData > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:OneHotEncoder_apply",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__OneHotEncoder, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OneHotEncoder_apply" "', argument " "1"" of type '" "daal::data_management::OneHotEncoder const *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::OneHotEncoder * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_daal__services__CollectionT_void_fpFfchar_const_p_daal__data_management__FeatureAuxData_R_double_pF_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OneHotEncoder_apply" "', argument " "2"" of type '" "daal::services::Collection< daal::data_management::functionT > &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "OneHotEncoder_apply" "', argument " "2"" of type '" "daal::services::Collection< daal::data_management::functionT > &""'"); 
  }
  arg2 = reinterpret_cast< daal::services::Collection< daal::data_management::functionT > * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_daal__services__CollectionT_daal__data_management__FeatureAuxData_t,  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "OneHotEncoder_apply" "', argument " "3"" of type '" "daal::services::Collection< daal::data_management::FeatureAuxData > &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "OneHotEncoder_apply" "', argument " "3"" of type '" "daal::services::Collection< daal::data_management::FeatureAuxData > &""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Collection< daal::data_management::FeatureAuxData > * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        ((daal::data_management::OneHotEncoder const *)arg1)->apply(*arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *OneHotEncoder_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__data_management__OneHotEncoder, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_ColumnFilter(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::ColumnFilter *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_ColumnFilter")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::ColumnFilter *)new daal::data_management::ColumnFilter();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_daal__data_management__ColumnFilter, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_ColumnFilter(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::ColumnFilter *arg1 = (daal::data_management::ColumnFilter *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_ColumnFilter",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__ColumnFilter, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_ColumnFilter" "', argument " "1"" of type '" "daal::data_management::ColumnFilter *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::ColumnFilter * >(argp1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete arg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ColumnFilter_odd(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::ColumnFilter *arg1 = (daal::data_management::ColumnFilter *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::ColumnFilter *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:ColumnFilter_odd",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__ColumnFilter, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ColumnFilter_odd" "', argument " "1"" of type '" "daal::data_management::ColumnFilter *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::ColumnFilter * >(argp1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::ColumnFilter *) &(arg1)->odd();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_daal__data_management__ColumnFilter, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ColumnFilter_even(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::ColumnFilter *arg1 = (daal::data_management::ColumnFilter *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::ColumnFilter *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:ColumnFilter_even",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__ColumnFilter, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ColumnFilter_even" "', argument " "1"" of type '" "daal::data_management::ColumnFilter *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::ColumnFilter * >(argp1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::ColumnFilter *) &(arg1)->even();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_daal__data_management__ColumnFilter, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ColumnFilter_none(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::ColumnFilter *arg1 = (daal::data_management::ColumnFilter *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::ColumnFilter *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:ColumnFilter_none",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__ColumnFilter, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ColumnFilter_none" "', argument " "1"" of type '" "daal::data_management::ColumnFilter *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::ColumnFilter * >(argp1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::ColumnFilter *) &(arg1)->none();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_daal__data_management__ColumnFilter, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ColumnFilter_list(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::ColumnFilter *arg1 = (daal::data_management::ColumnFilter *) 0 ;
  daal::services::Collection< size_t > arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::data_management::ColumnFilter *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:ColumnFilter_list",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__ColumnFilter, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ColumnFilter_list" "', argument " "1"" of type '" "daal::data_management::ColumnFilter *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::ColumnFilter * >(argp1);
  {
    if(!PyList_Check(obj1)) {
      SWIG_fail;
    }
    
    Py_ssize_t length = PyList_Size(obj1);
    (&arg2)->resize(length);
    
    for(Py_ssize_t i = 0; i < length; i++) {
      (&arg2)->push_back(PyLong_AsUnsignedLong(PyList_GetItem(obj1, i)));
    }
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::ColumnFilter *) &(arg1)->list(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_daal__data_management__ColumnFilter, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ColumnFilter_apply(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::ColumnFilter *arg1 = (daal::data_management::ColumnFilter *) 0 ;
  daal::services::Collection< daal::data_management::functionT > *arg2 = 0 ;
  daal::services::Collection< daal::data_management::FeatureAuxData > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:ColumnFilter_apply",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__data_management__ColumnFilter, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ColumnFilter_apply" "', argument " "1"" of type '" "daal::data_management::ColumnFilter const *""'"); 
  }
  arg1 = reinterpret_cast< daal::data_management::ColumnFilter * >(argp1);
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_daal__services__CollectionT_void_fpFfchar_const_p_daal__data_management__FeatureAuxData_R_double_pF_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "ColumnFilter_apply" "', argument " "2"" of type '" "daal::services::Collection< daal::data_management::functionT > &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ColumnFilter_apply" "', argument " "2"" of type '" "daal::services::Collection< daal::data_management::functionT > &""'"); 
  }
  arg2 = reinterpret_cast< daal::services::Collection< daal::data_management::functionT > * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_daal__services__CollectionT_daal__data_management__FeatureAuxData_t,  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "ColumnFilter_apply" "', argument " "3"" of type '" "daal::services::Collection< daal::data_management::FeatureAuxData > &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ColumnFilter_apply" "', argument " "3"" of type '" "daal::services::Collection< daal::data_management::FeatureAuxData > &""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Collection< daal::data_management::FeatureAuxData > * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        ((daal::data_management::ColumnFilter const *)arg1)->apply(*arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *ColumnFilter_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__data_management__ColumnFilter, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_CSVFeatureManager(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSVFeatureManager *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_CSVFeatureManager")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::CSVFeatureManager *)new daal::data_management::interface1::CSVFeatureManager();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::CSVFeatureManager > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::CSVFeatureManager >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSVFeatureManager_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_CSVFeatureManager(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSVFeatureManager *arg1 = (daal::data_management::interface1::CSVFeatureManager *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSVFeatureManager > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSVFeatureManager > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_CSVFeatureManager",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSVFeatureManager_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_CSVFeatureManager" "', argument " "1"" of type '" "daal::data_management::interface1::CSVFeatureManager *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSVFeatureManager > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSVFeatureManager > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSVFeatureManager * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSVFeatureManager > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSVFeatureManager * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_CSVFeatureManager" "', argument " "1"" of type '" "daal::data_management::interface1::CSVFeatureManager *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSVFeatureManager_setDelimiter(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSVFeatureManager *arg1 = (daal::data_management::interface1::CSVFeatureManager *) 0 ;
  char arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSVFeatureManager > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSVFeatureManager > *smartarg1 = 0 ;
  char val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:CSVFeatureManager_setDelimiter",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSVFeatureManager_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSVFeatureManager_setDelimiter" "', argument " "1"" of type '" "daal::data_management::interface1::CSVFeatureManager *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSVFeatureManager > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSVFeatureManager > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSVFeatureManager * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSVFeatureManager > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSVFeatureManager * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSVFeatureManager_setDelimiter" "', argument " "1"" of type '" "daal::data_management::interface1::CSVFeatureManager *""'"); 
  }
  ecode2 = SWIG_AsVal_char(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CSVFeatureManager_setDelimiter" "', argument " "2"" of type '" "char""'");
  } 
  arg2 = static_cast< char >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->setDelimiter(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSVFeatureManager_getNumericTableNumberOfColumns(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSVFeatureManager *arg1 = (daal::data_management::interface1::CSVFeatureManager *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSVFeatureManager const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSVFeatureManager const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:CSVFeatureManager_getNumericTableNumberOfColumns",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSVFeatureManager_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSVFeatureManager_getNumericTableNumberOfColumns" "', argument " "1"" of type '" "daal::data_management::interface1::CSVFeatureManager const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSVFeatureManager > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSVFeatureManager > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSVFeatureManager * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSVFeatureManager > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSVFeatureManager * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSVFeatureManager_getNumericTableNumberOfColumns" "', argument " "1"" of type '" "daal::data_management::interface1::CSVFeatureManager const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::CSVFeatureManager const *)arg1)->getNumericTableNumberOfColumns();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSVFeatureManager_setFeatureDetailsFromDictionary(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSVFeatureManager *arg1 = (daal::data_management::interface1::CSVFeatureManager *) 0 ;
  daal::data_management::interface1::DataSourceDictionary *arg2 = (daal::data_management::interface1::DataSourceDictionary *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSVFeatureManager > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSVFeatureManager > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > > tempshared2 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > > *smartarg2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:CSVFeatureManager_setFeatureDetailsFromDictionary",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSVFeatureManager_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSVFeatureManager_setFeatureDetailsFromDictionary" "', argument " "1"" of type '" "daal::data_management::interface1::CSVFeatureManager *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSVFeatureManager > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSVFeatureManager > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSVFeatureManager * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSVFeatureManager > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSVFeatureManager * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSVFeatureManager_setFeatureDetailsFromDictionary" "', argument " "1"" of type '" "daal::data_management::interface1::CSVFeatureManager *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res2) || !argp2) && obj1 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CSVFeatureManager_setFeatureDetailsFromDictionary" "', argument " "2"" of type '" "daal::data_management::interface1::DataSourceDictionary *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::DataSourceDictionary * >(tempshared2.get());
    } else {
      smartarg2 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::DataSourceDictionary * >((smartarg2 ? smartarg2->get() : 0));
    }
    if(!arg2 && obj1 != Py_None) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CSVFeatureManager_setFeatureDetailsFromDictionary" "', argument " "2"" of type '" "daal::data_management::interface1::DataSourceDictionary *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->setFeatureDetailsFromDictionary(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSVFeatureManager_addModifier__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSVFeatureManager *arg1 = (daal::data_management::interface1::CSVFeatureManager *) 0 ;
  daal::data_management::ModifierIface *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSVFeatureManager > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSVFeatureManager > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:CSVFeatureManager_addModifier",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSVFeatureManager_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSVFeatureManager_addModifier" "', argument " "1"" of type '" "daal::data_management::interface1::CSVFeatureManager *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSVFeatureManager > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSVFeatureManager > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSVFeatureManager * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSVFeatureManager > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSVFeatureManager * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSVFeatureManager_addModifier" "', argument " "1"" of type '" "daal::data_management::interface1::CSVFeatureManager *""'"); 
  }
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_daal__data_management__ModifierIface,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CSVFeatureManager_addModifier" "', argument " "2"" of type '" "daal::data_management::ModifierIface const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CSVFeatureManager_addModifier" "', argument " "2"" of type '" "daal::data_management::ModifierIface const &""'"); 
  }
  arg2 = reinterpret_cast< daal::data_management::ModifierIface * >(argp2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->addModifier((daal::data_management::ModifierIface const &)*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSVFeatureManager_addModifier__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSVFeatureManager *arg1 = (daal::data_management::interface1::CSVFeatureManager *) 0 ;
  daal::data_management::features::FeatureIdCollectionIfacePtr *arg2 = 0 ;
  daal::data_management::modifiers::csv::FeatureModifierIfacePtr *arg3 = 0 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSVFeatureManager > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSVFeatureManager > *smartarg1 = 0 ;
  daal::data_management::features::internal::FeatureIdListPtr tmp_list2 = daal::data_management::features::internal::FeatureIdList::create() ;
  daal::data_management::features::FeatureIdCollectionIfacePtr tmp_coll2 ;
  void *argp3 ;
  int res3 = 0 ;
  daal::data_management::modifiers::csv::FeatureModifierIfacePtr tempshared3 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::data_management::interface1::CSVFeatureManager *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:CSVFeatureManager_addModifier",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSVFeatureManager_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSVFeatureManager_addModifier" "', argument " "1"" of type '" "daal::data_management::interface1::CSVFeatureManager *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSVFeatureManager > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSVFeatureManager > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSVFeatureManager * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSVFeatureManager > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSVFeatureManager * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSVFeatureManager_addModifier" "', argument " "1"" of type '" "daal::data_management::interface1::CSVFeatureManager *""'"); 
  }
  {
    Py_ssize_t n = PySequence_Length(obj1);
    for(Py_ssize_t i = 0; i< n; ++i) {
      PyObject * v = PySequence_GetItem(obj1, i);
      if(PyInt_Check(v)) {
        tmp_list2->add(daal::data_management::features::IdFactory(PyLong_AsLong(v)).get());
      } else if(CHECK_STRING(v)) {
        tmp_list2->add(daal::data_management::features::IdFactory(GET_STRING(v)).get());
      } else {
        SWIG_fail;
      }
    }
    tmp_coll2 = tmp_list2;
    arg2 = &tmp_coll2;
  }
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifierIface_t,  0 , &newmem);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "CSVFeatureManager_addModifier" "', argument " "3"" of type '" "daal::data_management::modifiers::csv::FeatureModifierIfacePtr const &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      if (argp3) tempshared3 = *reinterpret_cast< daal::data_management::modifiers::csv::FeatureModifierIfacePtr * >(argp3);
      delete reinterpret_cast< daal::data_management::modifiers::csv::FeatureModifierIfacePtr * >(argp3);
      arg3 = &tempshared3;
    } else {
      arg3 = (argp3) ? reinterpret_cast< daal::data_management::modifiers::csv::FeatureModifierIfacePtr * >(argp3) : &tempshared3;
    }
  }
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "CSVFeatureManager_addModifier" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::CSVFeatureManager *) &(arg1)->addModifier((daal::data_management::features::FeatureIdCollectionIfacePtr const &)*arg2,(daal::data_management::modifiers::csv::FeatureModifierIfacePtr const &)*arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::CSVFeatureManager > *smartresult = new daal::services::SharedPtr<  daal::data_management::interface1::CSVFeatureManager >(result SWIG_NO_NULL_DELETER_0);
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSVFeatureManager_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSVFeatureManager_addModifier__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSVFeatureManager *arg1 = (daal::data_management::interface1::CSVFeatureManager *) 0 ;
  daal::data_management::features::FeatureIdCollectionIfacePtr *arg2 = 0 ;
  daal::data_management::modifiers::csv::FeatureModifierIfacePtr *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSVFeatureManager > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSVFeatureManager > *smartarg1 = 0 ;
  daal::data_management::features::internal::FeatureIdListPtr tmp_list2 = daal::data_management::features::internal::FeatureIdList::create() ;
  daal::data_management::features::FeatureIdCollectionIfacePtr tmp_coll2 ;
  void *argp3 ;
  int res3 = 0 ;
  daal::data_management::modifiers::csv::FeatureModifierIfacePtr tempshared3 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::data_management::interface1::CSVFeatureManager *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:CSVFeatureManager_addModifier",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSVFeatureManager_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSVFeatureManager_addModifier" "', argument " "1"" of type '" "daal::data_management::interface1::CSVFeatureManager *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSVFeatureManager > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSVFeatureManager > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSVFeatureManager * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSVFeatureManager > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSVFeatureManager * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSVFeatureManager_addModifier" "', argument " "1"" of type '" "daal::data_management::interface1::CSVFeatureManager *""'"); 
  }
  {
    Py_ssize_t n = PySequence_Length(obj1);
    for(Py_ssize_t i = 0; i< n; ++i) {
      PyObject * v = PySequence_GetItem(obj1, i);
      if(PyInt_Check(v)) {
        tmp_list2->add(daal::data_management::features::IdFactory(PyLong_AsLong(v)).get());
      } else if(CHECK_STRING(v)) {
        tmp_list2->add(daal::data_management::features::IdFactory(GET_STRING(v)).get());
      } else {
        SWIG_fail;
      }
    }
    tmp_coll2 = tmp_list2;
    arg2 = &tmp_coll2;
  }
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifierIface_t,  0 , &newmem);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "CSVFeatureManager_addModifier" "', argument " "3"" of type '" "daal::data_management::modifiers::csv::FeatureModifierIfacePtr const &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      if (argp3) tempshared3 = *reinterpret_cast< daal::data_management::modifiers::csv::FeatureModifierIfacePtr * >(argp3);
      delete reinterpret_cast< daal::data_management::modifiers::csv::FeatureModifierIfacePtr * >(argp3);
      arg3 = &tempshared3;
    } else {
      arg3 = (argp3) ? reinterpret_cast< daal::data_management::modifiers::csv::FeatureModifierIfacePtr * >(argp3) : &tempshared3;
    }
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::CSVFeatureManager *) &(arg1)->addModifier((daal::data_management::features::FeatureIdCollectionIfacePtr const &)*arg2,(daal::data_management::modifiers::csv::FeatureModifierIfacePtr const &)*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::CSVFeatureManager > *smartresult = new daal::services::SharedPtr<  daal::data_management::interface1::CSVFeatureManager >(result SWIG_NO_NULL_DELETER_0);
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSVFeatureManager_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSVFeatureManager_addModifier(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[5];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 4) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSVFeatureManager_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__data_management__ModifierIface, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_CSVFeatureManager_addModifier__SWIG_0(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSVFeatureManager_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        // we accept a sequence but not string, unicode
        _v = (PySequence_Check(argv[1]) && !CHECK_STRING(argv[1]));
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifierIface_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_CSVFeatureManager_addModifier__SWIG_2(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSVFeatureManager_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        // we accept a sequence but not string, unicode
        _v = (PySequence_Check(argv[1]) && !CHECK_STRING(argv[1]));
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifierIface_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_CSVFeatureManager_addModifier__SWIG_1(self, args);
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'CSVFeatureManager_addModifier'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::CSVFeatureManager::addModifier(daal::data_management::ModifierIface const &)\n"
    "    daal::data_management::interface1::CSVFeatureManager::addModifier(daal::data_management::features::FeatureIdCollectionIfacePtr const &,daal::data_management::modifiers::csv::FeatureModifierIfacePtr const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::CSVFeatureManager::addModifier(daal::data_management::features::FeatureIdCollectionIfacePtr const &,daal::data_management::modifiers::csv::FeatureModifierIfacePtr const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_CSVFeatureManager_parseRowAsHeader(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSVFeatureManager *arg1 = (daal::data_management::interface1::CSVFeatureManager *) 0 ;
  char *arg2 = (char *) 0 ;
  size_t arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSVFeatureManager > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSVFeatureManager > *smartarg1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  size_t size2 = 0 ;
  int alloc2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:CSVFeatureManager_parseRowAsHeader",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSVFeatureManager_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSVFeatureManager_parseRowAsHeader" "', argument " "1"" of type '" "daal::data_management::interface1::CSVFeatureManager *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSVFeatureManager > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSVFeatureManager > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSVFeatureManager * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSVFeatureManager > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSVFeatureManager * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSVFeatureManager_parseRowAsHeader" "', argument " "1"" of type '" "daal::data_management::interface1::CSVFeatureManager *""'"); 
  }
  res2 = SWIG_AsCharPtrAndSize(obj1, &buf2, &size2, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CSVFeatureManager_parseRowAsHeader" "', argument " "2"" of type '" "char *""'");
  }  
  arg2 = reinterpret_cast< char * >(buf2);
  arg3 = static_cast< size_t >(size2 - 1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->parseRowAsHeader(arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSVFeatureManager_parseRowAsDictionary(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSVFeatureManager *arg1 = (daal::data_management::interface1::CSVFeatureManager *) 0 ;
  char *arg2 = (char *) 0 ;
  size_t arg3 ;
  daal::data_management::interface1::DataSourceDictionary *arg4 = (daal::data_management::interface1::DataSourceDictionary *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSVFeatureManager > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSVFeatureManager > *smartarg1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  size_t size2 = 0 ;
  int alloc2 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > > tempshared4 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > > *smartarg4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:CSVFeatureManager_parseRowAsDictionary",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSVFeatureManager_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSVFeatureManager_parseRowAsDictionary" "', argument " "1"" of type '" "daal::data_management::interface1::CSVFeatureManager *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSVFeatureManager > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSVFeatureManager > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSVFeatureManager * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSVFeatureManager > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSVFeatureManager * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSVFeatureManager_parseRowAsDictionary" "', argument " "1"" of type '" "daal::data_management::interface1::CSVFeatureManager *""'"); 
  }
  res2 = SWIG_AsCharPtrAndSize(obj1, &buf2, &size2, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CSVFeatureManager_parseRowAsDictionary" "', argument " "2"" of type '" "char *""'");
  }  
  arg2 = reinterpret_cast< char * >(buf2);
  arg3 = static_cast< size_t >(size2 - 1);
  {
    int newmem = 0;
    res4 = SWIG_ConvertPtrAndOwn(obj2, &argp4, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res4) || !argp4) && obj2 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "CSVFeatureManager_parseRowAsDictionary" "', argument " "4"" of type '" "daal::data_management::interface1::DataSourceDictionary *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared4 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp4);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp4);
      arg4 = const_cast< daal::data_management::interface1::DataSourceDictionary * >(tempshared4.get());
    } else {
      smartarg4 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp4);
      arg4 = const_cast< daal::data_management::interface1::DataSourceDictionary * >((smartarg4 ? smartarg4->get() : 0));
    }
    if(!arg4 && obj2 != Py_None) SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "CSVFeatureManager_parseRowAsDictionary" "', argument " "4"" of type '" "daal::data_management::interface1::DataSourceDictionary *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->parseRowAsDictionary(arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSVFeatureManager_parseRowIn(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSVFeatureManager *arg1 = (daal::data_management::interface1::CSVFeatureManager *) 0 ;
  char *arg2 = (char *) 0 ;
  size_t arg3 ;
  daal::data_management::interface1::DataSourceDictionary *arg4 = (daal::data_management::interface1::DataSourceDictionary *) 0 ;
  daal::data_management::interface1::NumericTable *arg5 = (daal::data_management::interface1::NumericTable *) 0 ;
  size_t arg6 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSVFeatureManager > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSVFeatureManager > *smartarg1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  size_t size2 = 0 ;
  int alloc2 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > > tempshared4 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > > *smartarg4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > tempshared5 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > *smartarg5 = 0 ;
  size_t val6 ;
  int ecode6 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:CSVFeatureManager_parseRowIn",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSVFeatureManager_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSVFeatureManager_parseRowIn" "', argument " "1"" of type '" "daal::data_management::interface1::CSVFeatureManager *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSVFeatureManager > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSVFeatureManager > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSVFeatureManager * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSVFeatureManager > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSVFeatureManager * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSVFeatureManager_parseRowIn" "', argument " "1"" of type '" "daal::data_management::interface1::CSVFeatureManager *""'"); 
  }
  res2 = SWIG_AsCharPtrAndSize(obj1, &buf2, &size2, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CSVFeatureManager_parseRowIn" "', argument " "2"" of type '" "char *""'");
  }  
  arg2 = reinterpret_cast< char * >(buf2);
  arg3 = static_cast< size_t >(size2 - 1);
  {
    int newmem = 0;
    res4 = SWIG_ConvertPtrAndOwn(obj2, &argp4, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res4) || !argp4) && obj2 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "CSVFeatureManager_parseRowIn" "', argument " "4"" of type '" "daal::data_management::interface1::DataSourceDictionary *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared4 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp4);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp4);
      arg4 = const_cast< daal::data_management::interface1::DataSourceDictionary * >(tempshared4.get());
    } else {
      smartarg4 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp4);
      arg4 = const_cast< daal::data_management::interface1::DataSourceDictionary * >((smartarg4 ? smartarg4->get() : 0));
    }
    if(!arg4 && obj2 != Py_None) SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "CSVFeatureManager_parseRowIn" "', argument " "4"" of type '" "daal::data_management::interface1::DataSourceDictionary *""'"); 
  }
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj3, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res5) || !argp5) && obj3 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "CSVFeatureManager_parseRowIn" "', argument " "5"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::NumericTable * >(tempshared5.get());
    } else {
      smartarg5 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::NumericTable * >((smartarg5 ? smartarg5->get() : 0));
    }
    if(!arg5 && obj3 != Py_None) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "CSVFeatureManager_parseRowIn" "', argument " "5"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
  }
  ecode6 = SWIG_AsVal_size_t(obj4, &val6);
  if (!SWIG_IsOK(ecode6)) {
    SWIG_exception_fail(SWIG_ArgError(ecode6), "in method '" "CSVFeatureManager_parseRowIn" "', argument " "6"" of type '" "size_t""'");
  } 
  arg6 = static_cast< size_t >(val6);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->parseRowIn(arg2,arg3,arg4,arg5,arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSVFeatureManager_finalize(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSVFeatureManager *arg1 = (daal::data_management::interface1::CSVFeatureManager *) 0 ;
  daal::data_management::interface1::DataSourceDictionary *arg2 = (daal::data_management::interface1::DataSourceDictionary *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSVFeatureManager > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSVFeatureManager > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > > tempshared2 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > > *smartarg2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:CSVFeatureManager_finalize",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSVFeatureManager_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSVFeatureManager_finalize" "', argument " "1"" of type '" "daal::data_management::interface1::CSVFeatureManager *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSVFeatureManager > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSVFeatureManager > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSVFeatureManager * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSVFeatureManager > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSVFeatureManager * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSVFeatureManager_finalize" "', argument " "1"" of type '" "daal::data_management::interface1::CSVFeatureManager *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res2) || !argp2) && obj1 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CSVFeatureManager_finalize" "', argument " "2"" of type '" "daal::data_management::interface1::DataSourceDictionary *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::DataSourceDictionary * >(tempshared2.get());
    } else {
      smartarg2 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::DataSourceDictionary * >((smartarg2 ? smartarg2->get() : 0));
    }
    if(!arg2 && obj1 != Py_None) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CSVFeatureManager_finalize" "', argument " "2"" of type '" "daal::data_management::interface1::DataSourceDictionary *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->finalize(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *CSVFeatureManager_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSVFeatureManager_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_convertToHomogen_Float64__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::NumericTable *arg1 = 0 ;
  daal::MemType arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > tempshared1 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::data_management::NumericTablePtr result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:convertToHomogen_Float64",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t,  0 , &newmem);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "convertToHomogen_Float64" "', argument " "1"" of type '" "daal::data_management::NumericTable &""'"); 
    }
    if (!argp1) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "convertToHomogen_Float64" "', argument " "1"" of type '" "daal::data_management::NumericTable &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::NumericTable * >(tempshared1.get());
    } else {
      arg1 = const_cast< daal::data_management::NumericTable * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1)->get());
    }
    if(!arg1) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "convertToHomogen_Float64" "', argument " "1"" of type '" "daal::data_management::NumericTable &""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "convertToHomogen_Float64" "', argument " "2"" of type '" "daal::MemType""'");
  } 
  arg2 = static_cast< daal::MemType >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::SWIGTEMPLATEDISAMBIGUATOR convertToHomogen< double >(*arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::NumericTable >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_convertToHomogen_Float64__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::NumericTable *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > tempshared1 ;
  PyObject * obj0 = 0 ;
  daal::data_management::NumericTablePtr result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:convertToHomogen_Float64",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t,  0 , &newmem);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "convertToHomogen_Float64" "', argument " "1"" of type '" "daal::data_management::NumericTable &""'"); 
    }
    if (!argp1) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "convertToHomogen_Float64" "', argument " "1"" of type '" "daal::data_management::NumericTable &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::NumericTable * >(tempshared1.get());
    } else {
      arg1 = const_cast< daal::data_management::NumericTable * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1)->get());
    }
    if(!arg1) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "convertToHomogen_Float64" "', argument " "1"" of type '" "daal::data_management::NumericTable &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::SWIGTEMPLATEDISAMBIGUATOR convertToHomogen< double >(*arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::NumericTable >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_convertToHomogen_Float64(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_convertToHomogen_Float64__SWIG_1(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_convertToHomogen_Float64__SWIG_0(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'convertToHomogen_Float64'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::convertToHomogen< double >(daal::data_management::NumericTable &,daal::MemType)\n"
    "    daal::data_management::convertToHomogen< double >(daal::data_management::NumericTable &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_convertToHomogen_Float32__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::NumericTable *arg1 = 0 ;
  daal::MemType arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > tempshared1 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::data_management::NumericTablePtr result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:convertToHomogen_Float32",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t,  0 , &newmem);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "convertToHomogen_Float32" "', argument " "1"" of type '" "daal::data_management::NumericTable &""'"); 
    }
    if (!argp1) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "convertToHomogen_Float32" "', argument " "1"" of type '" "daal::data_management::NumericTable &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::NumericTable * >(tempshared1.get());
    } else {
      arg1 = const_cast< daal::data_management::NumericTable * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1)->get());
    }
    if(!arg1) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "convertToHomogen_Float32" "', argument " "1"" of type '" "daal::data_management::NumericTable &""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "convertToHomogen_Float32" "', argument " "2"" of type '" "daal::MemType""'");
  } 
  arg2 = static_cast< daal::MemType >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::SWIGTEMPLATEDISAMBIGUATOR convertToHomogen< float >(*arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::NumericTable >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_convertToHomogen_Float32__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::NumericTable *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > tempshared1 ;
  PyObject * obj0 = 0 ;
  daal::data_management::NumericTablePtr result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:convertToHomogen_Float32",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t,  0 , &newmem);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "convertToHomogen_Float32" "', argument " "1"" of type '" "daal::data_management::NumericTable &""'"); 
    }
    if (!argp1) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "convertToHomogen_Float32" "', argument " "1"" of type '" "daal::data_management::NumericTable &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::NumericTable * >(tempshared1.get());
    } else {
      arg1 = const_cast< daal::data_management::NumericTable * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1)->get());
    }
    if(!arg1) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "convertToHomogen_Float32" "', argument " "1"" of type '" "daal::data_management::NumericTable &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::SWIGTEMPLATEDISAMBIGUATOR convertToHomogen< float >(*arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::NumericTable >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_convertToHomogen_Float32(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_convertToHomogen_Float32__SWIG_1(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_convertToHomogen_Float32__SWIG_0(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'convertToHomogen_Float32'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::convertToHomogen< float >(daal::data_management::NumericTable &,daal::MemType)\n"
    "    daal::data_management::convertToHomogen< float >(daal::data_management::NumericTable &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_convertToHomogen_Intc__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::NumericTable *arg1 = 0 ;
  daal::MemType arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > tempshared1 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::data_management::NumericTablePtr result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:convertToHomogen_Intc",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t,  0 , &newmem);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "convertToHomogen_Intc" "', argument " "1"" of type '" "daal::data_management::NumericTable &""'"); 
    }
    if (!argp1) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "convertToHomogen_Intc" "', argument " "1"" of type '" "daal::data_management::NumericTable &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::NumericTable * >(tempshared1.get());
    } else {
      arg1 = const_cast< daal::data_management::NumericTable * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1)->get());
    }
    if(!arg1) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "convertToHomogen_Intc" "', argument " "1"" of type '" "daal::data_management::NumericTable &""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "convertToHomogen_Intc" "', argument " "2"" of type '" "daal::MemType""'");
  } 
  arg2 = static_cast< daal::MemType >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::SWIGTEMPLATEDISAMBIGUATOR convertToHomogen< int >(*arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::NumericTable >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_convertToHomogen_Intc__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::NumericTable *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > tempshared1 ;
  PyObject * obj0 = 0 ;
  daal::data_management::NumericTablePtr result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:convertToHomogen_Intc",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t,  0 , &newmem);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "convertToHomogen_Intc" "', argument " "1"" of type '" "daal::data_management::NumericTable &""'"); 
    }
    if (!argp1) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "convertToHomogen_Intc" "', argument " "1"" of type '" "daal::data_management::NumericTable &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1);
      arg1 = const_cast< daal::data_management::NumericTable * >(tempshared1.get());
    } else {
      arg1 = const_cast< daal::data_management::NumericTable * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp1)->get());
    }
    if(!arg1) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "convertToHomogen_Intc" "', argument " "1"" of type '" "daal::data_management::NumericTable &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::SWIGTEMPLATEDISAMBIGUATOR convertToHomogen< int >(*arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::NumericTable >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_convertToHomogen_Intc(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_convertToHomogen_Intc__SWIG_1(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_convertToHomogen_Intc__SWIG_0(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'convertToHomogen_Intc'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::convertToHomogen< int >(daal::data_management::NumericTable &,daal::MemType)\n"
    "    daal::data_management::convertToHomogen< int >(daal::data_management::NumericTable &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_NumericTableDictionary_serializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)":NumericTableDictionary_serializationTag")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 >::SWIGTEMPLATEDISAMBIGUATOR serializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTableDictionary_getSerializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *arg1 = (daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:NumericTableDictionary_getSerializationTag",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableDictionary_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableDictionary_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)((daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > const *)arg1)->getSerializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_NumericTableDictionary__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg2 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:new_NumericTableDictionary",&obj0,&obj1)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_NumericTableDictionary" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "new_NumericTableDictionary" "', argument " "2"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *)new daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 >(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_NumericTableDictionary__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t val1 ;
  int ecode1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:new_NumericTableDictionary",&obj0)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_NumericTableDictionary" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *)new daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 >(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTableDictionary_create__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg2 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:NumericTableDictionary_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "NumericTableDictionary_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "NumericTableDictionary_create" "', argument " "2"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "NumericTableDictionary_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTableDictionary_create__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg2 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:NumericTableDictionary_create",&obj0,&obj1)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "NumericTableDictionary_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "NumericTableDictionary_create" "', argument " "2"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTableDictionary_create__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t val1 ;
  int ecode1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:NumericTableDictionary_create",&obj0)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "NumericTableDictionary_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 >::SWIGTEMPLATEDISAMBIGUATOR create(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_NumericTableDictionary__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_NumericTableDictionary")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *)new daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 >();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_NumericTableDictionary(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_new_NumericTableDictionary__SWIG_2(self, args);
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_new_NumericTableDictionary__SWIG_1(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_new_NumericTableDictionary__SWIG_0(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'new_NumericTableDictionary'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 >::Dictionary(size_t,daal::data_management::interface1::DictionaryIface::FeaturesEqual)\n"
    "    daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 >::Dictionary(size_t)\n"
    "    daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 >::Dictionary()\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_NumericTableDictionary_create__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::Status *arg1 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:NumericTableDictionary_create",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableDictionary_create" "', argument " "1"" of type '" "daal::services::Status *""'"); 
  }
  arg1 = reinterpret_cast< daal::services::Status * >(argp1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 >::SWIGTEMPLATEDISAMBIGUATOR create(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTableDictionary_create__SWIG_4(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > > result;
  
  if (!PyArg_ParseTuple(args,(char *)":NumericTableDictionary_create")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 >::SWIGTEMPLATEDISAMBIGUATOR create();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTableDictionary_create(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[4];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 3) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_NumericTableDictionary_create__SWIG_4(self, args);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_NumericTableDictionary_create__SWIG_3(self, args);
    }
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_NumericTableDictionary_create__SWIG_2(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_NumericTableDictionary_create__SWIG_1(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_NumericTableDictionary_create__SWIG_0(self, args);
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'NumericTableDictionary_create'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 >::create(size_t,daal::data_management::interface1::DictionaryIface::FeaturesEqual,daal::services::Status *)\n"
    "    daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 >::create(size_t,daal::data_management::interface1::DictionaryIface::FeaturesEqual)\n"
    "    daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 >::create(size_t)\n"
    "    daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 >::create(daal::services::Status *)\n"
    "    daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 >::create()\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_NumericTableDictionary(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *arg1 = (daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_NumericTableDictionary",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_NumericTableDictionary" "', argument " "1"" of type '" "daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_NumericTableDictionary" "', argument " "1"" of type '" "daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTableDictionary_resetDictionary(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *arg1 = (daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:NumericTableDictionary_resetDictionary",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableDictionary_resetDictionary" "', argument " "1"" of type '" "daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableDictionary_resetDictionary" "', argument " "1"" of type '" "daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->resetDictionary();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTableDictionary_setAllFeatures(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *arg1 = (daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *) 0 ;
  daal::data_management::interface1::NumericTableFeature *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableFeature const > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:NumericTableDictionary_setAllFeatures",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableDictionary_setAllFeatures" "', argument " "1"" of type '" "daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableDictionary_setAllFeatures" "', argument " "1"" of type '" "daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "NumericTableDictionary_setAllFeatures" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTableFeature const &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "NumericTableDictionary_setAllFeatures" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTableFeature const &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTableFeature > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTableFeature > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::NumericTableFeature * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::NumericTableFeature * >(reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTableFeature > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "NumericTableDictionary_setAllFeatures" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTableFeature const &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->setAllFeatures((daal::data_management::interface1::NumericTableFeature const &)*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTableDictionary_setNumberOfFeatures(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *arg1 = (daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:NumericTableDictionary_setNumberOfFeatures",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableDictionary_setNumberOfFeatures" "', argument " "1"" of type '" "daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableDictionary_setNumberOfFeatures" "', argument " "1"" of type '" "daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "NumericTableDictionary_setNumberOfFeatures" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->setNumberOfFeatures(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTableDictionary_getNumberOfFeatures(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *arg1 = (daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:NumericTableDictionary_getNumberOfFeatures",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableDictionary_getNumberOfFeatures" "', argument " "1"" of type '" "daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableDictionary_getNumberOfFeatures" "', argument " "1"" of type '" "daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > const *)arg1)->getNumberOfFeatures();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTableDictionary_getFeaturesEqual(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *arg1 = (daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:NumericTableDictionary_getFeaturesEqual",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableDictionary_getFeaturesEqual" "', argument " "1"" of type '" "daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableDictionary_getFeaturesEqual" "', argument " "1"" of type '" "daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::DictionaryIface::FeaturesEqual)((daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > const *)arg1)->getFeaturesEqual();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTableDictionary_setFeature(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *arg1 = (daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *) 0 ;
  daal::data_management::interface1::NumericTableFeature *arg2 = 0 ;
  size_t arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableFeature const > tempshared2 ;
  size_t val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:NumericTableDictionary_setFeature",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableDictionary_setFeature" "', argument " "1"" of type '" "daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableDictionary_setFeature" "', argument " "1"" of type '" "daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "NumericTableDictionary_setFeature" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTableFeature const &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "NumericTableDictionary_setFeature" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTableFeature const &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTableFeature > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTableFeature > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::NumericTableFeature * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::NumericTableFeature * >(reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::NumericTableFeature > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "NumericTableDictionary_setFeature" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTableFeature const &""'"); 
  }
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "NumericTableDictionary_setFeature" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->setFeature((daal::data_management::interface1::NumericTableFeature const &)*arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTableDictionary_checkDictionary(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *arg1 = (daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:NumericTableDictionary_checkDictionary",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableDictionary_checkDictionary" "', argument " "1"" of type '" "daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableDictionary_checkDictionary" "', argument " "1"" of type '" "daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > const *)arg1)->checkDictionary();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTableDictionary___getitem__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *arg1 = (daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::data_management::interface1::NumericTableFeature *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:NumericTableDictionary___getitem__",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableDictionary___getitem__" "', argument " "1"" of type '" "daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableDictionary___getitem__" "', argument " "1"" of type '" "daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "NumericTableDictionary___getitem__" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::NumericTableFeature *) &daal_data_management_interface1_Dictionary_Sl_daal_data_management_interface1_NumericTableFeature_Sc_6000_Sg____getitem__(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > *smartresult = new daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature >(result SWIG_NO_NULL_DELETER_0);
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_NumericTableDictionary___setitem__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *arg1 = (daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *) 0 ;
  size_t arg2 ;
  daal::data_management::interface1::NumericTableFeature *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTableFeature > tempshared3 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::data_management::interface1::NumericTableFeature *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:NumericTableDictionary___setitem__",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableDictionary___setitem__" "', argument " "1"" of type '" "daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,daal::SERIALIZATION_DATADICTIONARY_NT_ID > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "NumericTableDictionary___setitem__" "', argument " "1"" of type '" "daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "NumericTableDictionary___setitem__" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_t,  0 , &newmem);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "NumericTableDictionary___setitem__" "', argument " "3"" of type '" "daal::data_management::interface1::NumericTableFeature &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "NumericTableDictionary___setitem__" "', argument " "3"" of type '" "daal::data_management::interface1::NumericTableFeature &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared3 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp3);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp3);
      arg3 = const_cast< daal::data_management::interface1::NumericTableFeature * >(tempshared3.get());
    } else {
      arg3 = const_cast< daal::data_management::interface1::NumericTableFeature * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > * >(argp3)->get());
    }
    if(!arg3) SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "NumericTableDictionary___setitem__" "', argument " "3"" of type '" "daal::data_management::interface1::NumericTableFeature &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::NumericTableFeature *) &daal_data_management_interface1_Dictionary_Sl_daal_data_management_interface1_NumericTableFeature_Sc_6000_Sg____setitem__(arg1,arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature > *smartresult = new daal::services::SharedPtr<  daal::data_management::interface1::NumericTableFeature >(result SWIG_NO_NULL_DELETER_0);
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *NumericTableDictionary_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_DataSourceDictionary_serializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)":DataSourceDictionary_serializationTag")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 >::SWIGTEMPLATEDISAMBIGUATOR serializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceDictionary_getSerializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *arg1 = (daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataSourceDictionary_getSerializationTag",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceDictionary_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceDictionary_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)((daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > const *)arg1)->getSerializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_DataSourceDictionary__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg2 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:new_DataSourceDictionary",&obj0,&obj1)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_DataSourceDictionary" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "new_DataSourceDictionary" "', argument " "2"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *)new daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 >(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_DataSourceDictionary__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t val1 ;
  int ecode1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:new_DataSourceDictionary",&obj0)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_DataSourceDictionary" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *)new daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 >(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceDictionary_create__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg2 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:DataSourceDictionary_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "DataSourceDictionary_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "DataSourceDictionary_create" "', argument " "2"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "DataSourceDictionary_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceDictionary_create__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg2 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DataSourceDictionary_create",&obj0,&obj1)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "DataSourceDictionary_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "DataSourceDictionary_create" "', argument " "2"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceDictionary_create__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t val1 ;
  int ecode1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataSourceDictionary_create",&obj0)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "DataSourceDictionary_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 >::SWIGTEMPLATEDISAMBIGUATOR create(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_DataSourceDictionary__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_DataSourceDictionary")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *)new daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 >();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_DataSourceDictionary(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_new_DataSourceDictionary__SWIG_2(self, args);
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_new_DataSourceDictionary__SWIG_1(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_new_DataSourceDictionary__SWIG_0(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'new_DataSourceDictionary'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 >::Dictionary(size_t,daal::data_management::interface1::DictionaryIface::FeaturesEqual)\n"
    "    daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 >::Dictionary(size_t)\n"
    "    daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 >::Dictionary()\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_DataSourceDictionary_create__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::Status *arg1 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataSourceDictionary_create",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceDictionary_create" "', argument " "1"" of type '" "daal::services::Status *""'"); 
  }
  arg1 = reinterpret_cast< daal::services::Status * >(argp1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 >::SWIGTEMPLATEDISAMBIGUATOR create(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceDictionary_create__SWIG_4(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > > result;
  
  if (!PyArg_ParseTuple(args,(char *)":DataSourceDictionary_create")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 >::SWIGTEMPLATEDISAMBIGUATOR create();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceDictionary_create(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[4];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 3) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_DataSourceDictionary_create__SWIG_4(self, args);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_DataSourceDictionary_create__SWIG_3(self, args);
    }
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_DataSourceDictionary_create__SWIG_2(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_DataSourceDictionary_create__SWIG_1(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_DataSourceDictionary_create__SWIG_0(self, args);
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'DataSourceDictionary_create'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 >::create(size_t,daal::data_management::interface1::DictionaryIface::FeaturesEqual,daal::services::Status *)\n"
    "    daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 >::create(size_t,daal::data_management::interface1::DictionaryIface::FeaturesEqual)\n"
    "    daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 >::create(size_t)\n"
    "    daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 >::create(daal::services::Status *)\n"
    "    daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 >::create()\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_DataSourceDictionary(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *arg1 = (daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_DataSourceDictionary",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_DataSourceDictionary" "', argument " "1"" of type '" "daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_DataSourceDictionary" "', argument " "1"" of type '" "daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceDictionary_resetDictionary(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *arg1 = (daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataSourceDictionary_resetDictionary",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceDictionary_resetDictionary" "', argument " "1"" of type '" "daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceDictionary_resetDictionary" "', argument " "1"" of type '" "daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->resetDictionary();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceDictionary_setAllFeatures(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *arg1 = (daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *) 0 ;
  daal::data_management::interface1::DataSourceFeature *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature const > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DataSourceDictionary_setAllFeatures",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceDictionary_setAllFeatures" "', argument " "1"" of type '" "daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceDictionary_setAllFeatures" "', argument " "1"" of type '" "daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DataSourceDictionary_setAllFeatures" "', argument " "2"" of type '" "daal::data_management::interface1::DataSourceFeature const &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "DataSourceDictionary_setAllFeatures" "', argument " "2"" of type '" "daal::data_management::interface1::DataSourceFeature const &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataSourceFeature > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataSourceFeature > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::DataSourceFeature * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::DataSourceFeature * >(reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataSourceFeature > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DataSourceDictionary_setAllFeatures" "', argument " "2"" of type '" "daal::data_management::interface1::DataSourceFeature const &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->setAllFeatures((daal::data_management::interface1::DataSourceFeature const &)*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceDictionary_setNumberOfFeatures(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *arg1 = (daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DataSourceDictionary_setNumberOfFeatures",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceDictionary_setNumberOfFeatures" "', argument " "1"" of type '" "daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceDictionary_setNumberOfFeatures" "', argument " "1"" of type '" "daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "DataSourceDictionary_setNumberOfFeatures" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->setNumberOfFeatures(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceDictionary_getNumberOfFeatures(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *arg1 = (daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataSourceDictionary_getNumberOfFeatures",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceDictionary_getNumberOfFeatures" "', argument " "1"" of type '" "daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceDictionary_getNumberOfFeatures" "', argument " "1"" of type '" "daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > const *)arg1)->getNumberOfFeatures();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceDictionary_getFeaturesEqual(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *arg1 = (daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataSourceDictionary_getFeaturesEqual",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceDictionary_getFeaturesEqual" "', argument " "1"" of type '" "daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceDictionary_getFeaturesEqual" "', argument " "1"" of type '" "daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::DictionaryIface::FeaturesEqual)((daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > const *)arg1)->getFeaturesEqual();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceDictionary_setFeature(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *arg1 = (daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *) 0 ;
  daal::data_management::interface1::DataSourceFeature *arg2 = 0 ;
  size_t arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature const > tempshared2 ;
  size_t val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:DataSourceDictionary_setFeature",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceDictionary_setFeature" "', argument " "1"" of type '" "daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceDictionary_setFeature" "', argument " "1"" of type '" "daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DataSourceDictionary_setFeature" "', argument " "2"" of type '" "daal::data_management::interface1::DataSourceFeature const &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "DataSourceDictionary_setFeature" "', argument " "2"" of type '" "daal::data_management::interface1::DataSourceFeature const &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataSourceFeature > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataSourceFeature > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::DataSourceFeature * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::DataSourceFeature * >(reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::DataSourceFeature > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DataSourceDictionary_setFeature" "', argument " "2"" of type '" "daal::data_management::interface1::DataSourceFeature const &""'"); 
  }
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "DataSourceDictionary_setFeature" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->setFeature((daal::data_management::interface1::DataSourceFeature const &)*arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceDictionary_checkDictionary(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *arg1 = (daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataSourceDictionary_checkDictionary",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceDictionary_checkDictionary" "', argument " "1"" of type '" "daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceDictionary_checkDictionary" "', argument " "1"" of type '" "daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > const *)arg1)->checkDictionary();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceDictionary___getitem__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *arg1 = (daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::data_management::interface1::DataSourceFeature *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:DataSourceDictionary___getitem__",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceDictionary___getitem__" "', argument " "1"" of type '" "daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceDictionary___getitem__" "', argument " "1"" of type '" "daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "DataSourceDictionary___getitem__" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::DataSourceFeature *) &daal_data_management_interface1_Dictionary_Sl_daal_data_management_interface1_DataSourceFeature_Sc_6010_Sg____getitem__(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > *smartresult = new daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature >(result SWIG_NO_NULL_DELETER_0);
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceDictionary___setitem__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *arg1 = (daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *) 0 ;
  size_t arg2 ;
  daal::data_management::interface1::DataSourceFeature *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature > tempshared3 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::data_management::interface1::DataSourceFeature *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:DataSourceDictionary___setitem__",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceDictionary___setitem__" "', argument " "1"" of type '" "daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceDictionary___setitem__" "', argument " "1"" of type '" "daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "DataSourceDictionary___setitem__" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t,  0 , &newmem);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "DataSourceDictionary___setitem__" "', argument " "3"" of type '" "daal::data_management::interface1::DataSourceFeature &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "DataSourceDictionary___setitem__" "', argument " "3"" of type '" "daal::data_management::interface1::DataSourceFeature &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared3 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp3);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp3);
      arg3 = const_cast< daal::data_management::interface1::DataSourceFeature * >(tempshared3.get());
    } else {
      arg3 = const_cast< daal::data_management::interface1::DataSourceFeature * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > * >(argp3)->get());
    }
    if(!arg3) SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "DataSourceDictionary___setitem__" "', argument " "3"" of type '" "daal::data_management::interface1::DataSourceFeature &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::DataSourceFeature *) &daal_data_management_interface1_Dictionary_Sl_daal_data_management_interface1_DataSourceFeature_Sc_6010_Sg____setitem__(arg1,arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature > *smartresult = new daal::services::SharedPtr<  daal::data_management::interface1::DataSourceFeature >(result SWIG_NO_NULL_DELETER_0);
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *DataSourceDictionary_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_BlockDescriptor_Float64(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::BlockDescriptor< double > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_BlockDescriptor_Float64")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::BlockDescriptor< double > *)new daal::data_management::interface1::BlockDescriptor< double >();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_BlockDescriptor_Float64(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::BlockDescriptor< double > *arg1 = (daal::data_management::interface1::BlockDescriptor< double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_BlockDescriptor_Float64",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_BlockDescriptor_Float64" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_BlockDescriptor_Float64" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< double > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BlockDescriptor_Float64_getBlockSharedPtr(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::BlockDescriptor< double > *arg1 = (daal::data_management::interface1::BlockDescriptor< double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  SwigValueWrapper< daal::services::SharedPtr< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:BlockDescriptor_Float64_getBlockSharedPtr",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float64_getBlockSharedPtr" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< double > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float64_getBlockSharedPtr" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< double > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::BlockDescriptor< double > const *)arg1)->getBlockSharedPtr();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::SharedPtr< double >(static_cast< const daal::services::SharedPtr< double >& >(result))), SWIGTYPE_p_daal__services__SharedPtrT_double_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BlockDescriptor_Float64_getNumberOfColumns(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::BlockDescriptor< double > *arg1 = (daal::data_management::interface1::BlockDescriptor< double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:BlockDescriptor_Float64_getNumberOfColumns",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float64_getNumberOfColumns" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< double > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float64_getNumberOfColumns" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< double > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::BlockDescriptor< double > const *)arg1)->getNumberOfColumns();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BlockDescriptor_Float64_getNumberOfRows(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::BlockDescriptor< double > *arg1 = (daal::data_management::interface1::BlockDescriptor< double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:BlockDescriptor_Float64_getNumberOfRows",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float64_getNumberOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< double > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float64_getNumberOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< double > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::BlockDescriptor< double > const *)arg1)->getNumberOfRows();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BlockDescriptor_Float64_reset(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::BlockDescriptor< double > *arg1 = (daal::data_management::interface1::BlockDescriptor< double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:BlockDescriptor_Float64_reset",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float64_reset" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float64_reset" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< double > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->reset();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BlockDescriptor_Float64_resizeBuffer__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::BlockDescriptor< double > *arg1 = (daal::data_management::interface1::BlockDescriptor< double > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:BlockDescriptor_Float64_resizeBuffer",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float64_resizeBuffer" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float64_resizeBuffer" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< double > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "BlockDescriptor_Float64_resizeBuffer" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "BlockDescriptor_Float64_resizeBuffer" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "BlockDescriptor_Float64_resizeBuffer" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (bool)(arg1)->resizeBuffer(arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BlockDescriptor_Float64_resizeBuffer__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::BlockDescriptor< double > *arg1 = (daal::data_management::interface1::BlockDescriptor< double > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:BlockDescriptor_Float64_resizeBuffer",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float64_resizeBuffer" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float64_resizeBuffer" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< double > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "BlockDescriptor_Float64_resizeBuffer" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "BlockDescriptor_Float64_resizeBuffer" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (bool)(arg1)->resizeBuffer(arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BlockDescriptor_Float64_resizeBuffer(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[5];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 4) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_BlockDescriptor_Float64_resizeBuffer__SWIG_1(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            return _wrap_BlockDescriptor_Float64_resizeBuffer__SWIG_0(self, args);
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'BlockDescriptor_Float64_resizeBuffer'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::BlockDescriptor< double >::resizeBuffer(size_t,size_t,size_t)\n"
    "    daal::data_management::interface1::BlockDescriptor< double >::resizeBuffer(size_t,size_t)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_BlockDescriptor_Float64_setDetails(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::BlockDescriptor< double > *arg1 = (daal::data_management::interface1::BlockDescriptor< double > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  int arg4 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:BlockDescriptor_Float64_setDetails",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float64_setDetails" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float64_setDetails" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< double > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "BlockDescriptor_Float64_setDetails" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "BlockDescriptor_Float64_setDetails" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "BlockDescriptor_Float64_setDetails" "', argument " "4"" of type '" "int""'");
  } 
  arg4 = static_cast< int >(val4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->setDetails(arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BlockDescriptor_Float64_getColumnsOffset(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::BlockDescriptor< double > *arg1 = (daal::data_management::interface1::BlockDescriptor< double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:BlockDescriptor_Float64_getColumnsOffset",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float64_getColumnsOffset" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< double > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float64_getColumnsOffset" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< double > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::BlockDescriptor< double > const *)arg1)->getColumnsOffset();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BlockDescriptor_Float64_getRowsOffset(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::BlockDescriptor< double > *arg1 = (daal::data_management::interface1::BlockDescriptor< double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:BlockDescriptor_Float64_getRowsOffset",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float64_getRowsOffset" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< double > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float64_getRowsOffset" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< double > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::BlockDescriptor< double > const *)arg1)->getRowsOffset();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BlockDescriptor_Float64_getRWFlag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::BlockDescriptor< double > *arg1 = (daal::data_management::interface1::BlockDescriptor< double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:BlockDescriptor_Float64_getRWFlag",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float64_getRWFlag" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< double > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float64_getRWFlag" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< double > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::BlockDescriptor< double > const *)arg1)->getRWFlag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BlockDescriptor_Float64_getAdditionalBufferPtr(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::BlockDescriptor< double > *arg1 = (daal::data_management::interface1::BlockDescriptor< double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  void *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:BlockDescriptor_Float64_getAdditionalBufferPtr",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float64_getAdditionalBufferPtr" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< double > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float64_getAdditionalBufferPtr" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< double > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (void *)((daal::data_management::interface1::BlockDescriptor< double > const *)arg1)->getAdditionalBufferPtr();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_void, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BlockDescriptor_Float64_getAdditionalBufferSharedPtr(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::BlockDescriptor< double > *arg1 = (daal::data_management::interface1::BlockDescriptor< double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  SwigValueWrapper< daal::services::SharedPtr< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:BlockDescriptor_Float64_getAdditionalBufferSharedPtr",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float64_getAdditionalBufferSharedPtr" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< double > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float64_getAdditionalBufferSharedPtr" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< double > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::BlockDescriptor< double > const *)arg1)->getAdditionalBufferSharedPtr();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::SharedPtr< double >(static_cast< const daal::services::SharedPtr< double >& >(result))), SWIGTYPE_p_daal__services__SharedPtrT_double_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BlockDescriptor_Float64_getArray(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::BlockDescriptor< double > *arg1 = (daal::data_management::interface1::BlockDescriptor< double > *) 0 ;
  daal::services::SharedPtr< double > *arg2 = (daal::services::SharedPtr< double > *) 0 ;
  size_t *arg3 = (size_t *) 0 ;
  size_t *arg4 = (size_t *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > *smartarg1 = 0 ;
  daal::services::SharedPtr< double > data_temp2 ;
  size_t dim1_temp2 ;
  size_t dim2_temp2 ;
  PyObject * obj0 = 0 ;
  
  {
    arg2 = &data_temp2;
    arg3 = &dim1_temp2;
    arg4 = &dim2_temp2;
  }
  if (!PyArg_ParseTuple(args,(char *)"O:BlockDescriptor_Float64_getArray",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float64_getArray" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float64_getArray" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< double > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        daal_data_management_interface1_BlockDescriptor_Sl_double_Sg__getArray(arg1,arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    npy_intp dims[2] = {
      static_cast<npy_intp>(*arg4), static_cast<npy_intp>(*arg3) 
    };
    PyObject* obj = PyArray_SimpleNewFromData(2, dims, NPY_DOUBLE, (void*)(arg2->get()));
    if (!obj) SWIG_fail;
    set_sp_base((PyArrayObject*)obj, *arg2);
    resultobj = SWIG_Python_AppendOutput(resultobj,obj);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *BlockDescriptor_Float64_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_BlockDescriptor_Float32(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::BlockDescriptor< float > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_BlockDescriptor_Float32")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::BlockDescriptor< float > *)new daal::data_management::interface1::BlockDescriptor< float >();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_BlockDescriptor_Float32(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::BlockDescriptor< float > *arg1 = (daal::data_management::interface1::BlockDescriptor< float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_BlockDescriptor_Float32",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_BlockDescriptor_Float32" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_BlockDescriptor_Float32" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< float > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BlockDescriptor_Float32_getBlockSharedPtr(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::BlockDescriptor< float > *arg1 = (daal::data_management::interface1::BlockDescriptor< float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  SwigValueWrapper< daal::services::SharedPtr< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:BlockDescriptor_Float32_getBlockSharedPtr",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float32_getBlockSharedPtr" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< float > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float32_getBlockSharedPtr" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< float > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::BlockDescriptor< float > const *)arg1)->getBlockSharedPtr();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::SharedPtr< float >(static_cast< const daal::services::SharedPtr< float >& >(result))), SWIGTYPE_p_daal__services__SharedPtrT_float_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BlockDescriptor_Float32_getNumberOfColumns(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::BlockDescriptor< float > *arg1 = (daal::data_management::interface1::BlockDescriptor< float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:BlockDescriptor_Float32_getNumberOfColumns",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float32_getNumberOfColumns" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< float > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float32_getNumberOfColumns" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< float > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::BlockDescriptor< float > const *)arg1)->getNumberOfColumns();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BlockDescriptor_Float32_getNumberOfRows(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::BlockDescriptor< float > *arg1 = (daal::data_management::interface1::BlockDescriptor< float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:BlockDescriptor_Float32_getNumberOfRows",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float32_getNumberOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< float > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float32_getNumberOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< float > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::BlockDescriptor< float > const *)arg1)->getNumberOfRows();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BlockDescriptor_Float32_reset(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::BlockDescriptor< float > *arg1 = (daal::data_management::interface1::BlockDescriptor< float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:BlockDescriptor_Float32_reset",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float32_reset" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float32_reset" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< float > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->reset();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BlockDescriptor_Float32_resizeBuffer__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::BlockDescriptor< float > *arg1 = (daal::data_management::interface1::BlockDescriptor< float > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:BlockDescriptor_Float32_resizeBuffer",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float32_resizeBuffer" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float32_resizeBuffer" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< float > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "BlockDescriptor_Float32_resizeBuffer" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "BlockDescriptor_Float32_resizeBuffer" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "BlockDescriptor_Float32_resizeBuffer" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (bool)(arg1)->resizeBuffer(arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BlockDescriptor_Float32_resizeBuffer__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::BlockDescriptor< float > *arg1 = (daal::data_management::interface1::BlockDescriptor< float > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:BlockDescriptor_Float32_resizeBuffer",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float32_resizeBuffer" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float32_resizeBuffer" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< float > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "BlockDescriptor_Float32_resizeBuffer" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "BlockDescriptor_Float32_resizeBuffer" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (bool)(arg1)->resizeBuffer(arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BlockDescriptor_Float32_resizeBuffer(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[5];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 4) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_BlockDescriptor_Float32_resizeBuffer__SWIG_1(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            return _wrap_BlockDescriptor_Float32_resizeBuffer__SWIG_0(self, args);
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'BlockDescriptor_Float32_resizeBuffer'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::BlockDescriptor< float >::resizeBuffer(size_t,size_t,size_t)\n"
    "    daal::data_management::interface1::BlockDescriptor< float >::resizeBuffer(size_t,size_t)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_BlockDescriptor_Float32_setDetails(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::BlockDescriptor< float > *arg1 = (daal::data_management::interface1::BlockDescriptor< float > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  int arg4 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:BlockDescriptor_Float32_setDetails",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float32_setDetails" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float32_setDetails" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< float > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "BlockDescriptor_Float32_setDetails" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "BlockDescriptor_Float32_setDetails" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "BlockDescriptor_Float32_setDetails" "', argument " "4"" of type '" "int""'");
  } 
  arg4 = static_cast< int >(val4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->setDetails(arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BlockDescriptor_Float32_getColumnsOffset(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::BlockDescriptor< float > *arg1 = (daal::data_management::interface1::BlockDescriptor< float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:BlockDescriptor_Float32_getColumnsOffset",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float32_getColumnsOffset" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< float > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float32_getColumnsOffset" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< float > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::BlockDescriptor< float > const *)arg1)->getColumnsOffset();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BlockDescriptor_Float32_getRowsOffset(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::BlockDescriptor< float > *arg1 = (daal::data_management::interface1::BlockDescriptor< float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:BlockDescriptor_Float32_getRowsOffset",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float32_getRowsOffset" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< float > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float32_getRowsOffset" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< float > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::BlockDescriptor< float > const *)arg1)->getRowsOffset();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BlockDescriptor_Float32_getRWFlag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::BlockDescriptor< float > *arg1 = (daal::data_management::interface1::BlockDescriptor< float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:BlockDescriptor_Float32_getRWFlag",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float32_getRWFlag" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< float > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float32_getRWFlag" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< float > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::BlockDescriptor< float > const *)arg1)->getRWFlag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BlockDescriptor_Float32_getAdditionalBufferPtr(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::BlockDescriptor< float > *arg1 = (daal::data_management::interface1::BlockDescriptor< float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  void *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:BlockDescriptor_Float32_getAdditionalBufferPtr",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float32_getAdditionalBufferPtr" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< float > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float32_getAdditionalBufferPtr" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< float > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (void *)((daal::data_management::interface1::BlockDescriptor< float > const *)arg1)->getAdditionalBufferPtr();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_void, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BlockDescriptor_Float32_getAdditionalBufferSharedPtr(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::BlockDescriptor< float > *arg1 = (daal::data_management::interface1::BlockDescriptor< float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  SwigValueWrapper< daal::services::SharedPtr< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:BlockDescriptor_Float32_getAdditionalBufferSharedPtr",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float32_getAdditionalBufferSharedPtr" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< float > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float32_getAdditionalBufferSharedPtr" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< float > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::BlockDescriptor< float > const *)arg1)->getAdditionalBufferSharedPtr();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::SharedPtr< float >(static_cast< const daal::services::SharedPtr< float >& >(result))), SWIGTYPE_p_daal__services__SharedPtrT_float_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BlockDescriptor_Float32_getArray(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::BlockDescriptor< float > *arg1 = (daal::data_management::interface1::BlockDescriptor< float > *) 0 ;
  daal::services::SharedPtr< float > *arg2 = (daal::services::SharedPtr< float > *) 0 ;
  size_t *arg3 = (size_t *) 0 ;
  size_t *arg4 = (size_t *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > *smartarg1 = 0 ;
  daal::services::SharedPtr< float > data_temp2 ;
  size_t dim1_temp2 ;
  size_t dim2_temp2 ;
  PyObject * obj0 = 0 ;
  
  {
    arg2 = &data_temp2;
    arg3 = &dim1_temp2;
    arg4 = &dim2_temp2;
  }
  if (!PyArg_ParseTuple(args,(char *)"O:BlockDescriptor_Float32_getArray",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float32_getArray" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Float32_getArray" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< float > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        daal_data_management_interface1_BlockDescriptor_Sl_float_Sg__getArray(arg1,arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    npy_intp dims[2] = {
      static_cast<npy_intp>(*arg4), static_cast<npy_intp>(*arg3) 
    };
    PyObject* obj = PyArray_SimpleNewFromData(2, dims, NPY_FLOAT, (void*)(arg2->get()));
    if (!obj) SWIG_fail;
    set_sp_base((PyArrayObject*)obj, *arg2);
    resultobj = SWIG_Python_AppendOutput(resultobj,obj);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *BlockDescriptor_Float32_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_BlockDescriptor_Intc(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::BlockDescriptor< int > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_BlockDescriptor_Intc")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::BlockDescriptor< int > *)new daal::data_management::interface1::BlockDescriptor< int >();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_BlockDescriptor_Intc(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::BlockDescriptor< int > *arg1 = (daal::data_management::interface1::BlockDescriptor< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_BlockDescriptor_Intc",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_BlockDescriptor_Intc" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_BlockDescriptor_Intc" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< int > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BlockDescriptor_Intc_getBlockSharedPtr(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::BlockDescriptor< int > *arg1 = (daal::data_management::interface1::BlockDescriptor< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  SwigValueWrapper< daal::services::SharedPtr< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:BlockDescriptor_Intc_getBlockSharedPtr",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Intc_getBlockSharedPtr" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< int > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Intc_getBlockSharedPtr" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< int > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::BlockDescriptor< int > const *)arg1)->getBlockSharedPtr();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::SharedPtr< int >(static_cast< const daal::services::SharedPtr< int >& >(result))), SWIGTYPE_p_daal__services__SharedPtrT_int_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BlockDescriptor_Intc_getNumberOfColumns(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::BlockDescriptor< int > *arg1 = (daal::data_management::interface1::BlockDescriptor< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:BlockDescriptor_Intc_getNumberOfColumns",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Intc_getNumberOfColumns" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< int > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Intc_getNumberOfColumns" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< int > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::BlockDescriptor< int > const *)arg1)->getNumberOfColumns();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BlockDescriptor_Intc_getNumberOfRows(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::BlockDescriptor< int > *arg1 = (daal::data_management::interface1::BlockDescriptor< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:BlockDescriptor_Intc_getNumberOfRows",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Intc_getNumberOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< int > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Intc_getNumberOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< int > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::BlockDescriptor< int > const *)arg1)->getNumberOfRows();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BlockDescriptor_Intc_reset(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::BlockDescriptor< int > *arg1 = (daal::data_management::interface1::BlockDescriptor< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:BlockDescriptor_Intc_reset",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Intc_reset" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Intc_reset" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< int > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->reset();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BlockDescriptor_Intc_resizeBuffer__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::BlockDescriptor< int > *arg1 = (daal::data_management::interface1::BlockDescriptor< int > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:BlockDescriptor_Intc_resizeBuffer",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Intc_resizeBuffer" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Intc_resizeBuffer" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< int > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "BlockDescriptor_Intc_resizeBuffer" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "BlockDescriptor_Intc_resizeBuffer" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "BlockDescriptor_Intc_resizeBuffer" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (bool)(arg1)->resizeBuffer(arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BlockDescriptor_Intc_resizeBuffer__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::BlockDescriptor< int > *arg1 = (daal::data_management::interface1::BlockDescriptor< int > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:BlockDescriptor_Intc_resizeBuffer",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Intc_resizeBuffer" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Intc_resizeBuffer" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< int > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "BlockDescriptor_Intc_resizeBuffer" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "BlockDescriptor_Intc_resizeBuffer" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (bool)(arg1)->resizeBuffer(arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BlockDescriptor_Intc_resizeBuffer(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[5];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 4) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_BlockDescriptor_Intc_resizeBuffer__SWIG_1(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            return _wrap_BlockDescriptor_Intc_resizeBuffer__SWIG_0(self, args);
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'BlockDescriptor_Intc_resizeBuffer'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::BlockDescriptor< int >::resizeBuffer(size_t,size_t,size_t)\n"
    "    daal::data_management::interface1::BlockDescriptor< int >::resizeBuffer(size_t,size_t)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_BlockDescriptor_Intc_setDetails(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::BlockDescriptor< int > *arg1 = (daal::data_management::interface1::BlockDescriptor< int > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  int arg4 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:BlockDescriptor_Intc_setDetails",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Intc_setDetails" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Intc_setDetails" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< int > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "BlockDescriptor_Intc_setDetails" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "BlockDescriptor_Intc_setDetails" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "BlockDescriptor_Intc_setDetails" "', argument " "4"" of type '" "int""'");
  } 
  arg4 = static_cast< int >(val4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->setDetails(arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BlockDescriptor_Intc_getColumnsOffset(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::BlockDescriptor< int > *arg1 = (daal::data_management::interface1::BlockDescriptor< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:BlockDescriptor_Intc_getColumnsOffset",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Intc_getColumnsOffset" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< int > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Intc_getColumnsOffset" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< int > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::BlockDescriptor< int > const *)arg1)->getColumnsOffset();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BlockDescriptor_Intc_getRowsOffset(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::BlockDescriptor< int > *arg1 = (daal::data_management::interface1::BlockDescriptor< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:BlockDescriptor_Intc_getRowsOffset",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Intc_getRowsOffset" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< int > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Intc_getRowsOffset" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< int > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::BlockDescriptor< int > const *)arg1)->getRowsOffset();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BlockDescriptor_Intc_getRWFlag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::BlockDescriptor< int > *arg1 = (daal::data_management::interface1::BlockDescriptor< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:BlockDescriptor_Intc_getRWFlag",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Intc_getRWFlag" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< int > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Intc_getRWFlag" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< int > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::BlockDescriptor< int > const *)arg1)->getRWFlag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BlockDescriptor_Intc_getAdditionalBufferPtr(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::BlockDescriptor< int > *arg1 = (daal::data_management::interface1::BlockDescriptor< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  void *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:BlockDescriptor_Intc_getAdditionalBufferPtr",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Intc_getAdditionalBufferPtr" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< int > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Intc_getAdditionalBufferPtr" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< int > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (void *)((daal::data_management::interface1::BlockDescriptor< int > const *)arg1)->getAdditionalBufferPtr();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_void, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BlockDescriptor_Intc_getAdditionalBufferSharedPtr(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::BlockDescriptor< int > *arg1 = (daal::data_management::interface1::BlockDescriptor< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  SwigValueWrapper< daal::services::SharedPtr< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:BlockDescriptor_Intc_getAdditionalBufferSharedPtr",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Intc_getAdditionalBufferSharedPtr" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< int > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::BlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Intc_getAdditionalBufferSharedPtr" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< int > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::BlockDescriptor< int > const *)arg1)->getAdditionalBufferSharedPtr();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::SharedPtr< int >(static_cast< const daal::services::SharedPtr< int >& >(result))), SWIGTYPE_p_daal__services__SharedPtrT_int_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BlockDescriptor_Intc_getArray(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::BlockDescriptor< int > *arg1 = (daal::data_management::interface1::BlockDescriptor< int > *) 0 ;
  daal::services::SharedPtr< int > *arg2 = (daal::services::SharedPtr< int > *) 0 ;
  size_t *arg3 = (size_t *) 0 ;
  size_t *arg4 = (size_t *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > *smartarg1 = 0 ;
  daal::services::SharedPtr< int > data_temp2 ;
  size_t dim1_temp2 ;
  size_t dim2_temp2 ;
  PyObject * obj0 = 0 ;
  
  {
    arg2 = &data_temp2;
    arg3 = &dim1_temp2;
    arg4 = &dim2_temp2;
  }
  if (!PyArg_ParseTuple(args,(char *)"O:BlockDescriptor_Intc_getArray",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Intc_getArray" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BlockDescriptor_Intc_getArray" "', argument " "1"" of type '" "daal::data_management::interface1::BlockDescriptor< int > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        daal_data_management_interface1_BlockDescriptor_Sl_int_Sg__getArray(arg1,arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    npy_intp dims[2] = {
      static_cast<npy_intp>(*arg4), static_cast<npy_intp>(*arg3) 
    };
    PyObject* obj = PyArray_SimpleNewFromData(2, dims, NPY_INT, (void*)(arg2->get()));
    if (!obj) SWIG_fail;
    set_sp_base((PyArrayObject*)obj, *arg2);
    resultobj = SWIG_Python_AppendOutput(resultobj,obj);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *BlockDescriptor_Intc_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_CSRBlockDescriptor_Float64(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRBlockDescriptor< double > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_CSRBlockDescriptor_Float64")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::CSRBlockDescriptor< double > *)new daal::data_management::interface1::CSRBlockDescriptor< double >();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< double > >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_double_t_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_CSRBlockDescriptor_Float64(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRBlockDescriptor< double > *arg1 = (daal::data_management::interface1::CSRBlockDescriptor< double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< double > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_CSRBlockDescriptor_Float64",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_CSRBlockDescriptor_Float64" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_CSRBlockDescriptor_Float64" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< double > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRBlockDescriptor_Float64_getBlockValuesPtr(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRBlockDescriptor< double > *arg1 = (daal::data_management::interface1::CSRBlockDescriptor< double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< double > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< double > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  double *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:CSRBlockDescriptor_Float64_getBlockValuesPtr",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float64_getBlockValuesPtr" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< double > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float64_getBlockValuesPtr" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< double > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (double *)((daal::data_management::interface1::CSRBlockDescriptor< double > const *)arg1)->getBlockValuesPtr();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_double, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRBlockDescriptor_Float64_getBlockValuesSharedPtr(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRBlockDescriptor< double > *arg1 = (daal::data_management::interface1::CSRBlockDescriptor< double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< double > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< double > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  SwigValueWrapper< daal::services::SharedPtr< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:CSRBlockDescriptor_Float64_getBlockValuesSharedPtr",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float64_getBlockValuesSharedPtr" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< double > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float64_getBlockValuesSharedPtr" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< double > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::CSRBlockDescriptor< double > const *)arg1)->getBlockValuesSharedPtr();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::SharedPtr< double >(static_cast< const daal::services::SharedPtr< double >& >(result))), SWIGTYPE_p_daal__services__SharedPtrT_double_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRBlockDescriptor_Float64_getNumberOfColumns(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRBlockDescriptor< double > *arg1 = (daal::data_management::interface1::CSRBlockDescriptor< double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< double > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< double > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:CSRBlockDescriptor_Float64_getNumberOfColumns",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float64_getNumberOfColumns" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< double > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float64_getNumberOfColumns" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< double > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::CSRBlockDescriptor< double > const *)arg1)->getNumberOfColumns();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRBlockDescriptor_Float64_getNumberOfRows(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRBlockDescriptor< double > *arg1 = (daal::data_management::interface1::CSRBlockDescriptor< double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< double > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< double > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:CSRBlockDescriptor_Float64_getNumberOfRows",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float64_getNumberOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< double > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float64_getNumberOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< double > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::CSRBlockDescriptor< double > const *)arg1)->getNumberOfRows();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRBlockDescriptor_Float64_getDataSize(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRBlockDescriptor< double > *arg1 = (daal::data_management::interface1::CSRBlockDescriptor< double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< double > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< double > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:CSRBlockDescriptor_Float64_getDataSize",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float64_getDataSize" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< double > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float64_getDataSize" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< double > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::CSRBlockDescriptor< double > const *)arg1)->getDataSize();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRBlockDescriptor_Float64_reset(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRBlockDescriptor< double > *arg1 = (daal::data_management::interface1::CSRBlockDescriptor< double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< double > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:CSRBlockDescriptor_Float64_reset",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float64_reset" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float64_reset" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< double > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->reset();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRBlockDescriptor_Float64_resizeValuesBuffer(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRBlockDescriptor< double > *arg1 = (daal::data_management::interface1::CSRBlockDescriptor< double > *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< double > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:CSRBlockDescriptor_Float64_resizeValuesBuffer",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float64_resizeValuesBuffer" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float64_resizeValuesBuffer" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< double > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CSRBlockDescriptor_Float64_resizeValuesBuffer" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (bool)(arg1)->resizeValuesBuffer(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRBlockDescriptor_Float64_resizeRowsBuffer(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRBlockDescriptor< double > *arg1 = (daal::data_management::interface1::CSRBlockDescriptor< double > *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< double > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:CSRBlockDescriptor_Float64_resizeRowsBuffer",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float64_resizeRowsBuffer" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float64_resizeRowsBuffer" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< double > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CSRBlockDescriptor_Float64_resizeRowsBuffer" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (bool)(arg1)->resizeRowsBuffer(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRBlockDescriptor_Float64_setDetails(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRBlockDescriptor< double > *arg1 = (daal::data_management::interface1::CSRBlockDescriptor< double > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  int arg4 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< double > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:CSRBlockDescriptor_Float64_setDetails",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float64_setDetails" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float64_setDetails" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< double > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CSRBlockDescriptor_Float64_setDetails" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "CSRBlockDescriptor_Float64_setDetails" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "CSRBlockDescriptor_Float64_setDetails" "', argument " "4"" of type '" "int""'");
  } 
  arg4 = static_cast< int >(val4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->setDetails(arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRBlockDescriptor_Float64_getRowsOffset(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRBlockDescriptor< double > *arg1 = (daal::data_management::interface1::CSRBlockDescriptor< double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< double > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< double > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:CSRBlockDescriptor_Float64_getRowsOffset",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float64_getRowsOffset" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< double > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float64_getRowsOffset" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< double > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::CSRBlockDescriptor< double > const *)arg1)->getRowsOffset();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRBlockDescriptor_Float64_getRWFlag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRBlockDescriptor< double > *arg1 = (daal::data_management::interface1::CSRBlockDescriptor< double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< double > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< double > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:CSRBlockDescriptor_Float64_getRWFlag",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float64_getRWFlag" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< double > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float64_getRWFlag" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< double > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::CSRBlockDescriptor< double > const *)arg1)->getRWFlag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRBlockDescriptor_Float64_getBlockColumnIndices(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRBlockDescriptor< double > *arg1 = (daal::data_management::interface1::CSRBlockDescriptor< double > *) 0 ;
  size_t *arg2 = (size_t *) 0 ;
  daal::services::SharedPtr< size_t > *arg3 = (daal::services::SharedPtr< size_t > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< double > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< double > const > *smartarg1 = 0 ;
  daal::services::SharedPtr< size_t > data_temp2 ;
  size_t dim_temp2 ;
  PyObject * obj0 = 0 ;
  
  {
    arg2 = &dim_temp2;
    arg3 = &data_temp2;
  }
  if (!PyArg_ParseTuple(args,(char *)"O:CSRBlockDescriptor_Float64_getBlockColumnIndices",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float64_getBlockColumnIndices" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< double > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float64_getBlockColumnIndices" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< double > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        daal_data_management_interface1_CSRBlockDescriptor_Sl_double_Sg__getBlockColumnIndices((daal::data_management::interface1::CSRBlockDescriptor< double > const *)arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    npy_intp dims[1] = {
      static_cast<npy_intp>(*arg2) 
    }; // Intel/FS static-cast
    PyObject* obj = PyArray_SimpleNewFromData(1, dims, NPY_UINT64, (void*)(arg3->get()));
    if (!obj) SWIG_fail;
    set_sp_base((PyArrayObject*)obj, *arg3);
    resultobj = SWIG_Python_AppendOutput(resultobj,obj);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRBlockDescriptor_Float64_getBlockRowIndices(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRBlockDescriptor< double > *arg1 = (daal::data_management::interface1::CSRBlockDescriptor< double > *) 0 ;
  size_t *arg2 = (size_t *) 0 ;
  daal::services::SharedPtr< size_t > *arg3 = (daal::services::SharedPtr< size_t > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< double > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< double > const > *smartarg1 = 0 ;
  daal::services::SharedPtr< size_t > data_temp2 ;
  size_t dim_temp2 ;
  PyObject * obj0 = 0 ;
  
  {
    arg2 = &dim_temp2;
    arg3 = &data_temp2;
  }
  if (!PyArg_ParseTuple(args,(char *)"O:CSRBlockDescriptor_Float64_getBlockRowIndices",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float64_getBlockRowIndices" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< double > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float64_getBlockRowIndices" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< double > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        daal_data_management_interface1_CSRBlockDescriptor_Sl_double_Sg__getBlockRowIndices((daal::data_management::interface1::CSRBlockDescriptor< double > const *)arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    npy_intp dims[1] = {
      static_cast<npy_intp>(*arg2) 
    }; // Intel/FS static-cast
    PyObject* obj = PyArray_SimpleNewFromData(1, dims, NPY_UINT64, (void*)(arg3->get()));
    if (!obj) SWIG_fail;
    set_sp_base((PyArrayObject*)obj, *arg3);
    resultobj = SWIG_Python_AppendOutput(resultobj,obj);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRBlockDescriptor_Float64_getBlockValues(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRBlockDescriptor< double > *arg1 = (daal::data_management::interface1::CSRBlockDescriptor< double > *) 0 ;
  size_t *arg2 = (size_t *) 0 ;
  daal::services::SharedPtr< double > *arg3 = (daal::services::SharedPtr< double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< double > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< double > const > *smartarg1 = 0 ;
  daal::services::SharedPtr< double > data_temp2 ;
  size_t dim_temp2 ;
  PyObject * obj0 = 0 ;
  
  {
    arg2 = &dim_temp2;
    arg3 = &data_temp2;
  }
  if (!PyArg_ParseTuple(args,(char *)"O:CSRBlockDescriptor_Float64_getBlockValues",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float64_getBlockValues" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< double > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float64_getBlockValues" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< double > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        daal_data_management_interface1_CSRBlockDescriptor_Sl_double_Sg__getBlockValues((daal::data_management::interface1::CSRBlockDescriptor< double > const *)arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    npy_intp dims[1] = {
      static_cast<npy_intp>(*arg2) 
    }; // Intel/FS static-cast
    PyObject* obj = PyArray_SimpleNewFromData(1, dims, NPY_DOUBLE, (void*)(arg3->get()));
    if (!obj) SWIG_fail;
    set_sp_base((PyArrayObject*)obj, *arg3);
    resultobj = SWIG_Python_AppendOutput(resultobj,obj);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *CSRBlockDescriptor_Float64_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_double_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_CSRBlockDescriptor_Float32(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRBlockDescriptor< float > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_CSRBlockDescriptor_Float32")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::CSRBlockDescriptor< float > *)new daal::data_management::interface1::CSRBlockDescriptor< float >();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< float > >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_float_t_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_CSRBlockDescriptor_Float32(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRBlockDescriptor< float > *arg1 = (daal::data_management::interface1::CSRBlockDescriptor< float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< float > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_CSRBlockDescriptor_Float32",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_CSRBlockDescriptor_Float32" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_CSRBlockDescriptor_Float32" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< float > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRBlockDescriptor_Float32_getBlockValuesPtr(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRBlockDescriptor< float > *arg1 = (daal::data_management::interface1::CSRBlockDescriptor< float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< float > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< float > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  float *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:CSRBlockDescriptor_Float32_getBlockValuesPtr",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float32_getBlockValuesPtr" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< float > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float32_getBlockValuesPtr" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< float > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (float *)((daal::data_management::interface1::CSRBlockDescriptor< float > const *)arg1)->getBlockValuesPtr();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_float, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRBlockDescriptor_Float32_getBlockValuesSharedPtr(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRBlockDescriptor< float > *arg1 = (daal::data_management::interface1::CSRBlockDescriptor< float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< float > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< float > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  SwigValueWrapper< daal::services::SharedPtr< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:CSRBlockDescriptor_Float32_getBlockValuesSharedPtr",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float32_getBlockValuesSharedPtr" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< float > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float32_getBlockValuesSharedPtr" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< float > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::CSRBlockDescriptor< float > const *)arg1)->getBlockValuesSharedPtr();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::SharedPtr< float >(static_cast< const daal::services::SharedPtr< float >& >(result))), SWIGTYPE_p_daal__services__SharedPtrT_float_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRBlockDescriptor_Float32_getNumberOfColumns(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRBlockDescriptor< float > *arg1 = (daal::data_management::interface1::CSRBlockDescriptor< float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< float > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< float > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:CSRBlockDescriptor_Float32_getNumberOfColumns",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float32_getNumberOfColumns" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< float > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float32_getNumberOfColumns" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< float > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::CSRBlockDescriptor< float > const *)arg1)->getNumberOfColumns();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRBlockDescriptor_Float32_getNumberOfRows(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRBlockDescriptor< float > *arg1 = (daal::data_management::interface1::CSRBlockDescriptor< float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< float > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< float > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:CSRBlockDescriptor_Float32_getNumberOfRows",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float32_getNumberOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< float > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float32_getNumberOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< float > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::CSRBlockDescriptor< float > const *)arg1)->getNumberOfRows();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRBlockDescriptor_Float32_getDataSize(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRBlockDescriptor< float > *arg1 = (daal::data_management::interface1::CSRBlockDescriptor< float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< float > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< float > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:CSRBlockDescriptor_Float32_getDataSize",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float32_getDataSize" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< float > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float32_getDataSize" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< float > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::CSRBlockDescriptor< float > const *)arg1)->getDataSize();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRBlockDescriptor_Float32_reset(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRBlockDescriptor< float > *arg1 = (daal::data_management::interface1::CSRBlockDescriptor< float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< float > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:CSRBlockDescriptor_Float32_reset",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float32_reset" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float32_reset" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< float > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->reset();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRBlockDescriptor_Float32_resizeValuesBuffer(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRBlockDescriptor< float > *arg1 = (daal::data_management::interface1::CSRBlockDescriptor< float > *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< float > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:CSRBlockDescriptor_Float32_resizeValuesBuffer",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float32_resizeValuesBuffer" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float32_resizeValuesBuffer" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< float > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CSRBlockDescriptor_Float32_resizeValuesBuffer" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (bool)(arg1)->resizeValuesBuffer(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRBlockDescriptor_Float32_resizeRowsBuffer(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRBlockDescriptor< float > *arg1 = (daal::data_management::interface1::CSRBlockDescriptor< float > *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< float > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:CSRBlockDescriptor_Float32_resizeRowsBuffer",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float32_resizeRowsBuffer" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float32_resizeRowsBuffer" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< float > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CSRBlockDescriptor_Float32_resizeRowsBuffer" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (bool)(arg1)->resizeRowsBuffer(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRBlockDescriptor_Float32_setDetails(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRBlockDescriptor< float > *arg1 = (daal::data_management::interface1::CSRBlockDescriptor< float > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  int arg4 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< float > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:CSRBlockDescriptor_Float32_setDetails",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float32_setDetails" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float32_setDetails" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< float > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CSRBlockDescriptor_Float32_setDetails" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "CSRBlockDescriptor_Float32_setDetails" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "CSRBlockDescriptor_Float32_setDetails" "', argument " "4"" of type '" "int""'");
  } 
  arg4 = static_cast< int >(val4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->setDetails(arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRBlockDescriptor_Float32_getRowsOffset(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRBlockDescriptor< float > *arg1 = (daal::data_management::interface1::CSRBlockDescriptor< float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< float > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< float > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:CSRBlockDescriptor_Float32_getRowsOffset",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float32_getRowsOffset" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< float > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float32_getRowsOffset" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< float > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::CSRBlockDescriptor< float > const *)arg1)->getRowsOffset();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRBlockDescriptor_Float32_getRWFlag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRBlockDescriptor< float > *arg1 = (daal::data_management::interface1::CSRBlockDescriptor< float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< float > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< float > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:CSRBlockDescriptor_Float32_getRWFlag",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float32_getRWFlag" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< float > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float32_getRWFlag" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< float > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::CSRBlockDescriptor< float > const *)arg1)->getRWFlag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRBlockDescriptor_Float32_getBlockColumnIndices(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRBlockDescriptor< float > *arg1 = (daal::data_management::interface1::CSRBlockDescriptor< float > *) 0 ;
  size_t *arg2 = (size_t *) 0 ;
  daal::services::SharedPtr< size_t > *arg3 = (daal::services::SharedPtr< size_t > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< float > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< float > const > *smartarg1 = 0 ;
  daal::services::SharedPtr< size_t > data_temp2 ;
  size_t dim_temp2 ;
  PyObject * obj0 = 0 ;
  
  {
    arg2 = &dim_temp2;
    arg3 = &data_temp2;
  }
  if (!PyArg_ParseTuple(args,(char *)"O:CSRBlockDescriptor_Float32_getBlockColumnIndices",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float32_getBlockColumnIndices" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< float > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float32_getBlockColumnIndices" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< float > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        daal_data_management_interface1_CSRBlockDescriptor_Sl_float_Sg__getBlockColumnIndices((daal::data_management::interface1::CSRBlockDescriptor< float > const *)arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    npy_intp dims[1] = {
      static_cast<npy_intp>(*arg2) 
    }; // Intel/FS static-cast
    PyObject* obj = PyArray_SimpleNewFromData(1, dims, NPY_UINT64, (void*)(arg3->get()));
    if (!obj) SWIG_fail;
    set_sp_base((PyArrayObject*)obj, *arg3);
    resultobj = SWIG_Python_AppendOutput(resultobj,obj);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRBlockDescriptor_Float32_getBlockRowIndices(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRBlockDescriptor< float > *arg1 = (daal::data_management::interface1::CSRBlockDescriptor< float > *) 0 ;
  size_t *arg2 = (size_t *) 0 ;
  daal::services::SharedPtr< size_t > *arg3 = (daal::services::SharedPtr< size_t > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< float > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< float > const > *smartarg1 = 0 ;
  daal::services::SharedPtr< size_t > data_temp2 ;
  size_t dim_temp2 ;
  PyObject * obj0 = 0 ;
  
  {
    arg2 = &dim_temp2;
    arg3 = &data_temp2;
  }
  if (!PyArg_ParseTuple(args,(char *)"O:CSRBlockDescriptor_Float32_getBlockRowIndices",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float32_getBlockRowIndices" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< float > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float32_getBlockRowIndices" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< float > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        daal_data_management_interface1_CSRBlockDescriptor_Sl_float_Sg__getBlockRowIndices((daal::data_management::interface1::CSRBlockDescriptor< float > const *)arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    npy_intp dims[1] = {
      static_cast<npy_intp>(*arg2) 
    }; // Intel/FS static-cast
    PyObject* obj = PyArray_SimpleNewFromData(1, dims, NPY_UINT64, (void*)(arg3->get()));
    if (!obj) SWIG_fail;
    set_sp_base((PyArrayObject*)obj, *arg3);
    resultobj = SWIG_Python_AppendOutput(resultobj,obj);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRBlockDescriptor_Float32_getBlockValues(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRBlockDescriptor< float > *arg1 = (daal::data_management::interface1::CSRBlockDescriptor< float > *) 0 ;
  size_t *arg2 = (size_t *) 0 ;
  daal::services::SharedPtr< float > *arg3 = (daal::services::SharedPtr< float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< float > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< float > const > *smartarg1 = 0 ;
  daal::services::SharedPtr< float > data_temp2 ;
  size_t dim_temp2 ;
  PyObject * obj0 = 0 ;
  
  {
    arg2 = &dim_temp2;
    arg3 = &data_temp2;
  }
  if (!PyArg_ParseTuple(args,(char *)"O:CSRBlockDescriptor_Float32_getBlockValues",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float32_getBlockValues" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< float > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Float32_getBlockValues" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< float > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        daal_data_management_interface1_CSRBlockDescriptor_Sl_float_Sg__getBlockValues((daal::data_management::interface1::CSRBlockDescriptor< float > const *)arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    npy_intp dims[1] = {
      static_cast<npy_intp>(*arg2) 
    }; // Intel/FS static-cast
    PyObject* obj = PyArray_SimpleNewFromData(1, dims, NPY_FLOAT, (void*)(arg3->get()));
    if (!obj) SWIG_fail;
    set_sp_base((PyArrayObject*)obj, *arg3);
    resultobj = SWIG_Python_AppendOutput(resultobj,obj);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *CSRBlockDescriptor_Float32_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_float_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_CSRBlockDescriptor_Intc(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRBlockDescriptor< int > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_CSRBlockDescriptor_Intc")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::CSRBlockDescriptor< int > *)new daal::data_management::interface1::CSRBlockDescriptor< int >();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< int > >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_int_t_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_CSRBlockDescriptor_Intc(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRBlockDescriptor< int > *arg1 = (daal::data_management::interface1::CSRBlockDescriptor< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< int > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_CSRBlockDescriptor_Intc",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_CSRBlockDescriptor_Intc" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_CSRBlockDescriptor_Intc" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< int > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRBlockDescriptor_Intc_getBlockValuesPtr(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRBlockDescriptor< int > *arg1 = (daal::data_management::interface1::CSRBlockDescriptor< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< int > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< int > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  int *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:CSRBlockDescriptor_Intc_getBlockValuesPtr",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Intc_getBlockValuesPtr" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< int > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Intc_getBlockValuesPtr" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< int > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int *)((daal::data_management::interface1::CSRBlockDescriptor< int > const *)arg1)->getBlockValuesPtr();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_int, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRBlockDescriptor_Intc_getBlockValuesSharedPtr(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRBlockDescriptor< int > *arg1 = (daal::data_management::interface1::CSRBlockDescriptor< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< int > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< int > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  SwigValueWrapper< daal::services::SharedPtr< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:CSRBlockDescriptor_Intc_getBlockValuesSharedPtr",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Intc_getBlockValuesSharedPtr" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< int > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Intc_getBlockValuesSharedPtr" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< int > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::CSRBlockDescriptor< int > const *)arg1)->getBlockValuesSharedPtr();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::SharedPtr< int >(static_cast< const daal::services::SharedPtr< int >& >(result))), SWIGTYPE_p_daal__services__SharedPtrT_int_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRBlockDescriptor_Intc_getNumberOfColumns(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRBlockDescriptor< int > *arg1 = (daal::data_management::interface1::CSRBlockDescriptor< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< int > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< int > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:CSRBlockDescriptor_Intc_getNumberOfColumns",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Intc_getNumberOfColumns" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< int > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Intc_getNumberOfColumns" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< int > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::CSRBlockDescriptor< int > const *)arg1)->getNumberOfColumns();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRBlockDescriptor_Intc_getNumberOfRows(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRBlockDescriptor< int > *arg1 = (daal::data_management::interface1::CSRBlockDescriptor< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< int > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< int > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:CSRBlockDescriptor_Intc_getNumberOfRows",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Intc_getNumberOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< int > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Intc_getNumberOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< int > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::CSRBlockDescriptor< int > const *)arg1)->getNumberOfRows();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRBlockDescriptor_Intc_getDataSize(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRBlockDescriptor< int > *arg1 = (daal::data_management::interface1::CSRBlockDescriptor< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< int > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< int > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:CSRBlockDescriptor_Intc_getDataSize",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Intc_getDataSize" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< int > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Intc_getDataSize" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< int > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::CSRBlockDescriptor< int > const *)arg1)->getDataSize();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRBlockDescriptor_Intc_reset(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRBlockDescriptor< int > *arg1 = (daal::data_management::interface1::CSRBlockDescriptor< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< int > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:CSRBlockDescriptor_Intc_reset",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Intc_reset" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Intc_reset" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< int > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->reset();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRBlockDescriptor_Intc_resizeValuesBuffer(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRBlockDescriptor< int > *arg1 = (daal::data_management::interface1::CSRBlockDescriptor< int > *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< int > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:CSRBlockDescriptor_Intc_resizeValuesBuffer",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Intc_resizeValuesBuffer" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Intc_resizeValuesBuffer" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< int > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CSRBlockDescriptor_Intc_resizeValuesBuffer" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (bool)(arg1)->resizeValuesBuffer(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRBlockDescriptor_Intc_resizeRowsBuffer(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRBlockDescriptor< int > *arg1 = (daal::data_management::interface1::CSRBlockDescriptor< int > *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< int > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:CSRBlockDescriptor_Intc_resizeRowsBuffer",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Intc_resizeRowsBuffer" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Intc_resizeRowsBuffer" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< int > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CSRBlockDescriptor_Intc_resizeRowsBuffer" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (bool)(arg1)->resizeRowsBuffer(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRBlockDescriptor_Intc_setDetails(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRBlockDescriptor< int > *arg1 = (daal::data_management::interface1::CSRBlockDescriptor< int > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  int arg4 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< int > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:CSRBlockDescriptor_Intc_setDetails",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Intc_setDetails" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Intc_setDetails" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< int > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CSRBlockDescriptor_Intc_setDetails" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "CSRBlockDescriptor_Intc_setDetails" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "CSRBlockDescriptor_Intc_setDetails" "', argument " "4"" of type '" "int""'");
  } 
  arg4 = static_cast< int >(val4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->setDetails(arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRBlockDescriptor_Intc_getRowsOffset(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRBlockDescriptor< int > *arg1 = (daal::data_management::interface1::CSRBlockDescriptor< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< int > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< int > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:CSRBlockDescriptor_Intc_getRowsOffset",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Intc_getRowsOffset" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< int > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Intc_getRowsOffset" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< int > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::CSRBlockDescriptor< int > const *)arg1)->getRowsOffset();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRBlockDescriptor_Intc_getRWFlag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRBlockDescriptor< int > *arg1 = (daal::data_management::interface1::CSRBlockDescriptor< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< int > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< int > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:CSRBlockDescriptor_Intc_getRWFlag",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Intc_getRWFlag" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< int > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Intc_getRWFlag" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< int > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::CSRBlockDescriptor< int > const *)arg1)->getRWFlag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRBlockDescriptor_Intc_getBlockColumnIndices(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRBlockDescriptor< int > *arg1 = (daal::data_management::interface1::CSRBlockDescriptor< int > *) 0 ;
  size_t *arg2 = (size_t *) 0 ;
  daal::services::SharedPtr< size_t > *arg3 = (daal::services::SharedPtr< size_t > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< int > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< int > const > *smartarg1 = 0 ;
  daal::services::SharedPtr< size_t > data_temp2 ;
  size_t dim_temp2 ;
  PyObject * obj0 = 0 ;
  
  {
    arg2 = &dim_temp2;
    arg3 = &data_temp2;
  }
  if (!PyArg_ParseTuple(args,(char *)"O:CSRBlockDescriptor_Intc_getBlockColumnIndices",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Intc_getBlockColumnIndices" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< int > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Intc_getBlockColumnIndices" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< int > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        daal_data_management_interface1_CSRBlockDescriptor_Sl_int_Sg__getBlockColumnIndices((daal::data_management::interface1::CSRBlockDescriptor< int > const *)arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    npy_intp dims[1] = {
      static_cast<npy_intp>(*arg2) 
    }; // Intel/FS static-cast
    PyObject* obj = PyArray_SimpleNewFromData(1, dims, NPY_UINT64, (void*)(arg3->get()));
    if (!obj) SWIG_fail;
    set_sp_base((PyArrayObject*)obj, *arg3);
    resultobj = SWIG_Python_AppendOutput(resultobj,obj);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRBlockDescriptor_Intc_getBlockRowIndices(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRBlockDescriptor< int > *arg1 = (daal::data_management::interface1::CSRBlockDescriptor< int > *) 0 ;
  size_t *arg2 = (size_t *) 0 ;
  daal::services::SharedPtr< size_t > *arg3 = (daal::services::SharedPtr< size_t > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< int > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< int > const > *smartarg1 = 0 ;
  daal::services::SharedPtr< size_t > data_temp2 ;
  size_t dim_temp2 ;
  PyObject * obj0 = 0 ;
  
  {
    arg2 = &dim_temp2;
    arg3 = &data_temp2;
  }
  if (!PyArg_ParseTuple(args,(char *)"O:CSRBlockDescriptor_Intc_getBlockRowIndices",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Intc_getBlockRowIndices" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< int > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Intc_getBlockRowIndices" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< int > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        daal_data_management_interface1_CSRBlockDescriptor_Sl_int_Sg__getBlockRowIndices((daal::data_management::interface1::CSRBlockDescriptor< int > const *)arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    npy_intp dims[1] = {
      static_cast<npy_intp>(*arg2) 
    }; // Intel/FS static-cast
    PyObject* obj = PyArray_SimpleNewFromData(1, dims, NPY_UINT64, (void*)(arg3->get()));
    if (!obj) SWIG_fail;
    set_sp_base((PyArrayObject*)obj, *arg3);
    resultobj = SWIG_Python_AppendOutput(resultobj,obj);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CSRBlockDescriptor_Intc_getBlockValues(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CSRBlockDescriptor< int > *arg1 = (daal::data_management::interface1::CSRBlockDescriptor< int > *) 0 ;
  size_t *arg2 = (size_t *) 0 ;
  daal::services::SharedPtr< int > *arg3 = (daal::services::SharedPtr< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< int > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< int > const > *smartarg1 = 0 ;
  daal::services::SharedPtr< int > data_temp2 ;
  size_t dim_temp2 ;
  PyObject * obj0 = 0 ;
  
  {
    arg2 = &dim_temp2;
    arg3 = &data_temp2;
  }
  if (!PyArg_ParseTuple(args,(char *)"O:CSRBlockDescriptor_Intc_getBlockValues",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Intc_getBlockValues" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< int > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::CSRBlockDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CSRBlockDescriptor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CSRBlockDescriptor_Intc_getBlockValues" "', argument " "1"" of type '" "daal::data_management::interface1::CSRBlockDescriptor< int > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        daal_data_management_interface1_CSRBlockDescriptor_Sl_int_Sg__getBlockValues((daal::data_management::interface1::CSRBlockDescriptor< int > const *)arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    npy_intp dims[1] = {
      static_cast<npy_intp>(*arg2) 
    }; // Intel/FS static-cast
    PyObject* obj = PyArray_SimpleNewFromData(1, dims, NPY_INT, (void*)(arg3->get()));
    if (!obj) SWIG_fail;
    set_sp_base((PyArrayObject*)obj, *arg3);
    resultobj = SWIG_Python_AppendOutput(resultobj,obj);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *CSRBlockDescriptor_Intc_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_int_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_Compressor_Bzip2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Compressor< daal::data_management::bzip2 > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_Compressor_Bzip2")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::Compressor< daal::data_management::bzip2 > *)new daal::data_management::interface1::Compressor< daal::data_management::bzip2 >();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::bzip2 > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::bzip2 > >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_t_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_Compressor_Bzip2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Compressor< daal::data_management::bzip2 > *arg1 = (daal::data_management::interface1::Compressor< daal::data_management::bzip2 > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::bzip2 > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::bzip2 > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_Compressor_Bzip2",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Compressor_Bzip2" "', argument " "1"" of type '" "daal::data_management::interface1::Compressor< daal::data_management::bzip2 > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::bzip2 > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::bzip2 > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compressor< daal::data_management::bzip2 > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::bzip2 > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compressor< daal::data_management::bzip2 > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Compressor_Bzip2" "', argument " "1"" of type '" "daal::data_management::interface1::Compressor< daal::data_management::bzip2 > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Compressor_Bzip2_setInputDataBlock(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Compressor< daal::data_management::bzip2 > *arg1 = (daal::data_management::interface1::Compressor< daal::data_management::bzip2 > *) 0 ;
  daal::byte *arg2 = (daal::byte *) 0 ;
  size_t arg3 ;
  size_t arg4 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::bzip2 > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::bzip2 > > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int i2 = 1 ;
  int is_new_object2 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Compressor_Bzip2_setInputDataBlock",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Compressor_Bzip2_setInputDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::Compressor< daal::data_management::bzip2 > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::bzip2 > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::bzip2 > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compressor< daal::data_management::bzip2 > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::bzip2 > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compressor< daal::data_management::bzip2 > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Compressor_Bzip2_setInputDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::Compressor< daal::data_management::bzip2 > *""'"); 
  }
  {
    array2 = (FORCE_INPLACE == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UBYTE)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UBYTE, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (unsigned char*) array_data(array2);
    arg3 = (size_t) array_size(array2,0);
  }
  ecode4 = SWIG_AsVal_size_t(obj2, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Compressor_Bzip2_setInputDataBlock" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->setInputDataBlock(arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_Compressor_Bzip2_run(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Compressor< daal::data_management::bzip2 > *arg1 = (daal::data_management::interface1::Compressor< daal::data_management::bzip2 > *) 0 ;
  daal::byte *arg2 = (daal::byte *) 0 ;
  size_t arg3 ;
  size_t arg4 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::bzip2 > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::bzip2 > > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int i2 = 1 ;
  int is_new_object2 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Compressor_Bzip2_run",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Compressor_Bzip2_run" "', argument " "1"" of type '" "daal::data_management::interface1::Compressor< daal::data_management::bzip2 > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::bzip2 > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::bzip2 > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compressor< daal::data_management::bzip2 > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::bzip2 > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compressor< daal::data_management::bzip2 > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Compressor_Bzip2_run" "', argument " "1"" of type '" "daal::data_management::interface1::Compressor< daal::data_management::bzip2 > *""'"); 
  }
  {
    array2 = (FORCE_INPLACE == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UBYTE)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UBYTE, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (unsigned char*) array_data(array2);
    arg3 = (size_t) array_size(array2,0);
  }
  ecode4 = SWIG_AsVal_size_t(obj2, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Compressor_Bzip2_run" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->run(arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_Compressor_Bzip2_parameter_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Compressor< daal::data_management::bzip2 > *arg1 = (daal::data_management::interface1::Compressor< daal::data_management::bzip2 > *) 0 ;
  daal::data_management::interface1::Bzip2CompressionParameter *arg2 = (daal::data_management::interface1::Bzip2CompressionParameter *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::bzip2 > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::bzip2 > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Compressor_Bzip2_parameter_set",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Compressor_Bzip2_parameter_set" "', argument " "1"" of type '" "daal::data_management::interface1::Compressor< daal::data_management::bzip2 > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::bzip2 > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::bzip2 > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compressor< daal::data_management::bzip2 > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::bzip2 > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compressor< daal::data_management::bzip2 > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Compressor_Bzip2_parameter_set" "', argument " "1"" of type '" "daal::data_management::interface1::Compressor< daal::data_management::bzip2 > *""'"); 
  }
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_daal__data_management__interface1__Bzip2CompressionParameter, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Compressor_Bzip2_parameter_set" "', argument " "2"" of type '" "daal::data_management::interface1::Bzip2CompressionParameter *""'"); 
  }
  arg2 = reinterpret_cast< daal::data_management::interface1::Bzip2CompressionParameter * >(argp2);
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    if (arg1) (arg1)->parameter = *arg2;
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Compressor_Bzip2_parameter_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Compressor< daal::data_management::bzip2 > *arg1 = (daal::data_management::interface1::Compressor< daal::data_management::bzip2 > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::bzip2 > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::bzip2 > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::Bzip2CompressionParameter *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Compressor_Bzip2_parameter_get",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Compressor_Bzip2_parameter_get" "', argument " "1"" of type '" "daal::data_management::interface1::Compressor< daal::data_management::bzip2 > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::bzip2 > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::bzip2 > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compressor< daal::data_management::bzip2 > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::bzip2 > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compressor< daal::data_management::bzip2 > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Compressor_Bzip2_parameter_get" "', argument " "1"" of type '" "daal::data_management::interface1::Compressor< daal::data_management::bzip2 > *""'"); 
  }
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    result = (daal::data_management::interface1::Bzip2CompressionParameter *)& ((arg1)->parameter);
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_daal__data_management__interface1__Bzip2CompressionParameter, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Compressor_Bzip2_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_Compressor_Lzo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Compressor< daal::data_management::lzo > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_Compressor_Lzo")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::Compressor< daal::data_management::lzo > *)new daal::data_management::interface1::Compressor< daal::data_management::lzo >();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::lzo > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::lzo > >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__lzo_t_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_Compressor_Lzo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Compressor< daal::data_management::lzo > *arg1 = (daal::data_management::interface1::Compressor< daal::data_management::lzo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::lzo > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::lzo > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_Compressor_Lzo",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__lzo_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Compressor_Lzo" "', argument " "1"" of type '" "daal::data_management::interface1::Compressor< daal::data_management::lzo > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::lzo > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::lzo > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compressor< daal::data_management::lzo > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::lzo > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compressor< daal::data_management::lzo > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Compressor_Lzo" "', argument " "1"" of type '" "daal::data_management::interface1::Compressor< daal::data_management::lzo > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Compressor_Lzo_setInputDataBlock(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Compressor< daal::data_management::lzo > *arg1 = (daal::data_management::interface1::Compressor< daal::data_management::lzo > *) 0 ;
  daal::byte *arg2 = (daal::byte *) 0 ;
  size_t arg3 ;
  size_t arg4 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::lzo > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::lzo > > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int i2 = 1 ;
  int is_new_object2 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Compressor_Lzo_setInputDataBlock",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__lzo_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Compressor_Lzo_setInputDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::Compressor< daal::data_management::lzo > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::lzo > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::lzo > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compressor< daal::data_management::lzo > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::lzo > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compressor< daal::data_management::lzo > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Compressor_Lzo_setInputDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::Compressor< daal::data_management::lzo > *""'"); 
  }
  {
    array2 = (FORCE_INPLACE == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UBYTE)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UBYTE, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (unsigned char*) array_data(array2);
    arg3 = (size_t) array_size(array2,0);
  }
  ecode4 = SWIG_AsVal_size_t(obj2, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Compressor_Lzo_setInputDataBlock" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->setInputDataBlock(arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_Compressor_Lzo_run(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Compressor< daal::data_management::lzo > *arg1 = (daal::data_management::interface1::Compressor< daal::data_management::lzo > *) 0 ;
  daal::byte *arg2 = (daal::byte *) 0 ;
  size_t arg3 ;
  size_t arg4 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::lzo > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::lzo > > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int i2 = 1 ;
  int is_new_object2 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Compressor_Lzo_run",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__lzo_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Compressor_Lzo_run" "', argument " "1"" of type '" "daal::data_management::interface1::Compressor< daal::data_management::lzo > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::lzo > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::lzo > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compressor< daal::data_management::lzo > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::lzo > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compressor< daal::data_management::lzo > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Compressor_Lzo_run" "', argument " "1"" of type '" "daal::data_management::interface1::Compressor< daal::data_management::lzo > *""'"); 
  }
  {
    array2 = (FORCE_INPLACE == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UBYTE)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UBYTE, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (unsigned char*) array_data(array2);
    arg3 = (size_t) array_size(array2,0);
  }
  ecode4 = SWIG_AsVal_size_t(obj2, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Compressor_Lzo_run" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->run(arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_Compressor_Lzo_parameter_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Compressor< daal::data_management::lzo > *arg1 = (daal::data_management::interface1::Compressor< daal::data_management::lzo > *) 0 ;
  daal::data_management::interface1::LzoCompressionParameter *arg2 = (daal::data_management::interface1::LzoCompressionParameter *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::lzo > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::lzo > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Compressor_Lzo_parameter_set",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__lzo_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Compressor_Lzo_parameter_set" "', argument " "1"" of type '" "daal::data_management::interface1::Compressor< daal::data_management::lzo > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::lzo > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::lzo > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compressor< daal::data_management::lzo > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::lzo > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compressor< daal::data_management::lzo > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Compressor_Lzo_parameter_set" "', argument " "1"" of type '" "daal::data_management::interface1::Compressor< daal::data_management::lzo > *""'"); 
  }
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_daal__data_management__interface1__LzoCompressionParameter, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Compressor_Lzo_parameter_set" "', argument " "2"" of type '" "daal::data_management::interface1::LzoCompressionParameter *""'"); 
  }
  arg2 = reinterpret_cast< daal::data_management::interface1::LzoCompressionParameter * >(argp2);
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    if (arg1) (arg1)->parameter = *arg2;
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Compressor_Lzo_parameter_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Compressor< daal::data_management::lzo > *arg1 = (daal::data_management::interface1::Compressor< daal::data_management::lzo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::lzo > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::lzo > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::LzoCompressionParameter *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Compressor_Lzo_parameter_get",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__lzo_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Compressor_Lzo_parameter_get" "', argument " "1"" of type '" "daal::data_management::interface1::Compressor< daal::data_management::lzo > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::lzo > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::lzo > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compressor< daal::data_management::lzo > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::lzo > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compressor< daal::data_management::lzo > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Compressor_Lzo_parameter_get" "', argument " "1"" of type '" "daal::data_management::interface1::Compressor< daal::data_management::lzo > *""'"); 
  }
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    result = (daal::data_management::interface1::LzoCompressionParameter *)& ((arg1)->parameter);
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_daal__data_management__interface1__LzoCompressionParameter, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Compressor_Lzo_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__lzo_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_Compressor_Rle(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Compressor< daal::data_management::rle > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_Compressor_Rle")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::Compressor< daal::data_management::rle > *)new daal::data_management::interface1::Compressor< daal::data_management::rle >();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::rle > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::rle > >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__rle_t_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_Compressor_Rle(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Compressor< daal::data_management::rle > *arg1 = (daal::data_management::interface1::Compressor< daal::data_management::rle > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::rle > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::rle > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_Compressor_Rle",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__rle_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Compressor_Rle" "', argument " "1"" of type '" "daal::data_management::interface1::Compressor< daal::data_management::rle > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::rle > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::rle > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compressor< daal::data_management::rle > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::rle > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compressor< daal::data_management::rle > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Compressor_Rle" "', argument " "1"" of type '" "daal::data_management::interface1::Compressor< daal::data_management::rle > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Compressor_Rle_setInputDataBlock(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Compressor< daal::data_management::rle > *arg1 = (daal::data_management::interface1::Compressor< daal::data_management::rle > *) 0 ;
  daal::byte *arg2 = (daal::byte *) 0 ;
  size_t arg3 ;
  size_t arg4 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::rle > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::rle > > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int i2 = 1 ;
  int is_new_object2 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Compressor_Rle_setInputDataBlock",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__rle_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Compressor_Rle_setInputDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::Compressor< daal::data_management::rle > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::rle > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::rle > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compressor< daal::data_management::rle > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::rle > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compressor< daal::data_management::rle > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Compressor_Rle_setInputDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::Compressor< daal::data_management::rle > *""'"); 
  }
  {
    array2 = (FORCE_INPLACE == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UBYTE)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UBYTE, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (unsigned char*) array_data(array2);
    arg3 = (size_t) array_size(array2,0);
  }
  ecode4 = SWIG_AsVal_size_t(obj2, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Compressor_Rle_setInputDataBlock" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->setInputDataBlock(arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_Compressor_Rle_run(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Compressor< daal::data_management::rle > *arg1 = (daal::data_management::interface1::Compressor< daal::data_management::rle > *) 0 ;
  daal::byte *arg2 = (daal::byte *) 0 ;
  size_t arg3 ;
  size_t arg4 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::rle > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::rle > > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int i2 = 1 ;
  int is_new_object2 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Compressor_Rle_run",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__rle_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Compressor_Rle_run" "', argument " "1"" of type '" "daal::data_management::interface1::Compressor< daal::data_management::rle > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::rle > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::rle > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compressor< daal::data_management::rle > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::rle > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compressor< daal::data_management::rle > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Compressor_Rle_run" "', argument " "1"" of type '" "daal::data_management::interface1::Compressor< daal::data_management::rle > *""'"); 
  }
  {
    array2 = (FORCE_INPLACE == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UBYTE)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UBYTE, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (unsigned char*) array_data(array2);
    arg3 = (size_t) array_size(array2,0);
  }
  ecode4 = SWIG_AsVal_size_t(obj2, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Compressor_Rle_run" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->run(arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_Compressor_Rle_parameter_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Compressor< daal::data_management::rle > *arg1 = (daal::data_management::interface1::Compressor< daal::data_management::rle > *) 0 ;
  daal::data_management::interface1::RleCompressionParameter *arg2 = (daal::data_management::interface1::RleCompressionParameter *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::rle > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::rle > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Compressor_Rle_parameter_set",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__rle_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Compressor_Rle_parameter_set" "', argument " "1"" of type '" "daal::data_management::interface1::Compressor< daal::data_management::rle > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::rle > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::rle > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compressor< daal::data_management::rle > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::rle > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compressor< daal::data_management::rle > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Compressor_Rle_parameter_set" "', argument " "1"" of type '" "daal::data_management::interface1::Compressor< daal::data_management::rle > *""'"); 
  }
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_daal__data_management__interface1__RleCompressionParameter, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Compressor_Rle_parameter_set" "', argument " "2"" of type '" "daal::data_management::interface1::RleCompressionParameter *""'"); 
  }
  arg2 = reinterpret_cast< daal::data_management::interface1::RleCompressionParameter * >(argp2);
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    if (arg1) (arg1)->parameter = *arg2;
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Compressor_Rle_parameter_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Compressor< daal::data_management::rle > *arg1 = (daal::data_management::interface1::Compressor< daal::data_management::rle > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::rle > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::rle > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::RleCompressionParameter *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Compressor_Rle_parameter_get",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__rle_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Compressor_Rle_parameter_get" "', argument " "1"" of type '" "daal::data_management::interface1::Compressor< daal::data_management::rle > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::rle > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::rle > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compressor< daal::data_management::rle > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::rle > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compressor< daal::data_management::rle > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Compressor_Rle_parameter_get" "', argument " "1"" of type '" "daal::data_management::interface1::Compressor< daal::data_management::rle > *""'"); 
  }
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    result = (daal::data_management::interface1::RleCompressionParameter *)& ((arg1)->parameter);
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_daal__data_management__interface1__RleCompressionParameter, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Compressor_Rle_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__rle_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_Compressor_Zlib(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Compressor< daal::data_management::zlib > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_Compressor_Zlib")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::Compressor< daal::data_management::zlib > *)new daal::data_management::interface1::Compressor< daal::data_management::zlib >();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::zlib > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::zlib > >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__zlib_t_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_Compressor_Zlib(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Compressor< daal::data_management::zlib > *arg1 = (daal::data_management::interface1::Compressor< daal::data_management::zlib > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::zlib > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::zlib > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_Compressor_Zlib",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__zlib_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Compressor_Zlib" "', argument " "1"" of type '" "daal::data_management::interface1::Compressor< daal::data_management::zlib > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::zlib > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::zlib > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compressor< daal::data_management::zlib > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::zlib > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compressor< daal::data_management::zlib > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Compressor_Zlib" "', argument " "1"" of type '" "daal::data_management::interface1::Compressor< daal::data_management::zlib > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Compressor_Zlib_setInputDataBlock(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Compressor< daal::data_management::zlib > *arg1 = (daal::data_management::interface1::Compressor< daal::data_management::zlib > *) 0 ;
  daal::byte *arg2 = (daal::byte *) 0 ;
  size_t arg3 ;
  size_t arg4 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::zlib > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::zlib > > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int i2 = 1 ;
  int is_new_object2 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Compressor_Zlib_setInputDataBlock",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__zlib_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Compressor_Zlib_setInputDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::Compressor< daal::data_management::zlib > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::zlib > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::zlib > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compressor< daal::data_management::zlib > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::zlib > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compressor< daal::data_management::zlib > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Compressor_Zlib_setInputDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::Compressor< daal::data_management::zlib > *""'"); 
  }
  {
    array2 = (FORCE_INPLACE == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UBYTE)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UBYTE, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (unsigned char*) array_data(array2);
    arg3 = (size_t) array_size(array2,0);
  }
  ecode4 = SWIG_AsVal_size_t(obj2, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Compressor_Zlib_setInputDataBlock" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->setInputDataBlock(arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_Compressor_Zlib_run(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Compressor< daal::data_management::zlib > *arg1 = (daal::data_management::interface1::Compressor< daal::data_management::zlib > *) 0 ;
  daal::byte *arg2 = (daal::byte *) 0 ;
  size_t arg3 ;
  size_t arg4 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::zlib > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::zlib > > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int i2 = 1 ;
  int is_new_object2 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Compressor_Zlib_run",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__zlib_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Compressor_Zlib_run" "', argument " "1"" of type '" "daal::data_management::interface1::Compressor< daal::data_management::zlib > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::zlib > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::zlib > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compressor< daal::data_management::zlib > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::zlib > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compressor< daal::data_management::zlib > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Compressor_Zlib_run" "', argument " "1"" of type '" "daal::data_management::interface1::Compressor< daal::data_management::zlib > *""'"); 
  }
  {
    array2 = (FORCE_INPLACE == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UBYTE)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UBYTE, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (unsigned char*) array_data(array2);
    arg3 = (size_t) array_size(array2,0);
  }
  ecode4 = SWIG_AsVal_size_t(obj2, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Compressor_Zlib_run" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->run(arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_Compressor_Zlib_parameter_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Compressor< daal::data_management::zlib > *arg1 = (daal::data_management::interface1::Compressor< daal::data_management::zlib > *) 0 ;
  daal::data_management::interface1::ZlibCompressionParameter *arg2 = (daal::data_management::interface1::ZlibCompressionParameter *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::zlib > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::zlib > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Compressor_Zlib_parameter_set",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__zlib_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Compressor_Zlib_parameter_set" "', argument " "1"" of type '" "daal::data_management::interface1::Compressor< daal::data_management::zlib > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::zlib > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::zlib > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compressor< daal::data_management::zlib > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::zlib > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compressor< daal::data_management::zlib > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Compressor_Zlib_parameter_set" "', argument " "1"" of type '" "daal::data_management::interface1::Compressor< daal::data_management::zlib > *""'"); 
  }
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_daal__data_management__interface1__ZlibCompressionParameter, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Compressor_Zlib_parameter_set" "', argument " "2"" of type '" "daal::data_management::interface1::ZlibCompressionParameter *""'"); 
  }
  arg2 = reinterpret_cast< daal::data_management::interface1::ZlibCompressionParameter * >(argp2);
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    if (arg1) (arg1)->parameter = *arg2;
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Compressor_Zlib_parameter_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Compressor< daal::data_management::zlib > *arg1 = (daal::data_management::interface1::Compressor< daal::data_management::zlib > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::zlib > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::zlib > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::ZlibCompressionParameter *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Compressor_Zlib_parameter_get",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__zlib_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Compressor_Zlib_parameter_get" "', argument " "1"" of type '" "daal::data_management::interface1::Compressor< daal::data_management::zlib > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::zlib > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::zlib > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compressor< daal::data_management::zlib > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Compressor< daal::data_management::zlib > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Compressor< daal::data_management::zlib > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Compressor_Zlib_parameter_get" "', argument " "1"" of type '" "daal::data_management::interface1::Compressor< daal::data_management::zlib > *""'"); 
  }
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    result = (daal::data_management::interface1::ZlibCompressionParameter *)& ((arg1)->parameter);
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_daal__data_management__interface1__ZlibCompressionParameter, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Compressor_Zlib_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__zlib_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_Decompressor_Bzip2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_Decompressor_Bzip2")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > *)new daal::data_management::interface1::Decompressor< daal::data_management::bzip2 >();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_t_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_Decompressor_Bzip2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > *arg1 = (daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_Decompressor_Bzip2",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Decompressor_Bzip2" "', argument " "1"" of type '" "daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Decompressor_Bzip2" "', argument " "1"" of type '" "daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Decompressor_Bzip2_setInputDataBlock(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > *arg1 = (daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > *) 0 ;
  daal::byte *arg2 = (daal::byte *) 0 ;
  size_t arg3 ;
  size_t arg4 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int i2 = 1 ;
  int is_new_object2 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Decompressor_Bzip2_setInputDataBlock",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Decompressor_Bzip2_setInputDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Decompressor_Bzip2_setInputDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > *""'"); 
  }
  {
    array2 = (FORCE_INPLACE == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UBYTE)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UBYTE, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (unsigned char*) array_data(array2);
    arg3 = (size_t) array_size(array2,0);
  }
  ecode4 = SWIG_AsVal_size_t(obj2, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Decompressor_Bzip2_setInputDataBlock" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->setInputDataBlock(arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_Decompressor_Bzip2_run(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > *arg1 = (daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > *) 0 ;
  daal::byte *arg2 = (daal::byte *) 0 ;
  size_t arg3 ;
  size_t arg4 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int i2 = 1 ;
  int is_new_object2 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Decompressor_Bzip2_run",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Decompressor_Bzip2_run" "', argument " "1"" of type '" "daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Decompressor_Bzip2_run" "', argument " "1"" of type '" "daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > *""'"); 
  }
  {
    array2 = (FORCE_INPLACE == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UBYTE)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UBYTE, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (unsigned char*) array_data(array2);
    arg3 = (size_t) array_size(array2,0);
  }
  ecode4 = SWIG_AsVal_size_t(obj2, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Decompressor_Bzip2_run" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->run(arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_Decompressor_Bzip2_parameter_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > *arg1 = (daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > *) 0 ;
  daal::data_management::interface1::Bzip2CompressionParameter *arg2 = (daal::data_management::interface1::Bzip2CompressionParameter *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Decompressor_Bzip2_parameter_set",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Decompressor_Bzip2_parameter_set" "', argument " "1"" of type '" "daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Decompressor_Bzip2_parameter_set" "', argument " "1"" of type '" "daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > *""'"); 
  }
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_daal__data_management__interface1__Bzip2CompressionParameter, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Decompressor_Bzip2_parameter_set" "', argument " "2"" of type '" "daal::data_management::interface1::Bzip2CompressionParameter *""'"); 
  }
  arg2 = reinterpret_cast< daal::data_management::interface1::Bzip2CompressionParameter * >(argp2);
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    if (arg1) (arg1)->parameter = *arg2;
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Decompressor_Bzip2_parameter_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > *arg1 = (daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::Bzip2CompressionParameter *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Decompressor_Bzip2_parameter_get",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Decompressor_Bzip2_parameter_get" "', argument " "1"" of type '" "daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Decompressor_Bzip2_parameter_get" "', argument " "1"" of type '" "daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > *""'"); 
  }
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    result = (daal::data_management::interface1::Bzip2CompressionParameter *)& ((arg1)->parameter);
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_daal__data_management__interface1__Bzip2CompressionParameter, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Decompressor_Bzip2_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_Decompressor_Lzo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Decompressor< daal::data_management::lzo > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_Decompressor_Lzo")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::Decompressor< daal::data_management::lzo > *)new daal::data_management::interface1::Decompressor< daal::data_management::lzo >();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::lzo > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::lzo > >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_t_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_Decompressor_Lzo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Decompressor< daal::data_management::lzo > *arg1 = (daal::data_management::interface1::Decompressor< daal::data_management::lzo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::lzo > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::lzo > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_Decompressor_Lzo",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Decompressor_Lzo" "', argument " "1"" of type '" "daal::data_management::interface1::Decompressor< daal::data_management::lzo > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::lzo > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::lzo > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Decompressor< daal::data_management::lzo > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::lzo > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Decompressor< daal::data_management::lzo > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Decompressor_Lzo" "', argument " "1"" of type '" "daal::data_management::interface1::Decompressor< daal::data_management::lzo > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Decompressor_Lzo_setInputDataBlock(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Decompressor< daal::data_management::lzo > *arg1 = (daal::data_management::interface1::Decompressor< daal::data_management::lzo > *) 0 ;
  daal::byte *arg2 = (daal::byte *) 0 ;
  size_t arg3 ;
  size_t arg4 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::lzo > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::lzo > > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int i2 = 1 ;
  int is_new_object2 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Decompressor_Lzo_setInputDataBlock",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Decompressor_Lzo_setInputDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::Decompressor< daal::data_management::lzo > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::lzo > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::lzo > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Decompressor< daal::data_management::lzo > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::lzo > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Decompressor< daal::data_management::lzo > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Decompressor_Lzo_setInputDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::Decompressor< daal::data_management::lzo > *""'"); 
  }
  {
    array2 = (FORCE_INPLACE == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UBYTE)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UBYTE, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (unsigned char*) array_data(array2);
    arg3 = (size_t) array_size(array2,0);
  }
  ecode4 = SWIG_AsVal_size_t(obj2, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Decompressor_Lzo_setInputDataBlock" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->setInputDataBlock(arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_Decompressor_Lzo_run(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Decompressor< daal::data_management::lzo > *arg1 = (daal::data_management::interface1::Decompressor< daal::data_management::lzo > *) 0 ;
  daal::byte *arg2 = (daal::byte *) 0 ;
  size_t arg3 ;
  size_t arg4 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::lzo > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::lzo > > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int i2 = 1 ;
  int is_new_object2 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Decompressor_Lzo_run",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Decompressor_Lzo_run" "', argument " "1"" of type '" "daal::data_management::interface1::Decompressor< daal::data_management::lzo > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::lzo > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::lzo > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Decompressor< daal::data_management::lzo > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::lzo > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Decompressor< daal::data_management::lzo > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Decompressor_Lzo_run" "', argument " "1"" of type '" "daal::data_management::interface1::Decompressor< daal::data_management::lzo > *""'"); 
  }
  {
    array2 = (FORCE_INPLACE == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UBYTE)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UBYTE, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (unsigned char*) array_data(array2);
    arg3 = (size_t) array_size(array2,0);
  }
  ecode4 = SWIG_AsVal_size_t(obj2, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Decompressor_Lzo_run" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->run(arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_Decompressor_Lzo_parameter_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Decompressor< daal::data_management::lzo > *arg1 = (daal::data_management::interface1::Decompressor< daal::data_management::lzo > *) 0 ;
  daal::data_management::interface1::LzoCompressionParameter *arg2 = (daal::data_management::interface1::LzoCompressionParameter *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::lzo > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::lzo > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Decompressor_Lzo_parameter_set",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Decompressor_Lzo_parameter_set" "', argument " "1"" of type '" "daal::data_management::interface1::Decompressor< daal::data_management::lzo > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::lzo > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::lzo > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Decompressor< daal::data_management::lzo > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::lzo > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Decompressor< daal::data_management::lzo > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Decompressor_Lzo_parameter_set" "', argument " "1"" of type '" "daal::data_management::interface1::Decompressor< daal::data_management::lzo > *""'"); 
  }
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_daal__data_management__interface1__LzoCompressionParameter, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Decompressor_Lzo_parameter_set" "', argument " "2"" of type '" "daal::data_management::interface1::LzoCompressionParameter *""'"); 
  }
  arg2 = reinterpret_cast< daal::data_management::interface1::LzoCompressionParameter * >(argp2);
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    if (arg1) (arg1)->parameter = *arg2;
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Decompressor_Lzo_parameter_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Decompressor< daal::data_management::lzo > *arg1 = (daal::data_management::interface1::Decompressor< daal::data_management::lzo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::lzo > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::lzo > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::LzoCompressionParameter *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Decompressor_Lzo_parameter_get",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Decompressor_Lzo_parameter_get" "', argument " "1"" of type '" "daal::data_management::interface1::Decompressor< daal::data_management::lzo > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::lzo > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::lzo > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Decompressor< daal::data_management::lzo > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::lzo > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Decompressor< daal::data_management::lzo > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Decompressor_Lzo_parameter_get" "', argument " "1"" of type '" "daal::data_management::interface1::Decompressor< daal::data_management::lzo > *""'"); 
  }
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    result = (daal::data_management::interface1::LzoCompressionParameter *)& ((arg1)->parameter);
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_daal__data_management__interface1__LzoCompressionParameter, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Decompressor_Lzo_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_Decompressor_Rle(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Decompressor< daal::data_management::rle > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_Decompressor_Rle")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::Decompressor< daal::data_management::rle > *)new daal::data_management::interface1::Decompressor< daal::data_management::rle >();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::rle > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::rle > >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__rle_t_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_Decompressor_Rle(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Decompressor< daal::data_management::rle > *arg1 = (daal::data_management::interface1::Decompressor< daal::data_management::rle > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::rle > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::rle > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_Decompressor_Rle",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__rle_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Decompressor_Rle" "', argument " "1"" of type '" "daal::data_management::interface1::Decompressor< daal::data_management::rle > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::rle > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::rle > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Decompressor< daal::data_management::rle > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::rle > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Decompressor< daal::data_management::rle > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Decompressor_Rle" "', argument " "1"" of type '" "daal::data_management::interface1::Decompressor< daal::data_management::rle > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Decompressor_Rle_setInputDataBlock(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Decompressor< daal::data_management::rle > *arg1 = (daal::data_management::interface1::Decompressor< daal::data_management::rle > *) 0 ;
  daal::byte *arg2 = (daal::byte *) 0 ;
  size_t arg3 ;
  size_t arg4 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::rle > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::rle > > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int i2 = 1 ;
  int is_new_object2 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Decompressor_Rle_setInputDataBlock",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__rle_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Decompressor_Rle_setInputDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::Decompressor< daal::data_management::rle > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::rle > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::rle > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Decompressor< daal::data_management::rle > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::rle > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Decompressor< daal::data_management::rle > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Decompressor_Rle_setInputDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::Decompressor< daal::data_management::rle > *""'"); 
  }
  {
    array2 = (FORCE_INPLACE == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UBYTE)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UBYTE, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (unsigned char*) array_data(array2);
    arg3 = (size_t) array_size(array2,0);
  }
  ecode4 = SWIG_AsVal_size_t(obj2, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Decompressor_Rle_setInputDataBlock" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->setInputDataBlock(arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_Decompressor_Rle_run(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Decompressor< daal::data_management::rle > *arg1 = (daal::data_management::interface1::Decompressor< daal::data_management::rle > *) 0 ;
  daal::byte *arg2 = (daal::byte *) 0 ;
  size_t arg3 ;
  size_t arg4 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::rle > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::rle > > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int i2 = 1 ;
  int is_new_object2 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Decompressor_Rle_run",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__rle_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Decompressor_Rle_run" "', argument " "1"" of type '" "daal::data_management::interface1::Decompressor< daal::data_management::rle > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::rle > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::rle > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Decompressor< daal::data_management::rle > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::rle > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Decompressor< daal::data_management::rle > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Decompressor_Rle_run" "', argument " "1"" of type '" "daal::data_management::interface1::Decompressor< daal::data_management::rle > *""'"); 
  }
  {
    array2 = (FORCE_INPLACE == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UBYTE)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UBYTE, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (unsigned char*) array_data(array2);
    arg3 = (size_t) array_size(array2,0);
  }
  ecode4 = SWIG_AsVal_size_t(obj2, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Decompressor_Rle_run" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->run(arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_Decompressor_Rle_parameter_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Decompressor< daal::data_management::rle > *arg1 = (daal::data_management::interface1::Decompressor< daal::data_management::rle > *) 0 ;
  daal::data_management::interface1::RleCompressionParameter *arg2 = (daal::data_management::interface1::RleCompressionParameter *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::rle > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::rle > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Decompressor_Rle_parameter_set",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__rle_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Decompressor_Rle_parameter_set" "', argument " "1"" of type '" "daal::data_management::interface1::Decompressor< daal::data_management::rle > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::rle > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::rle > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Decompressor< daal::data_management::rle > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::rle > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Decompressor< daal::data_management::rle > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Decompressor_Rle_parameter_set" "', argument " "1"" of type '" "daal::data_management::interface1::Decompressor< daal::data_management::rle > *""'"); 
  }
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_daal__data_management__interface1__RleCompressionParameter, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Decompressor_Rle_parameter_set" "', argument " "2"" of type '" "daal::data_management::interface1::RleCompressionParameter *""'"); 
  }
  arg2 = reinterpret_cast< daal::data_management::interface1::RleCompressionParameter * >(argp2);
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    if (arg1) (arg1)->parameter = *arg2;
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Decompressor_Rle_parameter_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Decompressor< daal::data_management::rle > *arg1 = (daal::data_management::interface1::Decompressor< daal::data_management::rle > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::rle > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::rle > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::RleCompressionParameter *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Decompressor_Rle_parameter_get",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__rle_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Decompressor_Rle_parameter_get" "', argument " "1"" of type '" "daal::data_management::interface1::Decompressor< daal::data_management::rle > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::rle > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::rle > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Decompressor< daal::data_management::rle > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::rle > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Decompressor< daal::data_management::rle > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Decompressor_Rle_parameter_get" "', argument " "1"" of type '" "daal::data_management::interface1::Decompressor< daal::data_management::rle > *""'"); 
  }
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    result = (daal::data_management::interface1::RleCompressionParameter *)& ((arg1)->parameter);
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_daal__data_management__interface1__RleCompressionParameter, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Decompressor_Rle_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__rle_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_Decompressor_Zlib(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Decompressor< daal::data_management::zlib > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_Decompressor_Zlib")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::Decompressor< daal::data_management::zlib > *)new daal::data_management::interface1::Decompressor< daal::data_management::zlib >();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::zlib > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::zlib > >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_t_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_Decompressor_Zlib(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Decompressor< daal::data_management::zlib > *arg1 = (daal::data_management::interface1::Decompressor< daal::data_management::zlib > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::zlib > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::zlib > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_Decompressor_Zlib",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Decompressor_Zlib" "', argument " "1"" of type '" "daal::data_management::interface1::Decompressor< daal::data_management::zlib > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::zlib > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::zlib > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Decompressor< daal::data_management::zlib > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::zlib > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Decompressor< daal::data_management::zlib > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Decompressor_Zlib" "', argument " "1"" of type '" "daal::data_management::interface1::Decompressor< daal::data_management::zlib > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Decompressor_Zlib_setInputDataBlock(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Decompressor< daal::data_management::zlib > *arg1 = (daal::data_management::interface1::Decompressor< daal::data_management::zlib > *) 0 ;
  daal::byte *arg2 = (daal::byte *) 0 ;
  size_t arg3 ;
  size_t arg4 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::zlib > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::zlib > > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int i2 = 1 ;
  int is_new_object2 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Decompressor_Zlib_setInputDataBlock",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Decompressor_Zlib_setInputDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::Decompressor< daal::data_management::zlib > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::zlib > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::zlib > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Decompressor< daal::data_management::zlib > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::zlib > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Decompressor< daal::data_management::zlib > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Decompressor_Zlib_setInputDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::Decompressor< daal::data_management::zlib > *""'"); 
  }
  {
    array2 = (FORCE_INPLACE == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UBYTE)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UBYTE, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (unsigned char*) array_data(array2);
    arg3 = (size_t) array_size(array2,0);
  }
  ecode4 = SWIG_AsVal_size_t(obj2, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Decompressor_Zlib_setInputDataBlock" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->setInputDataBlock(arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_Decompressor_Zlib_run(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Decompressor< daal::data_management::zlib > *arg1 = (daal::data_management::interface1::Decompressor< daal::data_management::zlib > *) 0 ;
  daal::byte *arg2 = (daal::byte *) 0 ;
  size_t arg3 ;
  size_t arg4 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::zlib > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::zlib > > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int i2 = 1 ;
  int is_new_object2 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Decompressor_Zlib_run",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Decompressor_Zlib_run" "', argument " "1"" of type '" "daal::data_management::interface1::Decompressor< daal::data_management::zlib > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::zlib > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::zlib > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Decompressor< daal::data_management::zlib > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::zlib > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Decompressor< daal::data_management::zlib > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Decompressor_Zlib_run" "', argument " "1"" of type '" "daal::data_management::interface1::Decompressor< daal::data_management::zlib > *""'"); 
  }
  {
    array2 = (FORCE_INPLACE == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UBYTE)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UBYTE, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (unsigned char*) array_data(array2);
    arg3 = (size_t) array_size(array2,0);
  }
  ecode4 = SWIG_AsVal_size_t(obj2, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Decompressor_Zlib_run" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->run(arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(FORCE_INPLACE != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_Decompressor_Zlib_parameter_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Decompressor< daal::data_management::zlib > *arg1 = (daal::data_management::interface1::Decompressor< daal::data_management::zlib > *) 0 ;
  daal::data_management::interface1::ZlibCompressionParameter *arg2 = (daal::data_management::interface1::ZlibCompressionParameter *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::zlib > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::zlib > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Decompressor_Zlib_parameter_set",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Decompressor_Zlib_parameter_set" "', argument " "1"" of type '" "daal::data_management::interface1::Decompressor< daal::data_management::zlib > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::zlib > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::zlib > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Decompressor< daal::data_management::zlib > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::zlib > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Decompressor< daal::data_management::zlib > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Decompressor_Zlib_parameter_set" "', argument " "1"" of type '" "daal::data_management::interface1::Decompressor< daal::data_management::zlib > *""'"); 
  }
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_daal__data_management__interface1__ZlibCompressionParameter, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Decompressor_Zlib_parameter_set" "', argument " "2"" of type '" "daal::data_management::interface1::ZlibCompressionParameter *""'"); 
  }
  arg2 = reinterpret_cast< daal::data_management::interface1::ZlibCompressionParameter * >(argp2);
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    if (arg1) (arg1)->parameter = *arg2;
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Decompressor_Zlib_parameter_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Decompressor< daal::data_management::zlib > *arg1 = (daal::data_management::interface1::Decompressor< daal::data_management::zlib > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::zlib > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::zlib > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::ZlibCompressionParameter *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Decompressor_Zlib_parameter_get",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Decompressor_Zlib_parameter_get" "', argument " "1"" of type '" "daal::data_management::interface1::Decompressor< daal::data_management::zlib > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::zlib > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::zlib > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Decompressor< daal::data_management::zlib > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Decompressor< daal::data_management::zlib > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Decompressor< daal::data_management::zlib > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Decompressor_Zlib_parameter_get" "', argument " "1"" of type '" "daal::data_management::interface1::Decompressor< daal::data_management::zlib > *""'"); 
  }
  {
    SWIG_PYTHON_THREAD_BEGIN_ALLOW;
    result = (daal::data_management::interface1::ZlibCompressionParameter *)& ((arg1)->parameter);
    SWIG_PYTHON_THREAD_END_ALLOW;
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_daal__data_management__interface1__ZlibCompressionParameter, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Decompressor_Zlib_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_serializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)":HomogenNumericTable_Float64_serializationTag")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)daal::data_management::interface1::HomogenNumericTable< double >::SWIGTEMPLATEDISAMBIGUATOR serializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_getSerializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< double > *arg1 = (daal::data_management::interface1::HomogenNumericTable< double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:HomogenNumericTable_Float64_getSerializationTag",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float64_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< double > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float64_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< double > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)((daal::data_management::interface1::HomogenNumericTable< double > const *)arg1)->getSerializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_create__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTableDictionaryPtr arg1 ;
  daal::services::Status *arg2 = (daal::services::Status *) 0 ;
  void *argp1 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenNumericTable_Float64_create",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float64_create" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableDictionaryPtr""'"); 
    }
    if (argp1) arg1 = *(reinterpret_cast< daal::data_management::interface1::NumericTableDictionaryPtr * >(argp1));
    if (newmem & SWIG_CAST_NEW_MEMORY) delete reinterpret_cast< daal::data_management::interface1::NumericTableDictionaryPtr * >(argp1);
  }
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Float64_create" "', argument " "2"" of type '" "daal::services::Status *""'"); 
  }
  arg2 = reinterpret_cast< daal::services::Status * >(argp2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_create__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTableDictionaryPtr arg1 ;
  void *argp1 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:HomogenNumericTable_Float64_create",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float64_create" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableDictionaryPtr""'"); 
    }
    if (argp1) arg1 = *(reinterpret_cast< daal::data_management::interface1::NumericTableDictionaryPtr * >(argp1));
    if (newmem & SWIG_CAST_NEW_MEMORY) delete reinterpret_cast< daal::data_management::interface1::NumericTableDictionaryPtr * >(argp1);
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_create__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::Status *arg1 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:HomogenNumericTable_Float64_create",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float64_create" "', argument " "1"" of type '" "daal::services::Status *""'"); 
  }
  arg1 = reinterpret_cast< daal::services::Status * >(argp1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_create__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)":HomogenNumericTable_Float64_create")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< double >::SWIGTEMPLATEDISAMBIGUATOR create();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_create__SWIG_4(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  double *arg1 = (double *) (double *)0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:HomogenNumericTable_Float64_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_double, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float64_create" "', argument " "1"" of type '" "double *const""'"); 
  }
  arg1 = reinterpret_cast< double * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Float64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Float64_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "HomogenNumericTable_Float64_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_create__SWIG_5(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  double *arg1 = (double *) (double *)0 ;
  size_t arg2 ;
  size_t arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:HomogenNumericTable_Float64_create",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_double, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float64_create" "', argument " "1"" of type '" "double *const""'"); 
  }
  arg1 = reinterpret_cast< double * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Float64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Float64_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_create__SWIG_6(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  double *arg1 = (double *) (double *)0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenNumericTable_Float64_create",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_double, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float64_create" "', argument " "1"" of type '" "double *const""'"); 
  }
  arg1 = reinterpret_cast< double * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Float64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_create__SWIG_7(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  double *arg1 = (double *) (double *)0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:HomogenNumericTable_Float64_create",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_double, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float64_create" "', argument " "1"" of type '" "double *const""'"); 
  }
  arg1 = reinterpret_cast< double * >(argp1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_create__SWIG_8(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< double > *arg1 = 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  daal::services::SharedPtr< double > r4p1 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenNumericTable_Float64_create",&obj0,&obj1)) SWIG_fail;
  {
    int is_new_object = 0;
    PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj0, NPY_DOUBLE)
      :obj_to_array_contiguous_allow_conversion(obj0, NPY_DOUBLE, &is_new_object));
    if (!array || !require_dimensions(array, 2) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p1 = daal::services::SharedPtr< double >((double*)array_data(array), NumpyDeleter(array));
    arg1 = &r4p1;
    arg2 = (size_t) array_size(array,1);
    arg3 = (size_t) array_size(array,0);
    // we need it increment the ref-count if we use the obj0 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj0) Py_INCREF(array);
  }
  res4 = SWIG_ConvertPtr(obj1, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "HomogenNumericTable_Float64_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< double >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::SharedPtr< double > const &)*arg1,arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_create__SWIG_9(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< double > *arg1 = 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::services::SharedPtr< double > r4p1 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:HomogenNumericTable_Float64_create",&obj0)) SWIG_fail;
  {
    int is_new_object = 0;
    PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj0, NPY_DOUBLE)
      :obj_to_array_contiguous_allow_conversion(obj0, NPY_DOUBLE, &is_new_object));
    if (!array || !require_dimensions(array, 2) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p1 = daal::services::SharedPtr< double >((double*)array_data(array), NumpyDeleter(array));
    arg1 = &r4p1;
    arg2 = (size_t) array_size(array,1);
    arg3 = (size_t) array_size(array,0);
    // we need it increment the ref-count if we use the obj0 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj0) Py_INCREF(array);
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< double >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::SharedPtr< double > const &)*arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_create__SWIG_10(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  double *arg2 = (double *) (double *)0 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::services::Status *arg5 = (daal::services::Status *) 0 ;
  int val1 ;
  int ecode1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:HomogenNumericTable_Float64_create",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Float64_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_double, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Float64_create" "', argument " "2"" of type '" "double *const""'"); 
  }
  arg2 = reinterpret_cast< double * >(argp2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Float64_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Float64_create" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  res5 = SWIG_ConvertPtr(obj4, &argp5,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "HomogenNumericTable_Float64_create" "', argument " "5"" of type '" "daal::services::Status *""'"); 
  }
  arg5 = reinterpret_cast< daal::services::Status * >(argp5);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4,arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_create__SWIG_11(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  double *arg2 = (double *) (double *)0 ;
  size_t arg3 ;
  size_t arg4 ;
  int val1 ;
  int ecode1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:HomogenNumericTable_Float64_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Float64_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_double, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Float64_create" "', argument " "2"" of type '" "double *const""'"); 
  }
  arg2 = reinterpret_cast< double * >(argp2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Float64_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Float64_create" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_create__SWIG_12(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  double *arg2 = (double *) (double *)0 ;
  size_t arg3 ;
  int val1 ;
  int ecode1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:HomogenNumericTable_Float64_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Float64_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_double, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Float64_create" "', argument " "2"" of type '" "double *const""'"); 
  }
  arg2 = reinterpret_cast< double * >(argp2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Float64_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_create__SWIG_13(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  double *arg2 = (double *) (double *)0 ;
  int val1 ;
  int ecode1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenNumericTable_Float64_create",&obj0,&obj1)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Float64_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_double, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Float64_create" "', argument " "2"" of type '" "double *const""'"); 
  }
  arg2 = reinterpret_cast< double * >(argp2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_create__SWIG_14(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  int val1 ;
  int ecode1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:HomogenNumericTable_Float64_create",&obj0)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Float64_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_create__SWIG_15(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  daal::services::SharedPtr< double > *arg2 = 0 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::services::Status *arg5 = (daal::services::Status *) 0 ;
  int val1 ;
  int ecode1 = 0 ;
  daal::services::SharedPtr< double > r4p2 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:HomogenNumericTable_Float64_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Float64_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  {
    int is_new_object = 0;
    PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_DOUBLE)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_DOUBLE, &is_new_object));
    if (!array || !require_dimensions(array, 2) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p2 = daal::services::SharedPtr< double >((double*)array_data(array), NumpyDeleter(array));
    arg2 = &r4p2;
    arg3 = (size_t) array_size(array,1);
    arg4 = (size_t) array_size(array,0);
    // we need it increment the ref-count if we use the obj1 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj1) Py_INCREF(array);
  }
  res5 = SWIG_ConvertPtr(obj2, &argp5,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "HomogenNumericTable_Float64_create" "', argument " "5"" of type '" "daal::services::Status *""'"); 
  }
  arg5 = reinterpret_cast< daal::services::Status * >(argp5);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,(daal::services::SharedPtr< double > const &)*arg2,arg3,arg4,arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_create__SWIG_16(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  daal::services::SharedPtr< double > *arg2 = 0 ;
  size_t arg3 ;
  size_t arg4 ;
  int val1 ;
  int ecode1 = 0 ;
  daal::services::SharedPtr< double > r4p2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenNumericTable_Float64_create",&obj0,&obj1)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Float64_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  {
    int is_new_object = 0;
    PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_DOUBLE)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_DOUBLE, &is_new_object));
    if (!array || !require_dimensions(array, 2) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p2 = daal::services::SharedPtr< double >((double*)array_data(array), NumpyDeleter(array));
    arg2 = &r4p2;
    arg3 = (size_t) array_size(array,1);
    arg4 = (size_t) array_size(array,0);
    // we need it increment the ref-count if we use the obj1 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj1) Py_INCREF(array);
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,(daal::services::SharedPtr< double > const &)*arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_create__SWIG_17(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  double *arg1 = (double *) (double *)0 ;
  size_t arg2 ;
  size_t arg3 ;
  double *arg4 = 0 ;
  daal::services::Status *arg5 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  double temp4 ;
  double val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:HomogenNumericTable_Float64_create",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_double, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float64_create" "', argument " "1"" of type '" "double *const""'"); 
  }
  arg1 = reinterpret_cast< double * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Float64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Float64_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_double(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Float64_create" "', argument " "4"" of type '" "double""'");
  } 
  temp4 = static_cast< double >(val4);
  arg4 = &temp4;
  res5 = SWIG_ConvertPtr(obj4, &argp5,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "HomogenNumericTable_Float64_create" "', argument " "5"" of type '" "daal::services::Status *""'"); 
  }
  arg5 = reinterpret_cast< daal::services::Status * >(argp5);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,(double const &)*arg4,arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_create__SWIG_18(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  double *arg1 = (double *) (double *)0 ;
  size_t arg2 ;
  size_t arg3 ;
  double *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  double temp4 ;
  double val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:HomogenNumericTable_Float64_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_double, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float64_create" "', argument " "1"" of type '" "double *const""'"); 
  }
  arg1 = reinterpret_cast< double * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Float64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Float64_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_double(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Float64_create" "', argument " "4"" of type '" "double""'");
  } 
  temp4 = static_cast< double >(val4);
  arg4 = &temp4;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,(double const &)*arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_create__SWIG_19(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< double > *arg1 = 0 ;
  size_t arg2 ;
  size_t arg3 ;
  double *arg4 = 0 ;
  daal::services::Status *arg5 = (daal::services::Status *) 0 ;
  daal::services::SharedPtr< double > r4p1 ;
  double temp4 ;
  double val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:HomogenNumericTable_Float64_create",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int is_new_object = 0;
    PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj0, NPY_DOUBLE)
      :obj_to_array_contiguous_allow_conversion(obj0, NPY_DOUBLE, &is_new_object));
    if (!array || !require_dimensions(array, 2) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p1 = daal::services::SharedPtr< double >((double*)array_data(array), NumpyDeleter(array));
    arg1 = &r4p1;
    arg2 = (size_t) array_size(array,1);
    arg3 = (size_t) array_size(array,0);
    // we need it increment the ref-count if we use the obj0 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj0) Py_INCREF(array);
  }
  ecode4 = SWIG_AsVal_double(obj1, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Float64_create" "', argument " "4"" of type '" "double""'");
  } 
  temp4 = static_cast< double >(val4);
  arg4 = &temp4;
  res5 = SWIG_ConvertPtr(obj2, &argp5,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "HomogenNumericTable_Float64_create" "', argument " "5"" of type '" "daal::services::Status *""'"); 
  }
  arg5 = reinterpret_cast< daal::services::Status * >(argp5);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< double >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::SharedPtr< double > const &)*arg1,arg2,arg3,(double const &)*arg4,arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_create__SWIG_20(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< double > *arg1 = 0 ;
  size_t arg2 ;
  size_t arg3 ;
  double *arg4 = 0 ;
  daal::services::SharedPtr< double > r4p1 ;
  double temp4 ;
  double val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenNumericTable_Float64_create",&obj0,&obj1)) SWIG_fail;
  {
    int is_new_object = 0;
    PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj0, NPY_DOUBLE)
      :obj_to_array_contiguous_allow_conversion(obj0, NPY_DOUBLE, &is_new_object));
    if (!array || !require_dimensions(array, 2) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p1 = daal::services::SharedPtr< double >((double*)array_data(array), NumpyDeleter(array));
    arg1 = &r4p1;
    arg2 = (size_t) array_size(array,1);
    arg3 = (size_t) array_size(array,0);
    // we need it increment the ref-count if we use the obj0 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj0) Py_INCREF(array);
  }
  ecode4 = SWIG_AsVal_double(obj1, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Float64_create" "', argument " "4"" of type '" "double""'");
  } 
  temp4 = static_cast< double >(val4);
  arg4 = &temp4;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< double >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::SharedPtr< double > const &)*arg1,arg2,arg3,(double const &)*arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_create__SWIG_21(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  double *arg2 = (double *) (double *)0 ;
  size_t arg3 ;
  size_t arg4 ;
  double *arg5 = 0 ;
  daal::services::Status *arg6 = (daal::services::Status *) 0 ;
  int val1 ;
  int ecode1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  double temp5 ;
  double val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:HomogenNumericTable_Float64_create",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Float64_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_double, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Float64_create" "', argument " "2"" of type '" "double *const""'"); 
  }
  arg2 = reinterpret_cast< double * >(argp2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Float64_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Float64_create" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_double(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "HomogenNumericTable_Float64_create" "', argument " "5"" of type '" "double""'");
  } 
  temp5 = static_cast< double >(val5);
  arg5 = &temp5;
  res6 = SWIG_ConvertPtr(obj5, &argp6,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res6)) {
    SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "HomogenNumericTable_Float64_create" "', argument " "6"" of type '" "daal::services::Status *""'"); 
  }
  arg6 = reinterpret_cast< daal::services::Status * >(argp6);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4,(double const &)*arg5,arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_create__SWIG_22(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  double *arg2 = (double *) (double *)0 ;
  size_t arg3 ;
  size_t arg4 ;
  double *arg5 = 0 ;
  int val1 ;
  int ecode1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  double temp5 ;
  double val5 ;
  int ecode5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:HomogenNumericTable_Float64_create",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Float64_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_double, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Float64_create" "', argument " "2"" of type '" "double *const""'"); 
  }
  arg2 = reinterpret_cast< double * >(argp2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Float64_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Float64_create" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_double(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "HomogenNumericTable_Float64_create" "', argument " "5"" of type '" "double""'");
  } 
  temp5 = static_cast< double >(val5);
  arg5 = &temp5;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4,(double const &)*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_create__SWIG_23(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  daal::services::SharedPtr< double > *arg2 = 0 ;
  size_t arg3 ;
  size_t arg4 ;
  double *arg5 = 0 ;
  daal::services::Status *arg6 = (daal::services::Status *) 0 ;
  int val1 ;
  int ecode1 = 0 ;
  daal::services::SharedPtr< double > r4p2 ;
  double temp5 ;
  double val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:HomogenNumericTable_Float64_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Float64_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  {
    int is_new_object = 0;
    PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_DOUBLE)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_DOUBLE, &is_new_object));
    if (!array || !require_dimensions(array, 2) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p2 = daal::services::SharedPtr< double >((double*)array_data(array), NumpyDeleter(array));
    arg2 = &r4p2;
    arg3 = (size_t) array_size(array,1);
    arg4 = (size_t) array_size(array,0);
    // we need it increment the ref-count if we use the obj1 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj1) Py_INCREF(array);
  }
  ecode5 = SWIG_AsVal_double(obj2, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "HomogenNumericTable_Float64_create" "', argument " "5"" of type '" "double""'");
  } 
  temp5 = static_cast< double >(val5);
  arg5 = &temp5;
  res6 = SWIG_ConvertPtr(obj3, &argp6,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res6)) {
    SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "HomogenNumericTable_Float64_create" "', argument " "6"" of type '" "daal::services::Status *""'"); 
  }
  arg6 = reinterpret_cast< daal::services::Status * >(argp6);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,(daal::services::SharedPtr< double > const &)*arg2,arg3,arg4,(double const &)*arg5,arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_create__SWIG_24(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  daal::services::SharedPtr< double > *arg2 = 0 ;
  size_t arg3 ;
  size_t arg4 ;
  double *arg5 = 0 ;
  int val1 ;
  int ecode1 = 0 ;
  daal::services::SharedPtr< double > r4p2 ;
  double temp5 ;
  double val5 ;
  int ecode5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:HomogenNumericTable_Float64_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Float64_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  {
    int is_new_object = 0;
    PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_DOUBLE)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_DOUBLE, &is_new_object));
    if (!array || !require_dimensions(array, 2) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p2 = daal::services::SharedPtr< double >((double*)array_data(array), NumpyDeleter(array));
    arg2 = &r4p2;
    arg3 = (size_t) array_size(array,1);
    arg4 = (size_t) array_size(array,0);
    // we need it increment the ref-count if we use the obj1 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj1) Py_INCREF(array);
  }
  ecode5 = SWIG_AsVal_double(obj2, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "HomogenNumericTable_Float64_create" "', argument " "5"" of type '" "double""'");
  } 
  temp5 = static_cast< double >(val5);
  arg5 = &temp5;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,(daal::services::SharedPtr< double > const &)*arg2,arg3,arg4,(double const &)*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_create__SWIG_25(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg3 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  int val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:HomogenNumericTable_Float64_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Float64_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Float64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Float64_create" "', argument " "3"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg3 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val3);
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "HomogenNumericTable_Float64_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_create__SWIG_26(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg3 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  int val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:HomogenNumericTable_Float64_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Float64_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Float64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Float64_create" "', argument " "3"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg3 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_create__SWIG_27(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg4 ;
  daal::services::Status *arg5 = (daal::services::Status *) 0 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:HomogenNumericTable_Float64_create",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Float64_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Float64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Float64_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Float64_create" "', argument " "4"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg4 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val4);
  res5 = SWIG_ConvertPtr(obj4, &argp5,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "HomogenNumericTable_Float64_create" "', argument " "5"" of type '" "daal::services::Status *""'"); 
  }
  arg5 = reinterpret_cast< daal::services::Status * >(argp5);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4,arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_create__SWIG_28(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg4 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:HomogenNumericTable_Float64_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Float64_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Float64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Float64_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Float64_create" "', argument " "4"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg4 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_create__SWIG_29(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg3 ;
  double *arg4 = 0 ;
  daal::services::Status *arg5 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  int val3 ;
  int ecode3 = 0 ;
  double temp4 ;
  double val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:HomogenNumericTable_Float64_create",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Float64_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Float64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Float64_create" "', argument " "3"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg3 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val3);
  ecode4 = SWIG_AsVal_double(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Float64_create" "', argument " "4"" of type '" "double""'");
  } 
  temp4 = static_cast< double >(val4);
  arg4 = &temp4;
  res5 = SWIG_ConvertPtr(obj4, &argp5,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "HomogenNumericTable_Float64_create" "', argument " "5"" of type '" "daal::services::Status *""'"); 
  }
  arg5 = reinterpret_cast< daal::services::Status * >(argp5);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,(double const &)*arg4,arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_create__SWIG_30(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg3 ;
  double *arg4 = 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  int val3 ;
  int ecode3 = 0 ;
  double temp4 ;
  double val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:HomogenNumericTable_Float64_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Float64_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Float64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Float64_create" "', argument " "3"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg3 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val3);
  ecode4 = SWIG_AsVal_double(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Float64_create" "', argument " "4"" of type '" "double""'");
  } 
  temp4 = static_cast< double >(val4);
  arg4 = &temp4;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,(double const &)*arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_create__SWIG_31(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg4 ;
  double *arg5 = 0 ;
  daal::services::Status *arg6 = (daal::services::Status *) 0 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  double temp5 ;
  double val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:HomogenNumericTable_Float64_create",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Float64_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Float64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Float64_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Float64_create" "', argument " "4"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg4 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val4);
  ecode5 = SWIG_AsVal_double(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "HomogenNumericTable_Float64_create" "', argument " "5"" of type '" "double""'");
  } 
  temp5 = static_cast< double >(val5);
  arg5 = &temp5;
  res6 = SWIG_ConvertPtr(obj5, &argp6,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res6)) {
    SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "HomogenNumericTable_Float64_create" "', argument " "6"" of type '" "daal::services::Status *""'"); 
  }
  arg6 = reinterpret_cast< daal::services::Status * >(argp6);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4,(double const &)*arg5,arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_create__SWIG_32(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg4 ;
  double *arg5 = 0 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  double temp5 ;
  double val5 ;
  int ecode5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:HomogenNumericTable_Float64_create",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Float64_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Float64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Float64_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Float64_create" "', argument " "4"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg4 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val4);
  ecode5 = SWIG_AsVal_double(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "HomogenNumericTable_Float64_create" "', argument " "5"" of type '" "double""'");
  } 
  temp5 = static_cast< double >(val5);
  arg5 = &temp5;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4,(double const &)*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_create(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[7];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 6) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_HomogenNumericTable_Float64_create__SWIG_3(self, args);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_HomogenNumericTable_Float64_create__SWIG_2(self, args);
    }
  }
  if (argc == 1) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_HomogenNumericTable_Float64_create__SWIG_1(self, args);
    }
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_double, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_HomogenNumericTable_Float64_create__SWIG_7(self, args);
    }
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_HomogenNumericTable_Float64_create__SWIG_14(self, args);
    }
  }
  if (argc == 1) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_DOUBLE))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      if (argc <= 1) {
        return _wrap_HomogenNumericTable_Float64_create__SWIG_9(self, args);
      }
      if (argc <= 2) {
        return _wrap_HomogenNumericTable_Float64_create__SWIG_9(self, args);
      }
      return _wrap_HomogenNumericTable_Float64_create__SWIG_9(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_double, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_HomogenNumericTable_Float64_create__SWIG_6(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenNumericTable_Float64_create__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_double, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenNumericTable_Float64_create__SWIG_13(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        _v = (ALLOW_CONVERSION == FORCE_INPLACE
          ? (is_array(argv[1]) && PyArray_EquivTypenums(array_type(argv[1]), NPY_DOUBLE))
          :(is_array(argv[1]) || PySequence_Check(argv[1])));
      }
      if (_v) {
        if (argc <= 2) {
          return _wrap_HomogenNumericTable_Float64_create__SWIG_16(self, args);
        }
        if (argc <= 3) {
          return _wrap_HomogenNumericTable_Float64_create__SWIG_16(self, args);
        }
        return _wrap_HomogenNumericTable_Float64_create__SWIG_16(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_DOUBLE))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenNumericTable_Float64_create__SWIG_8(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_DOUBLE))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      {
        int res = SWIG_AsVal_double(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_HomogenNumericTable_Float64_create__SWIG_20(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_double, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_HomogenNumericTable_Float64_create__SWIG_5(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_double, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_HomogenNumericTable_Float64_create__SWIG_12(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        _v = (ALLOW_CONVERSION == FORCE_INPLACE
          ? (is_array(argv[1]) && PyArray_EquivTypenums(array_type(argv[1]), NPY_DOUBLE))
          :(is_array(argv[1]) || PySequence_Check(argv[1])));
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_HomogenNumericTable_Float64_create__SWIG_15(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        _v = (ALLOW_CONVERSION == FORCE_INPLACE
          ? (is_array(argv[1]) && PyArray_EquivTypenums(array_type(argv[1]), NPY_DOUBLE))
          :(is_array(argv[1]) || PySequence_Check(argv[1])));
      }
      if (_v) {
        {
          int res = SWIG_AsVal_double(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_HomogenNumericTable_Float64_create__SWIG_24(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_HomogenNumericTable_Float64_create__SWIG_26(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_DOUBLE))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      {
        int res = SWIG_AsVal_double(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_HomogenNumericTable_Float64_create__SWIG_19(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_double, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_HomogenNumericTable_Float64_create__SWIG_4(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_double, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_double(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            return _wrap_HomogenNumericTable_Float64_create__SWIG_18(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_double, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            return _wrap_HomogenNumericTable_Float64_create__SWIG_11(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            return _wrap_HomogenNumericTable_Float64_create__SWIG_28(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        _v = (ALLOW_CONVERSION == FORCE_INPLACE
          ? (is_array(argv[1]) && PyArray_EquivTypenums(array_type(argv[1]), NPY_DOUBLE))
          :(is_array(argv[1]) || PySequence_Check(argv[1])));
      }
      if (_v) {
        {
          int res = SWIG_AsVal_double(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_HomogenNumericTable_Float64_create__SWIG_23(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_HomogenNumericTable_Float64_create__SWIG_25(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_double(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            return _wrap_HomogenNumericTable_Float64_create__SWIG_30(self, args);
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_double, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_double(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            void *vptr = 0;
            int res = SWIG_ConvertPtr(argv[4], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_HomogenNumericTable_Float64_create__SWIG_17(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_double, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            void *vptr = 0;
            int res = SWIG_ConvertPtr(argv[4], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_HomogenNumericTable_Float64_create__SWIG_10(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_double, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_double(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              return _wrap_HomogenNumericTable_Float64_create__SWIG_22(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            void *vptr = 0;
            int res = SWIG_ConvertPtr(argv[4], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_HomogenNumericTable_Float64_create__SWIG_27(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_double(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              return _wrap_HomogenNumericTable_Float64_create__SWIG_32(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_double(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            void *vptr = 0;
            int res = SWIG_ConvertPtr(argv[4], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_HomogenNumericTable_Float64_create__SWIG_29(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_double, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_double(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              void *vptr = 0;
              int res = SWIG_ConvertPtr(argv[5], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_HomogenNumericTable_Float64_create__SWIG_21(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_double(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              void *vptr = 0;
              int res = SWIG_ConvertPtr(argv[5], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_HomogenNumericTable_Float64_create__SWIG_31(self, args);
              }
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'HomogenNumericTable_Float64_create'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::HomogenNumericTable< double >::create(daal::data_management::interface1::NumericTableDictionaryPtr,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenNumericTable< double >::create(daal::data_management::interface1::NumericTableDictionaryPtr)\n"
    "    daal::data_management::interface1::HomogenNumericTable< double >::create(daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenNumericTable< double >::create()\n"
    "    daal::data_management::interface1::HomogenNumericTable< double >::create(double *const,size_t,size_t,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenNumericTable< double >::create(double *const,size_t,size_t)\n"
    "    daal::data_management::interface1::HomogenNumericTable< double >::create(double *const,size_t)\n"
    "    daal::data_management::interface1::HomogenNumericTable< double >::create(double *const)\n"
    "    daal::data_management::interface1::HomogenNumericTable< double >::create(daal::services::SharedPtr< double > const &,size_t,size_t,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenNumericTable< double >::create(daal::services::SharedPtr< double > const &,size_t,size_t)\n"
    "    daal::data_management::interface1::HomogenNumericTable< double >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,double *const,size_t,size_t,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenNumericTable< double >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,double *const,size_t,size_t)\n"
    "    daal::data_management::interface1::HomogenNumericTable< double >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,double *const,size_t)\n"
    "    daal::data_management::interface1::HomogenNumericTable< double >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,double *const)\n"
    "    daal::data_management::interface1::HomogenNumericTable< double >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual)\n"
    "    daal::data_management::interface1::HomogenNumericTable< double >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,daal::services::SharedPtr< double > const &,size_t,size_t,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenNumericTable< double >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,daal::services::SharedPtr< double > const &,size_t,size_t)\n"
    "    daal::data_management::interface1::HomogenNumericTable< double >::create(double *const,size_t,size_t,double const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenNumericTable< double >::create(double *const,size_t,size_t,double const &)\n"
    "    daal::data_management::interface1::HomogenNumericTable< double >::create(daal::services::SharedPtr< double > const &,size_t,size_t,double const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenNumericTable< double >::create(daal::services::SharedPtr< double > const &,size_t,size_t,double const &)\n"
    "    daal::data_management::interface1::HomogenNumericTable< double >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,double *const,size_t,size_t,double const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenNumericTable< double >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,double *const,size_t,size_t,double const &)\n"
    "    daal::data_management::interface1::HomogenNumericTable< double >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,daal::services::SharedPtr< double > const &,size_t,size_t,double const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenNumericTable< double >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,daal::services::SharedPtr< double > const &,size_t,size_t,double const &)\n"
    "    daal::data_management::interface1::HomogenNumericTable< double >::create(size_t,size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenNumericTable< double >::create(size_t,size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag)\n"
    "    daal::data_management::interface1::HomogenNumericTable< double >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenNumericTable< double >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag)\n"
    "    daal::data_management::interface1::HomogenNumericTable< double >::create(size_t,size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag,double const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenNumericTable< double >::create(size_t,size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag,double const &)\n"
    "    daal::data_management::interface1::HomogenNumericTable< double >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag,double const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenNumericTable< double >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag,double const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_HomogenNumericTable_Float64(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< double > *arg1 = (daal::data_management::interface1::HomogenNumericTable< double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_HomogenNumericTable_Float64",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_HomogenNumericTable_Float64" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_HomogenNumericTable_Float64" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< double > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_assign__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< double > *arg1 = (daal::data_management::interface1::HomogenNumericTable< double > *) 0 ;
  float arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > *smartarg1 = 0 ;
  float val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenNumericTable_Float64_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float64_assign" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float64_assign" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< double > *""'"); 
  }
  ecode2 = SWIG_AsVal_float(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Float64_assign" "', argument " "2"" of type '" "float""'");
  } 
  arg2 = static_cast< float >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_assign__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< double > *arg1 = (daal::data_management::interface1::HomogenNumericTable< double > *) 0 ;
  double arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > *smartarg1 = 0 ;
  double val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenNumericTable_Float64_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float64_assign" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float64_assign" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< double > *""'"); 
  }
  ecode2 = SWIG_AsVal_double(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Float64_assign" "', argument " "2"" of type '" "double""'");
  } 
  arg2 = static_cast< double >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_assign__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< double > *arg1 = (daal::data_management::interface1::HomogenNumericTable< double > *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenNumericTable_Float64_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float64_assign" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float64_assign" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< double > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Float64_assign" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_assign(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_HomogenNumericTable_Float64_assign__SWIG_3(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_float(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_HomogenNumericTable_Float64_assign__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_double(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_HomogenNumericTable_Float64_assign__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'HomogenNumericTable_Float64_assign'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::HomogenNumericTable< double >::assign(float)\n"
    "    daal::data_management::interface1::HomogenNumericTable< double >::assign(double)\n"
    "    daal::data_management::interface1::HomogenNumericTable< double >::assign(int)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_getBlockOfRows__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< double > *arg1 = (daal::data_management::interface1::HomogenNumericTable< double > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:HomogenNumericTable_Float64_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float64_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float64_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< double > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Float64_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Float64_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Float64_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "HomogenNumericTable_Float64_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenNumericTable_Float64_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "HomogenNumericTable_Float64_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_getBlockOfRows__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< double > *arg1 = (daal::data_management::interface1::HomogenNumericTable< double > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:HomogenNumericTable_Float64_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float64_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float64_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< double > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Float64_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Float64_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Float64_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "HomogenNumericTable_Float64_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenNumericTable_Float64_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "HomogenNumericTable_Float64_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_getBlockOfRows__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< double > *arg1 = (daal::data_management::interface1::HomogenNumericTable< double > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:HomogenNumericTable_Float64_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float64_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float64_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< double > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Float64_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Float64_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Float64_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "HomogenNumericTable_Float64_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenNumericTable_Float64_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "HomogenNumericTable_Float64_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_getBlockOfRows(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[6];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 5) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_HomogenNumericTable_Float64_getBlockOfRows__SWIG_0(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_HomogenNumericTable_Float64_getBlockOfRows__SWIG_1(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_HomogenNumericTable_Float64_getBlockOfRows__SWIG_2(self, args);
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'HomogenNumericTable_Float64_getBlockOfRows'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::HomogenNumericTable< double >::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::HomogenNumericTable< double >::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::HomogenNumericTable< double >::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_releaseBlockOfRows__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< double > *arg1 = (daal::data_management::interface1::HomogenNumericTable< double > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenNumericTable_Float64_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float64_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float64_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< double > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Float64_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenNumericTable_Float64_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Float64_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_releaseBlockOfRows__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< double > *arg1 = (daal::data_management::interface1::HomogenNumericTable< double > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenNumericTable_Float64_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float64_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float64_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< double > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Float64_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenNumericTable_Float64_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Float64_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_releaseBlockOfRows__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< double > *arg1 = (daal::data_management::interface1::HomogenNumericTable< double > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenNumericTable_Float64_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float64_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float64_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< double > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Float64_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenNumericTable_Float64_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Float64_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_releaseBlockOfRows(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenNumericTable_Float64_releaseBlockOfRows__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenNumericTable_Float64_releaseBlockOfRows__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenNumericTable_Float64_releaseBlockOfRows__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'HomogenNumericTable_Float64_releaseBlockOfRows'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::HomogenNumericTable< double >::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::HomogenNumericTable< double >::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::HomogenNumericTable< double >::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_getBlockOfColumnValues__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< double > *arg1 = (daal::data_management::interface1::HomogenNumericTable< double > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:HomogenNumericTable_Float64_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float64_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float64_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< double > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Float64_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Float64_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Float64_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "HomogenNumericTable_Float64_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "HomogenNumericTable_Float64_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenNumericTable_Float64_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "HomogenNumericTable_Float64_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_getBlockOfColumnValues__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< double > *arg1 = (daal::data_management::interface1::HomogenNumericTable< double > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:HomogenNumericTable_Float64_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float64_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float64_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< double > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Float64_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Float64_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Float64_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "HomogenNumericTable_Float64_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "HomogenNumericTable_Float64_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenNumericTable_Float64_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "HomogenNumericTable_Float64_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_getBlockOfColumnValues__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< double > *arg1 = (daal::data_management::interface1::HomogenNumericTable< double > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:HomogenNumericTable_Float64_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float64_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float64_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< double > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Float64_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Float64_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Float64_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "HomogenNumericTable_Float64_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "HomogenNumericTable_Float64_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenNumericTable_Float64_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "HomogenNumericTable_Float64_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_getBlockOfColumnValues(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[7];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 6) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_HomogenNumericTable_Float64_getBlockOfColumnValues__SWIG_0(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_HomogenNumericTable_Float64_getBlockOfColumnValues__SWIG_1(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_HomogenNumericTable_Float64_getBlockOfColumnValues__SWIG_2(self, args);
              }
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'HomogenNumericTable_Float64_getBlockOfColumnValues'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::HomogenNumericTable< double >::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::HomogenNumericTable< double >::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::HomogenNumericTable< double >::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_releaseBlockOfColumnValues__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< double > *arg1 = (daal::data_management::interface1::HomogenNumericTable< double > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenNumericTable_Float64_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float64_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float64_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< double > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Float64_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenNumericTable_Float64_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Float64_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_releaseBlockOfColumnValues__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< double > *arg1 = (daal::data_management::interface1::HomogenNumericTable< double > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenNumericTable_Float64_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float64_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float64_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< double > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Float64_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenNumericTable_Float64_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Float64_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_releaseBlockOfColumnValues__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< double > *arg1 = (daal::data_management::interface1::HomogenNumericTable< double > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenNumericTable_Float64_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float64_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float64_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< double > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Float64_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenNumericTable_Float64_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Float64_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_releaseBlockOfColumnValues(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenNumericTable_Float64_releaseBlockOfColumnValues__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenNumericTable_Float64_releaseBlockOfColumnValues__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenNumericTable_Float64_releaseBlockOfColumnValues__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'HomogenNumericTable_Float64_releaseBlockOfColumnValues'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::HomogenNumericTable< double >::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::HomogenNumericTable< double >::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::HomogenNumericTable< double >::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64___getitem__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< double > *arg1 = (daal::data_management::interface1::HomogenNumericTable< double > *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  double *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenNumericTable_Float64___getitem__",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float64___getitem__" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float64___getitem__" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< double > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Float64___getitem__" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (double *)daal_data_management_interface1_HomogenNumericTable_Sl_double_Sg____getitem__(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_double, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float64_getArray(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< double > *arg1 = (daal::data_management::interface1::HomogenNumericTable< double > *) 0 ;
  daal::services::SharedPtr< double > *arg2 = (daal::services::SharedPtr< double > *) 0 ;
  size_t *arg3 = (size_t *) 0 ;
  size_t *arg4 = (size_t *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > *smartarg1 = 0 ;
  daal::services::SharedPtr< double > data_temp2 ;
  size_t dim1_temp2 ;
  size_t dim2_temp2 ;
  PyObject * obj0 = 0 ;
  
  {
    arg2 = &data_temp2;
    arg3 = &dim1_temp2;
    arg4 = &dim2_temp2;
  }
  if (!PyArg_ParseTuple(args,(char *)"O:HomogenNumericTable_Float64_getArray",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float64_getArray" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float64_getArray" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< double > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        daal_data_management_interface1_HomogenNumericTable_Sl_double_Sg__getArray(arg1,arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    npy_intp dims[2] = {
      static_cast<npy_intp>(*arg4), static_cast<npy_intp>(*arg3) 
    };
    PyObject* obj = PyArray_SimpleNewFromData(2, dims, NPY_DOUBLE, (void*)(arg2->get()));
    if (!obj) SWIG_fail;
    set_sp_base((PyArrayObject*)obj, *arg2);
    resultobj = SWIG_Python_AppendOutput(resultobj,obj);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *HomogenNumericTable_Float64_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_serializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)":HomogenNumericTable_Float32_serializationTag")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)daal::data_management::interface1::HomogenNumericTable< float >::SWIGTEMPLATEDISAMBIGUATOR serializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_getSerializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< float > *arg1 = (daal::data_management::interface1::HomogenNumericTable< float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:HomogenNumericTable_Float32_getSerializationTag",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float32_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< float > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float32_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< float > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)((daal::data_management::interface1::HomogenNumericTable< float > const *)arg1)->getSerializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_create__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTableDictionaryPtr arg1 ;
  daal::services::Status *arg2 = (daal::services::Status *) 0 ;
  void *argp1 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenNumericTable_Float32_create",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float32_create" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableDictionaryPtr""'"); 
    }
    if (argp1) arg1 = *(reinterpret_cast< daal::data_management::interface1::NumericTableDictionaryPtr * >(argp1));
    if (newmem & SWIG_CAST_NEW_MEMORY) delete reinterpret_cast< daal::data_management::interface1::NumericTableDictionaryPtr * >(argp1);
  }
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Float32_create" "', argument " "2"" of type '" "daal::services::Status *""'"); 
  }
  arg2 = reinterpret_cast< daal::services::Status * >(argp2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_create__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTableDictionaryPtr arg1 ;
  void *argp1 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:HomogenNumericTable_Float32_create",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float32_create" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableDictionaryPtr""'"); 
    }
    if (argp1) arg1 = *(reinterpret_cast< daal::data_management::interface1::NumericTableDictionaryPtr * >(argp1));
    if (newmem & SWIG_CAST_NEW_MEMORY) delete reinterpret_cast< daal::data_management::interface1::NumericTableDictionaryPtr * >(argp1);
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_create__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::Status *arg1 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:HomogenNumericTable_Float32_create",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float32_create" "', argument " "1"" of type '" "daal::services::Status *""'"); 
  }
  arg1 = reinterpret_cast< daal::services::Status * >(argp1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_create__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)":HomogenNumericTable_Float32_create")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< float >::SWIGTEMPLATEDISAMBIGUATOR create();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_create__SWIG_4(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  float *arg1 = (float *) (float *)0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:HomogenNumericTable_Float32_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_float, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float32_create" "', argument " "1"" of type '" "float *const""'"); 
  }
  arg1 = reinterpret_cast< float * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Float32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Float32_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "HomogenNumericTable_Float32_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_create__SWIG_5(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  float *arg1 = (float *) (float *)0 ;
  size_t arg2 ;
  size_t arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:HomogenNumericTable_Float32_create",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_float, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float32_create" "', argument " "1"" of type '" "float *const""'"); 
  }
  arg1 = reinterpret_cast< float * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Float32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Float32_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_create__SWIG_6(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  float *arg1 = (float *) (float *)0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenNumericTable_Float32_create",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_float, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float32_create" "', argument " "1"" of type '" "float *const""'"); 
  }
  arg1 = reinterpret_cast< float * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Float32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_create__SWIG_7(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  float *arg1 = (float *) (float *)0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:HomogenNumericTable_Float32_create",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_float, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float32_create" "', argument " "1"" of type '" "float *const""'"); 
  }
  arg1 = reinterpret_cast< float * >(argp1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_create__SWIG_8(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< float > *arg1 = 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  daal::services::SharedPtr< float > r4p1 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenNumericTable_Float32_create",&obj0,&obj1)) SWIG_fail;
  {
    int is_new_object = 0;
    PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj0, NPY_FLOAT)
      :obj_to_array_contiguous_allow_conversion(obj0, NPY_FLOAT, &is_new_object));
    if (!array || !require_dimensions(array, 2) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p1 = daal::services::SharedPtr< float >((float*)array_data(array), NumpyDeleter(array));
    arg1 = &r4p1;
    arg2 = (size_t) array_size(array,1);
    arg3 = (size_t) array_size(array,0);
    // we need it increment the ref-count if we use the obj0 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj0) Py_INCREF(array);
  }
  res4 = SWIG_ConvertPtr(obj1, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "HomogenNumericTable_Float32_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< float >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::SharedPtr< float > const &)*arg1,arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_create__SWIG_9(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< float > *arg1 = 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::services::SharedPtr< float > r4p1 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:HomogenNumericTable_Float32_create",&obj0)) SWIG_fail;
  {
    int is_new_object = 0;
    PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj0, NPY_FLOAT)
      :obj_to_array_contiguous_allow_conversion(obj0, NPY_FLOAT, &is_new_object));
    if (!array || !require_dimensions(array, 2) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p1 = daal::services::SharedPtr< float >((float*)array_data(array), NumpyDeleter(array));
    arg1 = &r4p1;
    arg2 = (size_t) array_size(array,1);
    arg3 = (size_t) array_size(array,0);
    // we need it increment the ref-count if we use the obj0 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj0) Py_INCREF(array);
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< float >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::SharedPtr< float > const &)*arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_create__SWIG_10(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  float *arg2 = (float *) (float *)0 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::services::Status *arg5 = (daal::services::Status *) 0 ;
  int val1 ;
  int ecode1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:HomogenNumericTable_Float32_create",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Float32_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_float, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Float32_create" "', argument " "2"" of type '" "float *const""'"); 
  }
  arg2 = reinterpret_cast< float * >(argp2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Float32_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Float32_create" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  res5 = SWIG_ConvertPtr(obj4, &argp5,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "HomogenNumericTable_Float32_create" "', argument " "5"" of type '" "daal::services::Status *""'"); 
  }
  arg5 = reinterpret_cast< daal::services::Status * >(argp5);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4,arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_create__SWIG_11(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  float *arg2 = (float *) (float *)0 ;
  size_t arg3 ;
  size_t arg4 ;
  int val1 ;
  int ecode1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:HomogenNumericTable_Float32_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Float32_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_float, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Float32_create" "', argument " "2"" of type '" "float *const""'"); 
  }
  arg2 = reinterpret_cast< float * >(argp2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Float32_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Float32_create" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_create__SWIG_12(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  float *arg2 = (float *) (float *)0 ;
  size_t arg3 ;
  int val1 ;
  int ecode1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:HomogenNumericTable_Float32_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Float32_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_float, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Float32_create" "', argument " "2"" of type '" "float *const""'"); 
  }
  arg2 = reinterpret_cast< float * >(argp2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Float32_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_create__SWIG_13(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  float *arg2 = (float *) (float *)0 ;
  int val1 ;
  int ecode1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenNumericTable_Float32_create",&obj0,&obj1)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Float32_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_float, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Float32_create" "', argument " "2"" of type '" "float *const""'"); 
  }
  arg2 = reinterpret_cast< float * >(argp2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_create__SWIG_14(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  int val1 ;
  int ecode1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:HomogenNumericTable_Float32_create",&obj0)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Float32_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_create__SWIG_15(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  daal::services::SharedPtr< float > *arg2 = 0 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::services::Status *arg5 = (daal::services::Status *) 0 ;
  int val1 ;
  int ecode1 = 0 ;
  daal::services::SharedPtr< float > r4p2 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:HomogenNumericTable_Float32_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Float32_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  {
    int is_new_object = 0;
    PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_FLOAT)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_FLOAT, &is_new_object));
    if (!array || !require_dimensions(array, 2) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p2 = daal::services::SharedPtr< float >((float*)array_data(array), NumpyDeleter(array));
    arg2 = &r4p2;
    arg3 = (size_t) array_size(array,1);
    arg4 = (size_t) array_size(array,0);
    // we need it increment the ref-count if we use the obj1 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj1) Py_INCREF(array);
  }
  res5 = SWIG_ConvertPtr(obj2, &argp5,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "HomogenNumericTable_Float32_create" "', argument " "5"" of type '" "daal::services::Status *""'"); 
  }
  arg5 = reinterpret_cast< daal::services::Status * >(argp5);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,(daal::services::SharedPtr< float > const &)*arg2,arg3,arg4,arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_create__SWIG_16(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  daal::services::SharedPtr< float > *arg2 = 0 ;
  size_t arg3 ;
  size_t arg4 ;
  int val1 ;
  int ecode1 = 0 ;
  daal::services::SharedPtr< float > r4p2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenNumericTable_Float32_create",&obj0,&obj1)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Float32_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  {
    int is_new_object = 0;
    PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_FLOAT)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_FLOAT, &is_new_object));
    if (!array || !require_dimensions(array, 2) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p2 = daal::services::SharedPtr< float >((float*)array_data(array), NumpyDeleter(array));
    arg2 = &r4p2;
    arg3 = (size_t) array_size(array,1);
    arg4 = (size_t) array_size(array,0);
    // we need it increment the ref-count if we use the obj1 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj1) Py_INCREF(array);
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,(daal::services::SharedPtr< float > const &)*arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_create__SWIG_17(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  float *arg1 = (float *) (float *)0 ;
  size_t arg2 ;
  size_t arg3 ;
  float *arg4 = 0 ;
  daal::services::Status *arg5 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  float temp4 ;
  float val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:HomogenNumericTable_Float32_create",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_float, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float32_create" "', argument " "1"" of type '" "float *const""'"); 
  }
  arg1 = reinterpret_cast< float * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Float32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Float32_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_float(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Float32_create" "', argument " "4"" of type '" "float""'");
  } 
  temp4 = static_cast< float >(val4);
  arg4 = &temp4;
  res5 = SWIG_ConvertPtr(obj4, &argp5,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "HomogenNumericTable_Float32_create" "', argument " "5"" of type '" "daal::services::Status *""'"); 
  }
  arg5 = reinterpret_cast< daal::services::Status * >(argp5);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,(float const &)*arg4,arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_create__SWIG_18(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  float *arg1 = (float *) (float *)0 ;
  size_t arg2 ;
  size_t arg3 ;
  float *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  float temp4 ;
  float val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:HomogenNumericTable_Float32_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_float, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float32_create" "', argument " "1"" of type '" "float *const""'"); 
  }
  arg1 = reinterpret_cast< float * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Float32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Float32_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_float(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Float32_create" "', argument " "4"" of type '" "float""'");
  } 
  temp4 = static_cast< float >(val4);
  arg4 = &temp4;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,(float const &)*arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_create__SWIG_19(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< float > *arg1 = 0 ;
  size_t arg2 ;
  size_t arg3 ;
  float *arg4 = 0 ;
  daal::services::Status *arg5 = (daal::services::Status *) 0 ;
  daal::services::SharedPtr< float > r4p1 ;
  float temp4 ;
  float val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:HomogenNumericTable_Float32_create",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int is_new_object = 0;
    PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj0, NPY_FLOAT)
      :obj_to_array_contiguous_allow_conversion(obj0, NPY_FLOAT, &is_new_object));
    if (!array || !require_dimensions(array, 2) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p1 = daal::services::SharedPtr< float >((float*)array_data(array), NumpyDeleter(array));
    arg1 = &r4p1;
    arg2 = (size_t) array_size(array,1);
    arg3 = (size_t) array_size(array,0);
    // we need it increment the ref-count if we use the obj0 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj0) Py_INCREF(array);
  }
  ecode4 = SWIG_AsVal_float(obj1, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Float32_create" "', argument " "4"" of type '" "float""'");
  } 
  temp4 = static_cast< float >(val4);
  arg4 = &temp4;
  res5 = SWIG_ConvertPtr(obj2, &argp5,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "HomogenNumericTable_Float32_create" "', argument " "5"" of type '" "daal::services::Status *""'"); 
  }
  arg5 = reinterpret_cast< daal::services::Status * >(argp5);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< float >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::SharedPtr< float > const &)*arg1,arg2,arg3,(float const &)*arg4,arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_create__SWIG_20(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< float > *arg1 = 0 ;
  size_t arg2 ;
  size_t arg3 ;
  float *arg4 = 0 ;
  daal::services::SharedPtr< float > r4p1 ;
  float temp4 ;
  float val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenNumericTable_Float32_create",&obj0,&obj1)) SWIG_fail;
  {
    int is_new_object = 0;
    PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj0, NPY_FLOAT)
      :obj_to_array_contiguous_allow_conversion(obj0, NPY_FLOAT, &is_new_object));
    if (!array || !require_dimensions(array, 2) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p1 = daal::services::SharedPtr< float >((float*)array_data(array), NumpyDeleter(array));
    arg1 = &r4p1;
    arg2 = (size_t) array_size(array,1);
    arg3 = (size_t) array_size(array,0);
    // we need it increment the ref-count if we use the obj0 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj0) Py_INCREF(array);
  }
  ecode4 = SWIG_AsVal_float(obj1, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Float32_create" "', argument " "4"" of type '" "float""'");
  } 
  temp4 = static_cast< float >(val4);
  arg4 = &temp4;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< float >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::SharedPtr< float > const &)*arg1,arg2,arg3,(float const &)*arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_create__SWIG_21(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  float *arg2 = (float *) (float *)0 ;
  size_t arg3 ;
  size_t arg4 ;
  float *arg5 = 0 ;
  daal::services::Status *arg6 = (daal::services::Status *) 0 ;
  int val1 ;
  int ecode1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  float temp5 ;
  float val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:HomogenNumericTable_Float32_create",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Float32_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_float, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Float32_create" "', argument " "2"" of type '" "float *const""'"); 
  }
  arg2 = reinterpret_cast< float * >(argp2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Float32_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Float32_create" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_float(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "HomogenNumericTable_Float32_create" "', argument " "5"" of type '" "float""'");
  } 
  temp5 = static_cast< float >(val5);
  arg5 = &temp5;
  res6 = SWIG_ConvertPtr(obj5, &argp6,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res6)) {
    SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "HomogenNumericTable_Float32_create" "', argument " "6"" of type '" "daal::services::Status *""'"); 
  }
  arg6 = reinterpret_cast< daal::services::Status * >(argp6);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4,(float const &)*arg5,arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_create__SWIG_22(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  float *arg2 = (float *) (float *)0 ;
  size_t arg3 ;
  size_t arg4 ;
  float *arg5 = 0 ;
  int val1 ;
  int ecode1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  float temp5 ;
  float val5 ;
  int ecode5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:HomogenNumericTable_Float32_create",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Float32_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_float, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Float32_create" "', argument " "2"" of type '" "float *const""'"); 
  }
  arg2 = reinterpret_cast< float * >(argp2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Float32_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Float32_create" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_float(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "HomogenNumericTable_Float32_create" "', argument " "5"" of type '" "float""'");
  } 
  temp5 = static_cast< float >(val5);
  arg5 = &temp5;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4,(float const &)*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_create__SWIG_23(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  daal::services::SharedPtr< float > *arg2 = 0 ;
  size_t arg3 ;
  size_t arg4 ;
  float *arg5 = 0 ;
  daal::services::Status *arg6 = (daal::services::Status *) 0 ;
  int val1 ;
  int ecode1 = 0 ;
  daal::services::SharedPtr< float > r4p2 ;
  float temp5 ;
  float val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:HomogenNumericTable_Float32_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Float32_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  {
    int is_new_object = 0;
    PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_FLOAT)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_FLOAT, &is_new_object));
    if (!array || !require_dimensions(array, 2) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p2 = daal::services::SharedPtr< float >((float*)array_data(array), NumpyDeleter(array));
    arg2 = &r4p2;
    arg3 = (size_t) array_size(array,1);
    arg4 = (size_t) array_size(array,0);
    // we need it increment the ref-count if we use the obj1 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj1) Py_INCREF(array);
  }
  ecode5 = SWIG_AsVal_float(obj2, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "HomogenNumericTable_Float32_create" "', argument " "5"" of type '" "float""'");
  } 
  temp5 = static_cast< float >(val5);
  arg5 = &temp5;
  res6 = SWIG_ConvertPtr(obj3, &argp6,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res6)) {
    SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "HomogenNumericTable_Float32_create" "', argument " "6"" of type '" "daal::services::Status *""'"); 
  }
  arg6 = reinterpret_cast< daal::services::Status * >(argp6);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,(daal::services::SharedPtr< float > const &)*arg2,arg3,arg4,(float const &)*arg5,arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_create__SWIG_24(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  daal::services::SharedPtr< float > *arg2 = 0 ;
  size_t arg3 ;
  size_t arg4 ;
  float *arg5 = 0 ;
  int val1 ;
  int ecode1 = 0 ;
  daal::services::SharedPtr< float > r4p2 ;
  float temp5 ;
  float val5 ;
  int ecode5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:HomogenNumericTable_Float32_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Float32_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  {
    int is_new_object = 0;
    PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_FLOAT)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_FLOAT, &is_new_object));
    if (!array || !require_dimensions(array, 2) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p2 = daal::services::SharedPtr< float >((float*)array_data(array), NumpyDeleter(array));
    arg2 = &r4p2;
    arg3 = (size_t) array_size(array,1);
    arg4 = (size_t) array_size(array,0);
    // we need it increment the ref-count if we use the obj1 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj1) Py_INCREF(array);
  }
  ecode5 = SWIG_AsVal_float(obj2, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "HomogenNumericTable_Float32_create" "', argument " "5"" of type '" "float""'");
  } 
  temp5 = static_cast< float >(val5);
  arg5 = &temp5;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,(daal::services::SharedPtr< float > const &)*arg2,arg3,arg4,(float const &)*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_create__SWIG_25(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg3 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  int val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:HomogenNumericTable_Float32_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Float32_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Float32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Float32_create" "', argument " "3"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg3 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val3);
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "HomogenNumericTable_Float32_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_create__SWIG_26(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg3 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  int val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:HomogenNumericTable_Float32_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Float32_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Float32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Float32_create" "', argument " "3"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg3 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_create__SWIG_27(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg4 ;
  daal::services::Status *arg5 = (daal::services::Status *) 0 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:HomogenNumericTable_Float32_create",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Float32_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Float32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Float32_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Float32_create" "', argument " "4"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg4 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val4);
  res5 = SWIG_ConvertPtr(obj4, &argp5,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "HomogenNumericTable_Float32_create" "', argument " "5"" of type '" "daal::services::Status *""'"); 
  }
  arg5 = reinterpret_cast< daal::services::Status * >(argp5);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4,arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_create__SWIG_28(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg4 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:HomogenNumericTable_Float32_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Float32_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Float32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Float32_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Float32_create" "', argument " "4"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg4 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_create__SWIG_29(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg3 ;
  float *arg4 = 0 ;
  daal::services::Status *arg5 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  int val3 ;
  int ecode3 = 0 ;
  float temp4 ;
  float val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:HomogenNumericTable_Float32_create",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Float32_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Float32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Float32_create" "', argument " "3"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg3 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val3);
  ecode4 = SWIG_AsVal_float(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Float32_create" "', argument " "4"" of type '" "float""'");
  } 
  temp4 = static_cast< float >(val4);
  arg4 = &temp4;
  res5 = SWIG_ConvertPtr(obj4, &argp5,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "HomogenNumericTable_Float32_create" "', argument " "5"" of type '" "daal::services::Status *""'"); 
  }
  arg5 = reinterpret_cast< daal::services::Status * >(argp5);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,(float const &)*arg4,arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_create__SWIG_30(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg3 ;
  float *arg4 = 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  int val3 ;
  int ecode3 = 0 ;
  float temp4 ;
  float val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:HomogenNumericTable_Float32_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Float32_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Float32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Float32_create" "', argument " "3"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg3 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val3);
  ecode4 = SWIG_AsVal_float(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Float32_create" "', argument " "4"" of type '" "float""'");
  } 
  temp4 = static_cast< float >(val4);
  arg4 = &temp4;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,(float const &)*arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_create__SWIG_31(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg4 ;
  float *arg5 = 0 ;
  daal::services::Status *arg6 = (daal::services::Status *) 0 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  float temp5 ;
  float val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:HomogenNumericTable_Float32_create",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Float32_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Float32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Float32_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Float32_create" "', argument " "4"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg4 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val4);
  ecode5 = SWIG_AsVal_float(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "HomogenNumericTable_Float32_create" "', argument " "5"" of type '" "float""'");
  } 
  temp5 = static_cast< float >(val5);
  arg5 = &temp5;
  res6 = SWIG_ConvertPtr(obj5, &argp6,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res6)) {
    SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "HomogenNumericTable_Float32_create" "', argument " "6"" of type '" "daal::services::Status *""'"); 
  }
  arg6 = reinterpret_cast< daal::services::Status * >(argp6);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4,(float const &)*arg5,arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_create__SWIG_32(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg4 ;
  float *arg5 = 0 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  float temp5 ;
  float val5 ;
  int ecode5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:HomogenNumericTable_Float32_create",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Float32_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Float32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Float32_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Float32_create" "', argument " "4"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg4 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val4);
  ecode5 = SWIG_AsVal_float(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "HomogenNumericTable_Float32_create" "', argument " "5"" of type '" "float""'");
  } 
  temp5 = static_cast< float >(val5);
  arg5 = &temp5;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4,(float const &)*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_create(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[7];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 6) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_HomogenNumericTable_Float32_create__SWIG_3(self, args);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_HomogenNumericTable_Float32_create__SWIG_2(self, args);
    }
  }
  if (argc == 1) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_HomogenNumericTable_Float32_create__SWIG_1(self, args);
    }
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_float, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_HomogenNumericTable_Float32_create__SWIG_7(self, args);
    }
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_HomogenNumericTable_Float32_create__SWIG_14(self, args);
    }
  }
  if (argc == 1) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_FLOAT))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      if (argc <= 1) {
        return _wrap_HomogenNumericTable_Float32_create__SWIG_9(self, args);
      }
      if (argc <= 2) {
        return _wrap_HomogenNumericTable_Float32_create__SWIG_9(self, args);
      }
      return _wrap_HomogenNumericTable_Float32_create__SWIG_9(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_float, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_HomogenNumericTable_Float32_create__SWIG_6(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenNumericTable_Float32_create__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_float, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenNumericTable_Float32_create__SWIG_13(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        _v = (ALLOW_CONVERSION == FORCE_INPLACE
          ? (is_array(argv[1]) && PyArray_EquivTypenums(array_type(argv[1]), NPY_FLOAT))
          :(is_array(argv[1]) || PySequence_Check(argv[1])));
      }
      if (_v) {
        if (argc <= 2) {
          return _wrap_HomogenNumericTable_Float32_create__SWIG_16(self, args);
        }
        if (argc <= 3) {
          return _wrap_HomogenNumericTable_Float32_create__SWIG_16(self, args);
        }
        return _wrap_HomogenNumericTable_Float32_create__SWIG_16(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_FLOAT))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenNumericTable_Float32_create__SWIG_8(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_FLOAT))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      {
        int res = SWIG_AsVal_float(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_HomogenNumericTable_Float32_create__SWIG_20(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_float, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_HomogenNumericTable_Float32_create__SWIG_5(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_float, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_HomogenNumericTable_Float32_create__SWIG_12(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        _v = (ALLOW_CONVERSION == FORCE_INPLACE
          ? (is_array(argv[1]) && PyArray_EquivTypenums(array_type(argv[1]), NPY_FLOAT))
          :(is_array(argv[1]) || PySequence_Check(argv[1])));
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_HomogenNumericTable_Float32_create__SWIG_15(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        _v = (ALLOW_CONVERSION == FORCE_INPLACE
          ? (is_array(argv[1]) && PyArray_EquivTypenums(array_type(argv[1]), NPY_FLOAT))
          :(is_array(argv[1]) || PySequence_Check(argv[1])));
      }
      if (_v) {
        {
          int res = SWIG_AsVal_float(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_HomogenNumericTable_Float32_create__SWIG_24(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_HomogenNumericTable_Float32_create__SWIG_26(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_FLOAT))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      {
        int res = SWIG_AsVal_float(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_HomogenNumericTable_Float32_create__SWIG_19(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_float, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_HomogenNumericTable_Float32_create__SWIG_4(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_float, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_float(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            return _wrap_HomogenNumericTable_Float32_create__SWIG_18(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_float, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            return _wrap_HomogenNumericTable_Float32_create__SWIG_11(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            return _wrap_HomogenNumericTable_Float32_create__SWIG_28(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        _v = (ALLOW_CONVERSION == FORCE_INPLACE
          ? (is_array(argv[1]) && PyArray_EquivTypenums(array_type(argv[1]), NPY_FLOAT))
          :(is_array(argv[1]) || PySequence_Check(argv[1])));
      }
      if (_v) {
        {
          int res = SWIG_AsVal_float(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_HomogenNumericTable_Float32_create__SWIG_23(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_HomogenNumericTable_Float32_create__SWIG_25(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_float(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            return _wrap_HomogenNumericTable_Float32_create__SWIG_30(self, args);
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_float, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_float(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            void *vptr = 0;
            int res = SWIG_ConvertPtr(argv[4], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_HomogenNumericTable_Float32_create__SWIG_17(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_float, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            void *vptr = 0;
            int res = SWIG_ConvertPtr(argv[4], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_HomogenNumericTable_Float32_create__SWIG_10(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_float, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_float(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              return _wrap_HomogenNumericTable_Float32_create__SWIG_22(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            void *vptr = 0;
            int res = SWIG_ConvertPtr(argv[4], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_HomogenNumericTable_Float32_create__SWIG_27(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_float(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              return _wrap_HomogenNumericTable_Float32_create__SWIG_32(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_float(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            void *vptr = 0;
            int res = SWIG_ConvertPtr(argv[4], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_HomogenNumericTable_Float32_create__SWIG_29(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_float, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_float(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              void *vptr = 0;
              int res = SWIG_ConvertPtr(argv[5], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_HomogenNumericTable_Float32_create__SWIG_21(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_float(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              void *vptr = 0;
              int res = SWIG_ConvertPtr(argv[5], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_HomogenNumericTable_Float32_create__SWIG_31(self, args);
              }
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'HomogenNumericTable_Float32_create'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::HomogenNumericTable< float >::create(daal::data_management::interface1::NumericTableDictionaryPtr,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenNumericTable< float >::create(daal::data_management::interface1::NumericTableDictionaryPtr)\n"
    "    daal::data_management::interface1::HomogenNumericTable< float >::create(daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenNumericTable< float >::create()\n"
    "    daal::data_management::interface1::HomogenNumericTable< float >::create(float *const,size_t,size_t,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenNumericTable< float >::create(float *const,size_t,size_t)\n"
    "    daal::data_management::interface1::HomogenNumericTable< float >::create(float *const,size_t)\n"
    "    daal::data_management::interface1::HomogenNumericTable< float >::create(float *const)\n"
    "    daal::data_management::interface1::HomogenNumericTable< float >::create(daal::services::SharedPtr< float > const &,size_t,size_t,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenNumericTable< float >::create(daal::services::SharedPtr< float > const &,size_t,size_t)\n"
    "    daal::data_management::interface1::HomogenNumericTable< float >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,float *const,size_t,size_t,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenNumericTable< float >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,float *const,size_t,size_t)\n"
    "    daal::data_management::interface1::HomogenNumericTable< float >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,float *const,size_t)\n"
    "    daal::data_management::interface1::HomogenNumericTable< float >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,float *const)\n"
    "    daal::data_management::interface1::HomogenNumericTable< float >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual)\n"
    "    daal::data_management::interface1::HomogenNumericTable< float >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,daal::services::SharedPtr< float > const &,size_t,size_t,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenNumericTable< float >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,daal::services::SharedPtr< float > const &,size_t,size_t)\n"
    "    daal::data_management::interface1::HomogenNumericTable< float >::create(float *const,size_t,size_t,float const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenNumericTable< float >::create(float *const,size_t,size_t,float const &)\n"
    "    daal::data_management::interface1::HomogenNumericTable< float >::create(daal::services::SharedPtr< float > const &,size_t,size_t,float const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenNumericTable< float >::create(daal::services::SharedPtr< float > const &,size_t,size_t,float const &)\n"
    "    daal::data_management::interface1::HomogenNumericTable< float >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,float *const,size_t,size_t,float const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenNumericTable< float >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,float *const,size_t,size_t,float const &)\n"
    "    daal::data_management::interface1::HomogenNumericTable< float >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,daal::services::SharedPtr< float > const &,size_t,size_t,float const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenNumericTable< float >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,daal::services::SharedPtr< float > const &,size_t,size_t,float const &)\n"
    "    daal::data_management::interface1::HomogenNumericTable< float >::create(size_t,size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenNumericTable< float >::create(size_t,size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag)\n"
    "    daal::data_management::interface1::HomogenNumericTable< float >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenNumericTable< float >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag)\n"
    "    daal::data_management::interface1::HomogenNumericTable< float >::create(size_t,size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag,float const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenNumericTable< float >::create(size_t,size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag,float const &)\n"
    "    daal::data_management::interface1::HomogenNumericTable< float >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag,float const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenNumericTable< float >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag,float const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_HomogenNumericTable_Float32(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< float > *arg1 = (daal::data_management::interface1::HomogenNumericTable< float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_HomogenNumericTable_Float32",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_HomogenNumericTable_Float32" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_HomogenNumericTable_Float32" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< float > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_assign__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< float > *arg1 = (daal::data_management::interface1::HomogenNumericTable< float > *) 0 ;
  float arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > *smartarg1 = 0 ;
  float val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenNumericTable_Float32_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float32_assign" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float32_assign" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< float > *""'"); 
  }
  ecode2 = SWIG_AsVal_float(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Float32_assign" "', argument " "2"" of type '" "float""'");
  } 
  arg2 = static_cast< float >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_assign__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< float > *arg1 = (daal::data_management::interface1::HomogenNumericTable< float > *) 0 ;
  double arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > *smartarg1 = 0 ;
  double val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenNumericTable_Float32_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float32_assign" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float32_assign" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< float > *""'"); 
  }
  ecode2 = SWIG_AsVal_double(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Float32_assign" "', argument " "2"" of type '" "double""'");
  } 
  arg2 = static_cast< double >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_assign__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< float > *arg1 = (daal::data_management::interface1::HomogenNumericTable< float > *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenNumericTable_Float32_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float32_assign" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float32_assign" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< float > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Float32_assign" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_assign(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_HomogenNumericTable_Float32_assign__SWIG_3(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_float(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_HomogenNumericTable_Float32_assign__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_double(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_HomogenNumericTable_Float32_assign__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'HomogenNumericTable_Float32_assign'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::HomogenNumericTable< float >::assign(float)\n"
    "    daal::data_management::interface1::HomogenNumericTable< float >::assign(double)\n"
    "    daal::data_management::interface1::HomogenNumericTable< float >::assign(int)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_getBlockOfRows__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< float > *arg1 = (daal::data_management::interface1::HomogenNumericTable< float > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:HomogenNumericTable_Float32_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float32_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float32_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< float > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Float32_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Float32_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Float32_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "HomogenNumericTable_Float32_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenNumericTable_Float32_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "HomogenNumericTable_Float32_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_getBlockOfRows__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< float > *arg1 = (daal::data_management::interface1::HomogenNumericTable< float > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:HomogenNumericTable_Float32_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float32_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float32_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< float > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Float32_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Float32_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Float32_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "HomogenNumericTable_Float32_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenNumericTable_Float32_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "HomogenNumericTable_Float32_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_getBlockOfRows__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< float > *arg1 = (daal::data_management::interface1::HomogenNumericTable< float > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:HomogenNumericTable_Float32_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float32_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float32_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< float > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Float32_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Float32_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Float32_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "HomogenNumericTable_Float32_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenNumericTable_Float32_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "HomogenNumericTable_Float32_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_getBlockOfRows(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[6];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 5) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_HomogenNumericTable_Float32_getBlockOfRows__SWIG_0(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_HomogenNumericTable_Float32_getBlockOfRows__SWIG_1(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_HomogenNumericTable_Float32_getBlockOfRows__SWIG_2(self, args);
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'HomogenNumericTable_Float32_getBlockOfRows'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::HomogenNumericTable< float >::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::HomogenNumericTable< float >::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::HomogenNumericTable< float >::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_releaseBlockOfRows__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< float > *arg1 = (daal::data_management::interface1::HomogenNumericTable< float > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenNumericTable_Float32_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float32_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float32_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< float > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Float32_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenNumericTable_Float32_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Float32_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_releaseBlockOfRows__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< float > *arg1 = (daal::data_management::interface1::HomogenNumericTable< float > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenNumericTable_Float32_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float32_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float32_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< float > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Float32_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenNumericTable_Float32_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Float32_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_releaseBlockOfRows__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< float > *arg1 = (daal::data_management::interface1::HomogenNumericTable< float > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenNumericTable_Float32_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float32_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float32_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< float > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Float32_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenNumericTable_Float32_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Float32_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_releaseBlockOfRows(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenNumericTable_Float32_releaseBlockOfRows__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenNumericTable_Float32_releaseBlockOfRows__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenNumericTable_Float32_releaseBlockOfRows__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'HomogenNumericTable_Float32_releaseBlockOfRows'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::HomogenNumericTable< float >::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::HomogenNumericTable< float >::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::HomogenNumericTable< float >::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_getBlockOfColumnValues__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< float > *arg1 = (daal::data_management::interface1::HomogenNumericTable< float > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:HomogenNumericTable_Float32_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float32_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float32_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< float > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Float32_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Float32_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Float32_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "HomogenNumericTable_Float32_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "HomogenNumericTable_Float32_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenNumericTable_Float32_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "HomogenNumericTable_Float32_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_getBlockOfColumnValues__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< float > *arg1 = (daal::data_management::interface1::HomogenNumericTable< float > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:HomogenNumericTable_Float32_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float32_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float32_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< float > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Float32_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Float32_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Float32_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "HomogenNumericTable_Float32_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "HomogenNumericTable_Float32_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenNumericTable_Float32_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "HomogenNumericTable_Float32_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_getBlockOfColumnValues__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< float > *arg1 = (daal::data_management::interface1::HomogenNumericTable< float > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:HomogenNumericTable_Float32_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float32_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float32_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< float > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Float32_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Float32_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Float32_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "HomogenNumericTable_Float32_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "HomogenNumericTable_Float32_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenNumericTable_Float32_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "HomogenNumericTable_Float32_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_getBlockOfColumnValues(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[7];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 6) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_HomogenNumericTable_Float32_getBlockOfColumnValues__SWIG_0(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_HomogenNumericTable_Float32_getBlockOfColumnValues__SWIG_1(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_HomogenNumericTable_Float32_getBlockOfColumnValues__SWIG_2(self, args);
              }
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'HomogenNumericTable_Float32_getBlockOfColumnValues'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::HomogenNumericTable< float >::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::HomogenNumericTable< float >::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::HomogenNumericTable< float >::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_releaseBlockOfColumnValues__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< float > *arg1 = (daal::data_management::interface1::HomogenNumericTable< float > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenNumericTable_Float32_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float32_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float32_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< float > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Float32_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenNumericTable_Float32_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Float32_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_releaseBlockOfColumnValues__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< float > *arg1 = (daal::data_management::interface1::HomogenNumericTable< float > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenNumericTable_Float32_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float32_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float32_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< float > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Float32_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenNumericTable_Float32_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Float32_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_releaseBlockOfColumnValues__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< float > *arg1 = (daal::data_management::interface1::HomogenNumericTable< float > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenNumericTable_Float32_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float32_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float32_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< float > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Float32_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenNumericTable_Float32_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Float32_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_releaseBlockOfColumnValues(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenNumericTable_Float32_releaseBlockOfColumnValues__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenNumericTable_Float32_releaseBlockOfColumnValues__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenNumericTable_Float32_releaseBlockOfColumnValues__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'HomogenNumericTable_Float32_releaseBlockOfColumnValues'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::HomogenNumericTable< float >::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::HomogenNumericTable< float >::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::HomogenNumericTable< float >::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32___getitem__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< float > *arg1 = (daal::data_management::interface1::HomogenNumericTable< float > *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  float *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenNumericTable_Float32___getitem__",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float32___getitem__" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float32___getitem__" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< float > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Float32___getitem__" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (float *)daal_data_management_interface1_HomogenNumericTable_Sl_float_Sg____getitem__(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_float, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Float32_getArray(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< float > *arg1 = (daal::data_management::interface1::HomogenNumericTable< float > *) 0 ;
  daal::services::SharedPtr< float > *arg2 = (daal::services::SharedPtr< float > *) 0 ;
  size_t *arg3 = (size_t *) 0 ;
  size_t *arg4 = (size_t *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > *smartarg1 = 0 ;
  daal::services::SharedPtr< float > data_temp2 ;
  size_t dim1_temp2 ;
  size_t dim2_temp2 ;
  PyObject * obj0 = 0 ;
  
  {
    arg2 = &data_temp2;
    arg3 = &dim1_temp2;
    arg4 = &dim2_temp2;
  }
  if (!PyArg_ParseTuple(args,(char *)"O:HomogenNumericTable_Float32_getArray",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float32_getArray" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Float32_getArray" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< float > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        daal_data_management_interface1_HomogenNumericTable_Sl_float_Sg__getArray(arg1,arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    npy_intp dims[2] = {
      static_cast<npy_intp>(*arg4), static_cast<npy_intp>(*arg3) 
    };
    PyObject* obj = PyArray_SimpleNewFromData(2, dims, NPY_FLOAT, (void*)(arg2->get()));
    if (!obj) SWIG_fail;
    set_sp_base((PyArrayObject*)obj, *arg2);
    resultobj = SWIG_Python_AppendOutput(resultobj,obj);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *HomogenNumericTable_Float32_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_serializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)":HomogenNumericTable_Intc_serializationTag")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)daal::data_management::interface1::HomogenNumericTable< int >::SWIGTEMPLATEDISAMBIGUATOR serializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_getSerializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< int > *arg1 = (daal::data_management::interface1::HomogenNumericTable< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:HomogenNumericTable_Intc_getSerializationTag",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Intc_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< int > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Intc_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< int > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)((daal::data_management::interface1::HomogenNumericTable< int > const *)arg1)->getSerializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_create__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTableDictionaryPtr arg1 ;
  daal::services::Status *arg2 = (daal::services::Status *) 0 ;
  void *argp1 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenNumericTable_Intc_create",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Intc_create" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableDictionaryPtr""'"); 
    }
    if (argp1) arg1 = *(reinterpret_cast< daal::data_management::interface1::NumericTableDictionaryPtr * >(argp1));
    if (newmem & SWIG_CAST_NEW_MEMORY) delete reinterpret_cast< daal::data_management::interface1::NumericTableDictionaryPtr * >(argp1);
  }
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Intc_create" "', argument " "2"" of type '" "daal::services::Status *""'"); 
  }
  arg2 = reinterpret_cast< daal::services::Status * >(argp2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_create__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::NumericTableDictionaryPtr arg1 ;
  void *argp1 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:HomogenNumericTable_Intc_create",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Intc_create" "', argument " "1"" of type '" "daal::data_management::interface1::NumericTableDictionaryPtr""'"); 
    }
    if (argp1) arg1 = *(reinterpret_cast< daal::data_management::interface1::NumericTableDictionaryPtr * >(argp1));
    if (newmem & SWIG_CAST_NEW_MEMORY) delete reinterpret_cast< daal::data_management::interface1::NumericTableDictionaryPtr * >(argp1);
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_create__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::Status *arg1 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:HomogenNumericTable_Intc_create",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Intc_create" "', argument " "1"" of type '" "daal::services::Status *""'"); 
  }
  arg1 = reinterpret_cast< daal::services::Status * >(argp1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_create__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)":HomogenNumericTable_Intc_create")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< int >::SWIGTEMPLATEDISAMBIGUATOR create();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_create__SWIG_4(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int *arg1 = (int *) (int *)0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:HomogenNumericTable_Intc_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_int, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Intc_create" "', argument " "1"" of type '" "int *const""'"); 
  }
  arg1 = reinterpret_cast< int * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Intc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Intc_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "HomogenNumericTable_Intc_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_create__SWIG_5(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int *arg1 = (int *) (int *)0 ;
  size_t arg2 ;
  size_t arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:HomogenNumericTable_Intc_create",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_int, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Intc_create" "', argument " "1"" of type '" "int *const""'"); 
  }
  arg1 = reinterpret_cast< int * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Intc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Intc_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_create__SWIG_6(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int *arg1 = (int *) (int *)0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenNumericTable_Intc_create",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_int, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Intc_create" "', argument " "1"" of type '" "int *const""'"); 
  }
  arg1 = reinterpret_cast< int * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Intc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_create__SWIG_7(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int *arg1 = (int *) (int *)0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:HomogenNumericTable_Intc_create",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_int, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Intc_create" "', argument " "1"" of type '" "int *const""'"); 
  }
  arg1 = reinterpret_cast< int * >(argp1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_create__SWIG_8(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< int > *arg1 = 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  daal::services::SharedPtr< int > r4p1 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenNumericTable_Intc_create",&obj0,&obj1)) SWIG_fail;
  {
    int is_new_object = 0;
    PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj0, NPY_INT)
      :obj_to_array_contiguous_allow_conversion(obj0, NPY_INT, &is_new_object));
    if (!array || !require_dimensions(array, 2) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p1 = daal::services::SharedPtr< int >((int*)array_data(array), NumpyDeleter(array));
    arg1 = &r4p1;
    arg2 = (size_t) array_size(array,1);
    arg3 = (size_t) array_size(array,0);
    // we need it increment the ref-count if we use the obj0 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj0) Py_INCREF(array);
  }
  res4 = SWIG_ConvertPtr(obj1, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "HomogenNumericTable_Intc_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< int >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::SharedPtr< int > const &)*arg1,arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_create__SWIG_9(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< int > *arg1 = 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::services::SharedPtr< int > r4p1 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:HomogenNumericTable_Intc_create",&obj0)) SWIG_fail;
  {
    int is_new_object = 0;
    PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj0, NPY_INT)
      :obj_to_array_contiguous_allow_conversion(obj0, NPY_INT, &is_new_object));
    if (!array || !require_dimensions(array, 2) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p1 = daal::services::SharedPtr< int >((int*)array_data(array), NumpyDeleter(array));
    arg1 = &r4p1;
    arg2 = (size_t) array_size(array,1);
    arg3 = (size_t) array_size(array,0);
    // we need it increment the ref-count if we use the obj0 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj0) Py_INCREF(array);
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< int >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::SharedPtr< int > const &)*arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_create__SWIG_10(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  int *arg2 = (int *) (int *)0 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::services::Status *arg5 = (daal::services::Status *) 0 ;
  int val1 ;
  int ecode1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:HomogenNumericTable_Intc_create",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Intc_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_int, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Intc_create" "', argument " "2"" of type '" "int *const""'"); 
  }
  arg2 = reinterpret_cast< int * >(argp2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Intc_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Intc_create" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  res5 = SWIG_ConvertPtr(obj4, &argp5,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "HomogenNumericTable_Intc_create" "', argument " "5"" of type '" "daal::services::Status *""'"); 
  }
  arg5 = reinterpret_cast< daal::services::Status * >(argp5);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4,arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_create__SWIG_11(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  int *arg2 = (int *) (int *)0 ;
  size_t arg3 ;
  size_t arg4 ;
  int val1 ;
  int ecode1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:HomogenNumericTable_Intc_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Intc_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_int, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Intc_create" "', argument " "2"" of type '" "int *const""'"); 
  }
  arg2 = reinterpret_cast< int * >(argp2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Intc_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Intc_create" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_create__SWIG_12(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  int *arg2 = (int *) (int *)0 ;
  size_t arg3 ;
  int val1 ;
  int ecode1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:HomogenNumericTable_Intc_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Intc_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_int, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Intc_create" "', argument " "2"" of type '" "int *const""'"); 
  }
  arg2 = reinterpret_cast< int * >(argp2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Intc_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_create__SWIG_13(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  int *arg2 = (int *) (int *)0 ;
  int val1 ;
  int ecode1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenNumericTable_Intc_create",&obj0,&obj1)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Intc_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_int, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Intc_create" "', argument " "2"" of type '" "int *const""'"); 
  }
  arg2 = reinterpret_cast< int * >(argp2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_create__SWIG_14(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  int val1 ;
  int ecode1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:HomogenNumericTable_Intc_create",&obj0)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Intc_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_create__SWIG_15(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  daal::services::SharedPtr< int > *arg2 = 0 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::services::Status *arg5 = (daal::services::Status *) 0 ;
  int val1 ;
  int ecode1 = 0 ;
  daal::services::SharedPtr< int > r4p2 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:HomogenNumericTable_Intc_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Intc_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  {
    int is_new_object = 0;
    PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_INT)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_INT, &is_new_object));
    if (!array || !require_dimensions(array, 2) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p2 = daal::services::SharedPtr< int >((int*)array_data(array), NumpyDeleter(array));
    arg2 = &r4p2;
    arg3 = (size_t) array_size(array,1);
    arg4 = (size_t) array_size(array,0);
    // we need it increment the ref-count if we use the obj1 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj1) Py_INCREF(array);
  }
  res5 = SWIG_ConvertPtr(obj2, &argp5,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "HomogenNumericTable_Intc_create" "', argument " "5"" of type '" "daal::services::Status *""'"); 
  }
  arg5 = reinterpret_cast< daal::services::Status * >(argp5);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,(daal::services::SharedPtr< int > const &)*arg2,arg3,arg4,arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_create__SWIG_16(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  daal::services::SharedPtr< int > *arg2 = 0 ;
  size_t arg3 ;
  size_t arg4 ;
  int val1 ;
  int ecode1 = 0 ;
  daal::services::SharedPtr< int > r4p2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenNumericTable_Intc_create",&obj0,&obj1)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Intc_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  {
    int is_new_object = 0;
    PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_INT)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_INT, &is_new_object));
    if (!array || !require_dimensions(array, 2) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p2 = daal::services::SharedPtr< int >((int*)array_data(array), NumpyDeleter(array));
    arg2 = &r4p2;
    arg3 = (size_t) array_size(array,1);
    arg4 = (size_t) array_size(array,0);
    // we need it increment the ref-count if we use the obj1 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj1) Py_INCREF(array);
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,(daal::services::SharedPtr< int > const &)*arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_create__SWIG_17(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int *arg1 = (int *) (int *)0 ;
  size_t arg2 ;
  size_t arg3 ;
  int *arg4 = 0 ;
  daal::services::Status *arg5 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int temp4 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:HomogenNumericTable_Intc_create",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_int, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Intc_create" "', argument " "1"" of type '" "int *const""'"); 
  }
  arg1 = reinterpret_cast< int * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Intc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Intc_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Intc_create" "', argument " "4"" of type '" "int""'");
  } 
  temp4 = static_cast< int >(val4);
  arg4 = &temp4;
  res5 = SWIG_ConvertPtr(obj4, &argp5,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "HomogenNumericTable_Intc_create" "', argument " "5"" of type '" "daal::services::Status *""'"); 
  }
  arg5 = reinterpret_cast< daal::services::Status * >(argp5);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,(int const &)*arg4,arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_create__SWIG_18(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int *arg1 = (int *) (int *)0 ;
  size_t arg2 ;
  size_t arg3 ;
  int *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int temp4 ;
  int val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:HomogenNumericTable_Intc_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_int, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Intc_create" "', argument " "1"" of type '" "int *const""'"); 
  }
  arg1 = reinterpret_cast< int * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Intc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Intc_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Intc_create" "', argument " "4"" of type '" "int""'");
  } 
  temp4 = static_cast< int >(val4);
  arg4 = &temp4;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,(int const &)*arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_create__SWIG_19(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< int > *arg1 = 0 ;
  size_t arg2 ;
  size_t arg3 ;
  int *arg4 = 0 ;
  daal::services::Status *arg5 = (daal::services::Status *) 0 ;
  daal::services::SharedPtr< int > r4p1 ;
  int temp4 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:HomogenNumericTable_Intc_create",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int is_new_object = 0;
    PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj0, NPY_INT)
      :obj_to_array_contiguous_allow_conversion(obj0, NPY_INT, &is_new_object));
    if (!array || !require_dimensions(array, 2) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p1 = daal::services::SharedPtr< int >((int*)array_data(array), NumpyDeleter(array));
    arg1 = &r4p1;
    arg2 = (size_t) array_size(array,1);
    arg3 = (size_t) array_size(array,0);
    // we need it increment the ref-count if we use the obj0 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj0) Py_INCREF(array);
  }
  ecode4 = SWIG_AsVal_int(obj1, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Intc_create" "', argument " "4"" of type '" "int""'");
  } 
  temp4 = static_cast< int >(val4);
  arg4 = &temp4;
  res5 = SWIG_ConvertPtr(obj2, &argp5,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "HomogenNumericTable_Intc_create" "', argument " "5"" of type '" "daal::services::Status *""'"); 
  }
  arg5 = reinterpret_cast< daal::services::Status * >(argp5);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< int >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::SharedPtr< int > const &)*arg1,arg2,arg3,(int const &)*arg4,arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_create__SWIG_20(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< int > *arg1 = 0 ;
  size_t arg2 ;
  size_t arg3 ;
  int *arg4 = 0 ;
  daal::services::SharedPtr< int > r4p1 ;
  int temp4 ;
  int val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenNumericTable_Intc_create",&obj0,&obj1)) SWIG_fail;
  {
    int is_new_object = 0;
    PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj0, NPY_INT)
      :obj_to_array_contiguous_allow_conversion(obj0, NPY_INT, &is_new_object));
    if (!array || !require_dimensions(array, 2) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p1 = daal::services::SharedPtr< int >((int*)array_data(array), NumpyDeleter(array));
    arg1 = &r4p1;
    arg2 = (size_t) array_size(array,1);
    arg3 = (size_t) array_size(array,0);
    // we need it increment the ref-count if we use the obj0 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj0) Py_INCREF(array);
  }
  ecode4 = SWIG_AsVal_int(obj1, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Intc_create" "', argument " "4"" of type '" "int""'");
  } 
  temp4 = static_cast< int >(val4);
  arg4 = &temp4;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< int >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::SharedPtr< int > const &)*arg1,arg2,arg3,(int const &)*arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_create__SWIG_21(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  int *arg2 = (int *) (int *)0 ;
  size_t arg3 ;
  size_t arg4 ;
  int *arg5 = 0 ;
  daal::services::Status *arg6 = (daal::services::Status *) 0 ;
  int val1 ;
  int ecode1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int temp5 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:HomogenNumericTable_Intc_create",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Intc_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_int, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Intc_create" "', argument " "2"" of type '" "int *const""'"); 
  }
  arg2 = reinterpret_cast< int * >(argp2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Intc_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Intc_create" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "HomogenNumericTable_Intc_create" "', argument " "5"" of type '" "int""'");
  } 
  temp5 = static_cast< int >(val5);
  arg5 = &temp5;
  res6 = SWIG_ConvertPtr(obj5, &argp6,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res6)) {
    SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "HomogenNumericTable_Intc_create" "', argument " "6"" of type '" "daal::services::Status *""'"); 
  }
  arg6 = reinterpret_cast< daal::services::Status * >(argp6);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4,(int const &)*arg5,arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_create__SWIG_22(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  int *arg2 = (int *) (int *)0 ;
  size_t arg3 ;
  size_t arg4 ;
  int *arg5 = 0 ;
  int val1 ;
  int ecode1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int temp5 ;
  int val5 ;
  int ecode5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:HomogenNumericTable_Intc_create",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Intc_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_int, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Intc_create" "', argument " "2"" of type '" "int *const""'"); 
  }
  arg2 = reinterpret_cast< int * >(argp2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Intc_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Intc_create" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "HomogenNumericTable_Intc_create" "', argument " "5"" of type '" "int""'");
  } 
  temp5 = static_cast< int >(val5);
  arg5 = &temp5;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4,(int const &)*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_create__SWIG_23(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  daal::services::SharedPtr< int > *arg2 = 0 ;
  size_t arg3 ;
  size_t arg4 ;
  int *arg5 = 0 ;
  daal::services::Status *arg6 = (daal::services::Status *) 0 ;
  int val1 ;
  int ecode1 = 0 ;
  daal::services::SharedPtr< int > r4p2 ;
  int temp5 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:HomogenNumericTable_Intc_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Intc_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  {
    int is_new_object = 0;
    PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_INT)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_INT, &is_new_object));
    if (!array || !require_dimensions(array, 2) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p2 = daal::services::SharedPtr< int >((int*)array_data(array), NumpyDeleter(array));
    arg2 = &r4p2;
    arg3 = (size_t) array_size(array,1);
    arg4 = (size_t) array_size(array,0);
    // we need it increment the ref-count if we use the obj1 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj1) Py_INCREF(array);
  }
  ecode5 = SWIG_AsVal_int(obj2, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "HomogenNumericTable_Intc_create" "', argument " "5"" of type '" "int""'");
  } 
  temp5 = static_cast< int >(val5);
  arg5 = &temp5;
  res6 = SWIG_ConvertPtr(obj3, &argp6,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res6)) {
    SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "HomogenNumericTable_Intc_create" "', argument " "6"" of type '" "daal::services::Status *""'"); 
  }
  arg6 = reinterpret_cast< daal::services::Status * >(argp6);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,(daal::services::SharedPtr< int > const &)*arg2,arg3,arg4,(int const &)*arg5,arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_create__SWIG_24(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  daal::services::SharedPtr< int > *arg2 = 0 ;
  size_t arg3 ;
  size_t arg4 ;
  int *arg5 = 0 ;
  int val1 ;
  int ecode1 = 0 ;
  daal::services::SharedPtr< int > r4p2 ;
  int temp5 ;
  int val5 ;
  int ecode5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:HomogenNumericTable_Intc_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Intc_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  {
    int is_new_object = 0;
    PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_INT)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_INT, &is_new_object));
    if (!array || !require_dimensions(array, 2) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p2 = daal::services::SharedPtr< int >((int*)array_data(array), NumpyDeleter(array));
    arg2 = &r4p2;
    arg3 = (size_t) array_size(array,1);
    arg4 = (size_t) array_size(array,0);
    // we need it increment the ref-count if we use the obj1 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj1) Py_INCREF(array);
  }
  ecode5 = SWIG_AsVal_int(obj2, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "HomogenNumericTable_Intc_create" "', argument " "5"" of type '" "int""'");
  } 
  temp5 = static_cast< int >(val5);
  arg5 = &temp5;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,(daal::services::SharedPtr< int > const &)*arg2,arg3,arg4,(int const &)*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_create__SWIG_25(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg3 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  int val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:HomogenNumericTable_Intc_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Intc_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Intc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Intc_create" "', argument " "3"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg3 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val3);
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "HomogenNumericTable_Intc_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_create__SWIG_26(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg3 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  int val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:HomogenNumericTable_Intc_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Intc_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Intc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Intc_create" "', argument " "3"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg3 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_create__SWIG_27(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg4 ;
  daal::services::Status *arg5 = (daal::services::Status *) 0 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:HomogenNumericTable_Intc_create",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Intc_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Intc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Intc_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Intc_create" "', argument " "4"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg4 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val4);
  res5 = SWIG_ConvertPtr(obj4, &argp5,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "HomogenNumericTable_Intc_create" "', argument " "5"" of type '" "daal::services::Status *""'"); 
  }
  arg5 = reinterpret_cast< daal::services::Status * >(argp5);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4,arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_create__SWIG_28(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg4 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:HomogenNumericTable_Intc_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Intc_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Intc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Intc_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Intc_create" "', argument " "4"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg4 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_create__SWIG_29(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg3 ;
  int *arg4 = 0 ;
  daal::services::Status *arg5 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  int val3 ;
  int ecode3 = 0 ;
  int temp4 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:HomogenNumericTable_Intc_create",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Intc_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Intc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Intc_create" "', argument " "3"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg3 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Intc_create" "', argument " "4"" of type '" "int""'");
  } 
  temp4 = static_cast< int >(val4);
  arg4 = &temp4;
  res5 = SWIG_ConvertPtr(obj4, &argp5,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "HomogenNumericTable_Intc_create" "', argument " "5"" of type '" "daal::services::Status *""'"); 
  }
  arg5 = reinterpret_cast< daal::services::Status * >(argp5);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,(int const &)*arg4,arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_create__SWIG_30(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg3 ;
  int *arg4 = 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  int val3 ;
  int ecode3 = 0 ;
  int temp4 ;
  int val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:HomogenNumericTable_Intc_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Intc_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Intc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Intc_create" "', argument " "3"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg3 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Intc_create" "', argument " "4"" of type '" "int""'");
  } 
  temp4 = static_cast< int >(val4);
  arg4 = &temp4;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,(int const &)*arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_create__SWIG_31(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg4 ;
  int *arg5 = 0 ;
  daal::services::Status *arg6 = (daal::services::Status *) 0 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  int temp5 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:HomogenNumericTable_Intc_create",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Intc_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Intc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Intc_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Intc_create" "', argument " "4"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg4 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "HomogenNumericTable_Intc_create" "', argument " "5"" of type '" "int""'");
  } 
  temp5 = static_cast< int >(val5);
  arg5 = &temp5;
  res6 = SWIG_ConvertPtr(obj5, &argp6,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res6)) {
    SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "HomogenNumericTable_Intc_create" "', argument " "6"" of type '" "daal::services::Status *""'"); 
  }
  arg6 = reinterpret_cast< daal::services::Status * >(argp6);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4,(int const &)*arg5,arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_create__SWIG_32(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg4 ;
  int *arg5 = 0 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  int temp5 ;
  int val5 ;
  int ecode5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:HomogenNumericTable_Intc_create",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenNumericTable_Intc_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Intc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Intc_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Intc_create" "', argument " "4"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg4 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "HomogenNumericTable_Intc_create" "', argument " "5"" of type '" "int""'");
  } 
  temp5 = static_cast< int >(val5);
  arg5 = &temp5;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenNumericTable< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4,(int const &)*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_create(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[7];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 6) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_HomogenNumericTable_Intc_create__SWIG_3(self, args);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_HomogenNumericTable_Intc_create__SWIG_2(self, args);
    }
  }
  if (argc == 1) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_HomogenNumericTable_Intc_create__SWIG_1(self, args);
    }
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_int, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_HomogenNumericTable_Intc_create__SWIG_7(self, args);
    }
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_HomogenNumericTable_Intc_create__SWIG_14(self, args);
    }
  }
  if (argc == 1) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_INT))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      if (argc <= 1) {
        return _wrap_HomogenNumericTable_Intc_create__SWIG_9(self, args);
      }
      if (argc <= 2) {
        return _wrap_HomogenNumericTable_Intc_create__SWIG_9(self, args);
      }
      return _wrap_HomogenNumericTable_Intc_create__SWIG_9(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_int, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_HomogenNumericTable_Intc_create__SWIG_6(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenNumericTable_Intc_create__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_int, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenNumericTable_Intc_create__SWIG_13(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        _v = (ALLOW_CONVERSION == FORCE_INPLACE
          ? (is_array(argv[1]) && PyArray_EquivTypenums(array_type(argv[1]), NPY_INT))
          :(is_array(argv[1]) || PySequence_Check(argv[1])));
      }
      if (_v) {
        if (argc <= 2) {
          return _wrap_HomogenNumericTable_Intc_create__SWIG_16(self, args);
        }
        if (argc <= 3) {
          return _wrap_HomogenNumericTable_Intc_create__SWIG_16(self, args);
        }
        return _wrap_HomogenNumericTable_Intc_create__SWIG_16(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_INT))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenNumericTable_Intc_create__SWIG_8(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_INT))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_HomogenNumericTable_Intc_create__SWIG_20(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_int, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_HomogenNumericTable_Intc_create__SWIG_5(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_int, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_HomogenNumericTable_Intc_create__SWIG_12(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        _v = (ALLOW_CONVERSION == FORCE_INPLACE
          ? (is_array(argv[1]) && PyArray_EquivTypenums(array_type(argv[1]), NPY_INT))
          :(is_array(argv[1]) || PySequence_Check(argv[1])));
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_HomogenNumericTable_Intc_create__SWIG_15(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        _v = (ALLOW_CONVERSION == FORCE_INPLACE
          ? (is_array(argv[1]) && PyArray_EquivTypenums(array_type(argv[1]), NPY_INT))
          :(is_array(argv[1]) || PySequence_Check(argv[1])));
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_HomogenNumericTable_Intc_create__SWIG_24(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_HomogenNumericTable_Intc_create__SWIG_26(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_INT))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_HomogenNumericTable_Intc_create__SWIG_19(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_int, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_HomogenNumericTable_Intc_create__SWIG_4(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_int, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            return _wrap_HomogenNumericTable_Intc_create__SWIG_18(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_int, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            return _wrap_HomogenNumericTable_Intc_create__SWIG_11(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            return _wrap_HomogenNumericTable_Intc_create__SWIG_28(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        _v = (ALLOW_CONVERSION == FORCE_INPLACE
          ? (is_array(argv[1]) && PyArray_EquivTypenums(array_type(argv[1]), NPY_INT))
          :(is_array(argv[1]) || PySequence_Check(argv[1])));
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_HomogenNumericTable_Intc_create__SWIG_23(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_HomogenNumericTable_Intc_create__SWIG_25(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            return _wrap_HomogenNumericTable_Intc_create__SWIG_30(self, args);
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_int, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            void *vptr = 0;
            int res = SWIG_ConvertPtr(argv[4], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_HomogenNumericTable_Intc_create__SWIG_17(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_int, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            void *vptr = 0;
            int res = SWIG_ConvertPtr(argv[4], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_HomogenNumericTable_Intc_create__SWIG_10(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_int, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              return _wrap_HomogenNumericTable_Intc_create__SWIG_22(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            void *vptr = 0;
            int res = SWIG_ConvertPtr(argv[4], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_HomogenNumericTable_Intc_create__SWIG_27(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              return _wrap_HomogenNumericTable_Intc_create__SWIG_32(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            void *vptr = 0;
            int res = SWIG_ConvertPtr(argv[4], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_HomogenNumericTable_Intc_create__SWIG_29(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_int, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              void *vptr = 0;
              int res = SWIG_ConvertPtr(argv[5], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_HomogenNumericTable_Intc_create__SWIG_21(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              void *vptr = 0;
              int res = SWIG_ConvertPtr(argv[5], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_HomogenNumericTable_Intc_create__SWIG_31(self, args);
              }
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'HomogenNumericTable_Intc_create'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::HomogenNumericTable< int >::create(daal::data_management::interface1::NumericTableDictionaryPtr,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenNumericTable< int >::create(daal::data_management::interface1::NumericTableDictionaryPtr)\n"
    "    daal::data_management::interface1::HomogenNumericTable< int >::create(daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenNumericTable< int >::create()\n"
    "    daal::data_management::interface1::HomogenNumericTable< int >::create(int *const,size_t,size_t,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenNumericTable< int >::create(int *const,size_t,size_t)\n"
    "    daal::data_management::interface1::HomogenNumericTable< int >::create(int *const,size_t)\n"
    "    daal::data_management::interface1::HomogenNumericTable< int >::create(int *const)\n"
    "    daal::data_management::interface1::HomogenNumericTable< int >::create(daal::services::SharedPtr< int > const &,size_t,size_t,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenNumericTable< int >::create(daal::services::SharedPtr< int > const &,size_t,size_t)\n"
    "    daal::data_management::interface1::HomogenNumericTable< int >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,int *const,size_t,size_t,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenNumericTable< int >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,int *const,size_t,size_t)\n"
    "    daal::data_management::interface1::HomogenNumericTable< int >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,int *const,size_t)\n"
    "    daal::data_management::interface1::HomogenNumericTable< int >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,int *const)\n"
    "    daal::data_management::interface1::HomogenNumericTable< int >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual)\n"
    "    daal::data_management::interface1::HomogenNumericTable< int >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,daal::services::SharedPtr< int > const &,size_t,size_t,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenNumericTable< int >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,daal::services::SharedPtr< int > const &,size_t,size_t)\n"
    "    daal::data_management::interface1::HomogenNumericTable< int >::create(int *const,size_t,size_t,int const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenNumericTable< int >::create(int *const,size_t,size_t,int const &)\n"
    "    daal::data_management::interface1::HomogenNumericTable< int >::create(daal::services::SharedPtr< int > const &,size_t,size_t,int const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenNumericTable< int >::create(daal::services::SharedPtr< int > const &,size_t,size_t,int const &)\n"
    "    daal::data_management::interface1::HomogenNumericTable< int >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,int *const,size_t,size_t,int const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenNumericTable< int >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,int *const,size_t,size_t,int const &)\n"
    "    daal::data_management::interface1::HomogenNumericTable< int >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,daal::services::SharedPtr< int > const &,size_t,size_t,int const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenNumericTable< int >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,daal::services::SharedPtr< int > const &,size_t,size_t,int const &)\n"
    "    daal::data_management::interface1::HomogenNumericTable< int >::create(size_t,size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenNumericTable< int >::create(size_t,size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag)\n"
    "    daal::data_management::interface1::HomogenNumericTable< int >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenNumericTable< int >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag)\n"
    "    daal::data_management::interface1::HomogenNumericTable< int >::create(size_t,size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag,int const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenNumericTable< int >::create(size_t,size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag,int const &)\n"
    "    daal::data_management::interface1::HomogenNumericTable< int >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag,int const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenNumericTable< int >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag,int const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_HomogenNumericTable_Intc(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< int > *arg1 = (daal::data_management::interface1::HomogenNumericTable< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_HomogenNumericTable_Intc",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_HomogenNumericTable_Intc" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_HomogenNumericTable_Intc" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< int > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_assign__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< int > *arg1 = (daal::data_management::interface1::HomogenNumericTable< int > *) 0 ;
  float arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > *smartarg1 = 0 ;
  float val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenNumericTable_Intc_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Intc_assign" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Intc_assign" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< int > *""'"); 
  }
  ecode2 = SWIG_AsVal_float(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Intc_assign" "', argument " "2"" of type '" "float""'");
  } 
  arg2 = static_cast< float >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_assign__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< int > *arg1 = (daal::data_management::interface1::HomogenNumericTable< int > *) 0 ;
  double arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > *smartarg1 = 0 ;
  double val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenNumericTable_Intc_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Intc_assign" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Intc_assign" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< int > *""'"); 
  }
  ecode2 = SWIG_AsVal_double(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Intc_assign" "', argument " "2"" of type '" "double""'");
  } 
  arg2 = static_cast< double >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_assign__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< int > *arg1 = (daal::data_management::interface1::HomogenNumericTable< int > *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenNumericTable_Intc_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Intc_assign" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Intc_assign" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< int > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Intc_assign" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_assign(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_HomogenNumericTable_Intc_assign__SWIG_3(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_float(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_HomogenNumericTable_Intc_assign__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_double(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_HomogenNumericTable_Intc_assign__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'HomogenNumericTable_Intc_assign'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::HomogenNumericTable< int >::assign(float)\n"
    "    daal::data_management::interface1::HomogenNumericTable< int >::assign(double)\n"
    "    daal::data_management::interface1::HomogenNumericTable< int >::assign(int)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_getBlockOfRows__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< int > *arg1 = (daal::data_management::interface1::HomogenNumericTable< int > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:HomogenNumericTable_Intc_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Intc_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Intc_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< int > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Intc_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Intc_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Intc_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "HomogenNumericTable_Intc_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenNumericTable_Intc_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "HomogenNumericTable_Intc_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_getBlockOfRows__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< int > *arg1 = (daal::data_management::interface1::HomogenNumericTable< int > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:HomogenNumericTable_Intc_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Intc_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Intc_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< int > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Intc_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Intc_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Intc_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "HomogenNumericTable_Intc_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenNumericTable_Intc_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "HomogenNumericTable_Intc_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_getBlockOfRows__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< int > *arg1 = (daal::data_management::interface1::HomogenNumericTable< int > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:HomogenNumericTable_Intc_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Intc_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Intc_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< int > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Intc_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Intc_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Intc_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "HomogenNumericTable_Intc_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenNumericTable_Intc_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "HomogenNumericTable_Intc_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_getBlockOfRows(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[6];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 5) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_HomogenNumericTable_Intc_getBlockOfRows__SWIG_0(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_HomogenNumericTable_Intc_getBlockOfRows__SWIG_1(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_HomogenNumericTable_Intc_getBlockOfRows__SWIG_2(self, args);
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'HomogenNumericTable_Intc_getBlockOfRows'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::HomogenNumericTable< int >::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::HomogenNumericTable< int >::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::HomogenNumericTable< int >::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_releaseBlockOfRows__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< int > *arg1 = (daal::data_management::interface1::HomogenNumericTable< int > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenNumericTable_Intc_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Intc_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Intc_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< int > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Intc_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenNumericTable_Intc_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Intc_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_releaseBlockOfRows__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< int > *arg1 = (daal::data_management::interface1::HomogenNumericTable< int > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenNumericTable_Intc_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Intc_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Intc_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< int > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Intc_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenNumericTable_Intc_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Intc_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_releaseBlockOfRows__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< int > *arg1 = (daal::data_management::interface1::HomogenNumericTable< int > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenNumericTable_Intc_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Intc_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Intc_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< int > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Intc_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenNumericTable_Intc_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Intc_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_releaseBlockOfRows(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenNumericTable_Intc_releaseBlockOfRows__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenNumericTable_Intc_releaseBlockOfRows__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenNumericTable_Intc_releaseBlockOfRows__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'HomogenNumericTable_Intc_releaseBlockOfRows'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::HomogenNumericTable< int >::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::HomogenNumericTable< int >::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::HomogenNumericTable< int >::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_getBlockOfColumnValues__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< int > *arg1 = (daal::data_management::interface1::HomogenNumericTable< int > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:HomogenNumericTable_Intc_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Intc_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Intc_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< int > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Intc_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Intc_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Intc_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "HomogenNumericTable_Intc_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "HomogenNumericTable_Intc_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenNumericTable_Intc_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "HomogenNumericTable_Intc_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_getBlockOfColumnValues__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< int > *arg1 = (daal::data_management::interface1::HomogenNumericTable< int > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:HomogenNumericTable_Intc_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Intc_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Intc_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< int > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Intc_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Intc_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Intc_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "HomogenNumericTable_Intc_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "HomogenNumericTable_Intc_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenNumericTable_Intc_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "HomogenNumericTable_Intc_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_getBlockOfColumnValues__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< int > *arg1 = (daal::data_management::interface1::HomogenNumericTable< int > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:HomogenNumericTable_Intc_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Intc_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Intc_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< int > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Intc_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenNumericTable_Intc_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenNumericTable_Intc_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "HomogenNumericTable_Intc_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "HomogenNumericTable_Intc_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenNumericTable_Intc_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "HomogenNumericTable_Intc_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_getBlockOfColumnValues(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[7];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 6) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_HomogenNumericTable_Intc_getBlockOfColumnValues__SWIG_0(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_HomogenNumericTable_Intc_getBlockOfColumnValues__SWIG_1(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_HomogenNumericTable_Intc_getBlockOfColumnValues__SWIG_2(self, args);
              }
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'HomogenNumericTable_Intc_getBlockOfColumnValues'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::HomogenNumericTable< int >::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::HomogenNumericTable< int >::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::HomogenNumericTable< int >::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_releaseBlockOfColumnValues__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< int > *arg1 = (daal::data_management::interface1::HomogenNumericTable< int > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenNumericTable_Intc_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Intc_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Intc_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< int > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Intc_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenNumericTable_Intc_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Intc_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_releaseBlockOfColumnValues__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< int > *arg1 = (daal::data_management::interface1::HomogenNumericTable< int > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenNumericTable_Intc_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Intc_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Intc_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< int > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Intc_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenNumericTable_Intc_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Intc_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_releaseBlockOfColumnValues__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< int > *arg1 = (daal::data_management::interface1::HomogenNumericTable< int > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenNumericTable_Intc_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Intc_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Intc_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< int > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Intc_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenNumericTable_Intc_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenNumericTable_Intc_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_releaseBlockOfColumnValues(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenNumericTable_Intc_releaseBlockOfColumnValues__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenNumericTable_Intc_releaseBlockOfColumnValues__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenNumericTable_Intc_releaseBlockOfColumnValues__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'HomogenNumericTable_Intc_releaseBlockOfColumnValues'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::HomogenNumericTable< int >::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::HomogenNumericTable< int >::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::HomogenNumericTable< int >::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc___getitem__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< int > *arg1 = (daal::data_management::interface1::HomogenNumericTable< int > *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  int *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenNumericTable_Intc___getitem__",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Intc___getitem__" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Intc___getitem__" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< int > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenNumericTable_Intc___getitem__" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int *)daal_data_management_interface1_HomogenNumericTable_Sl_int_Sg____getitem__(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_int, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenNumericTable_Intc_getArray(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenNumericTable< int > *arg1 = (daal::data_management::interface1::HomogenNumericTable< int > *) 0 ;
  daal::services::SharedPtr< int > *arg2 = (daal::services::SharedPtr< int > *) 0 ;
  size_t *arg3 = (size_t *) 0 ;
  size_t *arg4 = (size_t *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > *smartarg1 = 0 ;
  daal::services::SharedPtr< int > data_temp2 ;
  size_t dim1_temp2 ;
  size_t dim2_temp2 ;
  PyObject * obj0 = 0 ;
  
  {
    arg2 = &data_temp2;
    arg3 = &dim1_temp2;
    arg4 = &dim2_temp2;
  }
  if (!PyArg_ParseTuple(args,(char *)"O:HomogenNumericTable_Intc_getArray",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Intc_getArray" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenNumericTable< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenNumericTable< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenNumericTable_Intc_getArray" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenNumericTable< int > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        daal_data_management_interface1_HomogenNumericTable_Sl_int_Sg__getArray(arg1,arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    npy_intp dims[2] = {
      static_cast<npy_intp>(*arg4), static_cast<npy_intp>(*arg3) 
    };
    PyObject* obj = PyArray_SimpleNewFromData(2, dims, NPY_INT, (void*)(arg2->get()));
    if (!obj) SWIG_fail;
    set_sp_base((PyArrayObject*)obj, *arg2);
    resultobj = SWIG_Python_AppendOutput(resultobj,obj);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *HomogenNumericTable_Intc_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_HomogenTensor_Float64_serializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)":HomogenTensor_Float64_serializationTag")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)daal::data_management::interface1::HomogenTensor< double >::SWIGTEMPLATEDISAMBIGUATOR serializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float64_getSerializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< double > *arg1 = (daal::data_management::interface1::HomogenTensor< double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:HomogenTensor_Float64_getSerializationTag",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float64_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< double > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float64_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< double > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)((daal::data_management::interface1::HomogenTensor< double > const *)arg1)->getSerializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float64_create__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::Status *arg1 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:HomogenTensor_Float64_create",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float64_create" "', argument " "1"" of type '" "daal::services::Status *""'"); 
  }
  arg1 = reinterpret_cast< daal::services::Status * >(argp1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float64_create__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)":HomogenTensor_Float64_create")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< double >::SWIGTEMPLATEDISAMBIGUATOR create();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float64_create__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t *arg2 = (size_t *) 0 ;
  double *arg3 = (double *) 0 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:HomogenTensor_Float64_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenTensor_Float64_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_size_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenTensor_Float64_create" "', argument " "2"" of type '" "size_t const *""'"); 
  }
  arg2 = reinterpret_cast< size_t * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_double, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "HomogenTensor_Float64_create" "', argument " "3"" of type '" "double *""'"); 
  }
  arg3 = reinterpret_cast< double * >(argp3);
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "HomogenTensor_Float64_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,(size_t const *)arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float64_create__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t *arg2 = (size_t *) 0 ;
  double *arg3 = (double *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:HomogenTensor_Float64_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenTensor_Float64_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_size_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenTensor_Float64_create" "', argument " "2"" of type '" "size_t const *""'"); 
  }
  arg2 = reinterpret_cast< size_t * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_double, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "HomogenTensor_Float64_create" "', argument " "3"" of type '" "double *""'"); 
  }
  arg3 = reinterpret_cast< double * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,(size_t const *)arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float64_create__SWIG_4(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t *arg2 = (size_t *) 0 ;
  daal::services::SharedPtr< double > *arg3 = 0 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  daal::services::SharedPtr< double > r4p1 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenTensor_Float64_create",&obj0,&obj1)) SWIG_fail;
  {
    int is_new_object = 0;
    PyArrayObject * array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj0, NPY_DOUBLE)
      :obj_to_array_contiguous_allow_conversion(obj0, NPY_DOUBLE, &is_new_object));
    if (!array || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    arg1 = (size_t)array_numdims(array);
    arg2 = (size_t*)array_dimensions(array);
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p1 = daal::services::SharedPtr< double >((double*)array_data(array), NumpyDeleter(array));
    arg3 = &r4p1;
    // we need it increment the ref-count if we use the obj0 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj0) Py_INCREF(array);
  }
  res4 = SWIG_ConvertPtr(obj1, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "HomogenTensor_Float64_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,(size_t const *)arg2,(daal::services::SharedPtr< double > const &)*arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float64_create__SWIG_5(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t *arg2 = (size_t *) 0 ;
  daal::services::SharedPtr< double > *arg3 = 0 ;
  daal::services::SharedPtr< double > r4p1 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:HomogenTensor_Float64_create",&obj0)) SWIG_fail;
  {
    int is_new_object = 0;
    PyArrayObject * array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj0, NPY_DOUBLE)
      :obj_to_array_contiguous_allow_conversion(obj0, NPY_DOUBLE, &is_new_object));
    if (!array || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    arg1 = (size_t)array_numdims(array);
    arg2 = (size_t*)array_dimensions(array);
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p1 = daal::services::SharedPtr< double >((double*)array_data(array), NumpyDeleter(array));
    arg3 = &r4p1;
    // we need it increment the ref-count if we use the obj0 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj0) Py_INCREF(array);
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,(size_t const *)arg2,(daal::services::SharedPtr< double > const &)*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float64_create__SWIG_6(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::Collection< size_t > *arg1 = 0 ;
  double *arg2 = (double *) 0 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  daal::services::Collection< size_t > *col_szt1 = NULL ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:HomogenTensor_Float64_create",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    Py_ssize_t n = PySequence_Length(obj0);
    if( n == 0 ) SWIG_fail;
    col_szt1 = new daal::services::Collection<size_t>(n);
    for( Py_ssize_t i=0; i<n; ++i ) {
      PyObject * o = PySequence_GetItem(obj0, i);
      size_t tmp = PyInt_AsSsize_t(o);
      if(PyErr_Occurred()) {
        PyErr_Format(PyExc_TypeError, "Sequence of integer values required");
        SWIG_fail;
      }
      (*col_szt1)[i] = tmp;
    }
    arg1 = col_szt1;
  }
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_double, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenTensor_Float64_create" "', argument " "2"" of type '" "double *""'"); 
  }
  arg2 = reinterpret_cast< double * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "HomogenTensor_Float64_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< double >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::Collection< size_t > const &)*arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, SWIG_POINTER_OWN);
  }
  {
    if( col_szt1 ) delete col_szt1;
  }
  return resultobj;
fail:
  {
    if( col_szt1 ) delete col_szt1;
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float64_create__SWIG_7(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::Collection< size_t > *arg1 = 0 ;
  double *arg2 = (double *) 0 ;
  daal::services::Collection< size_t > *col_szt1 = NULL ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenTensor_Float64_create",&obj0,&obj1)) SWIG_fail;
  {
    Py_ssize_t n = PySequence_Length(obj0);
    if( n == 0 ) SWIG_fail;
    col_szt1 = new daal::services::Collection<size_t>(n);
    for( Py_ssize_t i=0; i<n; ++i ) {
      PyObject * o = PySequence_GetItem(obj0, i);
      size_t tmp = PyInt_AsSsize_t(o);
      if(PyErr_Occurred()) {
        PyErr_Format(PyExc_TypeError, "Sequence of integer values required");
        SWIG_fail;
      }
      (*col_szt1)[i] = tmp;
    }
    arg1 = col_szt1;
  }
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_double, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenTensor_Float64_create" "', argument " "2"" of type '" "double *""'"); 
  }
  arg2 = reinterpret_cast< double * >(argp2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< double >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::Collection< size_t > const &)*arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, SWIG_POINTER_OWN);
  }
  {
    if( col_szt1 ) delete col_szt1;
  }
  return resultobj;
fail:
  {
    if( col_szt1 ) delete col_szt1;
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float64_create__SWIG_8(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::Collection< size_t > *arg1 = 0 ;
  daal::services::SharedPtr< double > *arg2 = 0 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  daal::services::Collection< size_t > *col_szt1 = NULL ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:HomogenTensor_Float64_create",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    Py_ssize_t n = PySequence_Length(obj0);
    if( n == 0 ) SWIG_fail;
    col_szt1 = new daal::services::Collection<size_t>(n);
    for( Py_ssize_t i=0; i<n; ++i ) {
      PyObject * o = PySequence_GetItem(obj0, i);
      size_t tmp = PyInt_AsSsize_t(o);
      if(PyErr_Occurred()) {
        PyErr_Format(PyExc_TypeError, "Sequence of integer values required");
        SWIG_fail;
      }
      (*col_szt1)[i] = tmp;
    }
    arg1 = col_szt1;
  }
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_double_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenTensor_Float64_create" "', argument " "2"" of type '" "daal::services::SharedPtr< double > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Float64_create" "', argument " "2"" of type '" "daal::services::SharedPtr< double > const &""'"); 
  }
  arg2 = reinterpret_cast< daal::services::SharedPtr< double > * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "HomogenTensor_Float64_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< double >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::Collection< size_t > const &)*arg1,(daal::services::SharedPtr< double > const &)*arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, SWIG_POINTER_OWN);
  }
  {
    if( col_szt1 ) delete col_szt1;
  }
  return resultobj;
fail:
  {
    if( col_szt1 ) delete col_szt1;
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float64_create__SWIG_9(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::Collection< size_t > *arg1 = 0 ;
  daal::services::SharedPtr< double > *arg2 = 0 ;
  daal::services::Collection< size_t > *col_szt1 = NULL ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenTensor_Float64_create",&obj0,&obj1)) SWIG_fail;
  {
    Py_ssize_t n = PySequence_Length(obj0);
    if( n == 0 ) SWIG_fail;
    col_szt1 = new daal::services::Collection<size_t>(n);
    for( Py_ssize_t i=0; i<n; ++i ) {
      PyObject * o = PySequence_GetItem(obj0, i);
      size_t tmp = PyInt_AsSsize_t(o);
      if(PyErr_Occurred()) {
        PyErr_Format(PyExc_TypeError, "Sequence of integer values required");
        SWIG_fail;
      }
      (*col_szt1)[i] = tmp;
    }
    arg1 = col_szt1;
  }
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_double_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenTensor_Float64_create" "', argument " "2"" of type '" "daal::services::SharedPtr< double > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Float64_create" "', argument " "2"" of type '" "daal::services::SharedPtr< double > const &""'"); 
  }
  arg2 = reinterpret_cast< daal::services::SharedPtr< double > * >(argp2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< double >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::Collection< size_t > const &)*arg1,(daal::services::SharedPtr< double > const &)*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, SWIG_POINTER_OWN);
  }
  {
    if( col_szt1 ) delete col_szt1;
  }
  return resultobj;
fail:
  {
    if( col_szt1 ) delete col_szt1;
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float64_create__SWIG_10(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::TensorOffsetLayout *arg1 = 0 ;
  double *arg2 = (double *) 0 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout const > tempshared1 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:HomogenTensor_Float64_create",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t,  0 , &newmem);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float64_create" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (!argp1) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Float64_create" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(tempshared1.get());
    } else {
      arg1 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1)->get());
    }
    if(!arg1) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float64_create" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
  }
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_double, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenTensor_Float64_create" "', argument " "2"" of type '" "double *""'"); 
  }
  arg2 = reinterpret_cast< double * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "HomogenTensor_Float64_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< double >::SWIGTEMPLATEDISAMBIGUATOR create((daal::data_management::interface1::TensorOffsetLayout const &)*arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float64_create__SWIG_11(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::TensorOffsetLayout *arg1 = 0 ;
  double *arg2 = (double *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout const > tempshared1 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenTensor_Float64_create",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t,  0 , &newmem);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float64_create" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (!argp1) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Float64_create" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(tempshared1.get());
    } else {
      arg1 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1)->get());
    }
    if(!arg1) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float64_create" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
  }
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_double, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenTensor_Float64_create" "', argument " "2"" of type '" "double *""'"); 
  }
  arg2 = reinterpret_cast< double * >(argp2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< double >::SWIGTEMPLATEDISAMBIGUATOR create((daal::data_management::interface1::TensorOffsetLayout const &)*arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float64_create__SWIG_12(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::TensorOffsetLayout *arg1 = 0 ;
  daal::services::SharedPtr< double > *arg2 = 0 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout const > tempshared1 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:HomogenTensor_Float64_create",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t,  0 , &newmem);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float64_create" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (!argp1) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Float64_create" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(tempshared1.get());
    } else {
      arg1 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1)->get());
    }
    if(!arg1) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float64_create" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
  }
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_double_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenTensor_Float64_create" "', argument " "2"" of type '" "daal::services::SharedPtr< double > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Float64_create" "', argument " "2"" of type '" "daal::services::SharedPtr< double > const &""'"); 
  }
  arg2 = reinterpret_cast< daal::services::SharedPtr< double > * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "HomogenTensor_Float64_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< double >::SWIGTEMPLATEDISAMBIGUATOR create((daal::data_management::interface1::TensorOffsetLayout const &)*arg1,(daal::services::SharedPtr< double > const &)*arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float64_create__SWIG_13(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::TensorOffsetLayout *arg1 = 0 ;
  daal::services::SharedPtr< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout const > tempshared1 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenTensor_Float64_create",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t,  0 , &newmem);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float64_create" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (!argp1) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Float64_create" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(tempshared1.get());
    } else {
      arg1 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1)->get());
    }
    if(!arg1) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float64_create" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
  }
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_double_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenTensor_Float64_create" "', argument " "2"" of type '" "daal::services::SharedPtr< double > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Float64_create" "', argument " "2"" of type '" "daal::services::SharedPtr< double > const &""'"); 
  }
  arg2 = reinterpret_cast< daal::services::SharedPtr< double > * >(argp2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< double >::SWIGTEMPLATEDISAMBIGUATOR create((daal::data_management::interface1::TensorOffsetLayout const &)*arg1,(daal::services::SharedPtr< double > const &)*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float64_create__SWIG_14(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::Collection< size_t > *arg1 = 0 ;
  daal::data_management::interface1::TensorIface::AllocationFlag arg2 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  daal::services::Collection< size_t > *col_szt1 = NULL ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:HomogenTensor_Float64_create",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    Py_ssize_t n = PySequence_Length(obj0);
    if( n == 0 ) SWIG_fail;
    col_szt1 = new daal::services::Collection<size_t>(n);
    for( Py_ssize_t i=0; i<n; ++i ) {
      PyObject * o = PySequence_GetItem(obj0, i);
      size_t tmp = PyInt_AsSsize_t(o);
      if(PyErr_Occurred()) {
        PyErr_Format(PyExc_TypeError, "Sequence of integer values required");
        SWIG_fail;
      }
      (*col_szt1)[i] = tmp;
    }
    arg1 = col_szt1;
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenTensor_Float64_create" "', argument " "2"" of type '" "daal::data_management::interface1::TensorIface::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::TensorIface::AllocationFlag >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "HomogenTensor_Float64_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< double >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::Collection< size_t > const &)*arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, SWIG_POINTER_OWN);
  }
  {
    if( col_szt1 ) delete col_szt1;
  }
  return resultobj;
fail:
  {
    if( col_szt1 ) delete col_szt1;
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float64_create__SWIG_15(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::Collection< size_t > *arg1 = 0 ;
  daal::data_management::interface1::TensorIface::AllocationFlag arg2 ;
  daal::services::Collection< size_t > *col_szt1 = NULL ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenTensor_Float64_create",&obj0,&obj1)) SWIG_fail;
  {
    Py_ssize_t n = PySequence_Length(obj0);
    if( n == 0 ) SWIG_fail;
    col_szt1 = new daal::services::Collection<size_t>(n);
    for( Py_ssize_t i=0; i<n; ++i ) {
      PyObject * o = PySequence_GetItem(obj0, i);
      size_t tmp = PyInt_AsSsize_t(o);
      if(PyErr_Occurred()) {
        PyErr_Format(PyExc_TypeError, "Sequence of integer values required");
        SWIG_fail;
      }
      (*col_szt1)[i] = tmp;
    }
    arg1 = col_szt1;
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenTensor_Float64_create" "', argument " "2"" of type '" "daal::data_management::interface1::TensorIface::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::TensorIface::AllocationFlag >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< double >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::Collection< size_t > const &)*arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, SWIG_POINTER_OWN);
  }
  {
    if( col_szt1 ) delete col_szt1;
  }
  return resultobj;
fail:
  {
    if( col_szt1 ) delete col_szt1;
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float64_create__SWIG_16(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::Collection< size_t > *arg1 = 0 ;
  daal::data_management::interface1::TensorIface::AllocationFlag arg2 ;
  double arg3 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  daal::services::Collection< size_t > *col_szt1 = NULL ;
  int val2 ;
  int ecode2 = 0 ;
  double val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:HomogenTensor_Float64_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  {
    Py_ssize_t n = PySequence_Length(obj0);
    if( n == 0 ) SWIG_fail;
    col_szt1 = new daal::services::Collection<size_t>(n);
    for( Py_ssize_t i=0; i<n; ++i ) {
      PyObject * o = PySequence_GetItem(obj0, i);
      size_t tmp = PyInt_AsSsize_t(o);
      if(PyErr_Occurred()) {
        PyErr_Format(PyExc_TypeError, "Sequence of integer values required");
        SWIG_fail;
      }
      (*col_szt1)[i] = tmp;
    }
    arg1 = col_szt1;
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenTensor_Float64_create" "', argument " "2"" of type '" "daal::data_management::interface1::TensorIface::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::TensorIface::AllocationFlag >(val2);
  ecode3 = SWIG_AsVal_double(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenTensor_Float64_create" "', argument " "3"" of type '" "double""'");
  } 
  arg3 = static_cast< double >(val3);
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "HomogenTensor_Float64_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< double >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::Collection< size_t > const &)*arg1,arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, SWIG_POINTER_OWN);
  }
  {
    if( col_szt1 ) delete col_szt1;
  }
  return resultobj;
fail:
  {
    if( col_szt1 ) delete col_szt1;
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float64_create__SWIG_17(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::Collection< size_t > *arg1 = 0 ;
  daal::data_management::interface1::TensorIface::AllocationFlag arg2 ;
  double arg3 ;
  daal::services::Collection< size_t > *col_szt1 = NULL ;
  int val2 ;
  int ecode2 = 0 ;
  double val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:HomogenTensor_Float64_create",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    Py_ssize_t n = PySequence_Length(obj0);
    if( n == 0 ) SWIG_fail;
    col_szt1 = new daal::services::Collection<size_t>(n);
    for( Py_ssize_t i=0; i<n; ++i ) {
      PyObject * o = PySequence_GetItem(obj0, i);
      size_t tmp = PyInt_AsSsize_t(o);
      if(PyErr_Occurred()) {
        PyErr_Format(PyExc_TypeError, "Sequence of integer values required");
        SWIG_fail;
      }
      (*col_szt1)[i] = tmp;
    }
    arg1 = col_szt1;
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenTensor_Float64_create" "', argument " "2"" of type '" "daal::data_management::interface1::TensorIface::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::TensorIface::AllocationFlag >(val2);
  ecode3 = SWIG_AsVal_double(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenTensor_Float64_create" "', argument " "3"" of type '" "double""'");
  } 
  arg3 = static_cast< double >(val3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< double >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::Collection< size_t > const &)*arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, SWIG_POINTER_OWN);
  }
  {
    if( col_szt1 ) delete col_szt1;
  }
  return resultobj;
fail:
  {
    if( col_szt1 ) delete col_szt1;
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float64_create(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[5];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 4) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_HomogenTensor_Float64_create__SWIG_1(self, args);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_HomogenTensor_Float64_create__SWIG_0(self, args);
    }
  }
  if (argc == 1) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_DOUBLE))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      if (argc <= 1) {
        return _wrap_HomogenTensor_Float64_create__SWIG_5(self, args);
      }
      if (argc <= 2) {
        return _wrap_HomogenTensor_Float64_create__SWIG_5(self, args);
      }
      return _wrap_HomogenTensor_Float64_create__SWIG_5(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_double, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenTensor_Float64_create__SWIG_11(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_double_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenTensor_Float64_create__SWIG_13(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      _v = PySequence_Check(argv[0]);
    }
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_double_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenTensor_Float64_create__SWIG_9(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_DOUBLE))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenTensor_Float64_create__SWIG_4(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      _v = PySequence_Check(argv[0]);
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_double, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenTensor_Float64_create__SWIG_7(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      _v = PySequence_Check(argv[0]);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_HomogenTensor_Float64_create__SWIG_15(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_double, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_HomogenTensor_Float64_create__SWIG_10(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_double_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_HomogenTensor_Float64_create__SWIG_12(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_size_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_double, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_HomogenTensor_Float64_create__SWIG_3(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      _v = PySequence_Check(argv[0]);
    }
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_double_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_HomogenTensor_Float64_create__SWIG_8(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      _v = PySequence_Check(argv[0]);
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_double, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_HomogenTensor_Float64_create__SWIG_6(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      _v = PySequence_Check(argv[0]);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_HomogenTensor_Float64_create__SWIG_14(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      _v = PySequence_Check(argv[0]);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_double(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_HomogenTensor_Float64_create__SWIG_17(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_size_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_double, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_HomogenTensor_Float64_create__SWIG_2(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      _v = PySequence_Check(argv[0]);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_double(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_HomogenTensor_Float64_create__SWIG_16(self, args);
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'HomogenTensor_Float64_create'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::HomogenTensor< double >::create(daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenTensor< double >::create()\n"
    "    daal::data_management::interface1::HomogenTensor< double >::create(size_t,size_t const *,double *,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenTensor< double >::create(size_t,size_t const *,double *)\n"
    "    daal::data_management::interface1::HomogenTensor< double >::create(size_t,size_t const *,daal::services::SharedPtr< double > const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenTensor< double >::create(size_t,size_t const *,daal::services::SharedPtr< double > const &)\n"
    "    daal::data_management::interface1::HomogenTensor< double >::create(daal::services::Collection< size_t > const &,double *,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenTensor< double >::create(daal::services::Collection< size_t > const &,double *)\n"
    "    daal::data_management::interface1::HomogenTensor< double >::create(daal::services::Collection< size_t > const &,daal::services::SharedPtr< double > const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenTensor< double >::create(daal::services::Collection< size_t > const &,daal::services::SharedPtr< double > const &)\n"
    "    daal::data_management::interface1::HomogenTensor< double >::create(daal::data_management::interface1::TensorOffsetLayout const &,double *,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenTensor< double >::create(daal::data_management::interface1::TensorOffsetLayout const &,double *)\n"
    "    daal::data_management::interface1::HomogenTensor< double >::create(daal::data_management::interface1::TensorOffsetLayout const &,daal::services::SharedPtr< double > const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenTensor< double >::create(daal::data_management::interface1::TensorOffsetLayout const &,daal::services::SharedPtr< double > const &)\n"
    "    daal::data_management::interface1::HomogenTensor< double >::create(daal::services::Collection< size_t > const &,daal::data_management::interface1::TensorIface::AllocationFlag,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenTensor< double >::create(daal::services::Collection< size_t > const &,daal::data_management::interface1::TensorIface::AllocationFlag)\n"
    "    daal::data_management::interface1::HomogenTensor< double >::create(daal::services::Collection< size_t > const &,daal::data_management::interface1::TensorIface::AllocationFlag,double const,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenTensor< double >::create(daal::services::Collection< size_t > const &,daal::data_management::interface1::TensorIface::AllocationFlag,double const)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_HomogenTensor_Float64(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< double > *arg1 = (daal::data_management::interface1::HomogenTensor< double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_HomogenTensor_Float64",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_HomogenTensor_Float64" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_HomogenTensor_Float64" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< double > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float64_getTensorLayout(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< double > *arg1 = (daal::data_management::interface1::HomogenTensor< double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::TensorOffsetLayout *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:HomogenTensor_Float64_getTensorLayout",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float64_getTensorLayout" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float64_getTensorLayout" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< double > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::TensorOffsetLayout *) &(arg1)->getTensorLayout();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::TensorOffsetLayout > *smartresult = new daal::services::SharedPtr<  daal::data_management::interface1::TensorOffsetLayout >(result SWIG_NO_NULL_DELETER_0);
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float64_createDefaultSubtensorLayout(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< double > *arg1 = (daal::data_management::interface1::HomogenTensor< double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  SwigValueWrapper< daal::data_management::interface1::TensorOffsetLayout > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:HomogenTensor_Float64_createDefaultSubtensorLayout",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float64_createDefaultSubtensorLayout" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< double > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float64_createDefaultSubtensorLayout" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< double > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::HomogenTensor< double > const *)arg1)->createDefaultSubtensorLayout();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::TensorOffsetLayout > *smartresult = new daal::services::SharedPtr<  daal::data_management::interface1::TensorOffsetLayout >(new daal::data_management::interface1::TensorOffsetLayout((daal::data_management::interface1::TensorOffsetLayout &)result));
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float64_createRawSubtensorLayout(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< double > *arg1 = (daal::data_management::interface1::HomogenTensor< double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  SwigValueWrapper< daal::data_management::interface1::TensorOffsetLayout > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:HomogenTensor_Float64_createRawSubtensorLayout",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float64_createRawSubtensorLayout" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< double > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float64_createRawSubtensorLayout" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< double > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::HomogenTensor< double > const *)arg1)->createRawSubtensorLayout();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::TensorOffsetLayout > *smartresult = new daal::services::SharedPtr<  daal::data_management::interface1::TensorOffsetLayout >(new daal::data_management::interface1::TensorOffsetLayout((daal::data_management::interface1::TensorOffsetLayout &)result));
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float64_setDimensions__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< double > *arg1 = (daal::data_management::interface1::HomogenTensor< double > *) 0 ;
  size_t arg2 ;
  size_t *arg3 = (size_t *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:HomogenTensor_Float64_setDimensions",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float64_setDimensions" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float64_setDimensions" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< double > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenTensor_Float64_setDimensions" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_size_t, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "HomogenTensor_Float64_setDimensions" "', argument " "3"" of type '" "size_t const *""'"); 
  }
  arg3 = reinterpret_cast< size_t * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->setDimensions(arg2,(size_t const *)arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float64_setDimensions__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< double > *arg1 = (daal::data_management::interface1::HomogenTensor< double > *) 0 ;
  daal::services::Collection< size_t > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > *smartarg1 = 0 ;
  daal::services::Collection< size_t > *col_szt2 = NULL ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenTensor_Float64_setDimensions",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float64_setDimensions" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float64_setDimensions" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< double > *""'"); 
  }
  {
    Py_ssize_t n = PySequence_Length(obj1);
    if( n == 0 ) SWIG_fail;
    col_szt2 = new daal::services::Collection<size_t>(n);
    for( Py_ssize_t i=0; i<n; ++i ) {
      PyObject * o = PySequence_GetItem(obj1, i);
      size_t tmp = PyInt_AsSsize_t(o);
      if(PyErr_Occurred()) {
        PyErr_Format(PyExc_TypeError, "Sequence of integer values required");
        SWIG_fail;
      }
      (*col_szt2)[i] = tmp;
    }
    arg2 = col_szt2;
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->setDimensions((daal::services::Collection< size_t > const &)*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  {
    if( col_szt2 ) delete col_szt2;
  }
  return resultobj;
fail:
  {
    if( col_szt2 ) delete col_szt2;
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float64_setDimensions(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[4];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 3) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySequence_Check(argv[1]);
      }
      if (_v) {
        return _wrap_HomogenTensor_Float64_setDimensions__SWIG_1(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_size_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_HomogenTensor_Float64_setDimensions__SWIG_0(self, args);
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'HomogenTensor_Float64_setDimensions'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::HomogenTensor< double >::setDimensions(size_t,size_t const *)\n"
    "    daal::data_management::interface1::HomogenTensor< double >::setDimensions(daal::services::Collection< size_t > const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float64_assign(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< double > *arg1 = (daal::data_management::interface1::HomogenTensor< double > *) 0 ;
  double arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > *smartarg1 = 0 ;
  double val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenTensor_Float64_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float64_assign" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float64_assign" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< double > *""'"); 
  }
  ecode2 = SWIG_AsVal_double(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenTensor_Float64_assign" "', argument " "2"" of type '" "double""'");
  } 
  arg2 = static_cast< double >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float64_getSubtensorEx__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< double > *arg1 = (daal::data_management::interface1::HomogenTensor< double > *) 0 ;
  size_t arg2 ;
  size_t *arg3 = (size_t *) 0 ;
  size_t arg4 ;
  size_t arg5 ;
  daal::data_management::ReadWriteMode arg6 ;
  daal::data_management::interface1::SubtensorDescriptor< double > *arg7 = 0 ;
  daal::data_management::interface1::TensorOffsetLayout *arg8 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int is_new_object2 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  size_t val5 ;
  int ecode5 = 0 ;
  int val6 ;
  int ecode6 = 0 ;
  void *argp7 = 0 ;
  int res7 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< double > > tempshared7 ;
  void *argp8 = 0 ;
  int res8 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout const > tempshared8 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  PyObject * obj6 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOOO:HomogenTensor_Float64_getSubtensorEx",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5,&obj6)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float64_getSubtensorEx" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float64_getSubtensorEx" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< double > *""'"); 
  }
  {
    array2 = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UINT64)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UINT64, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (size_t) array_size(array2,0);
    arg3 = (size_t*) array_data(array2);
  }
  ecode4 = SWIG_AsVal_size_t(obj2, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenTensor_Float64_getSubtensorEx" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_size_t(obj3, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "HomogenTensor_Float64_getSubtensorEx" "', argument " "5"" of type '" "size_t""'");
  } 
  arg5 = static_cast< size_t >(val5);
  ecode6 = SWIG_AsVal_int(obj4, &val6);
  if (!SWIG_IsOK(ecode6)) {
    SWIG_exception_fail(SWIG_ArgError(ecode6), "in method '" "HomogenTensor_Float64_getSubtensorEx" "', argument " "6"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg6 = static_cast< daal::data_management::ReadWriteMode >(val6);
  {
    int newmem = 0;
    res7 = SWIG_ConvertPtrAndOwn(obj5, &argp7, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res7)) {
      SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "HomogenTensor_Float64_getSubtensorEx" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > &""'"); 
    }
    if (!argp7) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Float64_getSubtensorEx" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared7 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp7);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp7);
      arg7 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >(tempshared7.get());
    } else {
      arg7 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp7)->get());
    }
    if(!arg7) SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "HomogenTensor_Float64_getSubtensorEx" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > &""'"); 
  }
  {
    int newmem = 0;
    res8 = SWIG_ConvertPtrAndOwn(obj6, &argp8, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t,  0 , &newmem);
    if (!SWIG_IsOK(res8)) {
      SWIG_exception_fail(SWIG_ArgError(res8), "in method '" "HomogenTensor_Float64_getSubtensorEx" "', argument " "8"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (!argp8) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Float64_getSubtensorEx" "', argument " "8"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared8 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp8);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp8);
      arg8 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(tempshared8.get());
    } else {
      arg8 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp8)->get());
    }
    if(!arg8) SWIG_exception_fail(SWIG_ArgError(res8), "in method '" "HomogenTensor_Float64_getSubtensorEx" "', argument " "8"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getSubtensorEx(arg2,(size_t const *)arg3,arg4,arg5,arg6,*arg7,(daal::data_management::interface1::TensorOffsetLayout const &)*arg8);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  {
    if(ALLOW_CONVERSION != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(ALLOW_CONVERSION != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float64_getSubtensorEx__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< double > *arg1 = (daal::data_management::interface1::HomogenTensor< double > *) 0 ;
  size_t arg2 ;
  size_t *arg3 = (size_t *) 0 ;
  size_t arg4 ;
  size_t arg5 ;
  daal::data_management::ReadWriteMode arg6 ;
  daal::data_management::interface1::SubtensorDescriptor< float > *arg7 = 0 ;
  daal::data_management::interface1::TensorOffsetLayout *arg8 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int is_new_object2 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  size_t val5 ;
  int ecode5 = 0 ;
  int val6 ;
  int ecode6 = 0 ;
  void *argp7 = 0 ;
  int res7 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< float > > tempshared7 ;
  void *argp8 = 0 ;
  int res8 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout const > tempshared8 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  PyObject * obj6 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOOO:HomogenTensor_Float64_getSubtensorEx",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5,&obj6)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float64_getSubtensorEx" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float64_getSubtensorEx" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< double > *""'"); 
  }
  {
    array2 = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UINT64)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UINT64, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (size_t) array_size(array2,0);
    arg3 = (size_t*) array_data(array2);
  }
  ecode4 = SWIG_AsVal_size_t(obj2, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenTensor_Float64_getSubtensorEx" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_size_t(obj3, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "HomogenTensor_Float64_getSubtensorEx" "', argument " "5"" of type '" "size_t""'");
  } 
  arg5 = static_cast< size_t >(val5);
  ecode6 = SWIG_AsVal_int(obj4, &val6);
  if (!SWIG_IsOK(ecode6)) {
    SWIG_exception_fail(SWIG_ArgError(ecode6), "in method '" "HomogenTensor_Float64_getSubtensorEx" "', argument " "6"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg6 = static_cast< daal::data_management::ReadWriteMode >(val6);
  {
    int newmem = 0;
    res7 = SWIG_ConvertPtrAndOwn(obj5, &argp7, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res7)) {
      SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "HomogenTensor_Float64_getSubtensorEx" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > &""'"); 
    }
    if (!argp7) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Float64_getSubtensorEx" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared7 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp7);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp7);
      arg7 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >(tempshared7.get());
    } else {
      arg7 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp7)->get());
    }
    if(!arg7) SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "HomogenTensor_Float64_getSubtensorEx" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > &""'"); 
  }
  {
    int newmem = 0;
    res8 = SWIG_ConvertPtrAndOwn(obj6, &argp8, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t,  0 , &newmem);
    if (!SWIG_IsOK(res8)) {
      SWIG_exception_fail(SWIG_ArgError(res8), "in method '" "HomogenTensor_Float64_getSubtensorEx" "', argument " "8"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (!argp8) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Float64_getSubtensorEx" "', argument " "8"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared8 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp8);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp8);
      arg8 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(tempshared8.get());
    } else {
      arg8 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp8)->get());
    }
    if(!arg8) SWIG_exception_fail(SWIG_ArgError(res8), "in method '" "HomogenTensor_Float64_getSubtensorEx" "', argument " "8"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getSubtensorEx(arg2,(size_t const *)arg3,arg4,arg5,arg6,*arg7,(daal::data_management::interface1::TensorOffsetLayout const &)*arg8);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  {
    if(ALLOW_CONVERSION != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(ALLOW_CONVERSION != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float64_getSubtensorEx__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< double > *arg1 = (daal::data_management::interface1::HomogenTensor< double > *) 0 ;
  size_t arg2 ;
  size_t *arg3 = (size_t *) 0 ;
  size_t arg4 ;
  size_t arg5 ;
  daal::data_management::ReadWriteMode arg6 ;
  daal::data_management::interface1::SubtensorDescriptor< int > *arg7 = 0 ;
  daal::data_management::interface1::TensorOffsetLayout *arg8 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int is_new_object2 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  size_t val5 ;
  int ecode5 = 0 ;
  int val6 ;
  int ecode6 = 0 ;
  void *argp7 = 0 ;
  int res7 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< int > > tempshared7 ;
  void *argp8 = 0 ;
  int res8 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout const > tempshared8 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  PyObject * obj6 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOOO:HomogenTensor_Float64_getSubtensorEx",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5,&obj6)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float64_getSubtensorEx" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float64_getSubtensorEx" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< double > *""'"); 
  }
  {
    array2 = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UINT64)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UINT64, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (size_t) array_size(array2,0);
    arg3 = (size_t*) array_data(array2);
  }
  ecode4 = SWIG_AsVal_size_t(obj2, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenTensor_Float64_getSubtensorEx" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_size_t(obj3, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "HomogenTensor_Float64_getSubtensorEx" "', argument " "5"" of type '" "size_t""'");
  } 
  arg5 = static_cast< size_t >(val5);
  ecode6 = SWIG_AsVal_int(obj4, &val6);
  if (!SWIG_IsOK(ecode6)) {
    SWIG_exception_fail(SWIG_ArgError(ecode6), "in method '" "HomogenTensor_Float64_getSubtensorEx" "', argument " "6"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg6 = static_cast< daal::data_management::ReadWriteMode >(val6);
  {
    int newmem = 0;
    res7 = SWIG_ConvertPtrAndOwn(obj5, &argp7, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res7)) {
      SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "HomogenTensor_Float64_getSubtensorEx" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > &""'"); 
    }
    if (!argp7) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Float64_getSubtensorEx" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared7 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp7);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp7);
      arg7 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >(tempshared7.get());
    } else {
      arg7 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp7)->get());
    }
    if(!arg7) SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "HomogenTensor_Float64_getSubtensorEx" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > &""'"); 
  }
  {
    int newmem = 0;
    res8 = SWIG_ConvertPtrAndOwn(obj6, &argp8, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t,  0 , &newmem);
    if (!SWIG_IsOK(res8)) {
      SWIG_exception_fail(SWIG_ArgError(res8), "in method '" "HomogenTensor_Float64_getSubtensorEx" "', argument " "8"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (!argp8) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Float64_getSubtensorEx" "', argument " "8"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared8 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp8);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp8);
      arg8 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(tempshared8.get());
    } else {
      arg8 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp8)->get());
    }
    if(!arg8) SWIG_exception_fail(SWIG_ArgError(res8), "in method '" "HomogenTensor_Float64_getSubtensorEx" "', argument " "8"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getSubtensorEx(arg2,(size_t const *)arg3,arg4,arg5,arg6,*arg7,(daal::data_management::interface1::TensorOffsetLayout const &)*arg8);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  {
    if(ALLOW_CONVERSION != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(ALLOW_CONVERSION != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float64_getSubtensorEx(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[8];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 7) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 7) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = (ALLOW_CONVERSION == FORCE_INPLACE
          ? (is_array(argv[1]) && PyArray_EquivTypenums(array_type(argv[1]), NPY_UINT64))
          :(is_array(argv[1]) || PySequence_Check(argv[1])));
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                int res = SWIG_ConvertPtr(argv[6], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, 0);
                _v = SWIG_CheckState(res);
                if (_v) {
                  return _wrap_HomogenTensor_Float64_getSubtensorEx__SWIG_0(self, args);
                }
              }
            }
          }
        }
      }
    }
  }
  if (argc == 7) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = (ALLOW_CONVERSION == FORCE_INPLACE
          ? (is_array(argv[1]) && PyArray_EquivTypenums(array_type(argv[1]), NPY_UINT64))
          :(is_array(argv[1]) || PySequence_Check(argv[1])));
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                int res = SWIG_ConvertPtr(argv[6], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, 0);
                _v = SWIG_CheckState(res);
                if (_v) {
                  return _wrap_HomogenTensor_Float64_getSubtensorEx__SWIG_1(self, args);
                }
              }
            }
          }
        }
      }
    }
  }
  if (argc == 7) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = (ALLOW_CONVERSION == FORCE_INPLACE
          ? (is_array(argv[1]) && PyArray_EquivTypenums(array_type(argv[1]), NPY_UINT64))
          :(is_array(argv[1]) || PySequence_Check(argv[1])));
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                int res = SWIG_ConvertPtr(argv[6], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, 0);
                _v = SWIG_CheckState(res);
                if (_v) {
                  return _wrap_HomogenTensor_Float64_getSubtensorEx__SWIG_2(self, args);
                }
              }
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'HomogenTensor_Float64_getSubtensorEx'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::HomogenTensor< double >::getSubtensorEx(size_t,size_t const *,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::SubtensorDescriptor< double > &,daal::data_management::interface1::TensorOffsetLayout const &)\n"
    "    daal::data_management::interface1::HomogenTensor< double >::getSubtensorEx(size_t,size_t const *,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::SubtensorDescriptor< float > &,daal::data_management::interface1::TensorOffsetLayout const &)\n"
    "    daal::data_management::interface1::HomogenTensor< double >::getSubtensorEx(size_t,size_t const *,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::SubtensorDescriptor< int > &,daal::data_management::interface1::TensorOffsetLayout const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float64_getSubtensor__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< double > *arg1 = (daal::data_management::interface1::HomogenTensor< double > *) 0 ;
  size_t arg2 ;
  size_t *arg3 = (size_t *) 0 ;
  size_t arg4 ;
  size_t arg5 ;
  daal::data_management::ReadWriteMode arg6 ;
  daal::data_management::interface1::SubtensorDescriptor< double > *arg7 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int is_new_object2 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  size_t val5 ;
  int ecode5 = 0 ;
  int val6 ;
  int ecode6 = 0 ;
  void *argp7 = 0 ;
  int res7 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< double > > tempshared7 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:HomogenTensor_Float64_getSubtensor",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float64_getSubtensor" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float64_getSubtensor" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< double > *""'"); 
  }
  {
    array2 = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UINT64)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UINT64, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (size_t) array_size(array2,0);
    arg3 = (size_t*) array_data(array2);
  }
  ecode4 = SWIG_AsVal_size_t(obj2, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenTensor_Float64_getSubtensor" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_size_t(obj3, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "HomogenTensor_Float64_getSubtensor" "', argument " "5"" of type '" "size_t""'");
  } 
  arg5 = static_cast< size_t >(val5);
  ecode6 = SWIG_AsVal_int(obj4, &val6);
  if (!SWIG_IsOK(ecode6)) {
    SWIG_exception_fail(SWIG_ArgError(ecode6), "in method '" "HomogenTensor_Float64_getSubtensor" "', argument " "6"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg6 = static_cast< daal::data_management::ReadWriteMode >(val6);
  {
    int newmem = 0;
    res7 = SWIG_ConvertPtrAndOwn(obj5, &argp7, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res7)) {
      SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "HomogenTensor_Float64_getSubtensor" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > &""'"); 
    }
    if (!argp7) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Float64_getSubtensor" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared7 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp7);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp7);
      arg7 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >(tempshared7.get());
    } else {
      arg7 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp7)->get());
    }
    if(!arg7) SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "HomogenTensor_Float64_getSubtensor" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getSubtensor(arg2,(size_t const *)arg3,arg4,arg5,arg6,*arg7);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  {
    if(ALLOW_CONVERSION != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(ALLOW_CONVERSION != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float64_getSubtensor__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< double > *arg1 = (daal::data_management::interface1::HomogenTensor< double > *) 0 ;
  size_t arg2 ;
  size_t *arg3 = (size_t *) 0 ;
  size_t arg4 ;
  size_t arg5 ;
  daal::data_management::ReadWriteMode arg6 ;
  daal::data_management::interface1::SubtensorDescriptor< float > *arg7 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int is_new_object2 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  size_t val5 ;
  int ecode5 = 0 ;
  int val6 ;
  int ecode6 = 0 ;
  void *argp7 = 0 ;
  int res7 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< float > > tempshared7 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:HomogenTensor_Float64_getSubtensor",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float64_getSubtensor" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float64_getSubtensor" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< double > *""'"); 
  }
  {
    array2 = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UINT64)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UINT64, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (size_t) array_size(array2,0);
    arg3 = (size_t*) array_data(array2);
  }
  ecode4 = SWIG_AsVal_size_t(obj2, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenTensor_Float64_getSubtensor" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_size_t(obj3, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "HomogenTensor_Float64_getSubtensor" "', argument " "5"" of type '" "size_t""'");
  } 
  arg5 = static_cast< size_t >(val5);
  ecode6 = SWIG_AsVal_int(obj4, &val6);
  if (!SWIG_IsOK(ecode6)) {
    SWIG_exception_fail(SWIG_ArgError(ecode6), "in method '" "HomogenTensor_Float64_getSubtensor" "', argument " "6"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg6 = static_cast< daal::data_management::ReadWriteMode >(val6);
  {
    int newmem = 0;
    res7 = SWIG_ConvertPtrAndOwn(obj5, &argp7, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res7)) {
      SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "HomogenTensor_Float64_getSubtensor" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > &""'"); 
    }
    if (!argp7) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Float64_getSubtensor" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared7 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp7);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp7);
      arg7 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >(tempshared7.get());
    } else {
      arg7 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp7)->get());
    }
    if(!arg7) SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "HomogenTensor_Float64_getSubtensor" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getSubtensor(arg2,(size_t const *)arg3,arg4,arg5,arg6,*arg7);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  {
    if(ALLOW_CONVERSION != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(ALLOW_CONVERSION != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float64_getSubtensor__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< double > *arg1 = (daal::data_management::interface1::HomogenTensor< double > *) 0 ;
  size_t arg2 ;
  size_t *arg3 = (size_t *) 0 ;
  size_t arg4 ;
  size_t arg5 ;
  daal::data_management::ReadWriteMode arg6 ;
  daal::data_management::interface1::SubtensorDescriptor< int > *arg7 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int is_new_object2 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  size_t val5 ;
  int ecode5 = 0 ;
  int val6 ;
  int ecode6 = 0 ;
  void *argp7 = 0 ;
  int res7 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< int > > tempshared7 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:HomogenTensor_Float64_getSubtensor",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float64_getSubtensor" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float64_getSubtensor" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< double > *""'"); 
  }
  {
    array2 = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UINT64)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UINT64, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (size_t) array_size(array2,0);
    arg3 = (size_t*) array_data(array2);
  }
  ecode4 = SWIG_AsVal_size_t(obj2, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenTensor_Float64_getSubtensor" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_size_t(obj3, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "HomogenTensor_Float64_getSubtensor" "', argument " "5"" of type '" "size_t""'");
  } 
  arg5 = static_cast< size_t >(val5);
  ecode6 = SWIG_AsVal_int(obj4, &val6);
  if (!SWIG_IsOK(ecode6)) {
    SWIG_exception_fail(SWIG_ArgError(ecode6), "in method '" "HomogenTensor_Float64_getSubtensor" "', argument " "6"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg6 = static_cast< daal::data_management::ReadWriteMode >(val6);
  {
    int newmem = 0;
    res7 = SWIG_ConvertPtrAndOwn(obj5, &argp7, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res7)) {
      SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "HomogenTensor_Float64_getSubtensor" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > &""'"); 
    }
    if (!argp7) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Float64_getSubtensor" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared7 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp7);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp7);
      arg7 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >(tempshared7.get());
    } else {
      arg7 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp7)->get());
    }
    if(!arg7) SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "HomogenTensor_Float64_getSubtensor" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getSubtensor(arg2,(size_t const *)arg3,arg4,arg5,arg6,*arg7);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  {
    if(ALLOW_CONVERSION != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(ALLOW_CONVERSION != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float64_getSubtensor(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[7];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 6) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = (ALLOW_CONVERSION == FORCE_INPLACE
          ? (is_array(argv[1]) && PyArray_EquivTypenums(array_type(argv[1]), NPY_UINT64))
          :(is_array(argv[1]) || PySequence_Check(argv[1])));
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_HomogenTensor_Float64_getSubtensor__SWIG_0(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = (ALLOW_CONVERSION == FORCE_INPLACE
          ? (is_array(argv[1]) && PyArray_EquivTypenums(array_type(argv[1]), NPY_UINT64))
          :(is_array(argv[1]) || PySequence_Check(argv[1])));
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_HomogenTensor_Float64_getSubtensor__SWIG_1(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = (ALLOW_CONVERSION == FORCE_INPLACE
          ? (is_array(argv[1]) && PyArray_EquivTypenums(array_type(argv[1]), NPY_UINT64))
          :(is_array(argv[1]) || PySequence_Check(argv[1])));
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_HomogenTensor_Float64_getSubtensor__SWIG_2(self, args);
              }
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'HomogenTensor_Float64_getSubtensor'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::HomogenTensor< double >::getSubtensor(size_t,size_t const *,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::SubtensorDescriptor< double > &)\n"
    "    daal::data_management::interface1::HomogenTensor< double >::getSubtensor(size_t,size_t const *,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::SubtensorDescriptor< float > &)\n"
    "    daal::data_management::interface1::HomogenTensor< double >::getSubtensor(size_t,size_t const *,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::SubtensorDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float64_releaseSubtensor__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< double > *arg1 = (daal::data_management::interface1::HomogenTensor< double > *) 0 ;
  daal::data_management::interface1::SubtensorDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenTensor_Float64_releaseSubtensor",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float64_releaseSubtensor" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float64_releaseSubtensor" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< double > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenTensor_Float64_releaseSubtensor" "', argument " "2"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Float64_releaseSubtensor" "', argument " "2"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenTensor_Float64_releaseSubtensor" "', argument " "2"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseSubtensor(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float64_releaseSubtensor__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< double > *arg1 = (daal::data_management::interface1::HomogenTensor< double > *) 0 ;
  daal::data_management::interface1::SubtensorDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenTensor_Float64_releaseSubtensor",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float64_releaseSubtensor" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float64_releaseSubtensor" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< double > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenTensor_Float64_releaseSubtensor" "', argument " "2"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Float64_releaseSubtensor" "', argument " "2"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenTensor_Float64_releaseSubtensor" "', argument " "2"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseSubtensor(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float64_releaseSubtensor__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< double > *arg1 = (daal::data_management::interface1::HomogenTensor< double > *) 0 ;
  daal::data_management::interface1::SubtensorDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenTensor_Float64_releaseSubtensor",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float64_releaseSubtensor" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float64_releaseSubtensor" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< double > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenTensor_Float64_releaseSubtensor" "', argument " "2"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Float64_releaseSubtensor" "', argument " "2"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenTensor_Float64_releaseSubtensor" "', argument " "2"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseSubtensor(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float64_releaseSubtensor(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenTensor_Float64_releaseSubtensor__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenTensor_Float64_releaseSubtensor__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenTensor_Float64_releaseSubtensor__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'HomogenTensor_Float64_releaseSubtensor'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::HomogenTensor< double >::releaseSubtensor(daal::data_management::interface1::SubtensorDescriptor< double > &)\n"
    "    daal::data_management::interface1::HomogenTensor< double >::releaseSubtensor(daal::data_management::interface1::SubtensorDescriptor< float > &)\n"
    "    daal::data_management::interface1::HomogenTensor< double >::releaseSubtensor(daal::data_management::interface1::SubtensorDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float64_getSampleTensor(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< double > *arg1 = (daal::data_management::interface1::HomogenTensor< double > *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Tensor > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenTensor_Float64_getSampleTensor",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float64_getSampleTensor" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float64_getSampleTensor" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< double > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenTensor_Float64_getSampleTensor" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getSampleTensor(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Tensor > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Tensor >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float64_getArray(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< double > *arg1 = (daal::data_management::interface1::HomogenTensor< double > *) 0 ;
  daal::services::Collection< size_t > **arg2 = (daal::services::Collection< size_t > **) 0 ;
  daal::services::SharedPtr< double > *arg3 = (daal::services::SharedPtr< double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > *smartarg1 = 0 ;
  daal::services::Collection< size_t > *dims_tmp2 ;
  daal::services::SharedPtr< double > data_tmp2 ;
  PyObject * obj0 = 0 ;
  
  {
    arg2 = &dims_tmp2;
    arg3 = &data_tmp2;
  }
  if (!PyArg_ParseTuple(args,(char *)"O:HomogenTensor_Float64_getArray",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float64_getArray" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float64_getArray" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< double > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        daal_data_management_interface1_HomogenTensor_Sl_double_Sg__getArray(arg1,(daal::services::Collection< size_t > const **)arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    npy_intp * dims = NULL;
    dims = new npy_intp[(*arg2)->size()];
    for( size_t i=0; i<(*arg2)->size(); ++i ) {
      dims[i] = (npy_intp)(*arg2)->get(i);
    }
    PyObject* obj = PyArray_SimpleNewFromData((*arg2)->size(), dims, NPY_DOUBLE, (void*)(arg3->get()));
    delete [] dims;
    if (!obj) SWIG_fail;
    set_sp_base((PyArrayObject*)obj, *arg3);
    resultobj = SWIG_Python_AppendOutput(resultobj, obj);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *HomogenTensor_Float64_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_HomogenTensor_Float32_serializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)":HomogenTensor_Float32_serializationTag")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)daal::data_management::interface1::HomogenTensor< float >::SWIGTEMPLATEDISAMBIGUATOR serializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float32_getSerializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< float > *arg1 = (daal::data_management::interface1::HomogenTensor< float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:HomogenTensor_Float32_getSerializationTag",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float32_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< float > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float32_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< float > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)((daal::data_management::interface1::HomogenTensor< float > const *)arg1)->getSerializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float32_create__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::Status *arg1 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:HomogenTensor_Float32_create",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float32_create" "', argument " "1"" of type '" "daal::services::Status *""'"); 
  }
  arg1 = reinterpret_cast< daal::services::Status * >(argp1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float32_create__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)":HomogenTensor_Float32_create")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< float >::SWIGTEMPLATEDISAMBIGUATOR create();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float32_create__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t *arg2 = (size_t *) 0 ;
  float *arg3 = (float *) 0 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:HomogenTensor_Float32_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenTensor_Float32_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_size_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenTensor_Float32_create" "', argument " "2"" of type '" "size_t const *""'"); 
  }
  arg2 = reinterpret_cast< size_t * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_float, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "HomogenTensor_Float32_create" "', argument " "3"" of type '" "float *""'"); 
  }
  arg3 = reinterpret_cast< float * >(argp3);
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "HomogenTensor_Float32_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,(size_t const *)arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float32_create__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t *arg2 = (size_t *) 0 ;
  float *arg3 = (float *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:HomogenTensor_Float32_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenTensor_Float32_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_size_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenTensor_Float32_create" "', argument " "2"" of type '" "size_t const *""'"); 
  }
  arg2 = reinterpret_cast< size_t * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_float, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "HomogenTensor_Float32_create" "', argument " "3"" of type '" "float *""'"); 
  }
  arg3 = reinterpret_cast< float * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,(size_t const *)arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float32_create__SWIG_4(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t *arg2 = (size_t *) 0 ;
  daal::services::SharedPtr< float > *arg3 = 0 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  daal::services::SharedPtr< float > r4p1 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenTensor_Float32_create",&obj0,&obj1)) SWIG_fail;
  {
    int is_new_object = 0;
    PyArrayObject * array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj0, NPY_FLOAT)
      :obj_to_array_contiguous_allow_conversion(obj0, NPY_FLOAT, &is_new_object));
    if (!array || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    arg1 = (size_t)array_numdims(array);
    arg2 = (size_t*)array_dimensions(array);
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p1 = daal::services::SharedPtr< float >((float*)array_data(array), NumpyDeleter(array));
    arg3 = &r4p1;
    // we need it increment the ref-count if we use the obj0 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj0) Py_INCREF(array);
  }
  res4 = SWIG_ConvertPtr(obj1, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "HomogenTensor_Float32_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,(size_t const *)arg2,(daal::services::SharedPtr< float > const &)*arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float32_create__SWIG_5(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t *arg2 = (size_t *) 0 ;
  daal::services::SharedPtr< float > *arg3 = 0 ;
  daal::services::SharedPtr< float > r4p1 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:HomogenTensor_Float32_create",&obj0)) SWIG_fail;
  {
    int is_new_object = 0;
    PyArrayObject * array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj0, NPY_FLOAT)
      :obj_to_array_contiguous_allow_conversion(obj0, NPY_FLOAT, &is_new_object));
    if (!array || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    arg1 = (size_t)array_numdims(array);
    arg2 = (size_t*)array_dimensions(array);
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p1 = daal::services::SharedPtr< float >((float*)array_data(array), NumpyDeleter(array));
    arg3 = &r4p1;
    // we need it increment the ref-count if we use the obj0 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj0) Py_INCREF(array);
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,(size_t const *)arg2,(daal::services::SharedPtr< float > const &)*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float32_create__SWIG_6(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::Collection< size_t > *arg1 = 0 ;
  float *arg2 = (float *) 0 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  daal::services::Collection< size_t > *col_szt1 = NULL ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:HomogenTensor_Float32_create",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    Py_ssize_t n = PySequence_Length(obj0);
    if( n == 0 ) SWIG_fail;
    col_szt1 = new daal::services::Collection<size_t>(n);
    for( Py_ssize_t i=0; i<n; ++i ) {
      PyObject * o = PySequence_GetItem(obj0, i);
      size_t tmp = PyInt_AsSsize_t(o);
      if(PyErr_Occurred()) {
        PyErr_Format(PyExc_TypeError, "Sequence of integer values required");
        SWIG_fail;
      }
      (*col_szt1)[i] = tmp;
    }
    arg1 = col_szt1;
  }
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_float, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenTensor_Float32_create" "', argument " "2"" of type '" "float *""'"); 
  }
  arg2 = reinterpret_cast< float * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "HomogenTensor_Float32_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< float >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::Collection< size_t > const &)*arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, SWIG_POINTER_OWN);
  }
  {
    if( col_szt1 ) delete col_szt1;
  }
  return resultobj;
fail:
  {
    if( col_szt1 ) delete col_szt1;
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float32_create__SWIG_7(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::Collection< size_t > *arg1 = 0 ;
  float *arg2 = (float *) 0 ;
  daal::services::Collection< size_t > *col_szt1 = NULL ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenTensor_Float32_create",&obj0,&obj1)) SWIG_fail;
  {
    Py_ssize_t n = PySequence_Length(obj0);
    if( n == 0 ) SWIG_fail;
    col_szt1 = new daal::services::Collection<size_t>(n);
    for( Py_ssize_t i=0; i<n; ++i ) {
      PyObject * o = PySequence_GetItem(obj0, i);
      size_t tmp = PyInt_AsSsize_t(o);
      if(PyErr_Occurred()) {
        PyErr_Format(PyExc_TypeError, "Sequence of integer values required");
        SWIG_fail;
      }
      (*col_szt1)[i] = tmp;
    }
    arg1 = col_szt1;
  }
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_float, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenTensor_Float32_create" "', argument " "2"" of type '" "float *""'"); 
  }
  arg2 = reinterpret_cast< float * >(argp2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< float >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::Collection< size_t > const &)*arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, SWIG_POINTER_OWN);
  }
  {
    if( col_szt1 ) delete col_szt1;
  }
  return resultobj;
fail:
  {
    if( col_szt1 ) delete col_szt1;
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float32_create__SWIG_8(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::Collection< size_t > *arg1 = 0 ;
  daal::services::SharedPtr< float > *arg2 = 0 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  daal::services::Collection< size_t > *col_szt1 = NULL ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:HomogenTensor_Float32_create",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    Py_ssize_t n = PySequence_Length(obj0);
    if( n == 0 ) SWIG_fail;
    col_szt1 = new daal::services::Collection<size_t>(n);
    for( Py_ssize_t i=0; i<n; ++i ) {
      PyObject * o = PySequence_GetItem(obj0, i);
      size_t tmp = PyInt_AsSsize_t(o);
      if(PyErr_Occurred()) {
        PyErr_Format(PyExc_TypeError, "Sequence of integer values required");
        SWIG_fail;
      }
      (*col_szt1)[i] = tmp;
    }
    arg1 = col_szt1;
  }
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_float_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenTensor_Float32_create" "', argument " "2"" of type '" "daal::services::SharedPtr< float > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Float32_create" "', argument " "2"" of type '" "daal::services::SharedPtr< float > const &""'"); 
  }
  arg2 = reinterpret_cast< daal::services::SharedPtr< float > * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "HomogenTensor_Float32_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< float >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::Collection< size_t > const &)*arg1,(daal::services::SharedPtr< float > const &)*arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, SWIG_POINTER_OWN);
  }
  {
    if( col_szt1 ) delete col_szt1;
  }
  return resultobj;
fail:
  {
    if( col_szt1 ) delete col_szt1;
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float32_create__SWIG_9(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::Collection< size_t > *arg1 = 0 ;
  daal::services::SharedPtr< float > *arg2 = 0 ;
  daal::services::Collection< size_t > *col_szt1 = NULL ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenTensor_Float32_create",&obj0,&obj1)) SWIG_fail;
  {
    Py_ssize_t n = PySequence_Length(obj0);
    if( n == 0 ) SWIG_fail;
    col_szt1 = new daal::services::Collection<size_t>(n);
    for( Py_ssize_t i=0; i<n; ++i ) {
      PyObject * o = PySequence_GetItem(obj0, i);
      size_t tmp = PyInt_AsSsize_t(o);
      if(PyErr_Occurred()) {
        PyErr_Format(PyExc_TypeError, "Sequence of integer values required");
        SWIG_fail;
      }
      (*col_szt1)[i] = tmp;
    }
    arg1 = col_szt1;
  }
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_float_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenTensor_Float32_create" "', argument " "2"" of type '" "daal::services::SharedPtr< float > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Float32_create" "', argument " "2"" of type '" "daal::services::SharedPtr< float > const &""'"); 
  }
  arg2 = reinterpret_cast< daal::services::SharedPtr< float > * >(argp2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< float >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::Collection< size_t > const &)*arg1,(daal::services::SharedPtr< float > const &)*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, SWIG_POINTER_OWN);
  }
  {
    if( col_szt1 ) delete col_szt1;
  }
  return resultobj;
fail:
  {
    if( col_szt1 ) delete col_szt1;
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float32_create__SWIG_10(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::TensorOffsetLayout *arg1 = 0 ;
  float *arg2 = (float *) 0 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout const > tempshared1 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:HomogenTensor_Float32_create",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t,  0 , &newmem);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float32_create" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (!argp1) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Float32_create" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(tempshared1.get());
    } else {
      arg1 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1)->get());
    }
    if(!arg1) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float32_create" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
  }
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_float, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenTensor_Float32_create" "', argument " "2"" of type '" "float *""'"); 
  }
  arg2 = reinterpret_cast< float * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "HomogenTensor_Float32_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< float >::SWIGTEMPLATEDISAMBIGUATOR create((daal::data_management::interface1::TensorOffsetLayout const &)*arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float32_create__SWIG_11(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::TensorOffsetLayout *arg1 = 0 ;
  float *arg2 = (float *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout const > tempshared1 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenTensor_Float32_create",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t,  0 , &newmem);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float32_create" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (!argp1) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Float32_create" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(tempshared1.get());
    } else {
      arg1 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1)->get());
    }
    if(!arg1) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float32_create" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
  }
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_float, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenTensor_Float32_create" "', argument " "2"" of type '" "float *""'"); 
  }
  arg2 = reinterpret_cast< float * >(argp2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< float >::SWIGTEMPLATEDISAMBIGUATOR create((daal::data_management::interface1::TensorOffsetLayout const &)*arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float32_create__SWIG_12(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::TensorOffsetLayout *arg1 = 0 ;
  daal::services::SharedPtr< float > *arg2 = 0 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout const > tempshared1 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:HomogenTensor_Float32_create",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t,  0 , &newmem);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float32_create" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (!argp1) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Float32_create" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(tempshared1.get());
    } else {
      arg1 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1)->get());
    }
    if(!arg1) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float32_create" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
  }
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_float_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenTensor_Float32_create" "', argument " "2"" of type '" "daal::services::SharedPtr< float > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Float32_create" "', argument " "2"" of type '" "daal::services::SharedPtr< float > const &""'"); 
  }
  arg2 = reinterpret_cast< daal::services::SharedPtr< float > * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "HomogenTensor_Float32_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< float >::SWIGTEMPLATEDISAMBIGUATOR create((daal::data_management::interface1::TensorOffsetLayout const &)*arg1,(daal::services::SharedPtr< float > const &)*arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float32_create__SWIG_13(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::TensorOffsetLayout *arg1 = 0 ;
  daal::services::SharedPtr< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout const > tempshared1 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenTensor_Float32_create",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t,  0 , &newmem);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float32_create" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (!argp1) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Float32_create" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(tempshared1.get());
    } else {
      arg1 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1)->get());
    }
    if(!arg1) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float32_create" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
  }
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_float_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenTensor_Float32_create" "', argument " "2"" of type '" "daal::services::SharedPtr< float > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Float32_create" "', argument " "2"" of type '" "daal::services::SharedPtr< float > const &""'"); 
  }
  arg2 = reinterpret_cast< daal::services::SharedPtr< float > * >(argp2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< float >::SWIGTEMPLATEDISAMBIGUATOR create((daal::data_management::interface1::TensorOffsetLayout const &)*arg1,(daal::services::SharedPtr< float > const &)*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float32_create__SWIG_14(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::Collection< size_t > *arg1 = 0 ;
  daal::data_management::interface1::TensorIface::AllocationFlag arg2 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  daal::services::Collection< size_t > *col_szt1 = NULL ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:HomogenTensor_Float32_create",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    Py_ssize_t n = PySequence_Length(obj0);
    if( n == 0 ) SWIG_fail;
    col_szt1 = new daal::services::Collection<size_t>(n);
    for( Py_ssize_t i=0; i<n; ++i ) {
      PyObject * o = PySequence_GetItem(obj0, i);
      size_t tmp = PyInt_AsSsize_t(o);
      if(PyErr_Occurred()) {
        PyErr_Format(PyExc_TypeError, "Sequence of integer values required");
        SWIG_fail;
      }
      (*col_szt1)[i] = tmp;
    }
    arg1 = col_szt1;
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenTensor_Float32_create" "', argument " "2"" of type '" "daal::data_management::interface1::TensorIface::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::TensorIface::AllocationFlag >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "HomogenTensor_Float32_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< float >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::Collection< size_t > const &)*arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, SWIG_POINTER_OWN);
  }
  {
    if( col_szt1 ) delete col_szt1;
  }
  return resultobj;
fail:
  {
    if( col_szt1 ) delete col_szt1;
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float32_create__SWIG_15(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::Collection< size_t > *arg1 = 0 ;
  daal::data_management::interface1::TensorIface::AllocationFlag arg2 ;
  daal::services::Collection< size_t > *col_szt1 = NULL ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenTensor_Float32_create",&obj0,&obj1)) SWIG_fail;
  {
    Py_ssize_t n = PySequence_Length(obj0);
    if( n == 0 ) SWIG_fail;
    col_szt1 = new daal::services::Collection<size_t>(n);
    for( Py_ssize_t i=0; i<n; ++i ) {
      PyObject * o = PySequence_GetItem(obj0, i);
      size_t tmp = PyInt_AsSsize_t(o);
      if(PyErr_Occurred()) {
        PyErr_Format(PyExc_TypeError, "Sequence of integer values required");
        SWIG_fail;
      }
      (*col_szt1)[i] = tmp;
    }
    arg1 = col_szt1;
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenTensor_Float32_create" "', argument " "2"" of type '" "daal::data_management::interface1::TensorIface::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::TensorIface::AllocationFlag >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< float >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::Collection< size_t > const &)*arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, SWIG_POINTER_OWN);
  }
  {
    if( col_szt1 ) delete col_szt1;
  }
  return resultobj;
fail:
  {
    if( col_szt1 ) delete col_szt1;
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float32_create__SWIG_16(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::Collection< size_t > *arg1 = 0 ;
  daal::data_management::interface1::TensorIface::AllocationFlag arg2 ;
  float arg3 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  daal::services::Collection< size_t > *col_szt1 = NULL ;
  int val2 ;
  int ecode2 = 0 ;
  float val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:HomogenTensor_Float32_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  {
    Py_ssize_t n = PySequence_Length(obj0);
    if( n == 0 ) SWIG_fail;
    col_szt1 = new daal::services::Collection<size_t>(n);
    for( Py_ssize_t i=0; i<n; ++i ) {
      PyObject * o = PySequence_GetItem(obj0, i);
      size_t tmp = PyInt_AsSsize_t(o);
      if(PyErr_Occurred()) {
        PyErr_Format(PyExc_TypeError, "Sequence of integer values required");
        SWIG_fail;
      }
      (*col_szt1)[i] = tmp;
    }
    arg1 = col_szt1;
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenTensor_Float32_create" "', argument " "2"" of type '" "daal::data_management::interface1::TensorIface::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::TensorIface::AllocationFlag >(val2);
  ecode3 = SWIG_AsVal_float(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenTensor_Float32_create" "', argument " "3"" of type '" "float""'");
  } 
  arg3 = static_cast< float >(val3);
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "HomogenTensor_Float32_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< float >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::Collection< size_t > const &)*arg1,arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, SWIG_POINTER_OWN);
  }
  {
    if( col_szt1 ) delete col_szt1;
  }
  return resultobj;
fail:
  {
    if( col_szt1 ) delete col_szt1;
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float32_create__SWIG_17(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::Collection< size_t > *arg1 = 0 ;
  daal::data_management::interface1::TensorIface::AllocationFlag arg2 ;
  float arg3 ;
  daal::services::Collection< size_t > *col_szt1 = NULL ;
  int val2 ;
  int ecode2 = 0 ;
  float val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:HomogenTensor_Float32_create",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    Py_ssize_t n = PySequence_Length(obj0);
    if( n == 0 ) SWIG_fail;
    col_szt1 = new daal::services::Collection<size_t>(n);
    for( Py_ssize_t i=0; i<n; ++i ) {
      PyObject * o = PySequence_GetItem(obj0, i);
      size_t tmp = PyInt_AsSsize_t(o);
      if(PyErr_Occurred()) {
        PyErr_Format(PyExc_TypeError, "Sequence of integer values required");
        SWIG_fail;
      }
      (*col_szt1)[i] = tmp;
    }
    arg1 = col_szt1;
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenTensor_Float32_create" "', argument " "2"" of type '" "daal::data_management::interface1::TensorIface::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::TensorIface::AllocationFlag >(val2);
  ecode3 = SWIG_AsVal_float(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenTensor_Float32_create" "', argument " "3"" of type '" "float""'");
  } 
  arg3 = static_cast< float >(val3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< float >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::Collection< size_t > const &)*arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, SWIG_POINTER_OWN);
  }
  {
    if( col_szt1 ) delete col_szt1;
  }
  return resultobj;
fail:
  {
    if( col_szt1 ) delete col_szt1;
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float32_create(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[5];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 4) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_HomogenTensor_Float32_create__SWIG_1(self, args);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_HomogenTensor_Float32_create__SWIG_0(self, args);
    }
  }
  if (argc == 1) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_FLOAT))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      if (argc <= 1) {
        return _wrap_HomogenTensor_Float32_create__SWIG_5(self, args);
      }
      if (argc <= 2) {
        return _wrap_HomogenTensor_Float32_create__SWIG_5(self, args);
      }
      return _wrap_HomogenTensor_Float32_create__SWIG_5(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_float, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenTensor_Float32_create__SWIG_11(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_float_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenTensor_Float32_create__SWIG_13(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      _v = PySequence_Check(argv[0]);
    }
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_float_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenTensor_Float32_create__SWIG_9(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_FLOAT))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenTensor_Float32_create__SWIG_4(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      _v = PySequence_Check(argv[0]);
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_float, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenTensor_Float32_create__SWIG_7(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      _v = PySequence_Check(argv[0]);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_HomogenTensor_Float32_create__SWIG_15(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_float, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_HomogenTensor_Float32_create__SWIG_10(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_float_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_HomogenTensor_Float32_create__SWIG_12(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_size_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_float, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_HomogenTensor_Float32_create__SWIG_3(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      _v = PySequence_Check(argv[0]);
    }
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_float_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_HomogenTensor_Float32_create__SWIG_8(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      _v = PySequence_Check(argv[0]);
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_float, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_HomogenTensor_Float32_create__SWIG_6(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      _v = PySequence_Check(argv[0]);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_HomogenTensor_Float32_create__SWIG_14(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      _v = PySequence_Check(argv[0]);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_float(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_HomogenTensor_Float32_create__SWIG_17(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_size_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_float, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_HomogenTensor_Float32_create__SWIG_2(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      _v = PySequence_Check(argv[0]);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_float(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_HomogenTensor_Float32_create__SWIG_16(self, args);
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'HomogenTensor_Float32_create'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::HomogenTensor< float >::create(daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenTensor< float >::create()\n"
    "    daal::data_management::interface1::HomogenTensor< float >::create(size_t,size_t const *,float *,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenTensor< float >::create(size_t,size_t const *,float *)\n"
    "    daal::data_management::interface1::HomogenTensor< float >::create(size_t,size_t const *,daal::services::SharedPtr< float > const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenTensor< float >::create(size_t,size_t const *,daal::services::SharedPtr< float > const &)\n"
    "    daal::data_management::interface1::HomogenTensor< float >::create(daal::services::Collection< size_t > const &,float *,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenTensor< float >::create(daal::services::Collection< size_t > const &,float *)\n"
    "    daal::data_management::interface1::HomogenTensor< float >::create(daal::services::Collection< size_t > const &,daal::services::SharedPtr< float > const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenTensor< float >::create(daal::services::Collection< size_t > const &,daal::services::SharedPtr< float > const &)\n"
    "    daal::data_management::interface1::HomogenTensor< float >::create(daal::data_management::interface1::TensorOffsetLayout const &,float *,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenTensor< float >::create(daal::data_management::interface1::TensorOffsetLayout const &,float *)\n"
    "    daal::data_management::interface1::HomogenTensor< float >::create(daal::data_management::interface1::TensorOffsetLayout const &,daal::services::SharedPtr< float > const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenTensor< float >::create(daal::data_management::interface1::TensorOffsetLayout const &,daal::services::SharedPtr< float > const &)\n"
    "    daal::data_management::interface1::HomogenTensor< float >::create(daal::services::Collection< size_t > const &,daal::data_management::interface1::TensorIface::AllocationFlag,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenTensor< float >::create(daal::services::Collection< size_t > const &,daal::data_management::interface1::TensorIface::AllocationFlag)\n"
    "    daal::data_management::interface1::HomogenTensor< float >::create(daal::services::Collection< size_t > const &,daal::data_management::interface1::TensorIface::AllocationFlag,float const,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenTensor< float >::create(daal::services::Collection< size_t > const &,daal::data_management::interface1::TensorIface::AllocationFlag,float const)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_HomogenTensor_Float32(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< float > *arg1 = (daal::data_management::interface1::HomogenTensor< float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_HomogenTensor_Float32",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_HomogenTensor_Float32" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_HomogenTensor_Float32" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< float > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float32_getTensorLayout(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< float > *arg1 = (daal::data_management::interface1::HomogenTensor< float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::TensorOffsetLayout *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:HomogenTensor_Float32_getTensorLayout",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float32_getTensorLayout" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float32_getTensorLayout" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< float > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::TensorOffsetLayout *) &(arg1)->getTensorLayout();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::TensorOffsetLayout > *smartresult = new daal::services::SharedPtr<  daal::data_management::interface1::TensorOffsetLayout >(result SWIG_NO_NULL_DELETER_0);
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float32_createDefaultSubtensorLayout(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< float > *arg1 = (daal::data_management::interface1::HomogenTensor< float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  SwigValueWrapper< daal::data_management::interface1::TensorOffsetLayout > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:HomogenTensor_Float32_createDefaultSubtensorLayout",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float32_createDefaultSubtensorLayout" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< float > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float32_createDefaultSubtensorLayout" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< float > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::HomogenTensor< float > const *)arg1)->createDefaultSubtensorLayout();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::TensorOffsetLayout > *smartresult = new daal::services::SharedPtr<  daal::data_management::interface1::TensorOffsetLayout >(new daal::data_management::interface1::TensorOffsetLayout((daal::data_management::interface1::TensorOffsetLayout &)result));
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float32_createRawSubtensorLayout(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< float > *arg1 = (daal::data_management::interface1::HomogenTensor< float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  SwigValueWrapper< daal::data_management::interface1::TensorOffsetLayout > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:HomogenTensor_Float32_createRawSubtensorLayout",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float32_createRawSubtensorLayout" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< float > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float32_createRawSubtensorLayout" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< float > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::HomogenTensor< float > const *)arg1)->createRawSubtensorLayout();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::TensorOffsetLayout > *smartresult = new daal::services::SharedPtr<  daal::data_management::interface1::TensorOffsetLayout >(new daal::data_management::interface1::TensorOffsetLayout((daal::data_management::interface1::TensorOffsetLayout &)result));
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float32_setDimensions__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< float > *arg1 = (daal::data_management::interface1::HomogenTensor< float > *) 0 ;
  size_t arg2 ;
  size_t *arg3 = (size_t *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:HomogenTensor_Float32_setDimensions",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float32_setDimensions" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float32_setDimensions" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< float > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenTensor_Float32_setDimensions" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_size_t, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "HomogenTensor_Float32_setDimensions" "', argument " "3"" of type '" "size_t const *""'"); 
  }
  arg3 = reinterpret_cast< size_t * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->setDimensions(arg2,(size_t const *)arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float32_setDimensions__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< float > *arg1 = (daal::data_management::interface1::HomogenTensor< float > *) 0 ;
  daal::services::Collection< size_t > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > *smartarg1 = 0 ;
  daal::services::Collection< size_t > *col_szt2 = NULL ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenTensor_Float32_setDimensions",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float32_setDimensions" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float32_setDimensions" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< float > *""'"); 
  }
  {
    Py_ssize_t n = PySequence_Length(obj1);
    if( n == 0 ) SWIG_fail;
    col_szt2 = new daal::services::Collection<size_t>(n);
    for( Py_ssize_t i=0; i<n; ++i ) {
      PyObject * o = PySequence_GetItem(obj1, i);
      size_t tmp = PyInt_AsSsize_t(o);
      if(PyErr_Occurred()) {
        PyErr_Format(PyExc_TypeError, "Sequence of integer values required");
        SWIG_fail;
      }
      (*col_szt2)[i] = tmp;
    }
    arg2 = col_szt2;
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->setDimensions((daal::services::Collection< size_t > const &)*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  {
    if( col_szt2 ) delete col_szt2;
  }
  return resultobj;
fail:
  {
    if( col_szt2 ) delete col_szt2;
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float32_setDimensions(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[4];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 3) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySequence_Check(argv[1]);
      }
      if (_v) {
        return _wrap_HomogenTensor_Float32_setDimensions__SWIG_1(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_size_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_HomogenTensor_Float32_setDimensions__SWIG_0(self, args);
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'HomogenTensor_Float32_setDimensions'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::HomogenTensor< float >::setDimensions(size_t,size_t const *)\n"
    "    daal::data_management::interface1::HomogenTensor< float >::setDimensions(daal::services::Collection< size_t > const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float32_assign(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< float > *arg1 = (daal::data_management::interface1::HomogenTensor< float > *) 0 ;
  float arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > *smartarg1 = 0 ;
  float val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenTensor_Float32_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float32_assign" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float32_assign" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< float > *""'"); 
  }
  ecode2 = SWIG_AsVal_float(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenTensor_Float32_assign" "', argument " "2"" of type '" "float""'");
  } 
  arg2 = static_cast< float >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float32_getSubtensorEx__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< float > *arg1 = (daal::data_management::interface1::HomogenTensor< float > *) 0 ;
  size_t arg2 ;
  size_t *arg3 = (size_t *) 0 ;
  size_t arg4 ;
  size_t arg5 ;
  daal::data_management::ReadWriteMode arg6 ;
  daal::data_management::interface1::SubtensorDescriptor< double > *arg7 = 0 ;
  daal::data_management::interface1::TensorOffsetLayout *arg8 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int is_new_object2 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  size_t val5 ;
  int ecode5 = 0 ;
  int val6 ;
  int ecode6 = 0 ;
  void *argp7 = 0 ;
  int res7 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< double > > tempshared7 ;
  void *argp8 = 0 ;
  int res8 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout const > tempshared8 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  PyObject * obj6 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOOO:HomogenTensor_Float32_getSubtensorEx",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5,&obj6)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float32_getSubtensorEx" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float32_getSubtensorEx" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< float > *""'"); 
  }
  {
    array2 = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UINT64)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UINT64, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (size_t) array_size(array2,0);
    arg3 = (size_t*) array_data(array2);
  }
  ecode4 = SWIG_AsVal_size_t(obj2, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenTensor_Float32_getSubtensorEx" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_size_t(obj3, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "HomogenTensor_Float32_getSubtensorEx" "', argument " "5"" of type '" "size_t""'");
  } 
  arg5 = static_cast< size_t >(val5);
  ecode6 = SWIG_AsVal_int(obj4, &val6);
  if (!SWIG_IsOK(ecode6)) {
    SWIG_exception_fail(SWIG_ArgError(ecode6), "in method '" "HomogenTensor_Float32_getSubtensorEx" "', argument " "6"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg6 = static_cast< daal::data_management::ReadWriteMode >(val6);
  {
    int newmem = 0;
    res7 = SWIG_ConvertPtrAndOwn(obj5, &argp7, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res7)) {
      SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "HomogenTensor_Float32_getSubtensorEx" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > &""'"); 
    }
    if (!argp7) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Float32_getSubtensorEx" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared7 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp7);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp7);
      arg7 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >(tempshared7.get());
    } else {
      arg7 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp7)->get());
    }
    if(!arg7) SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "HomogenTensor_Float32_getSubtensorEx" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > &""'"); 
  }
  {
    int newmem = 0;
    res8 = SWIG_ConvertPtrAndOwn(obj6, &argp8, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t,  0 , &newmem);
    if (!SWIG_IsOK(res8)) {
      SWIG_exception_fail(SWIG_ArgError(res8), "in method '" "HomogenTensor_Float32_getSubtensorEx" "', argument " "8"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (!argp8) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Float32_getSubtensorEx" "', argument " "8"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared8 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp8);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp8);
      arg8 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(tempshared8.get());
    } else {
      arg8 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp8)->get());
    }
    if(!arg8) SWIG_exception_fail(SWIG_ArgError(res8), "in method '" "HomogenTensor_Float32_getSubtensorEx" "', argument " "8"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getSubtensorEx(arg2,(size_t const *)arg3,arg4,arg5,arg6,*arg7,(daal::data_management::interface1::TensorOffsetLayout const &)*arg8);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  {
    if(ALLOW_CONVERSION != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(ALLOW_CONVERSION != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float32_getSubtensorEx__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< float > *arg1 = (daal::data_management::interface1::HomogenTensor< float > *) 0 ;
  size_t arg2 ;
  size_t *arg3 = (size_t *) 0 ;
  size_t arg4 ;
  size_t arg5 ;
  daal::data_management::ReadWriteMode arg6 ;
  daal::data_management::interface1::SubtensorDescriptor< float > *arg7 = 0 ;
  daal::data_management::interface1::TensorOffsetLayout *arg8 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int is_new_object2 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  size_t val5 ;
  int ecode5 = 0 ;
  int val6 ;
  int ecode6 = 0 ;
  void *argp7 = 0 ;
  int res7 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< float > > tempshared7 ;
  void *argp8 = 0 ;
  int res8 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout const > tempshared8 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  PyObject * obj6 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOOO:HomogenTensor_Float32_getSubtensorEx",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5,&obj6)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float32_getSubtensorEx" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float32_getSubtensorEx" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< float > *""'"); 
  }
  {
    array2 = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UINT64)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UINT64, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (size_t) array_size(array2,0);
    arg3 = (size_t*) array_data(array2);
  }
  ecode4 = SWIG_AsVal_size_t(obj2, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenTensor_Float32_getSubtensorEx" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_size_t(obj3, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "HomogenTensor_Float32_getSubtensorEx" "', argument " "5"" of type '" "size_t""'");
  } 
  arg5 = static_cast< size_t >(val5);
  ecode6 = SWIG_AsVal_int(obj4, &val6);
  if (!SWIG_IsOK(ecode6)) {
    SWIG_exception_fail(SWIG_ArgError(ecode6), "in method '" "HomogenTensor_Float32_getSubtensorEx" "', argument " "6"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg6 = static_cast< daal::data_management::ReadWriteMode >(val6);
  {
    int newmem = 0;
    res7 = SWIG_ConvertPtrAndOwn(obj5, &argp7, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res7)) {
      SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "HomogenTensor_Float32_getSubtensorEx" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > &""'"); 
    }
    if (!argp7) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Float32_getSubtensorEx" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared7 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp7);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp7);
      arg7 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >(tempshared7.get());
    } else {
      arg7 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp7)->get());
    }
    if(!arg7) SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "HomogenTensor_Float32_getSubtensorEx" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > &""'"); 
  }
  {
    int newmem = 0;
    res8 = SWIG_ConvertPtrAndOwn(obj6, &argp8, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t,  0 , &newmem);
    if (!SWIG_IsOK(res8)) {
      SWIG_exception_fail(SWIG_ArgError(res8), "in method '" "HomogenTensor_Float32_getSubtensorEx" "', argument " "8"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (!argp8) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Float32_getSubtensorEx" "', argument " "8"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared8 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp8);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp8);
      arg8 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(tempshared8.get());
    } else {
      arg8 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp8)->get());
    }
    if(!arg8) SWIG_exception_fail(SWIG_ArgError(res8), "in method '" "HomogenTensor_Float32_getSubtensorEx" "', argument " "8"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getSubtensorEx(arg2,(size_t const *)arg3,arg4,arg5,arg6,*arg7,(daal::data_management::interface1::TensorOffsetLayout const &)*arg8);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  {
    if(ALLOW_CONVERSION != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(ALLOW_CONVERSION != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float32_getSubtensorEx__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< float > *arg1 = (daal::data_management::interface1::HomogenTensor< float > *) 0 ;
  size_t arg2 ;
  size_t *arg3 = (size_t *) 0 ;
  size_t arg4 ;
  size_t arg5 ;
  daal::data_management::ReadWriteMode arg6 ;
  daal::data_management::interface1::SubtensorDescriptor< int > *arg7 = 0 ;
  daal::data_management::interface1::TensorOffsetLayout *arg8 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int is_new_object2 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  size_t val5 ;
  int ecode5 = 0 ;
  int val6 ;
  int ecode6 = 0 ;
  void *argp7 = 0 ;
  int res7 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< int > > tempshared7 ;
  void *argp8 = 0 ;
  int res8 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout const > tempshared8 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  PyObject * obj6 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOOO:HomogenTensor_Float32_getSubtensorEx",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5,&obj6)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float32_getSubtensorEx" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float32_getSubtensorEx" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< float > *""'"); 
  }
  {
    array2 = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UINT64)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UINT64, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (size_t) array_size(array2,0);
    arg3 = (size_t*) array_data(array2);
  }
  ecode4 = SWIG_AsVal_size_t(obj2, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenTensor_Float32_getSubtensorEx" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_size_t(obj3, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "HomogenTensor_Float32_getSubtensorEx" "', argument " "5"" of type '" "size_t""'");
  } 
  arg5 = static_cast< size_t >(val5);
  ecode6 = SWIG_AsVal_int(obj4, &val6);
  if (!SWIG_IsOK(ecode6)) {
    SWIG_exception_fail(SWIG_ArgError(ecode6), "in method '" "HomogenTensor_Float32_getSubtensorEx" "', argument " "6"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg6 = static_cast< daal::data_management::ReadWriteMode >(val6);
  {
    int newmem = 0;
    res7 = SWIG_ConvertPtrAndOwn(obj5, &argp7, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res7)) {
      SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "HomogenTensor_Float32_getSubtensorEx" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > &""'"); 
    }
    if (!argp7) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Float32_getSubtensorEx" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared7 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp7);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp7);
      arg7 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >(tempshared7.get());
    } else {
      arg7 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp7)->get());
    }
    if(!arg7) SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "HomogenTensor_Float32_getSubtensorEx" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > &""'"); 
  }
  {
    int newmem = 0;
    res8 = SWIG_ConvertPtrAndOwn(obj6, &argp8, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t,  0 , &newmem);
    if (!SWIG_IsOK(res8)) {
      SWIG_exception_fail(SWIG_ArgError(res8), "in method '" "HomogenTensor_Float32_getSubtensorEx" "', argument " "8"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (!argp8) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Float32_getSubtensorEx" "', argument " "8"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared8 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp8);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp8);
      arg8 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(tempshared8.get());
    } else {
      arg8 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp8)->get());
    }
    if(!arg8) SWIG_exception_fail(SWIG_ArgError(res8), "in method '" "HomogenTensor_Float32_getSubtensorEx" "', argument " "8"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getSubtensorEx(arg2,(size_t const *)arg3,arg4,arg5,arg6,*arg7,(daal::data_management::interface1::TensorOffsetLayout const &)*arg8);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  {
    if(ALLOW_CONVERSION != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(ALLOW_CONVERSION != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float32_getSubtensorEx(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[8];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 7) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 7) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = (ALLOW_CONVERSION == FORCE_INPLACE
          ? (is_array(argv[1]) && PyArray_EquivTypenums(array_type(argv[1]), NPY_UINT64))
          :(is_array(argv[1]) || PySequence_Check(argv[1])));
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                int res = SWIG_ConvertPtr(argv[6], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, 0);
                _v = SWIG_CheckState(res);
                if (_v) {
                  return _wrap_HomogenTensor_Float32_getSubtensorEx__SWIG_0(self, args);
                }
              }
            }
          }
        }
      }
    }
  }
  if (argc == 7) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = (ALLOW_CONVERSION == FORCE_INPLACE
          ? (is_array(argv[1]) && PyArray_EquivTypenums(array_type(argv[1]), NPY_UINT64))
          :(is_array(argv[1]) || PySequence_Check(argv[1])));
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                int res = SWIG_ConvertPtr(argv[6], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, 0);
                _v = SWIG_CheckState(res);
                if (_v) {
                  return _wrap_HomogenTensor_Float32_getSubtensorEx__SWIG_1(self, args);
                }
              }
            }
          }
        }
      }
    }
  }
  if (argc == 7) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = (ALLOW_CONVERSION == FORCE_INPLACE
          ? (is_array(argv[1]) && PyArray_EquivTypenums(array_type(argv[1]), NPY_UINT64))
          :(is_array(argv[1]) || PySequence_Check(argv[1])));
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                int res = SWIG_ConvertPtr(argv[6], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, 0);
                _v = SWIG_CheckState(res);
                if (_v) {
                  return _wrap_HomogenTensor_Float32_getSubtensorEx__SWIG_2(self, args);
                }
              }
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'HomogenTensor_Float32_getSubtensorEx'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::HomogenTensor< float >::getSubtensorEx(size_t,size_t const *,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::SubtensorDescriptor< double > &,daal::data_management::interface1::TensorOffsetLayout const &)\n"
    "    daal::data_management::interface1::HomogenTensor< float >::getSubtensorEx(size_t,size_t const *,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::SubtensorDescriptor< float > &,daal::data_management::interface1::TensorOffsetLayout const &)\n"
    "    daal::data_management::interface1::HomogenTensor< float >::getSubtensorEx(size_t,size_t const *,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::SubtensorDescriptor< int > &,daal::data_management::interface1::TensorOffsetLayout const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float32_getSubtensor__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< float > *arg1 = (daal::data_management::interface1::HomogenTensor< float > *) 0 ;
  size_t arg2 ;
  size_t *arg3 = (size_t *) 0 ;
  size_t arg4 ;
  size_t arg5 ;
  daal::data_management::ReadWriteMode arg6 ;
  daal::data_management::interface1::SubtensorDescriptor< double > *arg7 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int is_new_object2 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  size_t val5 ;
  int ecode5 = 0 ;
  int val6 ;
  int ecode6 = 0 ;
  void *argp7 = 0 ;
  int res7 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< double > > tempshared7 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:HomogenTensor_Float32_getSubtensor",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float32_getSubtensor" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float32_getSubtensor" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< float > *""'"); 
  }
  {
    array2 = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UINT64)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UINT64, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (size_t) array_size(array2,0);
    arg3 = (size_t*) array_data(array2);
  }
  ecode4 = SWIG_AsVal_size_t(obj2, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenTensor_Float32_getSubtensor" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_size_t(obj3, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "HomogenTensor_Float32_getSubtensor" "', argument " "5"" of type '" "size_t""'");
  } 
  arg5 = static_cast< size_t >(val5);
  ecode6 = SWIG_AsVal_int(obj4, &val6);
  if (!SWIG_IsOK(ecode6)) {
    SWIG_exception_fail(SWIG_ArgError(ecode6), "in method '" "HomogenTensor_Float32_getSubtensor" "', argument " "6"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg6 = static_cast< daal::data_management::ReadWriteMode >(val6);
  {
    int newmem = 0;
    res7 = SWIG_ConvertPtrAndOwn(obj5, &argp7, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res7)) {
      SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "HomogenTensor_Float32_getSubtensor" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > &""'"); 
    }
    if (!argp7) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Float32_getSubtensor" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared7 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp7);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp7);
      arg7 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >(tempshared7.get());
    } else {
      arg7 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp7)->get());
    }
    if(!arg7) SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "HomogenTensor_Float32_getSubtensor" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getSubtensor(arg2,(size_t const *)arg3,arg4,arg5,arg6,*arg7);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  {
    if(ALLOW_CONVERSION != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(ALLOW_CONVERSION != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float32_getSubtensor__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< float > *arg1 = (daal::data_management::interface1::HomogenTensor< float > *) 0 ;
  size_t arg2 ;
  size_t *arg3 = (size_t *) 0 ;
  size_t arg4 ;
  size_t arg5 ;
  daal::data_management::ReadWriteMode arg6 ;
  daal::data_management::interface1::SubtensorDescriptor< float > *arg7 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int is_new_object2 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  size_t val5 ;
  int ecode5 = 0 ;
  int val6 ;
  int ecode6 = 0 ;
  void *argp7 = 0 ;
  int res7 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< float > > tempshared7 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:HomogenTensor_Float32_getSubtensor",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float32_getSubtensor" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float32_getSubtensor" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< float > *""'"); 
  }
  {
    array2 = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UINT64)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UINT64, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (size_t) array_size(array2,0);
    arg3 = (size_t*) array_data(array2);
  }
  ecode4 = SWIG_AsVal_size_t(obj2, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenTensor_Float32_getSubtensor" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_size_t(obj3, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "HomogenTensor_Float32_getSubtensor" "', argument " "5"" of type '" "size_t""'");
  } 
  arg5 = static_cast< size_t >(val5);
  ecode6 = SWIG_AsVal_int(obj4, &val6);
  if (!SWIG_IsOK(ecode6)) {
    SWIG_exception_fail(SWIG_ArgError(ecode6), "in method '" "HomogenTensor_Float32_getSubtensor" "', argument " "6"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg6 = static_cast< daal::data_management::ReadWriteMode >(val6);
  {
    int newmem = 0;
    res7 = SWIG_ConvertPtrAndOwn(obj5, &argp7, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res7)) {
      SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "HomogenTensor_Float32_getSubtensor" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > &""'"); 
    }
    if (!argp7) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Float32_getSubtensor" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared7 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp7);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp7);
      arg7 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >(tempshared7.get());
    } else {
      arg7 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp7)->get());
    }
    if(!arg7) SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "HomogenTensor_Float32_getSubtensor" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getSubtensor(arg2,(size_t const *)arg3,arg4,arg5,arg6,*arg7);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  {
    if(ALLOW_CONVERSION != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(ALLOW_CONVERSION != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float32_getSubtensor__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< float > *arg1 = (daal::data_management::interface1::HomogenTensor< float > *) 0 ;
  size_t arg2 ;
  size_t *arg3 = (size_t *) 0 ;
  size_t arg4 ;
  size_t arg5 ;
  daal::data_management::ReadWriteMode arg6 ;
  daal::data_management::interface1::SubtensorDescriptor< int > *arg7 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int is_new_object2 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  size_t val5 ;
  int ecode5 = 0 ;
  int val6 ;
  int ecode6 = 0 ;
  void *argp7 = 0 ;
  int res7 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< int > > tempshared7 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:HomogenTensor_Float32_getSubtensor",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float32_getSubtensor" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float32_getSubtensor" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< float > *""'"); 
  }
  {
    array2 = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UINT64)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UINT64, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (size_t) array_size(array2,0);
    arg3 = (size_t*) array_data(array2);
  }
  ecode4 = SWIG_AsVal_size_t(obj2, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenTensor_Float32_getSubtensor" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_size_t(obj3, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "HomogenTensor_Float32_getSubtensor" "', argument " "5"" of type '" "size_t""'");
  } 
  arg5 = static_cast< size_t >(val5);
  ecode6 = SWIG_AsVal_int(obj4, &val6);
  if (!SWIG_IsOK(ecode6)) {
    SWIG_exception_fail(SWIG_ArgError(ecode6), "in method '" "HomogenTensor_Float32_getSubtensor" "', argument " "6"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg6 = static_cast< daal::data_management::ReadWriteMode >(val6);
  {
    int newmem = 0;
    res7 = SWIG_ConvertPtrAndOwn(obj5, &argp7, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res7)) {
      SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "HomogenTensor_Float32_getSubtensor" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > &""'"); 
    }
    if (!argp7) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Float32_getSubtensor" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared7 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp7);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp7);
      arg7 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >(tempshared7.get());
    } else {
      arg7 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp7)->get());
    }
    if(!arg7) SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "HomogenTensor_Float32_getSubtensor" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getSubtensor(arg2,(size_t const *)arg3,arg4,arg5,arg6,*arg7);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  {
    if(ALLOW_CONVERSION != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(ALLOW_CONVERSION != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float32_getSubtensor(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[7];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 6) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = (ALLOW_CONVERSION == FORCE_INPLACE
          ? (is_array(argv[1]) && PyArray_EquivTypenums(array_type(argv[1]), NPY_UINT64))
          :(is_array(argv[1]) || PySequence_Check(argv[1])));
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_HomogenTensor_Float32_getSubtensor__SWIG_0(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = (ALLOW_CONVERSION == FORCE_INPLACE
          ? (is_array(argv[1]) && PyArray_EquivTypenums(array_type(argv[1]), NPY_UINT64))
          :(is_array(argv[1]) || PySequence_Check(argv[1])));
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_HomogenTensor_Float32_getSubtensor__SWIG_1(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = (ALLOW_CONVERSION == FORCE_INPLACE
          ? (is_array(argv[1]) && PyArray_EquivTypenums(array_type(argv[1]), NPY_UINT64))
          :(is_array(argv[1]) || PySequence_Check(argv[1])));
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_HomogenTensor_Float32_getSubtensor__SWIG_2(self, args);
              }
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'HomogenTensor_Float32_getSubtensor'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::HomogenTensor< float >::getSubtensor(size_t,size_t const *,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::SubtensorDescriptor< double > &)\n"
    "    daal::data_management::interface1::HomogenTensor< float >::getSubtensor(size_t,size_t const *,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::SubtensorDescriptor< float > &)\n"
    "    daal::data_management::interface1::HomogenTensor< float >::getSubtensor(size_t,size_t const *,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::SubtensorDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float32_releaseSubtensor__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< float > *arg1 = (daal::data_management::interface1::HomogenTensor< float > *) 0 ;
  daal::data_management::interface1::SubtensorDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenTensor_Float32_releaseSubtensor",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float32_releaseSubtensor" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float32_releaseSubtensor" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< float > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenTensor_Float32_releaseSubtensor" "', argument " "2"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Float32_releaseSubtensor" "', argument " "2"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenTensor_Float32_releaseSubtensor" "', argument " "2"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseSubtensor(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float32_releaseSubtensor__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< float > *arg1 = (daal::data_management::interface1::HomogenTensor< float > *) 0 ;
  daal::data_management::interface1::SubtensorDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenTensor_Float32_releaseSubtensor",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float32_releaseSubtensor" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float32_releaseSubtensor" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< float > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenTensor_Float32_releaseSubtensor" "', argument " "2"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Float32_releaseSubtensor" "', argument " "2"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenTensor_Float32_releaseSubtensor" "', argument " "2"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseSubtensor(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float32_releaseSubtensor__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< float > *arg1 = (daal::data_management::interface1::HomogenTensor< float > *) 0 ;
  daal::data_management::interface1::SubtensorDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenTensor_Float32_releaseSubtensor",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float32_releaseSubtensor" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float32_releaseSubtensor" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< float > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenTensor_Float32_releaseSubtensor" "', argument " "2"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Float32_releaseSubtensor" "', argument " "2"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenTensor_Float32_releaseSubtensor" "', argument " "2"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseSubtensor(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float32_releaseSubtensor(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenTensor_Float32_releaseSubtensor__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenTensor_Float32_releaseSubtensor__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenTensor_Float32_releaseSubtensor__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'HomogenTensor_Float32_releaseSubtensor'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::HomogenTensor< float >::releaseSubtensor(daal::data_management::interface1::SubtensorDescriptor< double > &)\n"
    "    daal::data_management::interface1::HomogenTensor< float >::releaseSubtensor(daal::data_management::interface1::SubtensorDescriptor< float > &)\n"
    "    daal::data_management::interface1::HomogenTensor< float >::releaseSubtensor(daal::data_management::interface1::SubtensorDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float32_getSampleTensor(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< float > *arg1 = (daal::data_management::interface1::HomogenTensor< float > *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Tensor > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenTensor_Float32_getSampleTensor",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float32_getSampleTensor" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float32_getSampleTensor" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< float > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenTensor_Float32_getSampleTensor" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getSampleTensor(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Tensor > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Tensor >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Float32_getArray(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< float > *arg1 = (daal::data_management::interface1::HomogenTensor< float > *) 0 ;
  daal::services::Collection< size_t > **arg2 = (daal::services::Collection< size_t > **) 0 ;
  daal::services::SharedPtr< float > *arg3 = (daal::services::SharedPtr< float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > *smartarg1 = 0 ;
  daal::services::Collection< size_t > *dims_tmp2 ;
  daal::services::SharedPtr< float > data_tmp2 ;
  PyObject * obj0 = 0 ;
  
  {
    arg2 = &dims_tmp2;
    arg3 = &data_tmp2;
  }
  if (!PyArg_ParseTuple(args,(char *)"O:HomogenTensor_Float32_getArray",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float32_getArray" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Float32_getArray" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< float > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        daal_data_management_interface1_HomogenTensor_Sl_float_Sg__getArray(arg1,(daal::services::Collection< size_t > const **)arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    npy_intp * dims = NULL;
    dims = new npy_intp[(*arg2)->size()];
    for( size_t i=0; i<(*arg2)->size(); ++i ) {
      dims[i] = (npy_intp)(*arg2)->get(i);
    }
    PyObject* obj = PyArray_SimpleNewFromData((*arg2)->size(), dims, NPY_FLOAT, (void*)(arg3->get()));
    delete [] dims;
    if (!obj) SWIG_fail;
    set_sp_base((PyArrayObject*)obj, *arg3);
    resultobj = SWIG_Python_AppendOutput(resultobj, obj);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *HomogenTensor_Float32_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_HomogenTensor_Intc_serializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)":HomogenTensor_Intc_serializationTag")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)daal::data_management::interface1::HomogenTensor< int >::SWIGTEMPLATEDISAMBIGUATOR serializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Intc_getSerializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< int > *arg1 = (daal::data_management::interface1::HomogenTensor< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:HomogenTensor_Intc_getSerializationTag",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Intc_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< int > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Intc_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< int > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)((daal::data_management::interface1::HomogenTensor< int > const *)arg1)->getSerializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Intc_create__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::Status *arg1 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:HomogenTensor_Intc_create",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Intc_create" "', argument " "1"" of type '" "daal::services::Status *""'"); 
  }
  arg1 = reinterpret_cast< daal::services::Status * >(argp1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Intc_create__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)":HomogenTensor_Intc_create")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< int >::SWIGTEMPLATEDISAMBIGUATOR create();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Intc_create__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t *arg2 = (size_t *) 0 ;
  int *arg3 = (int *) 0 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:HomogenTensor_Intc_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenTensor_Intc_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_size_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenTensor_Intc_create" "', argument " "2"" of type '" "size_t const *""'"); 
  }
  arg2 = reinterpret_cast< size_t * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_int, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "HomogenTensor_Intc_create" "', argument " "3"" of type '" "int *""'"); 
  }
  arg3 = reinterpret_cast< int * >(argp3);
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "HomogenTensor_Intc_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,(size_t const *)arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Intc_create__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t *arg2 = (size_t *) 0 ;
  int *arg3 = (int *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:HomogenTensor_Intc_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "HomogenTensor_Intc_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_size_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenTensor_Intc_create" "', argument " "2"" of type '" "size_t const *""'"); 
  }
  arg2 = reinterpret_cast< size_t * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_int, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "HomogenTensor_Intc_create" "', argument " "3"" of type '" "int *""'"); 
  }
  arg3 = reinterpret_cast< int * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,(size_t const *)arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Intc_create__SWIG_4(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t *arg2 = (size_t *) 0 ;
  daal::services::SharedPtr< int > *arg3 = 0 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  daal::services::SharedPtr< int > r4p1 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenTensor_Intc_create",&obj0,&obj1)) SWIG_fail;
  {
    int is_new_object = 0;
    PyArrayObject * array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj0, NPY_INT)
      :obj_to_array_contiguous_allow_conversion(obj0, NPY_INT, &is_new_object));
    if (!array || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    arg1 = (size_t)array_numdims(array);
    arg2 = (size_t*)array_dimensions(array);
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p1 = daal::services::SharedPtr< int >((int*)array_data(array), NumpyDeleter(array));
    arg3 = &r4p1;
    // we need it increment the ref-count if we use the obj0 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj0) Py_INCREF(array);
  }
  res4 = SWIG_ConvertPtr(obj1, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "HomogenTensor_Intc_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,(size_t const *)arg2,(daal::services::SharedPtr< int > const &)*arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Intc_create__SWIG_5(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t *arg2 = (size_t *) 0 ;
  daal::services::SharedPtr< int > *arg3 = 0 ;
  daal::services::SharedPtr< int > r4p1 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:HomogenTensor_Intc_create",&obj0)) SWIG_fail;
  {
    int is_new_object = 0;
    PyArrayObject * array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj0, NPY_INT)
      :obj_to_array_contiguous_allow_conversion(obj0, NPY_INT, &is_new_object));
    if (!array || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    arg1 = (size_t)array_numdims(array);
    arg2 = (size_t*)array_dimensions(array);
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p1 = daal::services::SharedPtr< int >((int*)array_data(array), NumpyDeleter(array));
    arg3 = &r4p1;
    // we need it increment the ref-count if we use the obj0 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj0) Py_INCREF(array);
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,(size_t const *)arg2,(daal::services::SharedPtr< int > const &)*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Intc_create__SWIG_6(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::Collection< size_t > *arg1 = 0 ;
  int *arg2 = (int *) 0 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  daal::services::Collection< size_t > *col_szt1 = NULL ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:HomogenTensor_Intc_create",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    Py_ssize_t n = PySequence_Length(obj0);
    if( n == 0 ) SWIG_fail;
    col_szt1 = new daal::services::Collection<size_t>(n);
    for( Py_ssize_t i=0; i<n; ++i ) {
      PyObject * o = PySequence_GetItem(obj0, i);
      size_t tmp = PyInt_AsSsize_t(o);
      if(PyErr_Occurred()) {
        PyErr_Format(PyExc_TypeError, "Sequence of integer values required");
        SWIG_fail;
      }
      (*col_szt1)[i] = tmp;
    }
    arg1 = col_szt1;
  }
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_int, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenTensor_Intc_create" "', argument " "2"" of type '" "int *""'"); 
  }
  arg2 = reinterpret_cast< int * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "HomogenTensor_Intc_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< int >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::Collection< size_t > const &)*arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, SWIG_POINTER_OWN);
  }
  {
    if( col_szt1 ) delete col_szt1;
  }
  return resultobj;
fail:
  {
    if( col_szt1 ) delete col_szt1;
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Intc_create__SWIG_7(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::Collection< size_t > *arg1 = 0 ;
  int *arg2 = (int *) 0 ;
  daal::services::Collection< size_t > *col_szt1 = NULL ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenTensor_Intc_create",&obj0,&obj1)) SWIG_fail;
  {
    Py_ssize_t n = PySequence_Length(obj0);
    if( n == 0 ) SWIG_fail;
    col_szt1 = new daal::services::Collection<size_t>(n);
    for( Py_ssize_t i=0; i<n; ++i ) {
      PyObject * o = PySequence_GetItem(obj0, i);
      size_t tmp = PyInt_AsSsize_t(o);
      if(PyErr_Occurred()) {
        PyErr_Format(PyExc_TypeError, "Sequence of integer values required");
        SWIG_fail;
      }
      (*col_szt1)[i] = tmp;
    }
    arg1 = col_szt1;
  }
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_int, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenTensor_Intc_create" "', argument " "2"" of type '" "int *""'"); 
  }
  arg2 = reinterpret_cast< int * >(argp2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< int >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::Collection< size_t > const &)*arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, SWIG_POINTER_OWN);
  }
  {
    if( col_szt1 ) delete col_szt1;
  }
  return resultobj;
fail:
  {
    if( col_szt1 ) delete col_szt1;
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Intc_create__SWIG_8(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::Collection< size_t > *arg1 = 0 ;
  daal::services::SharedPtr< int > *arg2 = 0 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  daal::services::Collection< size_t > *col_szt1 = NULL ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:HomogenTensor_Intc_create",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    Py_ssize_t n = PySequence_Length(obj0);
    if( n == 0 ) SWIG_fail;
    col_szt1 = new daal::services::Collection<size_t>(n);
    for( Py_ssize_t i=0; i<n; ++i ) {
      PyObject * o = PySequence_GetItem(obj0, i);
      size_t tmp = PyInt_AsSsize_t(o);
      if(PyErr_Occurred()) {
        PyErr_Format(PyExc_TypeError, "Sequence of integer values required");
        SWIG_fail;
      }
      (*col_szt1)[i] = tmp;
    }
    arg1 = col_szt1;
  }
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_int_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenTensor_Intc_create" "', argument " "2"" of type '" "daal::services::SharedPtr< int > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Intc_create" "', argument " "2"" of type '" "daal::services::SharedPtr< int > const &""'"); 
  }
  arg2 = reinterpret_cast< daal::services::SharedPtr< int > * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "HomogenTensor_Intc_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< int >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::Collection< size_t > const &)*arg1,(daal::services::SharedPtr< int > const &)*arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, SWIG_POINTER_OWN);
  }
  {
    if( col_szt1 ) delete col_szt1;
  }
  return resultobj;
fail:
  {
    if( col_szt1 ) delete col_szt1;
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Intc_create__SWIG_9(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::Collection< size_t > *arg1 = 0 ;
  daal::services::SharedPtr< int > *arg2 = 0 ;
  daal::services::Collection< size_t > *col_szt1 = NULL ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenTensor_Intc_create",&obj0,&obj1)) SWIG_fail;
  {
    Py_ssize_t n = PySequence_Length(obj0);
    if( n == 0 ) SWIG_fail;
    col_szt1 = new daal::services::Collection<size_t>(n);
    for( Py_ssize_t i=0; i<n; ++i ) {
      PyObject * o = PySequence_GetItem(obj0, i);
      size_t tmp = PyInt_AsSsize_t(o);
      if(PyErr_Occurred()) {
        PyErr_Format(PyExc_TypeError, "Sequence of integer values required");
        SWIG_fail;
      }
      (*col_szt1)[i] = tmp;
    }
    arg1 = col_szt1;
  }
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_int_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenTensor_Intc_create" "', argument " "2"" of type '" "daal::services::SharedPtr< int > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Intc_create" "', argument " "2"" of type '" "daal::services::SharedPtr< int > const &""'"); 
  }
  arg2 = reinterpret_cast< daal::services::SharedPtr< int > * >(argp2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< int >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::Collection< size_t > const &)*arg1,(daal::services::SharedPtr< int > const &)*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, SWIG_POINTER_OWN);
  }
  {
    if( col_szt1 ) delete col_szt1;
  }
  return resultobj;
fail:
  {
    if( col_szt1 ) delete col_szt1;
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Intc_create__SWIG_10(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::TensorOffsetLayout *arg1 = 0 ;
  int *arg2 = (int *) 0 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout const > tempshared1 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:HomogenTensor_Intc_create",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t,  0 , &newmem);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Intc_create" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (!argp1) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Intc_create" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(tempshared1.get());
    } else {
      arg1 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1)->get());
    }
    if(!arg1) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Intc_create" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
  }
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_int, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenTensor_Intc_create" "', argument " "2"" of type '" "int *""'"); 
  }
  arg2 = reinterpret_cast< int * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "HomogenTensor_Intc_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< int >::SWIGTEMPLATEDISAMBIGUATOR create((daal::data_management::interface1::TensorOffsetLayout const &)*arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Intc_create__SWIG_11(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::TensorOffsetLayout *arg1 = 0 ;
  int *arg2 = (int *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout const > tempshared1 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenTensor_Intc_create",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t,  0 , &newmem);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Intc_create" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (!argp1) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Intc_create" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(tempshared1.get());
    } else {
      arg1 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1)->get());
    }
    if(!arg1) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Intc_create" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
  }
  res2 = SWIG_ConvertPtr(obj1, &argp2,SWIGTYPE_p_int, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenTensor_Intc_create" "', argument " "2"" of type '" "int *""'"); 
  }
  arg2 = reinterpret_cast< int * >(argp2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< int >::SWIGTEMPLATEDISAMBIGUATOR create((daal::data_management::interface1::TensorOffsetLayout const &)*arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Intc_create__SWIG_12(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::TensorOffsetLayout *arg1 = 0 ;
  daal::services::SharedPtr< int > *arg2 = 0 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout const > tempshared1 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:HomogenTensor_Intc_create",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t,  0 , &newmem);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Intc_create" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (!argp1) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Intc_create" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(tempshared1.get());
    } else {
      arg1 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1)->get());
    }
    if(!arg1) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Intc_create" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
  }
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_int_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenTensor_Intc_create" "', argument " "2"" of type '" "daal::services::SharedPtr< int > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Intc_create" "', argument " "2"" of type '" "daal::services::SharedPtr< int > const &""'"); 
  }
  arg2 = reinterpret_cast< daal::services::SharedPtr< int > * >(argp2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "HomogenTensor_Intc_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< int >::SWIGTEMPLATEDISAMBIGUATOR create((daal::data_management::interface1::TensorOffsetLayout const &)*arg1,(daal::services::SharedPtr< int > const &)*arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Intc_create__SWIG_13(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::TensorOffsetLayout *arg1 = 0 ;
  daal::services::SharedPtr< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout const > tempshared1 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenTensor_Intc_create",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t,  0 , &newmem);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Intc_create" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (!argp1) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Intc_create" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(tempshared1.get());
    } else {
      arg1 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp1)->get());
    }
    if(!arg1) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Intc_create" "', argument " "1"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
  }
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_int_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenTensor_Intc_create" "', argument " "2"" of type '" "daal::services::SharedPtr< int > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Intc_create" "', argument " "2"" of type '" "daal::services::SharedPtr< int > const &""'"); 
  }
  arg2 = reinterpret_cast< daal::services::SharedPtr< int > * >(argp2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< int >::SWIGTEMPLATEDISAMBIGUATOR create((daal::data_management::interface1::TensorOffsetLayout const &)*arg1,(daal::services::SharedPtr< int > const &)*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Intc_create__SWIG_14(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::Collection< size_t > *arg1 = 0 ;
  daal::data_management::interface1::TensorIface::AllocationFlag arg2 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  daal::services::Collection< size_t > *col_szt1 = NULL ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:HomogenTensor_Intc_create",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    Py_ssize_t n = PySequence_Length(obj0);
    if( n == 0 ) SWIG_fail;
    col_szt1 = new daal::services::Collection<size_t>(n);
    for( Py_ssize_t i=0; i<n; ++i ) {
      PyObject * o = PySequence_GetItem(obj0, i);
      size_t tmp = PyInt_AsSsize_t(o);
      if(PyErr_Occurred()) {
        PyErr_Format(PyExc_TypeError, "Sequence of integer values required");
        SWIG_fail;
      }
      (*col_szt1)[i] = tmp;
    }
    arg1 = col_szt1;
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenTensor_Intc_create" "', argument " "2"" of type '" "daal::data_management::interface1::TensorIface::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::TensorIface::AllocationFlag >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "HomogenTensor_Intc_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< int >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::Collection< size_t > const &)*arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, SWIG_POINTER_OWN);
  }
  {
    if( col_szt1 ) delete col_szt1;
  }
  return resultobj;
fail:
  {
    if( col_szt1 ) delete col_szt1;
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Intc_create__SWIG_15(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::Collection< size_t > *arg1 = 0 ;
  daal::data_management::interface1::TensorIface::AllocationFlag arg2 ;
  daal::services::Collection< size_t > *col_szt1 = NULL ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenTensor_Intc_create",&obj0,&obj1)) SWIG_fail;
  {
    Py_ssize_t n = PySequence_Length(obj0);
    if( n == 0 ) SWIG_fail;
    col_szt1 = new daal::services::Collection<size_t>(n);
    for( Py_ssize_t i=0; i<n; ++i ) {
      PyObject * o = PySequence_GetItem(obj0, i);
      size_t tmp = PyInt_AsSsize_t(o);
      if(PyErr_Occurred()) {
        PyErr_Format(PyExc_TypeError, "Sequence of integer values required");
        SWIG_fail;
      }
      (*col_szt1)[i] = tmp;
    }
    arg1 = col_szt1;
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenTensor_Intc_create" "', argument " "2"" of type '" "daal::data_management::interface1::TensorIface::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::TensorIface::AllocationFlag >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< int >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::Collection< size_t > const &)*arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, SWIG_POINTER_OWN);
  }
  {
    if( col_szt1 ) delete col_szt1;
  }
  return resultobj;
fail:
  {
    if( col_szt1 ) delete col_szt1;
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Intc_create__SWIG_16(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::Collection< size_t > *arg1 = 0 ;
  daal::data_management::interface1::TensorIface::AllocationFlag arg2 ;
  int arg3 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  daal::services::Collection< size_t > *col_szt1 = NULL ;
  int val2 ;
  int ecode2 = 0 ;
  int val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:HomogenTensor_Intc_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  {
    Py_ssize_t n = PySequence_Length(obj0);
    if( n == 0 ) SWIG_fail;
    col_szt1 = new daal::services::Collection<size_t>(n);
    for( Py_ssize_t i=0; i<n; ++i ) {
      PyObject * o = PySequence_GetItem(obj0, i);
      size_t tmp = PyInt_AsSsize_t(o);
      if(PyErr_Occurred()) {
        PyErr_Format(PyExc_TypeError, "Sequence of integer values required");
        SWIG_fail;
      }
      (*col_szt1)[i] = tmp;
    }
    arg1 = col_szt1;
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenTensor_Intc_create" "', argument " "2"" of type '" "daal::data_management::interface1::TensorIface::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::TensorIface::AllocationFlag >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenTensor_Intc_create" "', argument " "3"" of type '" "int""'");
  } 
  arg3 = static_cast< int >(val3);
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "HomogenTensor_Intc_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< int >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::Collection< size_t > const &)*arg1,arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, SWIG_POINTER_OWN);
  }
  {
    if( col_szt1 ) delete col_szt1;
  }
  return resultobj;
fail:
  {
    if( col_szt1 ) delete col_szt1;
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Intc_create__SWIG_17(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::Collection< size_t > *arg1 = 0 ;
  daal::data_management::interface1::TensorIface::AllocationFlag arg2 ;
  int arg3 ;
  daal::services::Collection< size_t > *col_szt1 = NULL ;
  int val2 ;
  int ecode2 = 0 ;
  int val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:HomogenTensor_Intc_create",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    Py_ssize_t n = PySequence_Length(obj0);
    if( n == 0 ) SWIG_fail;
    col_szt1 = new daal::services::Collection<size_t>(n);
    for( Py_ssize_t i=0; i<n; ++i ) {
      PyObject * o = PySequence_GetItem(obj0, i);
      size_t tmp = PyInt_AsSsize_t(o);
      if(PyErr_Occurred()) {
        PyErr_Format(PyExc_TypeError, "Sequence of integer values required");
        SWIG_fail;
      }
      (*col_szt1)[i] = tmp;
    }
    arg1 = col_szt1;
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenTensor_Intc_create" "', argument " "2"" of type '" "daal::data_management::interface1::TensorIface::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::TensorIface::AllocationFlag >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "HomogenTensor_Intc_create" "', argument " "3"" of type '" "int""'");
  } 
  arg3 = static_cast< int >(val3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::HomogenTensor< int >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::Collection< size_t > const &)*arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, SWIG_POINTER_OWN);
  }
  {
    if( col_szt1 ) delete col_szt1;
  }
  return resultobj;
fail:
  {
    if( col_szt1 ) delete col_szt1;
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Intc_create(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[5];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 4) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_HomogenTensor_Intc_create__SWIG_1(self, args);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_HomogenTensor_Intc_create__SWIG_0(self, args);
    }
  }
  if (argc == 1) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_INT))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      if (argc <= 1) {
        return _wrap_HomogenTensor_Intc_create__SWIG_5(self, args);
      }
      if (argc <= 2) {
        return _wrap_HomogenTensor_Intc_create__SWIG_5(self, args);
      }
      return _wrap_HomogenTensor_Intc_create__SWIG_5(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_int, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenTensor_Intc_create__SWIG_11(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_int_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenTensor_Intc_create__SWIG_13(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      _v = PySequence_Check(argv[0]);
    }
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_int_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenTensor_Intc_create__SWIG_9(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_INT))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenTensor_Intc_create__SWIG_4(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      _v = PySequence_Check(argv[0]);
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_int, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenTensor_Intc_create__SWIG_7(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      _v = PySequence_Check(argv[0]);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_HomogenTensor_Intc_create__SWIG_15(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_int, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_HomogenTensor_Intc_create__SWIG_10(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_int_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_HomogenTensor_Intc_create__SWIG_12(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_size_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_int, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_HomogenTensor_Intc_create__SWIG_3(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      _v = PySequence_Check(argv[0]);
    }
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_int_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_HomogenTensor_Intc_create__SWIG_8(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      _v = PySequence_Check(argv[0]);
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_int, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_HomogenTensor_Intc_create__SWIG_6(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      _v = PySequence_Check(argv[0]);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_HomogenTensor_Intc_create__SWIG_14(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      _v = PySequence_Check(argv[0]);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_HomogenTensor_Intc_create__SWIG_17(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_size_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_int, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_HomogenTensor_Intc_create__SWIG_2(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      _v = PySequence_Check(argv[0]);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_HomogenTensor_Intc_create__SWIG_16(self, args);
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'HomogenTensor_Intc_create'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::HomogenTensor< int >::create(daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenTensor< int >::create()\n"
    "    daal::data_management::interface1::HomogenTensor< int >::create(size_t,size_t const *,int *,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenTensor< int >::create(size_t,size_t const *,int *)\n"
    "    daal::data_management::interface1::HomogenTensor< int >::create(size_t,size_t const *,daal::services::SharedPtr< int > const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenTensor< int >::create(size_t,size_t const *,daal::services::SharedPtr< int > const &)\n"
    "    daal::data_management::interface1::HomogenTensor< int >::create(daal::services::Collection< size_t > const &,int *,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenTensor< int >::create(daal::services::Collection< size_t > const &,int *)\n"
    "    daal::data_management::interface1::HomogenTensor< int >::create(daal::services::Collection< size_t > const &,daal::services::SharedPtr< int > const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenTensor< int >::create(daal::services::Collection< size_t > const &,daal::services::SharedPtr< int > const &)\n"
    "    daal::data_management::interface1::HomogenTensor< int >::create(daal::data_management::interface1::TensorOffsetLayout const &,int *,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenTensor< int >::create(daal::data_management::interface1::TensorOffsetLayout const &,int *)\n"
    "    daal::data_management::interface1::HomogenTensor< int >::create(daal::data_management::interface1::TensorOffsetLayout const &,daal::services::SharedPtr< int > const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenTensor< int >::create(daal::data_management::interface1::TensorOffsetLayout const &,daal::services::SharedPtr< int > const &)\n"
    "    daal::data_management::interface1::HomogenTensor< int >::create(daal::services::Collection< size_t > const &,daal::data_management::interface1::TensorIface::AllocationFlag,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenTensor< int >::create(daal::services::Collection< size_t > const &,daal::data_management::interface1::TensorIface::AllocationFlag)\n"
    "    daal::data_management::interface1::HomogenTensor< int >::create(daal::services::Collection< size_t > const &,daal::data_management::interface1::TensorIface::AllocationFlag,int const,daal::services::Status *)\n"
    "    daal::data_management::interface1::HomogenTensor< int >::create(daal::services::Collection< size_t > const &,daal::data_management::interface1::TensorIface::AllocationFlag,int const)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_HomogenTensor_Intc(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< int > *arg1 = (daal::data_management::interface1::HomogenTensor< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_HomogenTensor_Intc",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_HomogenTensor_Intc" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_HomogenTensor_Intc" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< int > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Intc_getTensorLayout(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< int > *arg1 = (daal::data_management::interface1::HomogenTensor< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::TensorOffsetLayout *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:HomogenTensor_Intc_getTensorLayout",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Intc_getTensorLayout" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Intc_getTensorLayout" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< int > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::TensorOffsetLayout *) &(arg1)->getTensorLayout();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::TensorOffsetLayout > *smartresult = new daal::services::SharedPtr<  daal::data_management::interface1::TensorOffsetLayout >(result SWIG_NO_NULL_DELETER_0);
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Intc_createDefaultSubtensorLayout(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< int > *arg1 = (daal::data_management::interface1::HomogenTensor< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  SwigValueWrapper< daal::data_management::interface1::TensorOffsetLayout > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:HomogenTensor_Intc_createDefaultSubtensorLayout",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Intc_createDefaultSubtensorLayout" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< int > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Intc_createDefaultSubtensorLayout" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< int > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::HomogenTensor< int > const *)arg1)->createDefaultSubtensorLayout();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::TensorOffsetLayout > *smartresult = new daal::services::SharedPtr<  daal::data_management::interface1::TensorOffsetLayout >(new daal::data_management::interface1::TensorOffsetLayout((daal::data_management::interface1::TensorOffsetLayout &)result));
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Intc_createRawSubtensorLayout(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< int > *arg1 = (daal::data_management::interface1::HomogenTensor< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  SwigValueWrapper< daal::data_management::interface1::TensorOffsetLayout > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:HomogenTensor_Intc_createRawSubtensorLayout",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Intc_createRawSubtensorLayout" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< int > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Intc_createRawSubtensorLayout" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< int > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::HomogenTensor< int > const *)arg1)->createRawSubtensorLayout();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::TensorOffsetLayout > *smartresult = new daal::services::SharedPtr<  daal::data_management::interface1::TensorOffsetLayout >(new daal::data_management::interface1::TensorOffsetLayout((daal::data_management::interface1::TensorOffsetLayout &)result));
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Intc_setDimensions__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< int > *arg1 = (daal::data_management::interface1::HomogenTensor< int > *) 0 ;
  size_t arg2 ;
  size_t *arg3 = (size_t *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:HomogenTensor_Intc_setDimensions",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Intc_setDimensions" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Intc_setDimensions" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< int > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenTensor_Intc_setDimensions" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_size_t, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "HomogenTensor_Intc_setDimensions" "', argument " "3"" of type '" "size_t const *""'"); 
  }
  arg3 = reinterpret_cast< size_t * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->setDimensions(arg2,(size_t const *)arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Intc_setDimensions__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< int > *arg1 = (daal::data_management::interface1::HomogenTensor< int > *) 0 ;
  daal::services::Collection< size_t > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > *smartarg1 = 0 ;
  daal::services::Collection< size_t > *col_szt2 = NULL ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenTensor_Intc_setDimensions",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Intc_setDimensions" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Intc_setDimensions" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< int > *""'"); 
  }
  {
    Py_ssize_t n = PySequence_Length(obj1);
    if( n == 0 ) SWIG_fail;
    col_szt2 = new daal::services::Collection<size_t>(n);
    for( Py_ssize_t i=0; i<n; ++i ) {
      PyObject * o = PySequence_GetItem(obj1, i);
      size_t tmp = PyInt_AsSsize_t(o);
      if(PyErr_Occurred()) {
        PyErr_Format(PyExc_TypeError, "Sequence of integer values required");
        SWIG_fail;
      }
      (*col_szt2)[i] = tmp;
    }
    arg2 = col_szt2;
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->setDimensions((daal::services::Collection< size_t > const &)*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  {
    if( col_szt2 ) delete col_szt2;
  }
  return resultobj;
fail:
  {
    if( col_szt2 ) delete col_szt2;
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Intc_setDimensions(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[4];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 3) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySequence_Check(argv[1]);
      }
      if (_v) {
        return _wrap_HomogenTensor_Intc_setDimensions__SWIG_1(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_size_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_HomogenTensor_Intc_setDimensions__SWIG_0(self, args);
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'HomogenTensor_Intc_setDimensions'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::HomogenTensor< int >::setDimensions(size_t,size_t const *)\n"
    "    daal::data_management::interface1::HomogenTensor< int >::setDimensions(daal::services::Collection< size_t > const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Intc_assign(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< int > *arg1 = (daal::data_management::interface1::HomogenTensor< int > *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenTensor_Intc_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Intc_assign" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Intc_assign" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< int > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenTensor_Intc_assign" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Intc_getSubtensorEx__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< int > *arg1 = (daal::data_management::interface1::HomogenTensor< int > *) 0 ;
  size_t arg2 ;
  size_t *arg3 = (size_t *) 0 ;
  size_t arg4 ;
  size_t arg5 ;
  daal::data_management::ReadWriteMode arg6 ;
  daal::data_management::interface1::SubtensorDescriptor< double > *arg7 = 0 ;
  daal::data_management::interface1::TensorOffsetLayout *arg8 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int is_new_object2 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  size_t val5 ;
  int ecode5 = 0 ;
  int val6 ;
  int ecode6 = 0 ;
  void *argp7 = 0 ;
  int res7 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< double > > tempshared7 ;
  void *argp8 = 0 ;
  int res8 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout const > tempshared8 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  PyObject * obj6 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOOO:HomogenTensor_Intc_getSubtensorEx",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5,&obj6)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Intc_getSubtensorEx" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Intc_getSubtensorEx" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< int > *""'"); 
  }
  {
    array2 = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UINT64)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UINT64, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (size_t) array_size(array2,0);
    arg3 = (size_t*) array_data(array2);
  }
  ecode4 = SWIG_AsVal_size_t(obj2, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenTensor_Intc_getSubtensorEx" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_size_t(obj3, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "HomogenTensor_Intc_getSubtensorEx" "', argument " "5"" of type '" "size_t""'");
  } 
  arg5 = static_cast< size_t >(val5);
  ecode6 = SWIG_AsVal_int(obj4, &val6);
  if (!SWIG_IsOK(ecode6)) {
    SWIG_exception_fail(SWIG_ArgError(ecode6), "in method '" "HomogenTensor_Intc_getSubtensorEx" "', argument " "6"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg6 = static_cast< daal::data_management::ReadWriteMode >(val6);
  {
    int newmem = 0;
    res7 = SWIG_ConvertPtrAndOwn(obj5, &argp7, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res7)) {
      SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "HomogenTensor_Intc_getSubtensorEx" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > &""'"); 
    }
    if (!argp7) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Intc_getSubtensorEx" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared7 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp7);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp7);
      arg7 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >(tempshared7.get());
    } else {
      arg7 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp7)->get());
    }
    if(!arg7) SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "HomogenTensor_Intc_getSubtensorEx" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > &""'"); 
  }
  {
    int newmem = 0;
    res8 = SWIG_ConvertPtrAndOwn(obj6, &argp8, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t,  0 , &newmem);
    if (!SWIG_IsOK(res8)) {
      SWIG_exception_fail(SWIG_ArgError(res8), "in method '" "HomogenTensor_Intc_getSubtensorEx" "', argument " "8"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (!argp8) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Intc_getSubtensorEx" "', argument " "8"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared8 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp8);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp8);
      arg8 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(tempshared8.get());
    } else {
      arg8 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp8)->get());
    }
    if(!arg8) SWIG_exception_fail(SWIG_ArgError(res8), "in method '" "HomogenTensor_Intc_getSubtensorEx" "', argument " "8"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getSubtensorEx(arg2,(size_t const *)arg3,arg4,arg5,arg6,*arg7,(daal::data_management::interface1::TensorOffsetLayout const &)*arg8);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  {
    if(ALLOW_CONVERSION != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(ALLOW_CONVERSION != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Intc_getSubtensorEx__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< int > *arg1 = (daal::data_management::interface1::HomogenTensor< int > *) 0 ;
  size_t arg2 ;
  size_t *arg3 = (size_t *) 0 ;
  size_t arg4 ;
  size_t arg5 ;
  daal::data_management::ReadWriteMode arg6 ;
  daal::data_management::interface1::SubtensorDescriptor< float > *arg7 = 0 ;
  daal::data_management::interface1::TensorOffsetLayout *arg8 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int is_new_object2 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  size_t val5 ;
  int ecode5 = 0 ;
  int val6 ;
  int ecode6 = 0 ;
  void *argp7 = 0 ;
  int res7 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< float > > tempshared7 ;
  void *argp8 = 0 ;
  int res8 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout const > tempshared8 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  PyObject * obj6 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOOO:HomogenTensor_Intc_getSubtensorEx",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5,&obj6)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Intc_getSubtensorEx" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Intc_getSubtensorEx" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< int > *""'"); 
  }
  {
    array2 = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UINT64)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UINT64, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (size_t) array_size(array2,0);
    arg3 = (size_t*) array_data(array2);
  }
  ecode4 = SWIG_AsVal_size_t(obj2, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenTensor_Intc_getSubtensorEx" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_size_t(obj3, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "HomogenTensor_Intc_getSubtensorEx" "', argument " "5"" of type '" "size_t""'");
  } 
  arg5 = static_cast< size_t >(val5);
  ecode6 = SWIG_AsVal_int(obj4, &val6);
  if (!SWIG_IsOK(ecode6)) {
    SWIG_exception_fail(SWIG_ArgError(ecode6), "in method '" "HomogenTensor_Intc_getSubtensorEx" "', argument " "6"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg6 = static_cast< daal::data_management::ReadWriteMode >(val6);
  {
    int newmem = 0;
    res7 = SWIG_ConvertPtrAndOwn(obj5, &argp7, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res7)) {
      SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "HomogenTensor_Intc_getSubtensorEx" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > &""'"); 
    }
    if (!argp7) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Intc_getSubtensorEx" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared7 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp7);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp7);
      arg7 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >(tempshared7.get());
    } else {
      arg7 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp7)->get());
    }
    if(!arg7) SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "HomogenTensor_Intc_getSubtensorEx" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > &""'"); 
  }
  {
    int newmem = 0;
    res8 = SWIG_ConvertPtrAndOwn(obj6, &argp8, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t,  0 , &newmem);
    if (!SWIG_IsOK(res8)) {
      SWIG_exception_fail(SWIG_ArgError(res8), "in method '" "HomogenTensor_Intc_getSubtensorEx" "', argument " "8"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (!argp8) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Intc_getSubtensorEx" "', argument " "8"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared8 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp8);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp8);
      arg8 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(tempshared8.get());
    } else {
      arg8 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp8)->get());
    }
    if(!arg8) SWIG_exception_fail(SWIG_ArgError(res8), "in method '" "HomogenTensor_Intc_getSubtensorEx" "', argument " "8"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getSubtensorEx(arg2,(size_t const *)arg3,arg4,arg5,arg6,*arg7,(daal::data_management::interface1::TensorOffsetLayout const &)*arg8);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  {
    if(ALLOW_CONVERSION != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(ALLOW_CONVERSION != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Intc_getSubtensorEx__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< int > *arg1 = (daal::data_management::interface1::HomogenTensor< int > *) 0 ;
  size_t arg2 ;
  size_t *arg3 = (size_t *) 0 ;
  size_t arg4 ;
  size_t arg5 ;
  daal::data_management::ReadWriteMode arg6 ;
  daal::data_management::interface1::SubtensorDescriptor< int > *arg7 = 0 ;
  daal::data_management::interface1::TensorOffsetLayout *arg8 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int is_new_object2 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  size_t val5 ;
  int ecode5 = 0 ;
  int val6 ;
  int ecode6 = 0 ;
  void *argp7 = 0 ;
  int res7 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< int > > tempshared7 ;
  void *argp8 = 0 ;
  int res8 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout const > tempshared8 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  PyObject * obj6 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOOO:HomogenTensor_Intc_getSubtensorEx",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5,&obj6)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Intc_getSubtensorEx" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Intc_getSubtensorEx" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< int > *""'"); 
  }
  {
    array2 = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UINT64)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UINT64, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (size_t) array_size(array2,0);
    arg3 = (size_t*) array_data(array2);
  }
  ecode4 = SWIG_AsVal_size_t(obj2, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenTensor_Intc_getSubtensorEx" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_size_t(obj3, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "HomogenTensor_Intc_getSubtensorEx" "', argument " "5"" of type '" "size_t""'");
  } 
  arg5 = static_cast< size_t >(val5);
  ecode6 = SWIG_AsVal_int(obj4, &val6);
  if (!SWIG_IsOK(ecode6)) {
    SWIG_exception_fail(SWIG_ArgError(ecode6), "in method '" "HomogenTensor_Intc_getSubtensorEx" "', argument " "6"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg6 = static_cast< daal::data_management::ReadWriteMode >(val6);
  {
    int newmem = 0;
    res7 = SWIG_ConvertPtrAndOwn(obj5, &argp7, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res7)) {
      SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "HomogenTensor_Intc_getSubtensorEx" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > &""'"); 
    }
    if (!argp7) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Intc_getSubtensorEx" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared7 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp7);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp7);
      arg7 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >(tempshared7.get());
    } else {
      arg7 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp7)->get());
    }
    if(!arg7) SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "HomogenTensor_Intc_getSubtensorEx" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > &""'"); 
  }
  {
    int newmem = 0;
    res8 = SWIG_ConvertPtrAndOwn(obj6, &argp8, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t,  0 , &newmem);
    if (!SWIG_IsOK(res8)) {
      SWIG_exception_fail(SWIG_ArgError(res8), "in method '" "HomogenTensor_Intc_getSubtensorEx" "', argument " "8"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (!argp8) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Intc_getSubtensorEx" "', argument " "8"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared8 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp8);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp8);
      arg8 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(tempshared8.get());
    } else {
      arg8 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp8)->get());
    }
    if(!arg8) SWIG_exception_fail(SWIG_ArgError(res8), "in method '" "HomogenTensor_Intc_getSubtensorEx" "', argument " "8"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getSubtensorEx(arg2,(size_t const *)arg3,arg4,arg5,arg6,*arg7,(daal::data_management::interface1::TensorOffsetLayout const &)*arg8);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  {
    if(ALLOW_CONVERSION != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(ALLOW_CONVERSION != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Intc_getSubtensorEx(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[8];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 7) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 7) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = (ALLOW_CONVERSION == FORCE_INPLACE
          ? (is_array(argv[1]) && PyArray_EquivTypenums(array_type(argv[1]), NPY_UINT64))
          :(is_array(argv[1]) || PySequence_Check(argv[1])));
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                int res = SWIG_ConvertPtr(argv[6], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, 0);
                _v = SWIG_CheckState(res);
                if (_v) {
                  return _wrap_HomogenTensor_Intc_getSubtensorEx__SWIG_0(self, args);
                }
              }
            }
          }
        }
      }
    }
  }
  if (argc == 7) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = (ALLOW_CONVERSION == FORCE_INPLACE
          ? (is_array(argv[1]) && PyArray_EquivTypenums(array_type(argv[1]), NPY_UINT64))
          :(is_array(argv[1]) || PySequence_Check(argv[1])));
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                int res = SWIG_ConvertPtr(argv[6], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, 0);
                _v = SWIG_CheckState(res);
                if (_v) {
                  return _wrap_HomogenTensor_Intc_getSubtensorEx__SWIG_1(self, args);
                }
              }
            }
          }
        }
      }
    }
  }
  if (argc == 7) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = (ALLOW_CONVERSION == FORCE_INPLACE
          ? (is_array(argv[1]) && PyArray_EquivTypenums(array_type(argv[1]), NPY_UINT64))
          :(is_array(argv[1]) || PySequence_Check(argv[1])));
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                int res = SWIG_ConvertPtr(argv[6], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, 0);
                _v = SWIG_CheckState(res);
                if (_v) {
                  return _wrap_HomogenTensor_Intc_getSubtensorEx__SWIG_2(self, args);
                }
              }
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'HomogenTensor_Intc_getSubtensorEx'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::HomogenTensor< int >::getSubtensorEx(size_t,size_t const *,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::SubtensorDescriptor< double > &,daal::data_management::interface1::TensorOffsetLayout const &)\n"
    "    daal::data_management::interface1::HomogenTensor< int >::getSubtensorEx(size_t,size_t const *,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::SubtensorDescriptor< float > &,daal::data_management::interface1::TensorOffsetLayout const &)\n"
    "    daal::data_management::interface1::HomogenTensor< int >::getSubtensorEx(size_t,size_t const *,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::SubtensorDescriptor< int > &,daal::data_management::interface1::TensorOffsetLayout const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Intc_getSubtensor__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< int > *arg1 = (daal::data_management::interface1::HomogenTensor< int > *) 0 ;
  size_t arg2 ;
  size_t *arg3 = (size_t *) 0 ;
  size_t arg4 ;
  size_t arg5 ;
  daal::data_management::ReadWriteMode arg6 ;
  daal::data_management::interface1::SubtensorDescriptor< double > *arg7 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int is_new_object2 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  size_t val5 ;
  int ecode5 = 0 ;
  int val6 ;
  int ecode6 = 0 ;
  void *argp7 = 0 ;
  int res7 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< double > > tempshared7 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:HomogenTensor_Intc_getSubtensor",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Intc_getSubtensor" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Intc_getSubtensor" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< int > *""'"); 
  }
  {
    array2 = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UINT64)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UINT64, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (size_t) array_size(array2,0);
    arg3 = (size_t*) array_data(array2);
  }
  ecode4 = SWIG_AsVal_size_t(obj2, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenTensor_Intc_getSubtensor" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_size_t(obj3, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "HomogenTensor_Intc_getSubtensor" "', argument " "5"" of type '" "size_t""'");
  } 
  arg5 = static_cast< size_t >(val5);
  ecode6 = SWIG_AsVal_int(obj4, &val6);
  if (!SWIG_IsOK(ecode6)) {
    SWIG_exception_fail(SWIG_ArgError(ecode6), "in method '" "HomogenTensor_Intc_getSubtensor" "', argument " "6"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg6 = static_cast< daal::data_management::ReadWriteMode >(val6);
  {
    int newmem = 0;
    res7 = SWIG_ConvertPtrAndOwn(obj5, &argp7, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res7)) {
      SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "HomogenTensor_Intc_getSubtensor" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > &""'"); 
    }
    if (!argp7) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Intc_getSubtensor" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared7 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp7);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp7);
      arg7 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >(tempshared7.get());
    } else {
      arg7 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp7)->get());
    }
    if(!arg7) SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "HomogenTensor_Intc_getSubtensor" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getSubtensor(arg2,(size_t const *)arg3,arg4,arg5,arg6,*arg7);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  {
    if(ALLOW_CONVERSION != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(ALLOW_CONVERSION != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Intc_getSubtensor__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< int > *arg1 = (daal::data_management::interface1::HomogenTensor< int > *) 0 ;
  size_t arg2 ;
  size_t *arg3 = (size_t *) 0 ;
  size_t arg4 ;
  size_t arg5 ;
  daal::data_management::ReadWriteMode arg6 ;
  daal::data_management::interface1::SubtensorDescriptor< float > *arg7 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int is_new_object2 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  size_t val5 ;
  int ecode5 = 0 ;
  int val6 ;
  int ecode6 = 0 ;
  void *argp7 = 0 ;
  int res7 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< float > > tempshared7 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:HomogenTensor_Intc_getSubtensor",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Intc_getSubtensor" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Intc_getSubtensor" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< int > *""'"); 
  }
  {
    array2 = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UINT64)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UINT64, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (size_t) array_size(array2,0);
    arg3 = (size_t*) array_data(array2);
  }
  ecode4 = SWIG_AsVal_size_t(obj2, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenTensor_Intc_getSubtensor" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_size_t(obj3, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "HomogenTensor_Intc_getSubtensor" "', argument " "5"" of type '" "size_t""'");
  } 
  arg5 = static_cast< size_t >(val5);
  ecode6 = SWIG_AsVal_int(obj4, &val6);
  if (!SWIG_IsOK(ecode6)) {
    SWIG_exception_fail(SWIG_ArgError(ecode6), "in method '" "HomogenTensor_Intc_getSubtensor" "', argument " "6"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg6 = static_cast< daal::data_management::ReadWriteMode >(val6);
  {
    int newmem = 0;
    res7 = SWIG_ConvertPtrAndOwn(obj5, &argp7, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res7)) {
      SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "HomogenTensor_Intc_getSubtensor" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > &""'"); 
    }
    if (!argp7) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Intc_getSubtensor" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared7 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp7);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp7);
      arg7 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >(tempshared7.get());
    } else {
      arg7 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp7)->get());
    }
    if(!arg7) SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "HomogenTensor_Intc_getSubtensor" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getSubtensor(arg2,(size_t const *)arg3,arg4,arg5,arg6,*arg7);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  {
    if(ALLOW_CONVERSION != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(ALLOW_CONVERSION != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Intc_getSubtensor__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< int > *arg1 = (daal::data_management::interface1::HomogenTensor< int > *) 0 ;
  size_t arg2 ;
  size_t *arg3 = (size_t *) 0 ;
  size_t arg4 ;
  size_t arg5 ;
  daal::data_management::ReadWriteMode arg6 ;
  daal::data_management::interface1::SubtensorDescriptor< int > *arg7 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > *smartarg1 = 0 ;
  PyArrayObject *array2 = NULL ;
  int is_new_object2 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  size_t val5 ;
  int ecode5 = 0 ;
  int val6 ;
  int ecode6 = 0 ;
  void *argp7 = 0 ;
  int res7 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< int > > tempshared7 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:HomogenTensor_Intc_getSubtensor",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Intc_getSubtensor" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Intc_getSubtensor" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< int > *""'"); 
  }
  {
    array2 = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj1, NPY_UINT64)
      :obj_to_array_contiguous_allow_conversion(obj1, NPY_UINT64, &is_new_object2));
    if (!array2 || !require_dimensions(array2, 1) || !require_contiguous(array2) || !require_native(array2)) SWIG_fail;
    arg2 = (size_t) array_size(array2,0);
    arg3 = (size_t*) array_data(array2);
  }
  ecode4 = SWIG_AsVal_size_t(obj2, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "HomogenTensor_Intc_getSubtensor" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_size_t(obj3, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "HomogenTensor_Intc_getSubtensor" "', argument " "5"" of type '" "size_t""'");
  } 
  arg5 = static_cast< size_t >(val5);
  ecode6 = SWIG_AsVal_int(obj4, &val6);
  if (!SWIG_IsOK(ecode6)) {
    SWIG_exception_fail(SWIG_ArgError(ecode6), "in method '" "HomogenTensor_Intc_getSubtensor" "', argument " "6"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg6 = static_cast< daal::data_management::ReadWriteMode >(val6);
  {
    int newmem = 0;
    res7 = SWIG_ConvertPtrAndOwn(obj5, &argp7, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res7)) {
      SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "HomogenTensor_Intc_getSubtensor" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > &""'"); 
    }
    if (!argp7) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Intc_getSubtensor" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared7 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp7);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp7);
      arg7 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >(tempshared7.get());
    } else {
      arg7 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp7)->get());
    }
    if(!arg7) SWIG_exception_fail(SWIG_ArgError(res7), "in method '" "HomogenTensor_Intc_getSubtensor" "', argument " "7"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getSubtensor(arg2,(size_t const *)arg3,arg4,arg5,arg6,*arg7);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  {
    if(ALLOW_CONVERSION != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return resultobj;
fail:
  {
    if(ALLOW_CONVERSION != FORCE_INPLACE && is_new_object2 && array2) {
      Py_DECREF(array2);
    }
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Intc_getSubtensor(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[7];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 6) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = (ALLOW_CONVERSION == FORCE_INPLACE
          ? (is_array(argv[1]) && PyArray_EquivTypenums(array_type(argv[1]), NPY_UINT64))
          :(is_array(argv[1]) || PySequence_Check(argv[1])));
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_HomogenTensor_Intc_getSubtensor__SWIG_0(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = (ALLOW_CONVERSION == FORCE_INPLACE
          ? (is_array(argv[1]) && PyArray_EquivTypenums(array_type(argv[1]), NPY_UINT64))
          :(is_array(argv[1]) || PySequence_Check(argv[1])));
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_HomogenTensor_Intc_getSubtensor__SWIG_1(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = (ALLOW_CONVERSION == FORCE_INPLACE
          ? (is_array(argv[1]) && PyArray_EquivTypenums(array_type(argv[1]), NPY_UINT64))
          :(is_array(argv[1]) || PySequence_Check(argv[1])));
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_HomogenTensor_Intc_getSubtensor__SWIG_2(self, args);
              }
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'HomogenTensor_Intc_getSubtensor'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::HomogenTensor< int >::getSubtensor(size_t,size_t const *,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::SubtensorDescriptor< double > &)\n"
    "    daal::data_management::interface1::HomogenTensor< int >::getSubtensor(size_t,size_t const *,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::SubtensorDescriptor< float > &)\n"
    "    daal::data_management::interface1::HomogenTensor< int >::getSubtensor(size_t,size_t const *,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::SubtensorDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Intc_releaseSubtensor__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< int > *arg1 = (daal::data_management::interface1::HomogenTensor< int > *) 0 ;
  daal::data_management::interface1::SubtensorDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenTensor_Intc_releaseSubtensor",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Intc_releaseSubtensor" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Intc_releaseSubtensor" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< int > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenTensor_Intc_releaseSubtensor" "', argument " "2"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Intc_releaseSubtensor" "', argument " "2"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenTensor_Intc_releaseSubtensor" "', argument " "2"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseSubtensor(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Intc_releaseSubtensor__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< int > *arg1 = (daal::data_management::interface1::HomogenTensor< int > *) 0 ;
  daal::data_management::interface1::SubtensorDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenTensor_Intc_releaseSubtensor",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Intc_releaseSubtensor" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Intc_releaseSubtensor" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< int > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenTensor_Intc_releaseSubtensor" "', argument " "2"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Intc_releaseSubtensor" "', argument " "2"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenTensor_Intc_releaseSubtensor" "', argument " "2"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseSubtensor(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Intc_releaseSubtensor__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< int > *arg1 = (daal::data_management::interface1::HomogenTensor< int > *) 0 ;
  daal::data_management::interface1::SubtensorDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenTensor_Intc_releaseSubtensor",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Intc_releaseSubtensor" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Intc_releaseSubtensor" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< int > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenTensor_Intc_releaseSubtensor" "', argument " "2"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "HomogenTensor_Intc_releaseSubtensor" "', argument " "2"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "HomogenTensor_Intc_releaseSubtensor" "', argument " "2"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseSubtensor(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Intc_releaseSubtensor(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenTensor_Intc_releaseSubtensor__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenTensor_Intc_releaseSubtensor__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_HomogenTensor_Intc_releaseSubtensor__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'HomogenTensor_Intc_releaseSubtensor'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::HomogenTensor< int >::releaseSubtensor(daal::data_management::interface1::SubtensorDescriptor< double > &)\n"
    "    daal::data_management::interface1::HomogenTensor< int >::releaseSubtensor(daal::data_management::interface1::SubtensorDescriptor< float > &)\n"
    "    daal::data_management::interface1::HomogenTensor< int >::releaseSubtensor(daal::data_management::interface1::SubtensorDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Intc_getSampleTensor(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< int > *arg1 = (daal::data_management::interface1::HomogenTensor< int > *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Tensor > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:HomogenTensor_Intc_getSampleTensor",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Intc_getSampleTensor" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Intc_getSampleTensor" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< int > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "HomogenTensor_Intc_getSampleTensor" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getSampleTensor(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Tensor > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Tensor >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_HomogenTensor_Intc_getArray(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::HomogenTensor< int > *arg1 = (daal::data_management::interface1::HomogenTensor< int > *) 0 ;
  daal::services::Collection< size_t > **arg2 = (daal::services::Collection< size_t > **) 0 ;
  daal::services::SharedPtr< int > *arg3 = (daal::services::SharedPtr< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > *smartarg1 = 0 ;
  daal::services::Collection< size_t > *dims_tmp2 ;
  daal::services::SharedPtr< int > data_tmp2 ;
  PyObject * obj0 = 0 ;
  
  {
    arg2 = &dims_tmp2;
    arg3 = &data_tmp2;
  }
  if (!PyArg_ParseTuple(args,(char *)"O:HomogenTensor_Intc_getArray",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Intc_getArray" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::HomogenTensor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::HomogenTensor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "HomogenTensor_Intc_getArray" "', argument " "1"" of type '" "daal::data_management::interface1::HomogenTensor< int > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        daal_data_management_interface1_HomogenTensor_Sl_int_Sg__getArray(arg1,(daal::services::Collection< size_t > const **)arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    npy_intp * dims = NULL;
    dims = new npy_intp[(*arg2)->size()];
    for( size_t i=0; i<(*arg2)->size(); ++i ) {
      dims[i] = (npy_intp)(*arg2)->get(i);
    }
    PyObject* obj = PyArray_SimpleNewFromData((*arg2)->size(), dims, NPY_INT, (void*)(arg3->get()));
    delete [] dims;
    if (!obj) SWIG_fail;
    set_sp_base((PyArrayObject*)obj, *arg3);
    resultobj = SWIG_Python_AppendOutput(resultobj, obj);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *HomogenTensor_Intc_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_KeyValueCollection_SerializationIface__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_KeyValueCollection_SerializationIface")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > *)new daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface >();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_KeyValueCollection_SerializationIface__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > const > tempshared1 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:new_KeyValueCollection_SerializationIface",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_KeyValueCollection_SerializationIface" "', argument " "1"" of type '" "daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > const &""'"); 
    }
    if (!argp1) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_KeyValueCollection_SerializationIface" "', argument " "1"" of type '" "daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > const &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > * >(tempshared1.get());
    } else {
      arg1 = const_cast< daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > * >(reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > > * >(argp1)->get());
    }
    if(!arg1) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_KeyValueCollection_SerializationIface" "', argument " "1"" of type '" "daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > const &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > *)new daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface >((daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > const &)*arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_KeyValueCollection_SerializationIface__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::Collection< size_t > *arg1 = 0 ;
  daal::services::Collection< daal::services::SharedPtr< daal::data_management::interface1::SerializationIface > > *arg2 = 0 ;
  daal::services::Collection< size_t > *col_szt1 = NULL ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:new_KeyValueCollection_SerializationIface",&obj0,&obj1)) SWIG_fail;
  {
    Py_ssize_t n = PySequence_Length(obj0);
    if( n == 0 ) SWIG_fail;
    col_szt1 = new daal::services::Collection<size_t>(n);
    for( Py_ssize_t i=0; i<n; ++i ) {
      PyObject * o = PySequence_GetItem(obj0, i);
      size_t tmp = PyInt_AsSsize_t(o);
      if(PyErr_Occurred()) {
        PyErr_Format(PyExc_TypeError, "Sequence of integer values required");
        SWIG_fail;
      }
      (*col_szt1)[i] = tmp;
    }
    arg1 = col_szt1;
  }
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_daal__services__CollectionT_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "new_KeyValueCollection_SerializationIface" "', argument " "2"" of type '" "daal::services::Collection< daal::services::SharedPtr< daal::data_management::interface1::SerializationIface > > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_KeyValueCollection_SerializationIface" "', argument " "2"" of type '" "daal::services::Collection< daal::services::SharedPtr< daal::data_management::interface1::SerializationIface > > const &""'"); 
  }
  arg2 = reinterpret_cast< daal::services::Collection< daal::services::SharedPtr< daal::data_management::interface1::SerializationIface > > * >(argp2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > *)new daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface >((daal::services::Collection< size_t > const &)*arg1,(daal::services::Collection< daal::services::SharedPtr< daal::data_management::interface1::SerializationIface > > const &)*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  {
    if( col_szt1 ) delete col_szt1;
  }
  return resultobj;
fail:
  {
    if( col_szt1 ) delete col_szt1;
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_KeyValueCollection_SerializationIface(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_new_KeyValueCollection_SerializationIface__SWIG_0(self, args);
  }
  if (argc == 1) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_KeyValueCollection_SerializationIface__SWIG_1(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    {
      _v = PySequence_Check(argv[0]);
    }
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__CollectionT_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_new_KeyValueCollection_SerializationIface__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'new_KeyValueCollection_SerializationIface'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface >::KeyValueCollection()\n"
    "    daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface >::KeyValueCollection(daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > const &)\n"
    "    daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface >::KeyValueCollection(daal::services::Collection< size_t > const &,daal::services::Collection< daal::services::SharedPtr< daal::data_management::interface1::SerializationIface > > const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_KeyValueCollection_SerializationIface(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > *arg1 = (daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_KeyValueCollection_SerializationIface",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_KeyValueCollection_SerializationIface" "', argument " "1"" of type '" "daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_KeyValueCollection_SerializationIface" "', argument " "1"" of type '" "daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_KeyValueCollection_SerializationIface_getKeyByIndex(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > *arg1 = (daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > const > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:KeyValueCollection_SerializationIface_getKeyByIndex",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "KeyValueCollection_SerializationIface_getKeyByIndex" "', argument " "1"" of type '" "daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "KeyValueCollection_SerializationIface_getKeyByIndex" "', argument " "1"" of type '" "daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > const *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "KeyValueCollection_SerializationIface_getKeyByIndex" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > const *)arg1)->getKeyByIndex(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_KeyValueCollection_SerializationIface_getValueByIndex(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > *arg1 = (daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SerializationIface > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:KeyValueCollection_SerializationIface_getValueByIndex",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "KeyValueCollection_SerializationIface_getValueByIndex" "', argument " "1"" of type '" "daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "KeyValueCollection_SerializationIface_getValueByIndex" "', argument " "1"" of type '" "daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "KeyValueCollection_SerializationIface_getValueByIndex" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::services::SharedPtr< daal::data_management::interface1::SerializationIface > *) &(arg1)->getValueByIndex(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::SerializationIface > *smartresult = *result ? new daal::services::SharedPtr<  daal::data_management::interface1::SerializationIface >(*result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_KeyValueCollection_SerializationIface_getValueByIndexConst(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > *arg1 = (daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > const > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SerializationIface > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:KeyValueCollection_SerializationIface_getValueByIndexConst",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "KeyValueCollection_SerializationIface_getValueByIndexConst" "', argument " "1"" of type '" "daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "KeyValueCollection_SerializationIface_getValueByIndexConst" "', argument " "1"" of type '" "daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > const *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "KeyValueCollection_SerializationIface_getValueByIndexConst" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > const *)arg1)->getValueByIndex(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::SerializationIface > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::SerializationIface >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_KeyValueCollection_SerializationIface_size(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > *arg1 = (daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:KeyValueCollection_SerializationIface_size",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "KeyValueCollection_SerializationIface_size" "', argument " "1"" of type '" "daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "KeyValueCollection_SerializationIface_size" "', argument " "1"" of type '" "daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > const *)arg1)->size();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_KeyValueCollection_SerializationIface_clear(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > *arg1 = (daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:KeyValueCollection_SerializationIface_clear",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "KeyValueCollection_SerializationIface_clear" "', argument " "1"" of type '" "daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "KeyValueCollection_SerializationIface_clear" "', argument " "1"" of type '" "daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->clear();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_KeyValueCollection_SerializationIface___getitem__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > *arg1 = (daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::interface1::SharedPtr< daal::data_management::interface1::SerializationIface > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:KeyValueCollection_SerializationIface___getitem__",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "KeyValueCollection_SerializationIface___getitem__" "', argument " "1"" of type '" "daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "KeyValueCollection_SerializationIface___getitem__" "', argument " "1"" of type '" "daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "KeyValueCollection_SerializationIface___getitem__" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::services::interface1::SharedPtr< daal::data_management::interface1::SerializationIface > *) &daal_data_management_interface1_KeyValueCollection_Sl_daal_data_management_interface1_SerializationIface_Sg____getitem__(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::SerializationIface > *smartresult = *result ? new daal::services::SharedPtr<  daal::data_management::interface1::SerializationIface >(*result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_KeyValueCollection_SerializationIface___setitem__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > *arg1 = (daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > *) 0 ;
  size_t arg2 ;
  daal::services::interface1::SharedPtr< daal::data_management::interface1::SerializationIface > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 ;
  int res3 = 0 ;
  daal::services::interface1::SharedPtr< daal::data_management::interface1::SerializationIface > tempshared3 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::interface1::SharedPtr< daal::data_management::interface1::SerializationIface > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:KeyValueCollection_SerializationIface___setitem__",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "KeyValueCollection_SerializationIface___setitem__" "', argument " "1"" of type '" "daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "KeyValueCollection_SerializationIface___setitem__" "', argument " "1"" of type '" "daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "KeyValueCollection_SerializationIface___setitem__" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t,  0 , &newmem);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "KeyValueCollection_SerializationIface___setitem__" "', argument " "3"" of type '" "daal::services::interface1::SharedPtr< daal::data_management::interface1::SerializationIface > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      if (argp3) tempshared3 = *reinterpret_cast< daal::services::interface1::SharedPtr< daal::data_management::interface1::SerializationIface > * >(argp3);
      delete reinterpret_cast< daal::services::interface1::SharedPtr< daal::data_management::interface1::SerializationIface > * >(argp3);
      arg3 = &tempshared3;
    } else {
      arg3 = (argp3) ? reinterpret_cast< daal::services::interface1::SharedPtr< daal::data_management::interface1::SerializationIface > * >(argp3) : &tempshared3;
    }
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::services::interface1::SharedPtr< daal::data_management::interface1::SerializationIface > *) &daal_data_management_interface1_KeyValueCollection_Sl_daal_data_management_interface1_SerializationIface_Sg____setitem__(arg1,arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::SerializationIface > *smartresult = *result ? new daal::services::SharedPtr<  daal::data_management::interface1::SerializationIface >(*result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *KeyValueCollection_SerializationIface_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_KeyValueCollection_Input__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_KeyValueCollection_Input")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > *)new daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input >();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__algorithms__interface1__Input_t_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_KeyValueCollection_Input__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > const > tempshared1 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:new_KeyValueCollection_Input",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__algorithms__interface1__Input_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_KeyValueCollection_Input" "', argument " "1"" of type '" "daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > const &""'"); 
    }
    if (!argp1) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_KeyValueCollection_Input" "', argument " "1"" of type '" "daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > const &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > * >(tempshared1.get());
    } else {
      arg1 = const_cast< daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > * >(reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > > * >(argp1)->get());
    }
    if(!arg1) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_KeyValueCollection_Input" "', argument " "1"" of type '" "daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > const &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > *)new daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input >((daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > const &)*arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__algorithms__interface1__Input_t_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_KeyValueCollection_Input__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::Collection< size_t > *arg1 = 0 ;
  daal::services::Collection< daal::services::SharedPtr< daal::algorithms::interface1::Input > > *arg2 = 0 ;
  daal::services::Collection< size_t > *col_szt1 = NULL ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:new_KeyValueCollection_Input",&obj0,&obj1)) SWIG_fail;
  {
    Py_ssize_t n = PySequence_Length(obj0);
    if( n == 0 ) SWIG_fail;
    col_szt1 = new daal::services::Collection<size_t>(n);
    for( Py_ssize_t i=0; i<n; ++i ) {
      PyObject * o = PySequence_GetItem(obj0, i);
      size_t tmp = PyInt_AsSsize_t(o);
      if(PyErr_Occurred()) {
        PyErr_Format(PyExc_TypeError, "Sequence of integer values required");
        SWIG_fail;
      }
      (*col_szt1)[i] = tmp;
    }
    arg1 = col_szt1;
  }
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_daal__services__CollectionT_daal__services__SharedPtrT_daal__algorithms__interface1__Input_t_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "new_KeyValueCollection_Input" "', argument " "2"" of type '" "daal::services::Collection< daal::services::SharedPtr< daal::algorithms::interface1::Input > > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_KeyValueCollection_Input" "', argument " "2"" of type '" "daal::services::Collection< daal::services::SharedPtr< daal::algorithms::interface1::Input > > const &""'"); 
  }
  arg2 = reinterpret_cast< daal::services::Collection< daal::services::SharedPtr< daal::algorithms::interface1::Input > > * >(argp2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > *)new daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input >((daal::services::Collection< size_t > const &)*arg1,(daal::services::Collection< daal::services::SharedPtr< daal::algorithms::interface1::Input > > const &)*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__algorithms__interface1__Input_t_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  {
    if( col_szt1 ) delete col_szt1;
  }
  return resultobj;
fail:
  {
    if( col_szt1 ) delete col_szt1;
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_KeyValueCollection_Input(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_new_KeyValueCollection_Input__SWIG_0(self, args);
  }
  if (argc == 1) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__algorithms__interface1__Input_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_KeyValueCollection_Input__SWIG_1(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    {
      _v = PySequence_Check(argv[0]);
    }
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__CollectionT_daal__services__SharedPtrT_daal__algorithms__interface1__Input_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_new_KeyValueCollection_Input__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'new_KeyValueCollection_Input'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input >::KeyValueCollection()\n"
    "    daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input >::KeyValueCollection(daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > const &)\n"
    "    daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input >::KeyValueCollection(daal::services::Collection< size_t > const &,daal::services::Collection< daal::services::SharedPtr< daal::algorithms::interface1::Input > > const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_KeyValueCollection_Input(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > *arg1 = (daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_KeyValueCollection_Input",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__algorithms__interface1__Input_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_KeyValueCollection_Input" "', argument " "1"" of type '" "daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_KeyValueCollection_Input" "', argument " "1"" of type '" "daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_KeyValueCollection_Input_getKeyByIndex(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > *arg1 = (daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > const > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:KeyValueCollection_Input_getKeyByIndex",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__algorithms__interface1__Input_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "KeyValueCollection_Input_getKeyByIndex" "', argument " "1"" of type '" "daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "KeyValueCollection_Input_getKeyByIndex" "', argument " "1"" of type '" "daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > const *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "KeyValueCollection_Input_getKeyByIndex" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > const *)arg1)->getKeyByIndex(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_KeyValueCollection_Input_getValueByIndex(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > *arg1 = (daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::algorithms::interface1::Input > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:KeyValueCollection_Input_getValueByIndex",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__algorithms__interface1__Input_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "KeyValueCollection_Input_getValueByIndex" "', argument " "1"" of type '" "daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "KeyValueCollection_Input_getValueByIndex" "', argument " "1"" of type '" "daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "KeyValueCollection_Input_getValueByIndex" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::services::SharedPtr< daal::algorithms::interface1::Input > *) &(arg1)->getValueByIndex(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::algorithms::interface1::Input > *smartresult = *result ? new daal::services::SharedPtr<  daal::algorithms::interface1::Input >(*result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__Input_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_KeyValueCollection_Input_getValueByIndexConst(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > *arg1 = (daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > const > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::algorithms::interface1::Input > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:KeyValueCollection_Input_getValueByIndexConst",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__algorithms__interface1__Input_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "KeyValueCollection_Input_getValueByIndexConst" "', argument " "1"" of type '" "daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "KeyValueCollection_Input_getValueByIndexConst" "', argument " "1"" of type '" "daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > const *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "KeyValueCollection_Input_getValueByIndexConst" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > const *)arg1)->getValueByIndex(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::algorithms::interface1::Input > *smartresult = result ? new daal::services::SharedPtr<  daal::algorithms::interface1::Input >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__Input_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_KeyValueCollection_Input_size(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > *arg1 = (daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:KeyValueCollection_Input_size",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__algorithms__interface1__Input_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "KeyValueCollection_Input_size" "', argument " "1"" of type '" "daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "KeyValueCollection_Input_size" "', argument " "1"" of type '" "daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > const *)arg1)->size();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_KeyValueCollection_Input_clear(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > *arg1 = (daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:KeyValueCollection_Input_clear",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__algorithms__interface1__Input_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "KeyValueCollection_Input_clear" "', argument " "1"" of type '" "daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "KeyValueCollection_Input_clear" "', argument " "1"" of type '" "daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->clear();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_KeyValueCollection_Input___getitem__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > *arg1 = (daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::interface1::SharedPtr< daal::algorithms::interface1::Input > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:KeyValueCollection_Input___getitem__",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__algorithms__interface1__Input_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "KeyValueCollection_Input___getitem__" "', argument " "1"" of type '" "daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "KeyValueCollection_Input___getitem__" "', argument " "1"" of type '" "daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "KeyValueCollection_Input___getitem__" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::services::interface1::SharedPtr< daal::algorithms::interface1::Input > *) &daal_data_management_interface1_KeyValueCollection_Sl_daal_algorithms_interface1_Input_Sg____getitem__(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::algorithms::interface1::Input > *smartresult = *result ? new daal::services::SharedPtr<  daal::algorithms::interface1::Input >(*result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__Input_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_KeyValueCollection_Input___setitem__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > *arg1 = (daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > *) 0 ;
  size_t arg2 ;
  daal::services::interface1::SharedPtr< daal::algorithms::interface1::Input > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 ;
  int res3 = 0 ;
  daal::services::interface1::SharedPtr< daal::algorithms::interface1::Input > tempshared3 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::interface1::SharedPtr< daal::algorithms::interface1::Input > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:KeyValueCollection_Input___setitem__",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__algorithms__interface1__Input_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "KeyValueCollection_Input___setitem__" "', argument " "1"" of type '" "daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "KeyValueCollection_Input___setitem__" "', argument " "1"" of type '" "daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "KeyValueCollection_Input___setitem__" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__Input_t,  0 , &newmem);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "KeyValueCollection_Input___setitem__" "', argument " "3"" of type '" "daal::services::interface1::SharedPtr< daal::algorithms::interface1::Input > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      if (argp3) tempshared3 = *reinterpret_cast< daal::services::interface1::SharedPtr< daal::algorithms::interface1::Input > * >(argp3);
      delete reinterpret_cast< daal::services::interface1::SharedPtr< daal::algorithms::interface1::Input > * >(argp3);
      arg3 = &tempshared3;
    } else {
      arg3 = (argp3) ? reinterpret_cast< daal::services::interface1::SharedPtr< daal::algorithms::interface1::Input > * >(argp3) : &tempshared3;
    }
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::services::interface1::SharedPtr< daal::algorithms::interface1::Input > *) &daal_data_management_interface1_KeyValueCollection_Sl_daal_algorithms_interface1_Input_Sg____setitem__(arg1,arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::algorithms::interface1::Input > *smartresult = *result ? new daal::services::SharedPtr<  daal::algorithms::interface1::Input >(*result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__algorithms__interface1__Input_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *KeyValueCollection_Input_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__algorithms__interface1__Input_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_Matrix_Float64_serializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)":Matrix_Float64_serializationTag")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)daal::data_management::interface1::Matrix< double >::SWIGTEMPLATEDISAMBIGUATOR serializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float64_getSerializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Matrix< double > *arg1 = (daal::data_management::interface1::Matrix< double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Matrix_Float64_getSerializationTag",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Matrix_Float64_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::Matrix< double > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Matrix< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Matrix< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Matrix< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Matrix< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Matrix< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Matrix_Float64_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::Matrix< double > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)((daal::data_management::interface1::Matrix< double > const *)arg1)->getSerializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float64_create__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  double *arg3 = (double *) (double *)0 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Matrix_Float64_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float64_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_double, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Matrix_Float64_create" "', argument " "3"" of type '" "double *const""'"); 
  }
  arg3 = reinterpret_cast< double * >(argp3);
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Matrix_Float64_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float64_create__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  double *arg3 = (double *) (double *)0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Matrix_Float64_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float64_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_double, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Matrix_Float64_create" "', argument " "3"" of type '" "double *const""'"); 
  }
  arg3 = reinterpret_cast< double * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float64_create__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Matrix_Float64_create",&obj0,&obj1)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float64_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float64_create__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t val1 ;
  int ecode1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Matrix_Float64_create",&obj0)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float64_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float64_create__SWIG_4(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)":Matrix_Float64_create")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< double >::SWIGTEMPLATEDISAMBIGUATOR create();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float64_create__SWIG_5(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  daal::services::SharedPtr< double > *arg3 = 0 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Matrix_Float64_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float64_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_double_t,  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Matrix_Float64_create" "', argument " "3"" of type '" "daal::services::SharedPtr< double > &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Matrix_Float64_create" "', argument " "3"" of type '" "daal::services::SharedPtr< double > &""'"); 
  }
  arg3 = reinterpret_cast< daal::services::SharedPtr< double > * >(argp3);
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Matrix_Float64_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,*arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float64_create__SWIG_6(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  daal::services::SharedPtr< double > *arg3 = 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Matrix_Float64_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float64_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_double_t,  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Matrix_Float64_create" "', argument " "3"" of type '" "daal::services::SharedPtr< double > &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Matrix_Float64_create" "', argument " "3"" of type '" "daal::services::SharedPtr< double > &""'"); 
  }
  arg3 = reinterpret_cast< daal::services::SharedPtr< double > * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float64_create__SWIG_7(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  double *arg4 = (double *) (double *)0 ;
  daal::services::Status *arg5 = (daal::services::Status *) 0 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:Matrix_Float64_create",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float64_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Float64_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_double, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Matrix_Float64_create" "', argument " "4"" of type '" "double *const""'"); 
  }
  arg4 = reinterpret_cast< double * >(argp4);
  res5 = SWIG_ConvertPtr(obj4, &argp5,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "Matrix_Float64_create" "', argument " "5"" of type '" "daal::services::Status *""'"); 
  }
  arg5 = reinterpret_cast< daal::services::Status * >(argp5);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4,arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float64_create__SWIG_8(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  double *arg4 = (double *) (double *)0 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Matrix_Float64_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float64_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Float64_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_double, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Matrix_Float64_create" "', argument " "4"" of type '" "double *const""'"); 
  }
  arg4 = reinterpret_cast< double * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float64_create__SWIG_9(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Matrix_Float64_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float64_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Float64_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float64_create__SWIG_10(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Matrix_Float64_create",&obj0,&obj1)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float64_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float64_create__SWIG_11(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  int val1 ;
  int ecode1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Matrix_Float64_create",&obj0)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float64_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float64_create__SWIG_12(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::services::SharedPtr< double > *arg4 = 0 ;
  daal::services::Status *arg5 = (daal::services::Status *) 0 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:Matrix_Float64_create",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float64_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Float64_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  res4 = SWIG_ConvertPtr(obj3, &argp4, SWIGTYPE_p_daal__services__SharedPtrT_double_t,  0  | 0);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Matrix_Float64_create" "', argument " "4"" of type '" "daal::services::SharedPtr< double > const &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Matrix_Float64_create" "', argument " "4"" of type '" "daal::services::SharedPtr< double > const &""'"); 
  }
  arg4 = reinterpret_cast< daal::services::SharedPtr< double > * >(argp4);
  res5 = SWIG_ConvertPtr(obj4, &argp5,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "Matrix_Float64_create" "', argument " "5"" of type '" "daal::services::Status *""'"); 
  }
  arg5 = reinterpret_cast< daal::services::Status * >(argp5);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,(daal::services::SharedPtr< double > const &)*arg4,arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float64_create__SWIG_13(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::services::SharedPtr< double > *arg4 = 0 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Matrix_Float64_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float64_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Float64_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  res4 = SWIG_ConvertPtr(obj3, &argp4, SWIGTYPE_p_daal__services__SharedPtrT_double_t,  0  | 0);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Matrix_Float64_create" "', argument " "4"" of type '" "daal::services::SharedPtr< double > const &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Matrix_Float64_create" "', argument " "4"" of type '" "daal::services::SharedPtr< double > const &""'"); 
  }
  arg4 = reinterpret_cast< daal::services::SharedPtr< double > * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,(daal::services::SharedPtr< double > const &)*arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float64_create__SWIG_14(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  daal::data_management::interface1::NumericTable::AllocationFlag arg3 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  int val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Matrix_Float64_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float64_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Float64_create" "', argument " "3"" of type '" "daal::data_management::interface1::NumericTable::AllocationFlag""'");
  } 
  arg3 = static_cast< daal::data_management::interface1::NumericTable::AllocationFlag >(val3);
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Matrix_Float64_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float64_create__SWIG_15(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  daal::data_management::interface1::NumericTable::AllocationFlag arg3 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  int val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Matrix_Float64_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float64_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Float64_create" "', argument " "3"" of type '" "daal::data_management::interface1::NumericTable::AllocationFlag""'");
  } 
  arg3 = static_cast< daal::data_management::interface1::NumericTable::AllocationFlag >(val3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float64_create__SWIG_16(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::interface1::NumericTable::AllocationFlag arg4 ;
  daal::services::Status *arg5 = (daal::services::Status *) 0 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:Matrix_Float64_create",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float64_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Float64_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Matrix_Float64_create" "', argument " "4"" of type '" "daal::data_management::interface1::NumericTable::AllocationFlag""'");
  } 
  arg4 = static_cast< daal::data_management::interface1::NumericTable::AllocationFlag >(val4);
  res5 = SWIG_ConvertPtr(obj4, &argp5,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "Matrix_Float64_create" "', argument " "5"" of type '" "daal::services::Status *""'"); 
  }
  arg5 = reinterpret_cast< daal::services::Status * >(argp5);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4,arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float64_create__SWIG_17(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::interface1::NumericTable::AllocationFlag arg4 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Matrix_Float64_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float64_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Float64_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Matrix_Float64_create" "', argument " "4"" of type '" "daal::data_management::interface1::NumericTable::AllocationFlag""'");
  } 
  arg4 = static_cast< daal::data_management::interface1::NumericTable::AllocationFlag >(val4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float64_create__SWIG_18(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  double *arg3 = (double *) (double *)0 ;
  double *arg4 = 0 ;
  daal::services::Status *arg5 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  double temp4 ;
  double val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:Matrix_Float64_create",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float64_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_double, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Matrix_Float64_create" "', argument " "3"" of type '" "double *const""'"); 
  }
  arg3 = reinterpret_cast< double * >(argp3);
  ecode4 = SWIG_AsVal_double(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Matrix_Float64_create" "', argument " "4"" of type '" "double""'");
  } 
  temp4 = static_cast< double >(val4);
  arg4 = &temp4;
  res5 = SWIG_ConvertPtr(obj4, &argp5,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "Matrix_Float64_create" "', argument " "5"" of type '" "daal::services::Status *""'"); 
  }
  arg5 = reinterpret_cast< daal::services::Status * >(argp5);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,(double const &)*arg4,arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float64_create__SWIG_19(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  double *arg3 = (double *) (double *)0 ;
  double *arg4 = 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  double temp4 ;
  double val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Matrix_Float64_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float64_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_double, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Matrix_Float64_create" "', argument " "3"" of type '" "double *const""'"); 
  }
  arg3 = reinterpret_cast< double * >(argp3);
  ecode4 = SWIG_AsVal_double(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Matrix_Float64_create" "', argument " "4"" of type '" "double""'");
  } 
  temp4 = static_cast< double >(val4);
  arg4 = &temp4;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,(double const &)*arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float64_create__SWIG_20(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  daal::services::SharedPtr< double > *arg3 = 0 ;
  double *arg4 = 0 ;
  daal::services::Status *arg5 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  double temp4 ;
  double val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:Matrix_Float64_create",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float64_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_double_t,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Matrix_Float64_create" "', argument " "3"" of type '" "daal::services::SharedPtr< double > const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Matrix_Float64_create" "', argument " "3"" of type '" "daal::services::SharedPtr< double > const &""'"); 
  }
  arg3 = reinterpret_cast< daal::services::SharedPtr< double > * >(argp3);
  ecode4 = SWIG_AsVal_double(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Matrix_Float64_create" "', argument " "4"" of type '" "double""'");
  } 
  temp4 = static_cast< double >(val4);
  arg4 = &temp4;
  res5 = SWIG_ConvertPtr(obj4, &argp5,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "Matrix_Float64_create" "', argument " "5"" of type '" "daal::services::Status *""'"); 
  }
  arg5 = reinterpret_cast< daal::services::Status * >(argp5);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(daal::services::SharedPtr< double > const &)*arg3,(double const &)*arg4,arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float64_create__SWIG_21(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  daal::services::SharedPtr< double > *arg3 = 0 ;
  double *arg4 = 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  double temp4 ;
  double val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Matrix_Float64_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float64_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_double_t,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Matrix_Float64_create" "', argument " "3"" of type '" "daal::services::SharedPtr< double > const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Matrix_Float64_create" "', argument " "3"" of type '" "daal::services::SharedPtr< double > const &""'"); 
  }
  arg3 = reinterpret_cast< daal::services::SharedPtr< double > * >(argp3);
  ecode4 = SWIG_AsVal_double(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Matrix_Float64_create" "', argument " "4"" of type '" "double""'");
  } 
  temp4 = static_cast< double >(val4);
  arg4 = &temp4;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(daal::services::SharedPtr< double > const &)*arg3,(double const &)*arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float64_create__SWIG_22(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  double *arg4 = (double *) (double *)0 ;
  double *arg5 = 0 ;
  daal::services::Status *arg6 = (daal::services::Status *) 0 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  double temp5 ;
  double val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:Matrix_Float64_create",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float64_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Float64_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_double, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Matrix_Float64_create" "', argument " "4"" of type '" "double *const""'"); 
  }
  arg4 = reinterpret_cast< double * >(argp4);
  ecode5 = SWIG_AsVal_double(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "Matrix_Float64_create" "', argument " "5"" of type '" "double""'");
  } 
  temp5 = static_cast< double >(val5);
  arg5 = &temp5;
  res6 = SWIG_ConvertPtr(obj5, &argp6,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res6)) {
    SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "Matrix_Float64_create" "', argument " "6"" of type '" "daal::services::Status *""'"); 
  }
  arg6 = reinterpret_cast< daal::services::Status * >(argp6);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4,(double const &)*arg5,arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float64_create__SWIG_23(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  double *arg4 = (double *) (double *)0 ;
  double *arg5 = 0 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  double temp5 ;
  double val5 ;
  int ecode5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:Matrix_Float64_create",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float64_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Float64_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_double, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Matrix_Float64_create" "', argument " "4"" of type '" "double *const""'"); 
  }
  arg4 = reinterpret_cast< double * >(argp4);
  ecode5 = SWIG_AsVal_double(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "Matrix_Float64_create" "', argument " "5"" of type '" "double""'");
  } 
  temp5 = static_cast< double >(val5);
  arg5 = &temp5;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4,(double const &)*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float64_create__SWIG_24(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::services::SharedPtr< double > *arg4 = 0 ;
  double *arg5 = 0 ;
  daal::services::Status *arg6 = (daal::services::Status *) 0 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  double temp5 ;
  double val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:Matrix_Float64_create",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float64_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Float64_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  res4 = SWIG_ConvertPtr(obj3, &argp4, SWIGTYPE_p_daal__services__SharedPtrT_double_t,  0  | 0);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Matrix_Float64_create" "', argument " "4"" of type '" "daal::services::SharedPtr< double > const &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Matrix_Float64_create" "', argument " "4"" of type '" "daal::services::SharedPtr< double > const &""'"); 
  }
  arg4 = reinterpret_cast< daal::services::SharedPtr< double > * >(argp4);
  ecode5 = SWIG_AsVal_double(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "Matrix_Float64_create" "', argument " "5"" of type '" "double""'");
  } 
  temp5 = static_cast< double >(val5);
  arg5 = &temp5;
  res6 = SWIG_ConvertPtr(obj5, &argp6,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res6)) {
    SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "Matrix_Float64_create" "', argument " "6"" of type '" "daal::services::Status *""'"); 
  }
  arg6 = reinterpret_cast< daal::services::Status * >(argp6);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,(daal::services::SharedPtr< double > const &)*arg4,(double const &)*arg5,arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float64_create__SWIG_25(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::services::SharedPtr< double > *arg4 = 0 ;
  double *arg5 = 0 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  double temp5 ;
  double val5 ;
  int ecode5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:Matrix_Float64_create",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float64_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Float64_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  res4 = SWIG_ConvertPtr(obj3, &argp4, SWIGTYPE_p_daal__services__SharedPtrT_double_t,  0  | 0);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Matrix_Float64_create" "', argument " "4"" of type '" "daal::services::SharedPtr< double > const &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Matrix_Float64_create" "', argument " "4"" of type '" "daal::services::SharedPtr< double > const &""'"); 
  }
  arg4 = reinterpret_cast< daal::services::SharedPtr< double > * >(argp4);
  ecode5 = SWIG_AsVal_double(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "Matrix_Float64_create" "', argument " "5"" of type '" "double""'");
  } 
  temp5 = static_cast< double >(val5);
  arg5 = &temp5;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,(daal::services::SharedPtr< double > const &)*arg4,(double const &)*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float64_create__SWIG_26(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  daal::data_management::interface1::NumericTable::AllocationFlag arg3 ;
  double *arg4 = 0 ;
  daal::services::Status *arg5 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  int val3 ;
  int ecode3 = 0 ;
  double temp4 ;
  double val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:Matrix_Float64_create",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float64_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Float64_create" "', argument " "3"" of type '" "daal::data_management::interface1::NumericTable::AllocationFlag""'");
  } 
  arg3 = static_cast< daal::data_management::interface1::NumericTable::AllocationFlag >(val3);
  ecode4 = SWIG_AsVal_double(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Matrix_Float64_create" "', argument " "4"" of type '" "double""'");
  } 
  temp4 = static_cast< double >(val4);
  arg4 = &temp4;
  res5 = SWIG_ConvertPtr(obj4, &argp5,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "Matrix_Float64_create" "', argument " "5"" of type '" "daal::services::Status *""'"); 
  }
  arg5 = reinterpret_cast< daal::services::Status * >(argp5);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,(double const &)*arg4,arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float64_create__SWIG_27(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  daal::data_management::interface1::NumericTable::AllocationFlag arg3 ;
  double *arg4 = 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  int val3 ;
  int ecode3 = 0 ;
  double temp4 ;
  double val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Matrix_Float64_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float64_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Float64_create" "', argument " "3"" of type '" "daal::data_management::interface1::NumericTable::AllocationFlag""'");
  } 
  arg3 = static_cast< daal::data_management::interface1::NumericTable::AllocationFlag >(val3);
  ecode4 = SWIG_AsVal_double(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Matrix_Float64_create" "', argument " "4"" of type '" "double""'");
  } 
  temp4 = static_cast< double >(val4);
  arg4 = &temp4;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,(double const &)*arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float64_create__SWIG_28(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::interface1::NumericTable::AllocationFlag arg4 ;
  double *arg5 = 0 ;
  daal::services::Status *arg6 = (daal::services::Status *) 0 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  double temp5 ;
  double val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:Matrix_Float64_create",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float64_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Float64_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Matrix_Float64_create" "', argument " "4"" of type '" "daal::data_management::interface1::NumericTable::AllocationFlag""'");
  } 
  arg4 = static_cast< daal::data_management::interface1::NumericTable::AllocationFlag >(val4);
  ecode5 = SWIG_AsVal_double(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "Matrix_Float64_create" "', argument " "5"" of type '" "double""'");
  } 
  temp5 = static_cast< double >(val5);
  arg5 = &temp5;
  res6 = SWIG_ConvertPtr(obj5, &argp6,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res6)) {
    SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "Matrix_Float64_create" "', argument " "6"" of type '" "daal::services::Status *""'"); 
  }
  arg6 = reinterpret_cast< daal::services::Status * >(argp6);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4,(double const &)*arg5,arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float64_create__SWIG_29(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::interface1::NumericTable::AllocationFlag arg4 ;
  double *arg5 = 0 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  double temp5 ;
  double val5 ;
  int ecode5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:Matrix_Float64_create",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float64_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Float64_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Matrix_Float64_create" "', argument " "4"" of type '" "daal::data_management::interface1::NumericTable::AllocationFlag""'");
  } 
  arg4 = static_cast< daal::data_management::interface1::NumericTable::AllocationFlag >(val4);
  ecode5 = SWIG_AsVal_double(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "Matrix_Float64_create" "', argument " "5"" of type '" "double""'");
  } 
  temp5 = static_cast< double >(val5);
  arg5 = &temp5;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4,(double const &)*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_Matrix_Float64(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Matrix< double > *arg1 = (daal::data_management::interface1::Matrix< double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_Matrix_Float64",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Matrix_Float64" "', argument " "1"" of type '" "daal::data_management::interface1::Matrix< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Matrix< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Matrix< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Matrix_Float64" "', argument " "1"" of type '" "daal::data_management::interface1::Matrix< double > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float64_create__SWIG_30(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< double > *arg1 = 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::services::SharedPtr< double > r4p1 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Matrix_Float64_create",&obj0)) SWIG_fail;
  {
    int is_new_object = 0;
    PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj0, NPY_DOUBLE)
      :obj_to_array_contiguous_allow_conversion(obj0, NPY_DOUBLE, &is_new_object));
    if (!array || !require_dimensions(array, 2) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p1 = daal::services::SharedPtr< double >((double*)array_data(array), NumpyDeleter(array));
    arg1 = &r4p1;
    arg2 = (size_t) array_size(array,1);
    arg3 = (size_t) array_size(array,0);
    // we need it increment the ref-count if we use the obj0 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj0) Py_INCREF(array);
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal_data_management_interface1_Matrix_Sl_double_Sg__create__SWIG_30((daal::services::SharedPtr< double > const &)*arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float64_create__SWIG_31(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< double > *arg1 = 0 ;
  size_t arg2 ;
  size_t arg3 ;
  double *arg4 = 0 ;
  daal::services::SharedPtr< double > r4p1 ;
  double temp4 ;
  double val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Matrix_Float64_create",&obj0,&obj1)) SWIG_fail;
  {
    int is_new_object = 0;
    PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj0, NPY_DOUBLE)
      :obj_to_array_contiguous_allow_conversion(obj0, NPY_DOUBLE, &is_new_object));
    if (!array || !require_dimensions(array, 2) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p1 = daal::services::SharedPtr< double >((double*)array_data(array), NumpyDeleter(array));
    arg1 = &r4p1;
    arg2 = (size_t) array_size(array,1);
    arg3 = (size_t) array_size(array,0);
    // we need it increment the ref-count if we use the obj0 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj0) Py_INCREF(array);
  }
  ecode4 = SWIG_AsVal_double(obj1, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Matrix_Float64_create" "', argument " "4"" of type '" "double""'");
  } 
  temp4 = static_cast< double >(val4);
  arg4 = &temp4;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal_data_management_interface1_Matrix_Sl_double_Sg__create__SWIG_31((daal::services::SharedPtr< double > const &)*arg1,arg2,arg3,(double const &)*arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float64_create(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[7];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 6) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_Matrix_Float64_create__SWIG_4(self, args);
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_Matrix_Float64_create__SWIG_11(self, args);
    }
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_Matrix_Float64_create__SWIG_3(self, args);
    }
  }
  if (argc == 1) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_DOUBLE))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      if (argc <= 1) {
        return _wrap_Matrix_Float64_create__SWIG_30(self, args);
      }
      if (argc <= 2) {
        return _wrap_Matrix_Float64_create__SWIG_30(self, args);
      }
      return _wrap_Matrix_Float64_create__SWIG_30(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_Matrix_Float64_create__SWIG_10(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_Matrix_Float64_create__SWIG_2(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_DOUBLE))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      {
        int res = SWIG_AsVal_double(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_Matrix_Float64_create__SWIG_31(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_Matrix_Float64_create__SWIG_9(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__SharedPtrT_double_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_Matrix_Float64_create__SWIG_6(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_double, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_Matrix_Float64_create__SWIG_1(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_Matrix_Float64_create__SWIG_15(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = SWIG_ConvertPtr(argv[3], 0, SWIGTYPE_p_daal__services__SharedPtrT_double_t, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_Matrix_Float64_create__SWIG_13(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_double, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_Matrix_Float64_create__SWIG_8(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            return _wrap_Matrix_Float64_create__SWIG_17(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_double, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_Matrix_Float64_create__SWIG_0(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__SharedPtrT_double_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_Matrix_Float64_create__SWIG_5(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_double, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          {
            int res = SWIG_AsVal_double(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            return _wrap_Matrix_Float64_create__SWIG_19(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_double_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          {
            int res = SWIG_AsVal_double(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            return _wrap_Matrix_Float64_create__SWIG_21(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_Matrix_Float64_create__SWIG_14(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_double(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            return _wrap_Matrix_Float64_create__SWIG_27(self, args);
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_double, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            void *vptr = 0;
            int res = SWIG_ConvertPtr(argv[4], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_Matrix_Float64_create__SWIG_7(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = SWIG_ConvertPtr(argv[3], 0, SWIGTYPE_p_daal__services__SharedPtrT_double_t, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            void *vptr = 0;
            int res = SWIG_ConvertPtr(argv[4], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_Matrix_Float64_create__SWIG_12(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = SWIG_ConvertPtr(argv[3], 0, SWIGTYPE_p_daal__services__SharedPtrT_double_t, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            {
              int res = SWIG_AsVal_double(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              return _wrap_Matrix_Float64_create__SWIG_25(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_double, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            {
              int res = SWIG_AsVal_double(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              return _wrap_Matrix_Float64_create__SWIG_23(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            void *vptr = 0;
            int res = SWIG_ConvertPtr(argv[4], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_Matrix_Float64_create__SWIG_16(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_double(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              return _wrap_Matrix_Float64_create__SWIG_29(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_double, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          {
            int res = SWIG_AsVal_double(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            void *vptr = 0;
            int res = SWIG_ConvertPtr(argv[4], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_Matrix_Float64_create__SWIG_18(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_double_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          {
            int res = SWIG_AsVal_double(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            void *vptr = 0;
            int res = SWIG_ConvertPtr(argv[4], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_Matrix_Float64_create__SWIG_20(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_double(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            void *vptr = 0;
            int res = SWIG_ConvertPtr(argv[4], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_Matrix_Float64_create__SWIG_26(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = SWIG_ConvertPtr(argv[3], 0, SWIGTYPE_p_daal__services__SharedPtrT_double_t, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            {
              int res = SWIG_AsVal_double(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              void *vptr = 0;
              int res = SWIG_ConvertPtr(argv[5], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_Matrix_Float64_create__SWIG_24(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_double, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            {
              int res = SWIG_AsVal_double(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              void *vptr = 0;
              int res = SWIG_ConvertPtr(argv[5], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_Matrix_Float64_create__SWIG_22(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_double(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              void *vptr = 0;
              int res = SWIG_ConvertPtr(argv[5], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_Matrix_Float64_create__SWIG_28(self, args);
              }
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Matrix_Float64_create'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::Matrix< double >::create(size_t,size_t,double *const,daal::services::Status *)\n"
    "    daal::data_management::interface1::Matrix< double >::create(size_t,size_t,double *const)\n"
    "    daal::data_management::interface1::Matrix< double >::create(size_t,size_t)\n"
    "    daal::data_management::interface1::Matrix< double >::create(size_t)\n"
    "    daal::data_management::interface1::Matrix< double >::create()\n"
    "    daal::data_management::interface1::Matrix< double >::create(size_t,size_t,daal::services::SharedPtr< double > &,daal::services::Status *)\n"
    "    daal::data_management::interface1::Matrix< double >::create(size_t,size_t,daal::services::SharedPtr< double > &)\n"
    "    daal::data_management::interface1::Matrix< double >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t,double *const,daal::services::Status *)\n"
    "    daal::data_management::interface1::Matrix< double >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t,double *const)\n"
    "    daal::data_management::interface1::Matrix< double >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t)\n"
    "    daal::data_management::interface1::Matrix< double >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t)\n"
    "    daal::data_management::interface1::Matrix< double >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual)\n"
    "    daal::data_management::interface1::Matrix< double >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t,daal::services::SharedPtr< double > const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::Matrix< double >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t,daal::services::SharedPtr< double > const &)\n"
    "    daal::data_management::interface1::Matrix< double >::create(size_t,size_t,daal::data_management::interface1::NumericTable::AllocationFlag,daal::services::Status *)\n"
    "    daal::data_management::interface1::Matrix< double >::create(size_t,size_t,daal::data_management::interface1::NumericTable::AllocationFlag)\n"
    "    daal::data_management::interface1::Matrix< double >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t,daal::data_management::interface1::NumericTable::AllocationFlag,daal::services::Status *)\n"
    "    daal::data_management::interface1::Matrix< double >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t,daal::data_management::interface1::NumericTable::AllocationFlag)\n"
    "    daal::data_management::interface1::Matrix< double >::create(size_t,size_t,double *const,double const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::Matrix< double >::create(size_t,size_t,double *const,double const &)\n"
    "    daal::data_management::interface1::Matrix< double >::create(size_t,size_t,daal::services::SharedPtr< double > const &,double const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::Matrix< double >::create(size_t,size_t,daal::services::SharedPtr< double > const &,double const &)\n"
    "    daal::data_management::interface1::Matrix< double >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t,double *const,double const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::Matrix< double >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t,double *const,double const &)\n"
    "    daal::data_management::interface1::Matrix< double >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t,daal::services::SharedPtr< double > const &,double const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::Matrix< double >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t,daal::services::SharedPtr< double > const &,double const &)\n"
    "    daal::data_management::interface1::Matrix< double >::create(size_t,size_t,daal::data_management::interface1::NumericTable::AllocationFlag,double const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::Matrix< double >::create(size_t,size_t,daal::data_management::interface1::NumericTable::AllocationFlag,double const &)\n"
    "    daal::data_management::interface1::Matrix< double >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t,daal::data_management::interface1::NumericTable::AllocationFlag,double const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::Matrix< double >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t,daal::data_management::interface1::NumericTable::AllocationFlag,double const &)\n"
    "    daal::data_management::interface1::Matrix< double >::create(daal::services::SharedPtr< double > const &,size_t,size_t)\n"
    "    daal::data_management::interface1::Matrix< double >::daal_data_management_interface1_Matrix_Sl_double_Sg__create__SWIG_31(daal::services::SharedPtr< double > const &,size_t,size_t,double const &)\n");
  return 0;
}


SWIGINTERN PyObject *Matrix_Float64_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_Matrix_Float32_serializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)":Matrix_Float32_serializationTag")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)daal::data_management::interface1::Matrix< float >::SWIGTEMPLATEDISAMBIGUATOR serializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float32_getSerializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Matrix< float > *arg1 = (daal::data_management::interface1::Matrix< float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Matrix_Float32_getSerializationTag",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Matrix_Float32_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::Matrix< float > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Matrix< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Matrix< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Matrix< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Matrix< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Matrix< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Matrix_Float32_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::Matrix< float > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)((daal::data_management::interface1::Matrix< float > const *)arg1)->getSerializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float32_create__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  float *arg3 = (float *) (float *)0 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Matrix_Float32_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float32_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_float, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Matrix_Float32_create" "', argument " "3"" of type '" "float *const""'"); 
  }
  arg3 = reinterpret_cast< float * >(argp3);
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Matrix_Float32_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float32_create__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  float *arg3 = (float *) (float *)0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Matrix_Float32_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float32_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_float, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Matrix_Float32_create" "', argument " "3"" of type '" "float *const""'"); 
  }
  arg3 = reinterpret_cast< float * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float32_create__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Matrix_Float32_create",&obj0,&obj1)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float32_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float32_create__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t val1 ;
  int ecode1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Matrix_Float32_create",&obj0)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float32_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float32_create__SWIG_4(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)":Matrix_Float32_create")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< float >::SWIGTEMPLATEDISAMBIGUATOR create();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float32_create__SWIG_5(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  daal::services::SharedPtr< float > *arg3 = 0 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Matrix_Float32_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float32_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_float_t,  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Matrix_Float32_create" "', argument " "3"" of type '" "daal::services::SharedPtr< float > &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Matrix_Float32_create" "', argument " "3"" of type '" "daal::services::SharedPtr< float > &""'"); 
  }
  arg3 = reinterpret_cast< daal::services::SharedPtr< float > * >(argp3);
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Matrix_Float32_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,*arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float32_create__SWIG_6(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  daal::services::SharedPtr< float > *arg3 = 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Matrix_Float32_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float32_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_float_t,  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Matrix_Float32_create" "', argument " "3"" of type '" "daal::services::SharedPtr< float > &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Matrix_Float32_create" "', argument " "3"" of type '" "daal::services::SharedPtr< float > &""'"); 
  }
  arg3 = reinterpret_cast< daal::services::SharedPtr< float > * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float32_create__SWIG_7(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  float *arg4 = (float *) (float *)0 ;
  daal::services::Status *arg5 = (daal::services::Status *) 0 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:Matrix_Float32_create",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float32_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Float32_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_float, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Matrix_Float32_create" "', argument " "4"" of type '" "float *const""'"); 
  }
  arg4 = reinterpret_cast< float * >(argp4);
  res5 = SWIG_ConvertPtr(obj4, &argp5,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "Matrix_Float32_create" "', argument " "5"" of type '" "daal::services::Status *""'"); 
  }
  arg5 = reinterpret_cast< daal::services::Status * >(argp5);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4,arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float32_create__SWIG_8(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  float *arg4 = (float *) (float *)0 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Matrix_Float32_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float32_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Float32_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_float, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Matrix_Float32_create" "', argument " "4"" of type '" "float *const""'"); 
  }
  arg4 = reinterpret_cast< float * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float32_create__SWIG_9(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Matrix_Float32_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float32_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Float32_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float32_create__SWIG_10(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Matrix_Float32_create",&obj0,&obj1)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float32_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float32_create__SWIG_11(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  int val1 ;
  int ecode1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Matrix_Float32_create",&obj0)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float32_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float32_create__SWIG_12(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::services::SharedPtr< float > *arg4 = 0 ;
  daal::services::Status *arg5 = (daal::services::Status *) 0 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:Matrix_Float32_create",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float32_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Float32_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  res4 = SWIG_ConvertPtr(obj3, &argp4, SWIGTYPE_p_daal__services__SharedPtrT_float_t,  0  | 0);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Matrix_Float32_create" "', argument " "4"" of type '" "daal::services::SharedPtr< float > const &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Matrix_Float32_create" "', argument " "4"" of type '" "daal::services::SharedPtr< float > const &""'"); 
  }
  arg4 = reinterpret_cast< daal::services::SharedPtr< float > * >(argp4);
  res5 = SWIG_ConvertPtr(obj4, &argp5,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "Matrix_Float32_create" "', argument " "5"" of type '" "daal::services::Status *""'"); 
  }
  arg5 = reinterpret_cast< daal::services::Status * >(argp5);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,(daal::services::SharedPtr< float > const &)*arg4,arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float32_create__SWIG_13(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::services::SharedPtr< float > *arg4 = 0 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Matrix_Float32_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float32_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Float32_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  res4 = SWIG_ConvertPtr(obj3, &argp4, SWIGTYPE_p_daal__services__SharedPtrT_float_t,  0  | 0);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Matrix_Float32_create" "', argument " "4"" of type '" "daal::services::SharedPtr< float > const &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Matrix_Float32_create" "', argument " "4"" of type '" "daal::services::SharedPtr< float > const &""'"); 
  }
  arg4 = reinterpret_cast< daal::services::SharedPtr< float > * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,(daal::services::SharedPtr< float > const &)*arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float32_create__SWIG_14(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  daal::data_management::interface1::NumericTable::AllocationFlag arg3 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  int val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Matrix_Float32_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float32_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Float32_create" "', argument " "3"" of type '" "daal::data_management::interface1::NumericTable::AllocationFlag""'");
  } 
  arg3 = static_cast< daal::data_management::interface1::NumericTable::AllocationFlag >(val3);
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Matrix_Float32_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float32_create__SWIG_15(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  daal::data_management::interface1::NumericTable::AllocationFlag arg3 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  int val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Matrix_Float32_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float32_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Float32_create" "', argument " "3"" of type '" "daal::data_management::interface1::NumericTable::AllocationFlag""'");
  } 
  arg3 = static_cast< daal::data_management::interface1::NumericTable::AllocationFlag >(val3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float32_create__SWIG_16(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::interface1::NumericTable::AllocationFlag arg4 ;
  daal::services::Status *arg5 = (daal::services::Status *) 0 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:Matrix_Float32_create",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float32_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Float32_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Matrix_Float32_create" "', argument " "4"" of type '" "daal::data_management::interface1::NumericTable::AllocationFlag""'");
  } 
  arg4 = static_cast< daal::data_management::interface1::NumericTable::AllocationFlag >(val4);
  res5 = SWIG_ConvertPtr(obj4, &argp5,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "Matrix_Float32_create" "', argument " "5"" of type '" "daal::services::Status *""'"); 
  }
  arg5 = reinterpret_cast< daal::services::Status * >(argp5);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4,arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float32_create__SWIG_17(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::interface1::NumericTable::AllocationFlag arg4 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Matrix_Float32_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float32_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Float32_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Matrix_Float32_create" "', argument " "4"" of type '" "daal::data_management::interface1::NumericTable::AllocationFlag""'");
  } 
  arg4 = static_cast< daal::data_management::interface1::NumericTable::AllocationFlag >(val4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float32_create__SWIG_18(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  float *arg3 = (float *) (float *)0 ;
  float *arg4 = 0 ;
  daal::services::Status *arg5 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  float temp4 ;
  float val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:Matrix_Float32_create",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float32_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_float, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Matrix_Float32_create" "', argument " "3"" of type '" "float *const""'"); 
  }
  arg3 = reinterpret_cast< float * >(argp3);
  ecode4 = SWIG_AsVal_float(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Matrix_Float32_create" "', argument " "4"" of type '" "float""'");
  } 
  temp4 = static_cast< float >(val4);
  arg4 = &temp4;
  res5 = SWIG_ConvertPtr(obj4, &argp5,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "Matrix_Float32_create" "', argument " "5"" of type '" "daal::services::Status *""'"); 
  }
  arg5 = reinterpret_cast< daal::services::Status * >(argp5);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,(float const &)*arg4,arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float32_create__SWIG_19(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  float *arg3 = (float *) (float *)0 ;
  float *arg4 = 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  float temp4 ;
  float val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Matrix_Float32_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float32_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_float, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Matrix_Float32_create" "', argument " "3"" of type '" "float *const""'"); 
  }
  arg3 = reinterpret_cast< float * >(argp3);
  ecode4 = SWIG_AsVal_float(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Matrix_Float32_create" "', argument " "4"" of type '" "float""'");
  } 
  temp4 = static_cast< float >(val4);
  arg4 = &temp4;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,(float const &)*arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float32_create__SWIG_20(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  daal::services::SharedPtr< float > *arg3 = 0 ;
  float *arg4 = 0 ;
  daal::services::Status *arg5 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  float temp4 ;
  float val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:Matrix_Float32_create",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float32_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_float_t,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Matrix_Float32_create" "', argument " "3"" of type '" "daal::services::SharedPtr< float > const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Matrix_Float32_create" "', argument " "3"" of type '" "daal::services::SharedPtr< float > const &""'"); 
  }
  arg3 = reinterpret_cast< daal::services::SharedPtr< float > * >(argp3);
  ecode4 = SWIG_AsVal_float(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Matrix_Float32_create" "', argument " "4"" of type '" "float""'");
  } 
  temp4 = static_cast< float >(val4);
  arg4 = &temp4;
  res5 = SWIG_ConvertPtr(obj4, &argp5,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "Matrix_Float32_create" "', argument " "5"" of type '" "daal::services::Status *""'"); 
  }
  arg5 = reinterpret_cast< daal::services::Status * >(argp5);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(daal::services::SharedPtr< float > const &)*arg3,(float const &)*arg4,arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float32_create__SWIG_21(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  daal::services::SharedPtr< float > *arg3 = 0 ;
  float *arg4 = 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  float temp4 ;
  float val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Matrix_Float32_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float32_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_float_t,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Matrix_Float32_create" "', argument " "3"" of type '" "daal::services::SharedPtr< float > const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Matrix_Float32_create" "', argument " "3"" of type '" "daal::services::SharedPtr< float > const &""'"); 
  }
  arg3 = reinterpret_cast< daal::services::SharedPtr< float > * >(argp3);
  ecode4 = SWIG_AsVal_float(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Matrix_Float32_create" "', argument " "4"" of type '" "float""'");
  } 
  temp4 = static_cast< float >(val4);
  arg4 = &temp4;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(daal::services::SharedPtr< float > const &)*arg3,(float const &)*arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float32_create__SWIG_22(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  float *arg4 = (float *) (float *)0 ;
  float *arg5 = 0 ;
  daal::services::Status *arg6 = (daal::services::Status *) 0 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  float temp5 ;
  float val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:Matrix_Float32_create",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float32_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Float32_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_float, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Matrix_Float32_create" "', argument " "4"" of type '" "float *const""'"); 
  }
  arg4 = reinterpret_cast< float * >(argp4);
  ecode5 = SWIG_AsVal_float(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "Matrix_Float32_create" "', argument " "5"" of type '" "float""'");
  } 
  temp5 = static_cast< float >(val5);
  arg5 = &temp5;
  res6 = SWIG_ConvertPtr(obj5, &argp6,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res6)) {
    SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "Matrix_Float32_create" "', argument " "6"" of type '" "daal::services::Status *""'"); 
  }
  arg6 = reinterpret_cast< daal::services::Status * >(argp6);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4,(float const &)*arg5,arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float32_create__SWIG_23(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  float *arg4 = (float *) (float *)0 ;
  float *arg5 = 0 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  float temp5 ;
  float val5 ;
  int ecode5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:Matrix_Float32_create",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float32_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Float32_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_float, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Matrix_Float32_create" "', argument " "4"" of type '" "float *const""'"); 
  }
  arg4 = reinterpret_cast< float * >(argp4);
  ecode5 = SWIG_AsVal_float(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "Matrix_Float32_create" "', argument " "5"" of type '" "float""'");
  } 
  temp5 = static_cast< float >(val5);
  arg5 = &temp5;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4,(float const &)*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float32_create__SWIG_24(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::services::SharedPtr< float > *arg4 = 0 ;
  float *arg5 = 0 ;
  daal::services::Status *arg6 = (daal::services::Status *) 0 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  float temp5 ;
  float val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:Matrix_Float32_create",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float32_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Float32_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  res4 = SWIG_ConvertPtr(obj3, &argp4, SWIGTYPE_p_daal__services__SharedPtrT_float_t,  0  | 0);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Matrix_Float32_create" "', argument " "4"" of type '" "daal::services::SharedPtr< float > const &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Matrix_Float32_create" "', argument " "4"" of type '" "daal::services::SharedPtr< float > const &""'"); 
  }
  arg4 = reinterpret_cast< daal::services::SharedPtr< float > * >(argp4);
  ecode5 = SWIG_AsVal_float(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "Matrix_Float32_create" "', argument " "5"" of type '" "float""'");
  } 
  temp5 = static_cast< float >(val5);
  arg5 = &temp5;
  res6 = SWIG_ConvertPtr(obj5, &argp6,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res6)) {
    SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "Matrix_Float32_create" "', argument " "6"" of type '" "daal::services::Status *""'"); 
  }
  arg6 = reinterpret_cast< daal::services::Status * >(argp6);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,(daal::services::SharedPtr< float > const &)*arg4,(float const &)*arg5,arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float32_create__SWIG_25(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::services::SharedPtr< float > *arg4 = 0 ;
  float *arg5 = 0 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  float temp5 ;
  float val5 ;
  int ecode5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:Matrix_Float32_create",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float32_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Float32_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  res4 = SWIG_ConvertPtr(obj3, &argp4, SWIGTYPE_p_daal__services__SharedPtrT_float_t,  0  | 0);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Matrix_Float32_create" "', argument " "4"" of type '" "daal::services::SharedPtr< float > const &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Matrix_Float32_create" "', argument " "4"" of type '" "daal::services::SharedPtr< float > const &""'"); 
  }
  arg4 = reinterpret_cast< daal::services::SharedPtr< float > * >(argp4);
  ecode5 = SWIG_AsVal_float(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "Matrix_Float32_create" "', argument " "5"" of type '" "float""'");
  } 
  temp5 = static_cast< float >(val5);
  arg5 = &temp5;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,(daal::services::SharedPtr< float > const &)*arg4,(float const &)*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float32_create__SWIG_26(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  daal::data_management::interface1::NumericTable::AllocationFlag arg3 ;
  float *arg4 = 0 ;
  daal::services::Status *arg5 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  int val3 ;
  int ecode3 = 0 ;
  float temp4 ;
  float val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:Matrix_Float32_create",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float32_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Float32_create" "', argument " "3"" of type '" "daal::data_management::interface1::NumericTable::AllocationFlag""'");
  } 
  arg3 = static_cast< daal::data_management::interface1::NumericTable::AllocationFlag >(val3);
  ecode4 = SWIG_AsVal_float(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Matrix_Float32_create" "', argument " "4"" of type '" "float""'");
  } 
  temp4 = static_cast< float >(val4);
  arg4 = &temp4;
  res5 = SWIG_ConvertPtr(obj4, &argp5,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "Matrix_Float32_create" "', argument " "5"" of type '" "daal::services::Status *""'"); 
  }
  arg5 = reinterpret_cast< daal::services::Status * >(argp5);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,(float const &)*arg4,arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float32_create__SWIG_27(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  daal::data_management::interface1::NumericTable::AllocationFlag arg3 ;
  float *arg4 = 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  int val3 ;
  int ecode3 = 0 ;
  float temp4 ;
  float val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Matrix_Float32_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float32_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Float32_create" "', argument " "3"" of type '" "daal::data_management::interface1::NumericTable::AllocationFlag""'");
  } 
  arg3 = static_cast< daal::data_management::interface1::NumericTable::AllocationFlag >(val3);
  ecode4 = SWIG_AsVal_float(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Matrix_Float32_create" "', argument " "4"" of type '" "float""'");
  } 
  temp4 = static_cast< float >(val4);
  arg4 = &temp4;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,(float const &)*arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float32_create__SWIG_28(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::interface1::NumericTable::AllocationFlag arg4 ;
  float *arg5 = 0 ;
  daal::services::Status *arg6 = (daal::services::Status *) 0 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  float temp5 ;
  float val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:Matrix_Float32_create",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float32_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Float32_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Matrix_Float32_create" "', argument " "4"" of type '" "daal::data_management::interface1::NumericTable::AllocationFlag""'");
  } 
  arg4 = static_cast< daal::data_management::interface1::NumericTable::AllocationFlag >(val4);
  ecode5 = SWIG_AsVal_float(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "Matrix_Float32_create" "', argument " "5"" of type '" "float""'");
  } 
  temp5 = static_cast< float >(val5);
  arg5 = &temp5;
  res6 = SWIG_ConvertPtr(obj5, &argp6,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res6)) {
    SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "Matrix_Float32_create" "', argument " "6"" of type '" "daal::services::Status *""'"); 
  }
  arg6 = reinterpret_cast< daal::services::Status * >(argp6);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4,(float const &)*arg5,arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float32_create__SWIG_29(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::interface1::NumericTable::AllocationFlag arg4 ;
  float *arg5 = 0 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  float temp5 ;
  float val5 ;
  int ecode5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:Matrix_Float32_create",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Float32_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Float32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Float32_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Matrix_Float32_create" "', argument " "4"" of type '" "daal::data_management::interface1::NumericTable::AllocationFlag""'");
  } 
  arg4 = static_cast< daal::data_management::interface1::NumericTable::AllocationFlag >(val4);
  ecode5 = SWIG_AsVal_float(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "Matrix_Float32_create" "', argument " "5"" of type '" "float""'");
  } 
  temp5 = static_cast< float >(val5);
  arg5 = &temp5;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4,(float const &)*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_Matrix_Float32(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Matrix< float > *arg1 = (daal::data_management::interface1::Matrix< float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_Matrix_Float32",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Matrix_Float32" "', argument " "1"" of type '" "daal::data_management::interface1::Matrix< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Matrix< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Matrix< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Matrix_Float32" "', argument " "1"" of type '" "daal::data_management::interface1::Matrix< float > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float32_create__SWIG_30(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< float > *arg1 = 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::services::SharedPtr< float > r4p1 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Matrix_Float32_create",&obj0)) SWIG_fail;
  {
    int is_new_object = 0;
    PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj0, NPY_FLOAT)
      :obj_to_array_contiguous_allow_conversion(obj0, NPY_FLOAT, &is_new_object));
    if (!array || !require_dimensions(array, 2) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p1 = daal::services::SharedPtr< float >((float*)array_data(array), NumpyDeleter(array));
    arg1 = &r4p1;
    arg2 = (size_t) array_size(array,1);
    arg3 = (size_t) array_size(array,0);
    // we need it increment the ref-count if we use the obj0 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj0) Py_INCREF(array);
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal_data_management_interface1_Matrix_Sl_float_Sg__create__SWIG_30((daal::services::SharedPtr< float > const &)*arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float32_create__SWIG_31(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< float > *arg1 = 0 ;
  size_t arg2 ;
  size_t arg3 ;
  float *arg4 = 0 ;
  daal::services::SharedPtr< float > r4p1 ;
  float temp4 ;
  float val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Matrix_Float32_create",&obj0,&obj1)) SWIG_fail;
  {
    int is_new_object = 0;
    PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj0, NPY_FLOAT)
      :obj_to_array_contiguous_allow_conversion(obj0, NPY_FLOAT, &is_new_object));
    if (!array || !require_dimensions(array, 2) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p1 = daal::services::SharedPtr< float >((float*)array_data(array), NumpyDeleter(array));
    arg1 = &r4p1;
    arg2 = (size_t) array_size(array,1);
    arg3 = (size_t) array_size(array,0);
    // we need it increment the ref-count if we use the obj0 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj0) Py_INCREF(array);
  }
  ecode4 = SWIG_AsVal_float(obj1, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Matrix_Float32_create" "', argument " "4"" of type '" "float""'");
  } 
  temp4 = static_cast< float >(val4);
  arg4 = &temp4;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal_data_management_interface1_Matrix_Sl_float_Sg__create__SWIG_31((daal::services::SharedPtr< float > const &)*arg1,arg2,arg3,(float const &)*arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Float32_create(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[7];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 6) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_Matrix_Float32_create__SWIG_4(self, args);
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_Matrix_Float32_create__SWIG_11(self, args);
    }
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_Matrix_Float32_create__SWIG_3(self, args);
    }
  }
  if (argc == 1) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_FLOAT))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      if (argc <= 1) {
        return _wrap_Matrix_Float32_create__SWIG_30(self, args);
      }
      if (argc <= 2) {
        return _wrap_Matrix_Float32_create__SWIG_30(self, args);
      }
      return _wrap_Matrix_Float32_create__SWIG_30(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_Matrix_Float32_create__SWIG_10(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_Matrix_Float32_create__SWIG_2(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_FLOAT))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      {
        int res = SWIG_AsVal_float(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_Matrix_Float32_create__SWIG_31(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_Matrix_Float32_create__SWIG_9(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__SharedPtrT_float_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_Matrix_Float32_create__SWIG_6(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_float, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_Matrix_Float32_create__SWIG_1(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_Matrix_Float32_create__SWIG_15(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = SWIG_ConvertPtr(argv[3], 0, SWIGTYPE_p_daal__services__SharedPtrT_float_t, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_Matrix_Float32_create__SWIG_13(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_float, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_Matrix_Float32_create__SWIG_8(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            return _wrap_Matrix_Float32_create__SWIG_17(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_float, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_Matrix_Float32_create__SWIG_0(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__SharedPtrT_float_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_Matrix_Float32_create__SWIG_5(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_float, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          {
            int res = SWIG_AsVal_float(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            return _wrap_Matrix_Float32_create__SWIG_19(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_float_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          {
            int res = SWIG_AsVal_float(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            return _wrap_Matrix_Float32_create__SWIG_21(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_Matrix_Float32_create__SWIG_14(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_float(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            return _wrap_Matrix_Float32_create__SWIG_27(self, args);
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_float, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            void *vptr = 0;
            int res = SWIG_ConvertPtr(argv[4], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_Matrix_Float32_create__SWIG_7(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = SWIG_ConvertPtr(argv[3], 0, SWIGTYPE_p_daal__services__SharedPtrT_float_t, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            void *vptr = 0;
            int res = SWIG_ConvertPtr(argv[4], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_Matrix_Float32_create__SWIG_12(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = SWIG_ConvertPtr(argv[3], 0, SWIGTYPE_p_daal__services__SharedPtrT_float_t, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            {
              int res = SWIG_AsVal_float(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              return _wrap_Matrix_Float32_create__SWIG_25(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_float, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            {
              int res = SWIG_AsVal_float(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              return _wrap_Matrix_Float32_create__SWIG_23(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            void *vptr = 0;
            int res = SWIG_ConvertPtr(argv[4], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_Matrix_Float32_create__SWIG_16(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_float(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              return _wrap_Matrix_Float32_create__SWIG_29(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_float, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          {
            int res = SWIG_AsVal_float(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            void *vptr = 0;
            int res = SWIG_ConvertPtr(argv[4], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_Matrix_Float32_create__SWIG_18(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_float_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          {
            int res = SWIG_AsVal_float(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            void *vptr = 0;
            int res = SWIG_ConvertPtr(argv[4], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_Matrix_Float32_create__SWIG_20(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_float(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            void *vptr = 0;
            int res = SWIG_ConvertPtr(argv[4], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_Matrix_Float32_create__SWIG_26(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = SWIG_ConvertPtr(argv[3], 0, SWIGTYPE_p_daal__services__SharedPtrT_float_t, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            {
              int res = SWIG_AsVal_float(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              void *vptr = 0;
              int res = SWIG_ConvertPtr(argv[5], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_Matrix_Float32_create__SWIG_24(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_float, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            {
              int res = SWIG_AsVal_float(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              void *vptr = 0;
              int res = SWIG_ConvertPtr(argv[5], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_Matrix_Float32_create__SWIG_22(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_float(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              void *vptr = 0;
              int res = SWIG_ConvertPtr(argv[5], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_Matrix_Float32_create__SWIG_28(self, args);
              }
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Matrix_Float32_create'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::Matrix< float >::create(size_t,size_t,float *const,daal::services::Status *)\n"
    "    daal::data_management::interface1::Matrix< float >::create(size_t,size_t,float *const)\n"
    "    daal::data_management::interface1::Matrix< float >::create(size_t,size_t)\n"
    "    daal::data_management::interface1::Matrix< float >::create(size_t)\n"
    "    daal::data_management::interface1::Matrix< float >::create()\n"
    "    daal::data_management::interface1::Matrix< float >::create(size_t,size_t,daal::services::SharedPtr< float > &,daal::services::Status *)\n"
    "    daal::data_management::interface1::Matrix< float >::create(size_t,size_t,daal::services::SharedPtr< float > &)\n"
    "    daal::data_management::interface1::Matrix< float >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t,float *const,daal::services::Status *)\n"
    "    daal::data_management::interface1::Matrix< float >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t,float *const)\n"
    "    daal::data_management::interface1::Matrix< float >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t)\n"
    "    daal::data_management::interface1::Matrix< float >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t)\n"
    "    daal::data_management::interface1::Matrix< float >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual)\n"
    "    daal::data_management::interface1::Matrix< float >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t,daal::services::SharedPtr< float > const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::Matrix< float >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t,daal::services::SharedPtr< float > const &)\n"
    "    daal::data_management::interface1::Matrix< float >::create(size_t,size_t,daal::data_management::interface1::NumericTable::AllocationFlag,daal::services::Status *)\n"
    "    daal::data_management::interface1::Matrix< float >::create(size_t,size_t,daal::data_management::interface1::NumericTable::AllocationFlag)\n"
    "    daal::data_management::interface1::Matrix< float >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t,daal::data_management::interface1::NumericTable::AllocationFlag,daal::services::Status *)\n"
    "    daal::data_management::interface1::Matrix< float >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t,daal::data_management::interface1::NumericTable::AllocationFlag)\n"
    "    daal::data_management::interface1::Matrix< float >::create(size_t,size_t,float *const,float const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::Matrix< float >::create(size_t,size_t,float *const,float const &)\n"
    "    daal::data_management::interface1::Matrix< float >::create(size_t,size_t,daal::services::SharedPtr< float > const &,float const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::Matrix< float >::create(size_t,size_t,daal::services::SharedPtr< float > const &,float const &)\n"
    "    daal::data_management::interface1::Matrix< float >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t,float *const,float const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::Matrix< float >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t,float *const,float const &)\n"
    "    daal::data_management::interface1::Matrix< float >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t,daal::services::SharedPtr< float > const &,float const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::Matrix< float >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t,daal::services::SharedPtr< float > const &,float const &)\n"
    "    daal::data_management::interface1::Matrix< float >::create(size_t,size_t,daal::data_management::interface1::NumericTable::AllocationFlag,float const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::Matrix< float >::create(size_t,size_t,daal::data_management::interface1::NumericTable::AllocationFlag,float const &)\n"
    "    daal::data_management::interface1::Matrix< float >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t,daal::data_management::interface1::NumericTable::AllocationFlag,float const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::Matrix< float >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t,daal::data_management::interface1::NumericTable::AllocationFlag,float const &)\n"
    "    daal::data_management::interface1::Matrix< float >::create(daal::services::SharedPtr< float > const &,size_t,size_t)\n"
    "    daal::data_management::interface1::Matrix< float >::daal_data_management_interface1_Matrix_Sl_float_Sg__create__SWIG_31(daal::services::SharedPtr< float > const &,size_t,size_t,float const &)\n");
  return 0;
}


SWIGINTERN PyObject *Matrix_Float32_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_Matrix_Intc_serializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)":Matrix_Intc_serializationTag")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)daal::data_management::interface1::Matrix< int >::SWIGTEMPLATEDISAMBIGUATOR serializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Intc_getSerializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Matrix< int > *arg1 = (daal::data_management::interface1::Matrix< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Matrix_Intc_getSerializationTag",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Matrix_Intc_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::Matrix< int > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Matrix< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Matrix< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Matrix< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::Matrix< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Matrix< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Matrix_Intc_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::Matrix< int > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)((daal::data_management::interface1::Matrix< int > const *)arg1)->getSerializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Intc_create__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  int *arg3 = (int *) (int *)0 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Matrix_Intc_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Intc_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Intc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_int, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Matrix_Intc_create" "', argument " "3"" of type '" "int *const""'"); 
  }
  arg3 = reinterpret_cast< int * >(argp3);
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Matrix_Intc_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Intc_create__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  int *arg3 = (int *) (int *)0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Matrix_Intc_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Intc_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Intc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_int, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Matrix_Intc_create" "', argument " "3"" of type '" "int *const""'"); 
  }
  arg3 = reinterpret_cast< int * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Intc_create__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Matrix_Intc_create",&obj0,&obj1)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Intc_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Intc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Intc_create__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t val1 ;
  int ecode1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Matrix_Intc_create",&obj0)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Intc_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Intc_create__SWIG_4(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)":Matrix_Intc_create")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< int >::SWIGTEMPLATEDISAMBIGUATOR create();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Intc_create__SWIG_5(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  daal::services::SharedPtr< int > *arg3 = 0 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Matrix_Intc_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Intc_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Intc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_int_t,  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Matrix_Intc_create" "', argument " "3"" of type '" "daal::services::SharedPtr< int > &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Matrix_Intc_create" "', argument " "3"" of type '" "daal::services::SharedPtr< int > &""'"); 
  }
  arg3 = reinterpret_cast< daal::services::SharedPtr< int > * >(argp3);
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Matrix_Intc_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,*arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Intc_create__SWIG_6(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  daal::services::SharedPtr< int > *arg3 = 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Matrix_Intc_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Intc_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Intc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_int_t,  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Matrix_Intc_create" "', argument " "3"" of type '" "daal::services::SharedPtr< int > &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Matrix_Intc_create" "', argument " "3"" of type '" "daal::services::SharedPtr< int > &""'"); 
  }
  arg3 = reinterpret_cast< daal::services::SharedPtr< int > * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Intc_create__SWIG_7(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  int *arg4 = (int *) (int *)0 ;
  daal::services::Status *arg5 = (daal::services::Status *) 0 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:Matrix_Intc_create",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Intc_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Intc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Intc_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_int, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Matrix_Intc_create" "', argument " "4"" of type '" "int *const""'"); 
  }
  arg4 = reinterpret_cast< int * >(argp4);
  res5 = SWIG_ConvertPtr(obj4, &argp5,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "Matrix_Intc_create" "', argument " "5"" of type '" "daal::services::Status *""'"); 
  }
  arg5 = reinterpret_cast< daal::services::Status * >(argp5);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4,arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Intc_create__SWIG_8(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  int *arg4 = (int *) (int *)0 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Matrix_Intc_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Intc_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Intc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Intc_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_int, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Matrix_Intc_create" "', argument " "4"" of type '" "int *const""'"); 
  }
  arg4 = reinterpret_cast< int * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Intc_create__SWIG_9(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Matrix_Intc_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Intc_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Intc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Intc_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Intc_create__SWIG_10(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Matrix_Intc_create",&obj0,&obj1)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Intc_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Intc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Intc_create__SWIG_11(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  int val1 ;
  int ecode1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Matrix_Intc_create",&obj0)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Intc_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Intc_create__SWIG_12(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::services::SharedPtr< int > *arg4 = 0 ;
  daal::services::Status *arg5 = (daal::services::Status *) 0 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:Matrix_Intc_create",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Intc_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Intc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Intc_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  res4 = SWIG_ConvertPtr(obj3, &argp4, SWIGTYPE_p_daal__services__SharedPtrT_int_t,  0  | 0);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Matrix_Intc_create" "', argument " "4"" of type '" "daal::services::SharedPtr< int > const &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Matrix_Intc_create" "', argument " "4"" of type '" "daal::services::SharedPtr< int > const &""'"); 
  }
  arg4 = reinterpret_cast< daal::services::SharedPtr< int > * >(argp4);
  res5 = SWIG_ConvertPtr(obj4, &argp5,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "Matrix_Intc_create" "', argument " "5"" of type '" "daal::services::Status *""'"); 
  }
  arg5 = reinterpret_cast< daal::services::Status * >(argp5);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,(daal::services::SharedPtr< int > const &)*arg4,arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Intc_create__SWIG_13(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::services::SharedPtr< int > *arg4 = 0 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Matrix_Intc_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Intc_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Intc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Intc_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  res4 = SWIG_ConvertPtr(obj3, &argp4, SWIGTYPE_p_daal__services__SharedPtrT_int_t,  0  | 0);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Matrix_Intc_create" "', argument " "4"" of type '" "daal::services::SharedPtr< int > const &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Matrix_Intc_create" "', argument " "4"" of type '" "daal::services::SharedPtr< int > const &""'"); 
  }
  arg4 = reinterpret_cast< daal::services::SharedPtr< int > * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,(daal::services::SharedPtr< int > const &)*arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Intc_create__SWIG_14(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  daal::data_management::interface1::NumericTable::AllocationFlag arg3 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  int val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Matrix_Intc_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Intc_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Intc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Intc_create" "', argument " "3"" of type '" "daal::data_management::interface1::NumericTable::AllocationFlag""'");
  } 
  arg3 = static_cast< daal::data_management::interface1::NumericTable::AllocationFlag >(val3);
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Matrix_Intc_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Intc_create__SWIG_15(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  daal::data_management::interface1::NumericTable::AllocationFlag arg3 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  int val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:Matrix_Intc_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Intc_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Intc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Intc_create" "', argument " "3"" of type '" "daal::data_management::interface1::NumericTable::AllocationFlag""'");
  } 
  arg3 = static_cast< daal::data_management::interface1::NumericTable::AllocationFlag >(val3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Intc_create__SWIG_16(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::interface1::NumericTable::AllocationFlag arg4 ;
  daal::services::Status *arg5 = (daal::services::Status *) 0 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:Matrix_Intc_create",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Intc_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Intc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Intc_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Matrix_Intc_create" "', argument " "4"" of type '" "daal::data_management::interface1::NumericTable::AllocationFlag""'");
  } 
  arg4 = static_cast< daal::data_management::interface1::NumericTable::AllocationFlag >(val4);
  res5 = SWIG_ConvertPtr(obj4, &argp5,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "Matrix_Intc_create" "', argument " "5"" of type '" "daal::services::Status *""'"); 
  }
  arg5 = reinterpret_cast< daal::services::Status * >(argp5);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4,arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Intc_create__SWIG_17(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::interface1::NumericTable::AllocationFlag arg4 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Matrix_Intc_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Intc_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Intc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Intc_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Matrix_Intc_create" "', argument " "4"" of type '" "daal::data_management::interface1::NumericTable::AllocationFlag""'");
  } 
  arg4 = static_cast< daal::data_management::interface1::NumericTable::AllocationFlag >(val4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Intc_create__SWIG_18(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  int *arg3 = (int *) (int *)0 ;
  int *arg4 = 0 ;
  daal::services::Status *arg5 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  int temp4 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:Matrix_Intc_create",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Intc_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Intc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_int, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Matrix_Intc_create" "', argument " "3"" of type '" "int *const""'"); 
  }
  arg3 = reinterpret_cast< int * >(argp3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Matrix_Intc_create" "', argument " "4"" of type '" "int""'");
  } 
  temp4 = static_cast< int >(val4);
  arg4 = &temp4;
  res5 = SWIG_ConvertPtr(obj4, &argp5,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "Matrix_Intc_create" "', argument " "5"" of type '" "daal::services::Status *""'"); 
  }
  arg5 = reinterpret_cast< daal::services::Status * >(argp5);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,(int const &)*arg4,arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Intc_create__SWIG_19(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  int *arg3 = (int *) (int *)0 ;
  int *arg4 = 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  int temp4 ;
  int val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Matrix_Intc_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Intc_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Intc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_int, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Matrix_Intc_create" "', argument " "3"" of type '" "int *const""'"); 
  }
  arg3 = reinterpret_cast< int * >(argp3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Matrix_Intc_create" "', argument " "4"" of type '" "int""'");
  } 
  temp4 = static_cast< int >(val4);
  arg4 = &temp4;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,(int const &)*arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Intc_create__SWIG_20(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  daal::services::SharedPtr< int > *arg3 = 0 ;
  int *arg4 = 0 ;
  daal::services::Status *arg5 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  int temp4 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:Matrix_Intc_create",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Intc_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Intc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_int_t,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Matrix_Intc_create" "', argument " "3"" of type '" "daal::services::SharedPtr< int > const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Matrix_Intc_create" "', argument " "3"" of type '" "daal::services::SharedPtr< int > const &""'"); 
  }
  arg3 = reinterpret_cast< daal::services::SharedPtr< int > * >(argp3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Matrix_Intc_create" "', argument " "4"" of type '" "int""'");
  } 
  temp4 = static_cast< int >(val4);
  arg4 = &temp4;
  res5 = SWIG_ConvertPtr(obj4, &argp5,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "Matrix_Intc_create" "', argument " "5"" of type '" "daal::services::Status *""'"); 
  }
  arg5 = reinterpret_cast< daal::services::Status * >(argp5);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(daal::services::SharedPtr< int > const &)*arg3,(int const &)*arg4,arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Intc_create__SWIG_21(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  daal::services::SharedPtr< int > *arg3 = 0 ;
  int *arg4 = 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  int temp4 ;
  int val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Matrix_Intc_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Intc_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Intc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_int_t,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Matrix_Intc_create" "', argument " "3"" of type '" "daal::services::SharedPtr< int > const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Matrix_Intc_create" "', argument " "3"" of type '" "daal::services::SharedPtr< int > const &""'"); 
  }
  arg3 = reinterpret_cast< daal::services::SharedPtr< int > * >(argp3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Matrix_Intc_create" "', argument " "4"" of type '" "int""'");
  } 
  temp4 = static_cast< int >(val4);
  arg4 = &temp4;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(daal::services::SharedPtr< int > const &)*arg3,(int const &)*arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Intc_create__SWIG_22(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  int *arg4 = (int *) (int *)0 ;
  int *arg5 = 0 ;
  daal::services::Status *arg6 = (daal::services::Status *) 0 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  int temp5 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:Matrix_Intc_create",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Intc_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Intc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Intc_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_int, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Matrix_Intc_create" "', argument " "4"" of type '" "int *const""'"); 
  }
  arg4 = reinterpret_cast< int * >(argp4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "Matrix_Intc_create" "', argument " "5"" of type '" "int""'");
  } 
  temp5 = static_cast< int >(val5);
  arg5 = &temp5;
  res6 = SWIG_ConvertPtr(obj5, &argp6,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res6)) {
    SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "Matrix_Intc_create" "', argument " "6"" of type '" "daal::services::Status *""'"); 
  }
  arg6 = reinterpret_cast< daal::services::Status * >(argp6);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4,(int const &)*arg5,arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Intc_create__SWIG_23(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  int *arg4 = (int *) (int *)0 ;
  int *arg5 = 0 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  int temp5 ;
  int val5 ;
  int ecode5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:Matrix_Intc_create",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Intc_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Intc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Intc_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_int, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Matrix_Intc_create" "', argument " "4"" of type '" "int *const""'"); 
  }
  arg4 = reinterpret_cast< int * >(argp4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "Matrix_Intc_create" "', argument " "5"" of type '" "int""'");
  } 
  temp5 = static_cast< int >(val5);
  arg5 = &temp5;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4,(int const &)*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Intc_create__SWIG_24(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::services::SharedPtr< int > *arg4 = 0 ;
  int *arg5 = 0 ;
  daal::services::Status *arg6 = (daal::services::Status *) 0 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  int temp5 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:Matrix_Intc_create",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Intc_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Intc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Intc_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  res4 = SWIG_ConvertPtr(obj3, &argp4, SWIGTYPE_p_daal__services__SharedPtrT_int_t,  0  | 0);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Matrix_Intc_create" "', argument " "4"" of type '" "daal::services::SharedPtr< int > const &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Matrix_Intc_create" "', argument " "4"" of type '" "daal::services::SharedPtr< int > const &""'"); 
  }
  arg4 = reinterpret_cast< daal::services::SharedPtr< int > * >(argp4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "Matrix_Intc_create" "', argument " "5"" of type '" "int""'");
  } 
  temp5 = static_cast< int >(val5);
  arg5 = &temp5;
  res6 = SWIG_ConvertPtr(obj5, &argp6,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res6)) {
    SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "Matrix_Intc_create" "', argument " "6"" of type '" "daal::services::Status *""'"); 
  }
  arg6 = reinterpret_cast< daal::services::Status * >(argp6);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,(daal::services::SharedPtr< int > const &)*arg4,(int const &)*arg5,arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Intc_create__SWIG_25(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::services::SharedPtr< int > *arg4 = 0 ;
  int *arg5 = 0 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  int temp5 ;
  int val5 ;
  int ecode5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:Matrix_Intc_create",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Intc_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Intc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Intc_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  res4 = SWIG_ConvertPtr(obj3, &argp4, SWIGTYPE_p_daal__services__SharedPtrT_int_t,  0  | 0);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Matrix_Intc_create" "', argument " "4"" of type '" "daal::services::SharedPtr< int > const &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Matrix_Intc_create" "', argument " "4"" of type '" "daal::services::SharedPtr< int > const &""'"); 
  }
  arg4 = reinterpret_cast< daal::services::SharedPtr< int > * >(argp4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "Matrix_Intc_create" "', argument " "5"" of type '" "int""'");
  } 
  temp5 = static_cast< int >(val5);
  arg5 = &temp5;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,(daal::services::SharedPtr< int > const &)*arg4,(int const &)*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Intc_create__SWIG_26(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  daal::data_management::interface1::NumericTable::AllocationFlag arg3 ;
  int *arg4 = 0 ;
  daal::services::Status *arg5 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  int val3 ;
  int ecode3 = 0 ;
  int temp4 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:Matrix_Intc_create",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Intc_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Intc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Intc_create" "', argument " "3"" of type '" "daal::data_management::interface1::NumericTable::AllocationFlag""'");
  } 
  arg3 = static_cast< daal::data_management::interface1::NumericTable::AllocationFlag >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Matrix_Intc_create" "', argument " "4"" of type '" "int""'");
  } 
  temp4 = static_cast< int >(val4);
  arg4 = &temp4;
  res5 = SWIG_ConvertPtr(obj4, &argp5,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "Matrix_Intc_create" "', argument " "5"" of type '" "daal::services::Status *""'"); 
  }
  arg5 = reinterpret_cast< daal::services::Status * >(argp5);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,(int const &)*arg4,arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Intc_create__SWIG_27(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  size_t arg2 ;
  daal::data_management::interface1::NumericTable::AllocationFlag arg3 ;
  int *arg4 = 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  int val3 ;
  int ecode3 = 0 ;
  int temp4 ;
  int val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:Matrix_Intc_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Intc_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Intc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Intc_create" "', argument " "3"" of type '" "daal::data_management::interface1::NumericTable::AllocationFlag""'");
  } 
  arg3 = static_cast< daal::data_management::interface1::NumericTable::AllocationFlag >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Matrix_Intc_create" "', argument " "4"" of type '" "int""'");
  } 
  temp4 = static_cast< int >(val4);
  arg4 = &temp4;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,(int const &)*arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Intc_create__SWIG_28(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::interface1::NumericTable::AllocationFlag arg4 ;
  int *arg5 = 0 ;
  daal::services::Status *arg6 = (daal::services::Status *) 0 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  int temp5 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:Matrix_Intc_create",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Intc_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Intc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Intc_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Matrix_Intc_create" "', argument " "4"" of type '" "daal::data_management::interface1::NumericTable::AllocationFlag""'");
  } 
  arg4 = static_cast< daal::data_management::interface1::NumericTable::AllocationFlag >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "Matrix_Intc_create" "', argument " "5"" of type '" "int""'");
  } 
  temp5 = static_cast< int >(val5);
  arg5 = &temp5;
  res6 = SWIG_ConvertPtr(obj5, &argp6,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res6)) {
    SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "Matrix_Intc_create" "', argument " "6"" of type '" "daal::services::Status *""'"); 
  }
  arg6 = reinterpret_cast< daal::services::Status * >(argp6);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4,(int const &)*arg5,arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Intc_create__SWIG_29(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DictionaryIface::FeaturesEqual arg1 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::interface1::NumericTable::AllocationFlag arg4 ;
  int *arg5 = 0 ;
  int val1 ;
  int ecode1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  int temp5 ;
  int val5 ;
  int ecode5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:Matrix_Intc_create",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Matrix_Intc_create" "', argument " "1"" of type '" "daal::data_management::interface1::DictionaryIface::FeaturesEqual""'");
  } 
  arg1 = static_cast< daal::data_management::interface1::DictionaryIface::FeaturesEqual >(val1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Matrix_Intc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Matrix_Intc_create" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Matrix_Intc_create" "', argument " "4"" of type '" "daal::data_management::interface1::NumericTable::AllocationFlag""'");
  } 
  arg4 = static_cast< daal::data_management::interface1::NumericTable::AllocationFlag >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "Matrix_Intc_create" "', argument " "5"" of type '" "int""'");
  } 
  temp5 = static_cast< int >(val5);
  arg5 = &temp5;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::Matrix< int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3,arg4,(int const &)*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_Matrix_Intc(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::Matrix< int > *arg1 = (daal::data_management::interface1::Matrix< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_Matrix_Intc",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Matrix_Intc" "', argument " "1"" of type '" "daal::data_management::interface1::Matrix< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Matrix< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::Matrix< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Matrix_Intc" "', argument " "1"" of type '" "daal::data_management::interface1::Matrix< int > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Intc_create__SWIG_30(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< int > *arg1 = 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::services::SharedPtr< int > r4p1 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:Matrix_Intc_create",&obj0)) SWIG_fail;
  {
    int is_new_object = 0;
    PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj0, NPY_INT)
      :obj_to_array_contiguous_allow_conversion(obj0, NPY_INT, &is_new_object));
    if (!array || !require_dimensions(array, 2) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p1 = daal::services::SharedPtr< int >((int*)array_data(array), NumpyDeleter(array));
    arg1 = &r4p1;
    arg2 = (size_t) array_size(array,1);
    arg3 = (size_t) array_size(array,0);
    // we need it increment the ref-count if we use the obj0 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj0) Py_INCREF(array);
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal_data_management_interface1_Matrix_Sl_int_Sg__create__SWIG_30((daal::services::SharedPtr< int > const &)*arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Intc_create__SWIG_31(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< int > *arg1 = 0 ;
  size_t arg2 ;
  size_t arg3 ;
  int *arg4 = 0 ;
  daal::services::SharedPtr< int > r4p1 ;
  int temp4 ;
  int val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:Matrix_Intc_create",&obj0,&obj1)) SWIG_fail;
  {
    int is_new_object = 0;
    PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
      ? obj_to_array_no_conversion(obj0, NPY_INT)
      :obj_to_array_contiguous_allow_conversion(obj0, NPY_INT, &is_new_object));
    if (!array || !require_dimensions(array, 2) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
    // we provide the SharedPtr with a deleter which decrements the pyref
    r4p1 = daal::services::SharedPtr< int >((int*)array_data(array), NumpyDeleter(array));
    arg1 = &r4p1;
    arg2 = (size_t) array_size(array,1);
    arg3 = (size_t) array_size(array,0);
    // we need it increment the ref-count if we use the obj0 array in-place
    // if we copied/converted it we already own our own reference
    if((PyObject*)array == obj0) Py_INCREF(array);
  }
  ecode4 = SWIG_AsVal_int(obj1, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Matrix_Intc_create" "', argument " "4"" of type '" "int""'");
  } 
  temp4 = static_cast< int >(val4);
  arg4 = &temp4;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal_data_management_interface1_Matrix_Sl_int_Sg__create__SWIG_31((daal::services::SharedPtr< int > const &)*arg1,arg2,arg3,(int const &)*arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::Matrix< int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Matrix_Intc_create(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[7];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 6) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_Matrix_Intc_create__SWIG_4(self, args);
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_Matrix_Intc_create__SWIG_11(self, args);
    }
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_Matrix_Intc_create__SWIG_3(self, args);
    }
  }
  if (argc == 1) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_INT))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      if (argc <= 1) {
        return _wrap_Matrix_Intc_create__SWIG_30(self, args);
      }
      if (argc <= 2) {
        return _wrap_Matrix_Intc_create__SWIG_30(self, args);
      }
      return _wrap_Matrix_Intc_create__SWIG_30(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_Matrix_Intc_create__SWIG_10(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_Matrix_Intc_create__SWIG_2(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_INT))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_Matrix_Intc_create__SWIG_31(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_Matrix_Intc_create__SWIG_9(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__SharedPtrT_int_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_Matrix_Intc_create__SWIG_6(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_int, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_Matrix_Intc_create__SWIG_1(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_Matrix_Intc_create__SWIG_15(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = SWIG_ConvertPtr(argv[3], 0, SWIGTYPE_p_daal__services__SharedPtrT_int_t, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_Matrix_Intc_create__SWIG_13(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_int, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_Matrix_Intc_create__SWIG_8(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            return _wrap_Matrix_Intc_create__SWIG_17(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_int, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_Matrix_Intc_create__SWIG_0(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__SharedPtrT_int_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_Matrix_Intc_create__SWIG_5(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_int, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            return _wrap_Matrix_Intc_create__SWIG_19(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_int_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            return _wrap_Matrix_Intc_create__SWIG_21(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_Matrix_Intc_create__SWIG_14(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            return _wrap_Matrix_Intc_create__SWIG_27(self, args);
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_int, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            void *vptr = 0;
            int res = SWIG_ConvertPtr(argv[4], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_Matrix_Intc_create__SWIG_7(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = SWIG_ConvertPtr(argv[3], 0, SWIGTYPE_p_daal__services__SharedPtrT_int_t, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            void *vptr = 0;
            int res = SWIG_ConvertPtr(argv[4], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_Matrix_Intc_create__SWIG_12(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = SWIG_ConvertPtr(argv[3], 0, SWIGTYPE_p_daal__services__SharedPtrT_int_t, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              return _wrap_Matrix_Intc_create__SWIG_25(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_int, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              return _wrap_Matrix_Intc_create__SWIG_23(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            void *vptr = 0;
            int res = SWIG_ConvertPtr(argv[4], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_Matrix_Intc_create__SWIG_16(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              return _wrap_Matrix_Intc_create__SWIG_29(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_int, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            void *vptr = 0;
            int res = SWIG_ConvertPtr(argv[4], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_Matrix_Intc_create__SWIG_18(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_int_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            void *vptr = 0;
            int res = SWIG_ConvertPtr(argv[4], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_Matrix_Intc_create__SWIG_20(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            void *vptr = 0;
            int res = SWIG_ConvertPtr(argv[4], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_Matrix_Intc_create__SWIG_26(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = SWIG_ConvertPtr(argv[3], 0, SWIGTYPE_p_daal__services__SharedPtrT_int_t, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              void *vptr = 0;
              int res = SWIG_ConvertPtr(argv[5], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_Matrix_Intc_create__SWIG_24(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_int, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              void *vptr = 0;
              int res = SWIG_ConvertPtr(argv[5], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_Matrix_Intc_create__SWIG_22(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              void *vptr = 0;
              int res = SWIG_ConvertPtr(argv[5], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_Matrix_Intc_create__SWIG_28(self, args);
              }
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'Matrix_Intc_create'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::Matrix< int >::create(size_t,size_t,int *const,daal::services::Status *)\n"
    "    daal::data_management::interface1::Matrix< int >::create(size_t,size_t,int *const)\n"
    "    daal::data_management::interface1::Matrix< int >::create(size_t,size_t)\n"
    "    daal::data_management::interface1::Matrix< int >::create(size_t)\n"
    "    daal::data_management::interface1::Matrix< int >::create()\n"
    "    daal::data_management::interface1::Matrix< int >::create(size_t,size_t,daal::services::SharedPtr< int > &,daal::services::Status *)\n"
    "    daal::data_management::interface1::Matrix< int >::create(size_t,size_t,daal::services::SharedPtr< int > &)\n"
    "    daal::data_management::interface1::Matrix< int >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t,int *const,daal::services::Status *)\n"
    "    daal::data_management::interface1::Matrix< int >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t,int *const)\n"
    "    daal::data_management::interface1::Matrix< int >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t)\n"
    "    daal::data_management::interface1::Matrix< int >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t)\n"
    "    daal::data_management::interface1::Matrix< int >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual)\n"
    "    daal::data_management::interface1::Matrix< int >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t,daal::services::SharedPtr< int > const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::Matrix< int >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t,daal::services::SharedPtr< int > const &)\n"
    "    daal::data_management::interface1::Matrix< int >::create(size_t,size_t,daal::data_management::interface1::NumericTable::AllocationFlag,daal::services::Status *)\n"
    "    daal::data_management::interface1::Matrix< int >::create(size_t,size_t,daal::data_management::interface1::NumericTable::AllocationFlag)\n"
    "    daal::data_management::interface1::Matrix< int >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t,daal::data_management::interface1::NumericTable::AllocationFlag,daal::services::Status *)\n"
    "    daal::data_management::interface1::Matrix< int >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t,daal::data_management::interface1::NumericTable::AllocationFlag)\n"
    "    daal::data_management::interface1::Matrix< int >::create(size_t,size_t,int *const,int const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::Matrix< int >::create(size_t,size_t,int *const,int const &)\n"
    "    daal::data_management::interface1::Matrix< int >::create(size_t,size_t,daal::services::SharedPtr< int > const &,int const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::Matrix< int >::create(size_t,size_t,daal::services::SharedPtr< int > const &,int const &)\n"
    "    daal::data_management::interface1::Matrix< int >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t,int *const,int const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::Matrix< int >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t,int *const,int const &)\n"
    "    daal::data_management::interface1::Matrix< int >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t,daal::services::SharedPtr< int > const &,int const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::Matrix< int >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t,daal::services::SharedPtr< int > const &,int const &)\n"
    "    daal::data_management::interface1::Matrix< int >::create(size_t,size_t,daal::data_management::interface1::NumericTable::AllocationFlag,int const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::Matrix< int >::create(size_t,size_t,daal::data_management::interface1::NumericTable::AllocationFlag,int const &)\n"
    "    daal::data_management::interface1::Matrix< int >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t,daal::data_management::interface1::NumericTable::AllocationFlag,int const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::Matrix< int >::create(daal::data_management::interface1::DictionaryIface::FeaturesEqual,size_t,size_t,daal::data_management::interface1::NumericTable::AllocationFlag,int const &)\n"
    "    daal::data_management::interface1::Matrix< int >::create(daal::services::SharedPtr< int > const &,size_t,size_t)\n"
    "    daal::data_management::interface1::Matrix< int >::daal_data_management_interface1_Matrix_Sl_int_Sg__create__SWIG_31(daal::services::SharedPtr< int > const &,size_t,size_t,int const &)\n");
  return 0;
}


SWIGINTERN PyObject *Matrix_Intc_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_SerializableKeyValueCollection_SerializationIface_serializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)":SerializableKeyValueCollection_SerializationIface_serializationTag")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface >::SWIGTEMPLATEDISAMBIGUATOR serializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SerializableKeyValueCollection_SerializationIface_getSerializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > *arg1 = (daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:SerializableKeyValueCollection_SerializationIface_getSerializationTag",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SerializableKeyValueCollection_SerializationIface_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SerializableKeyValueCollection_SerializationIface_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)((daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > const *)arg1)->getSerializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_SerializableKeyValueCollection_SerializationIface__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_SerializableKeyValueCollection_SerializationIface")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > *)new daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface >();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_SerializableKeyValueCollection_SerializationIface__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > const > tempshared1 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:new_SerializableKeyValueCollection_SerializationIface",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_SerializableKeyValueCollection_SerializationIface" "', argument " "1"" of type '" "daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > const &""'"); 
    }
    if (!argp1) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_SerializableKeyValueCollection_SerializationIface" "', argument " "1"" of type '" "daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > const &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > * >(tempshared1.get());
    } else {
      arg1 = const_cast< daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > * >(reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > > * >(argp1)->get());
    }
    if(!arg1) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_SerializableKeyValueCollection_SerializationIface" "', argument " "1"" of type '" "daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > const &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > *)new daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface >((daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > const &)*arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_SerializableKeyValueCollection_SerializationIface__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::Collection< size_t > *arg1 = 0 ;
  daal::services::Collection< daal::services::SharedPtr< daal::data_management::interface1::SerializationIface > > *arg2 = 0 ;
  daal::services::Collection< size_t > *col_szt1 = NULL ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:new_SerializableKeyValueCollection_SerializationIface",&obj0,&obj1)) SWIG_fail;
  {
    Py_ssize_t n = PySequence_Length(obj0);
    if( n == 0 ) SWIG_fail;
    col_szt1 = new daal::services::Collection<size_t>(n);
    for( Py_ssize_t i=0; i<n; ++i ) {
      PyObject * o = PySequence_GetItem(obj0, i);
      size_t tmp = PyInt_AsSsize_t(o);
      if(PyErr_Occurred()) {
        PyErr_Format(PyExc_TypeError, "Sequence of integer values required");
        SWIG_fail;
      }
      (*col_szt1)[i] = tmp;
    }
    arg1 = col_szt1;
  }
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_daal__services__CollectionT_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "new_SerializableKeyValueCollection_SerializationIface" "', argument " "2"" of type '" "daal::services::Collection< daal::services::SharedPtr< daal::data_management::interface1::SerializationIface > > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_SerializableKeyValueCollection_SerializationIface" "', argument " "2"" of type '" "daal::services::Collection< daal::services::SharedPtr< daal::data_management::interface1::SerializationIface > > const &""'"); 
  }
  arg2 = reinterpret_cast< daal::services::Collection< daal::services::SharedPtr< daal::data_management::interface1::SerializationIface > > * >(argp2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > *)new daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface >((daal::services::Collection< size_t > const &)*arg1,(daal::services::Collection< daal::services::SharedPtr< daal::data_management::interface1::SerializationIface > > const &)*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  {
    if( col_szt1 ) delete col_szt1;
  }
  return resultobj;
fail:
  {
    if( col_szt1 ) delete col_szt1;
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_SerializableKeyValueCollection_SerializationIface(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_new_SerializableKeyValueCollection_SerializationIface__SWIG_0(self, args);
  }
  if (argc == 1) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_SerializableKeyValueCollection_SerializationIface__SWIG_1(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    {
      _v = PySequence_Check(argv[0]);
    }
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__CollectionT_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_new_SerializableKeyValueCollection_SerializationIface__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'new_SerializableKeyValueCollection_SerializationIface'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface >::SerializableKeyValueCollection()\n"
    "    daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface >::SerializableKeyValueCollection(daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > const &)\n"
    "    daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface >::SerializableKeyValueCollection(daal::services::Collection< size_t > const &,daal::services::Collection< daal::services::SharedPtr< daal::data_management::interface1::SerializationIface > > const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_SerializableKeyValueCollection_SerializationIface(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > *arg1 = (daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_SerializableKeyValueCollection_SerializationIface",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_SerializableKeyValueCollection_SerializationIface" "', argument " "1"" of type '" "daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_SerializableKeyValueCollection_SerializationIface" "', argument " "1"" of type '" "daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *SerializableKeyValueCollection_SerializationIface_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_SubtensorDescriptor_Float64(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< double > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_SubtensorDescriptor_Float64")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::SubtensorDescriptor< double > *)new daal::data_management::interface1::SubtensorDescriptor< double >();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_SubtensorDescriptor_Float64(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< double > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< double > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_SubtensorDescriptor_Float64",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_SubtensorDescriptor_Float64" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_SubtensorDescriptor_Float64" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SubtensorDescriptor_Float64_getNumberOfDims(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< double > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< double > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< double > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:SubtensorDescriptor_Float64_getNumberOfDims",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float64_getNumberOfDims" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float64_getNumberOfDims" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::SubtensorDescriptor< double > const *)arg1)->getNumberOfDims();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SubtensorDescriptor_Float64_getLayout(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< double > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< double > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< double > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::TensorOffsetLayout *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:SubtensorDescriptor_Float64_getLayout",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float64_getLayout" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float64_getLayout" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::TensorOffsetLayout *)((daal::data_management::interface1::SubtensorDescriptor< double > const *)arg1)->getLayout();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > *smartresult = result ? new daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout >(result SWIG_NO_NULL_DELETER_0) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, 0 | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SubtensorDescriptor_Float64_getInplaceFlag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< double > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< double > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< double > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:SubtensorDescriptor_Float64_getInplaceFlag",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float64_getInplaceFlag" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float64_getInplaceFlag" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (bool)((daal::data_management::interface1::SubtensorDescriptor< double > const *)arg1)->getInplaceFlag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SubtensorDescriptor_Float64_reset(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< double > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< double > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:SubtensorDescriptor_Float64_reset",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float64_reset" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float64_reset" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->reset();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SubtensorDescriptor_Float64_resizeBuffer(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< double > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< double > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:SubtensorDescriptor_Float64_resizeBuffer",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float64_resizeBuffer" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float64_resizeBuffer" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (bool)(arg1)->resizeBuffer();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SubtensorDescriptor_Float64_setDetails(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< double > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< double > *) 0 ;
  size_t arg2 ;
  size_t *arg3 = (size_t *) 0 ;
  size_t arg4 ;
  size_t *arg5 = (size_t *) 0 ;
  size_t arg6 ;
  size_t arg7 ;
  int arg8 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< double > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  size_t val6 ;
  int ecode6 = 0 ;
  size_t val7 ;
  int ecode7 = 0 ;
  int val8 ;
  int ecode8 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  PyObject * obj6 = 0 ;
  PyObject * obj7 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOOOO:SubtensorDescriptor_Float64_setDetails",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5,&obj6,&obj7)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float64_setDetails" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float64_setDetails" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SubtensorDescriptor_Float64_setDetails" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_size_t, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "SubtensorDescriptor_Float64_setDetails" "', argument " "3"" of type '" "size_t const *""'"); 
  }
  arg3 = reinterpret_cast< size_t * >(argp3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "SubtensorDescriptor_Float64_setDetails" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  res5 = SWIG_ConvertPtr(obj4, &argp5,SWIGTYPE_p_size_t, 0 |  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "SubtensorDescriptor_Float64_setDetails" "', argument " "5"" of type '" "size_t const *""'"); 
  }
  arg5 = reinterpret_cast< size_t * >(argp5);
  ecode6 = SWIG_AsVal_size_t(obj5, &val6);
  if (!SWIG_IsOK(ecode6)) {
    SWIG_exception_fail(SWIG_ArgError(ecode6), "in method '" "SubtensorDescriptor_Float64_setDetails" "', argument " "6"" of type '" "size_t""'");
  } 
  arg6 = static_cast< size_t >(val6);
  ecode7 = SWIG_AsVal_size_t(obj6, &val7);
  if (!SWIG_IsOK(ecode7)) {
    SWIG_exception_fail(SWIG_ArgError(ecode7), "in method '" "SubtensorDescriptor_Float64_setDetails" "', argument " "7"" of type '" "size_t""'");
  } 
  arg7 = static_cast< size_t >(val7);
  ecode8 = SWIG_AsVal_int(obj7, &val8);
  if (!SWIG_IsOK(ecode8)) {
    SWIG_exception_fail(SWIG_ArgError(ecode8), "in method '" "SubtensorDescriptor_Float64_setDetails" "', argument " "8"" of type '" "int""'");
  } 
  arg8 = static_cast< int >(val8);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->setDetails(arg2,(size_t const *)arg3,arg4,(size_t const *)arg5,arg6,arg7,arg8);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SubtensorDescriptor_Float64_saveOffsetLayout(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< double > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< double > *) 0 ;
  daal::data_management::interface1::TensorOffsetLayout *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< double > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout const > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:SubtensorDescriptor_Float64_saveOffsetLayout",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float64_saveOffsetLayout" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float64_saveOffsetLayout" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SubtensorDescriptor_Float64_saveOffsetLayout" "', argument " "2"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SubtensorDescriptor_Float64_saveOffsetLayout" "', argument " "2"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SubtensorDescriptor_Float64_saveOffsetLayout" "', argument " "2"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (bool)(arg1)->saveOffsetLayout((daal::data_management::interface1::TensorOffsetLayout const &)*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SubtensorDescriptor_Float64_saveOffsetLayoutCopy(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< double > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< double > *) 0 ;
  daal::data_management::interface1::TensorOffsetLayout *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< double > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout const > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:SubtensorDescriptor_Float64_saveOffsetLayoutCopy",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float64_saveOffsetLayoutCopy" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float64_saveOffsetLayoutCopy" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SubtensorDescriptor_Float64_saveOffsetLayoutCopy" "', argument " "2"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SubtensorDescriptor_Float64_saveOffsetLayoutCopy" "', argument " "2"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SubtensorDescriptor_Float64_saveOffsetLayoutCopy" "', argument " "2"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (bool)(arg1)->saveOffsetLayoutCopy((daal::data_management::interface1::TensorOffsetLayout const &)*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SubtensorDescriptor_Float64_getSize(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< double > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< double > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< double > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:SubtensorDescriptor_Float64_getSize",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float64_getSize" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float64_getSize" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::SubtensorDescriptor< double > const *)arg1)->getSize();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SubtensorDescriptor_Float64_getFixedDims(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< double > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< double > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< double > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:SubtensorDescriptor_Float64_getFixedDims",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float64_getFixedDims" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float64_getFixedDims" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::SubtensorDescriptor< double > const *)arg1)->getFixedDims();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SubtensorDescriptor_Float64_getRangeDimIdx(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< double > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< double > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< double > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:SubtensorDescriptor_Float64_getRangeDimIdx",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float64_getRangeDimIdx" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float64_getRangeDimIdx" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::SubtensorDescriptor< double > const *)arg1)->getRangeDimIdx();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SubtensorDescriptor_Float64_getRangeDimNum(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< double > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< double > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< double > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:SubtensorDescriptor_Float64_getRangeDimNum",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float64_getRangeDimNum" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float64_getRangeDimNum" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::SubtensorDescriptor< double > const *)arg1)->getRangeDimNum();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SubtensorDescriptor_Float64_getRWFlag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< double > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< double > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< double > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:SubtensorDescriptor_Float64_getRWFlag",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float64_getRWFlag" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float64_getRWFlag" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::SubtensorDescriptor< double > const *)arg1)->getRWFlag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SubtensorDescriptor_Float64_getArray(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< double > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< double > *) 0 ;
  size_t *arg2 = (size_t *) 0 ;
  size_t **arg3 = (size_t **) 0 ;
  daal::services::SharedPtr< double > *arg4 = (daal::services::SharedPtr< double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< double > > *smartarg1 = 0 ;
  size_t ndims_tmp2 ;
  size_t *dimsizes_tmp2 ;
  daal::services::SharedPtr< double > data_tmp2 ;
  PyObject * obj0 = 0 ;
  
  {
    arg2 = &ndims_tmp2;
    arg3 = &dimsizes_tmp2;
    arg4 = &data_tmp2;
  }
  if (!PyArg_ParseTuple(args,(char *)"O:SubtensorDescriptor_Float64_getArray",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float64_getArray" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float64_getArray" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        daal_data_management_interface1_SubtensorDescriptor_Sl_double_Sg__getArray(arg1,arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    npy_intp * dims = NULL;
    if( sizeof(npy_intp) == sizeof(size_t) ) {
      dims = (npy_intp*)*arg3;
    } else {
      dims = new npy_intp[*arg2];
      for( size_t i=0; i<*arg2; ++i ) {
        dims[i] = (npy_intp)(*arg3)[i];
      }
    }
    PyObject* obj = PyArray_SimpleNewFromData(*arg2, dims, NPY_DOUBLE, (void*)(arg4->get()));
    if( sizeof(npy_intp) != sizeof(size_t) ) delete [] dims;
    if (!obj) SWIG_fail;
    set_sp_base((PyArrayObject*)obj, *arg4);
    resultobj = SWIG_Python_AppendOutput(resultobj, obj);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SubtensorDescriptor_Float64_getSubtensorDimSizes(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< double > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< double > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:SubtensorDescriptor_Float64_getSubtensorDimSizes",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float64_getSubtensorDimSizes" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float64_getSubtensorDimSizes" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (PyObject *)daal_data_management_interface1_SubtensorDescriptor_Sl_double_Sg__getSubtensorDimSizes(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = result;
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SubtensorDescriptor_Float64_getFixedDimNums(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< double > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< double > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:SubtensorDescriptor_Float64_getFixedDimNums",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float64_getFixedDimNums" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float64_getFixedDimNums" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< double > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (PyObject *)daal_data_management_interface1_SubtensorDescriptor_Sl_double_Sg__getFixedDimNums(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = result;
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *SubtensorDescriptor_Float64_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_SubtensorDescriptor_Float32(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< float > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_SubtensorDescriptor_Float32")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::SubtensorDescriptor< float > *)new daal::data_management::interface1::SubtensorDescriptor< float >();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_SubtensorDescriptor_Float32(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< float > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< float > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_SubtensorDescriptor_Float32",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_SubtensorDescriptor_Float32" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_SubtensorDescriptor_Float32" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SubtensorDescriptor_Float32_getNumberOfDims(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< float > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< float > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< float > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:SubtensorDescriptor_Float32_getNumberOfDims",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float32_getNumberOfDims" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float32_getNumberOfDims" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::SubtensorDescriptor< float > const *)arg1)->getNumberOfDims();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SubtensorDescriptor_Float32_getLayout(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< float > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< float > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< float > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::TensorOffsetLayout *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:SubtensorDescriptor_Float32_getLayout",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float32_getLayout" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float32_getLayout" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::TensorOffsetLayout *)((daal::data_management::interface1::SubtensorDescriptor< float > const *)arg1)->getLayout();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > *smartresult = result ? new daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout >(result SWIG_NO_NULL_DELETER_0) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, 0 | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SubtensorDescriptor_Float32_getInplaceFlag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< float > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< float > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< float > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:SubtensorDescriptor_Float32_getInplaceFlag",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float32_getInplaceFlag" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float32_getInplaceFlag" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (bool)((daal::data_management::interface1::SubtensorDescriptor< float > const *)arg1)->getInplaceFlag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SubtensorDescriptor_Float32_reset(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< float > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< float > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:SubtensorDescriptor_Float32_reset",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float32_reset" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float32_reset" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->reset();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SubtensorDescriptor_Float32_resizeBuffer(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< float > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< float > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:SubtensorDescriptor_Float32_resizeBuffer",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float32_resizeBuffer" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float32_resizeBuffer" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (bool)(arg1)->resizeBuffer();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SubtensorDescriptor_Float32_setDetails(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< float > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< float > *) 0 ;
  size_t arg2 ;
  size_t *arg3 = (size_t *) 0 ;
  size_t arg4 ;
  size_t *arg5 = (size_t *) 0 ;
  size_t arg6 ;
  size_t arg7 ;
  int arg8 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< float > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  size_t val6 ;
  int ecode6 = 0 ;
  size_t val7 ;
  int ecode7 = 0 ;
  int val8 ;
  int ecode8 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  PyObject * obj6 = 0 ;
  PyObject * obj7 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOOOO:SubtensorDescriptor_Float32_setDetails",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5,&obj6,&obj7)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float32_setDetails" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float32_setDetails" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SubtensorDescriptor_Float32_setDetails" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_size_t, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "SubtensorDescriptor_Float32_setDetails" "', argument " "3"" of type '" "size_t const *""'"); 
  }
  arg3 = reinterpret_cast< size_t * >(argp3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "SubtensorDescriptor_Float32_setDetails" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  res5 = SWIG_ConvertPtr(obj4, &argp5,SWIGTYPE_p_size_t, 0 |  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "SubtensorDescriptor_Float32_setDetails" "', argument " "5"" of type '" "size_t const *""'"); 
  }
  arg5 = reinterpret_cast< size_t * >(argp5);
  ecode6 = SWIG_AsVal_size_t(obj5, &val6);
  if (!SWIG_IsOK(ecode6)) {
    SWIG_exception_fail(SWIG_ArgError(ecode6), "in method '" "SubtensorDescriptor_Float32_setDetails" "', argument " "6"" of type '" "size_t""'");
  } 
  arg6 = static_cast< size_t >(val6);
  ecode7 = SWIG_AsVal_size_t(obj6, &val7);
  if (!SWIG_IsOK(ecode7)) {
    SWIG_exception_fail(SWIG_ArgError(ecode7), "in method '" "SubtensorDescriptor_Float32_setDetails" "', argument " "7"" of type '" "size_t""'");
  } 
  arg7 = static_cast< size_t >(val7);
  ecode8 = SWIG_AsVal_int(obj7, &val8);
  if (!SWIG_IsOK(ecode8)) {
    SWIG_exception_fail(SWIG_ArgError(ecode8), "in method '" "SubtensorDescriptor_Float32_setDetails" "', argument " "8"" of type '" "int""'");
  } 
  arg8 = static_cast< int >(val8);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->setDetails(arg2,(size_t const *)arg3,arg4,(size_t const *)arg5,arg6,arg7,arg8);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SubtensorDescriptor_Float32_saveOffsetLayout(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< float > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< float > *) 0 ;
  daal::data_management::interface1::TensorOffsetLayout *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< float > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout const > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:SubtensorDescriptor_Float32_saveOffsetLayout",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float32_saveOffsetLayout" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float32_saveOffsetLayout" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SubtensorDescriptor_Float32_saveOffsetLayout" "', argument " "2"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SubtensorDescriptor_Float32_saveOffsetLayout" "', argument " "2"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SubtensorDescriptor_Float32_saveOffsetLayout" "', argument " "2"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (bool)(arg1)->saveOffsetLayout((daal::data_management::interface1::TensorOffsetLayout const &)*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SubtensorDescriptor_Float32_saveOffsetLayoutCopy(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< float > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< float > *) 0 ;
  daal::data_management::interface1::TensorOffsetLayout *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< float > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout const > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:SubtensorDescriptor_Float32_saveOffsetLayoutCopy",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float32_saveOffsetLayoutCopy" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float32_saveOffsetLayoutCopy" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SubtensorDescriptor_Float32_saveOffsetLayoutCopy" "', argument " "2"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SubtensorDescriptor_Float32_saveOffsetLayoutCopy" "', argument " "2"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SubtensorDescriptor_Float32_saveOffsetLayoutCopy" "', argument " "2"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (bool)(arg1)->saveOffsetLayoutCopy((daal::data_management::interface1::TensorOffsetLayout const &)*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SubtensorDescriptor_Float32_getSize(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< float > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< float > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< float > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:SubtensorDescriptor_Float32_getSize",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float32_getSize" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float32_getSize" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::SubtensorDescriptor< float > const *)arg1)->getSize();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SubtensorDescriptor_Float32_getFixedDims(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< float > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< float > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< float > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:SubtensorDescriptor_Float32_getFixedDims",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float32_getFixedDims" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float32_getFixedDims" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::SubtensorDescriptor< float > const *)arg1)->getFixedDims();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SubtensorDescriptor_Float32_getRangeDimIdx(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< float > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< float > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< float > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:SubtensorDescriptor_Float32_getRangeDimIdx",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float32_getRangeDimIdx" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float32_getRangeDimIdx" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::SubtensorDescriptor< float > const *)arg1)->getRangeDimIdx();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SubtensorDescriptor_Float32_getRangeDimNum(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< float > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< float > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< float > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:SubtensorDescriptor_Float32_getRangeDimNum",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float32_getRangeDimNum" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float32_getRangeDimNum" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::SubtensorDescriptor< float > const *)arg1)->getRangeDimNum();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SubtensorDescriptor_Float32_getRWFlag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< float > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< float > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< float > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:SubtensorDescriptor_Float32_getRWFlag",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float32_getRWFlag" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float32_getRWFlag" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::SubtensorDescriptor< float > const *)arg1)->getRWFlag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SubtensorDescriptor_Float32_getArray(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< float > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< float > *) 0 ;
  size_t *arg2 = (size_t *) 0 ;
  size_t **arg3 = (size_t **) 0 ;
  daal::services::SharedPtr< float > *arg4 = (daal::services::SharedPtr< float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< float > > *smartarg1 = 0 ;
  size_t ndims_tmp2 ;
  size_t *dimsizes_tmp2 ;
  daal::services::SharedPtr< float > data_tmp2 ;
  PyObject * obj0 = 0 ;
  
  {
    arg2 = &ndims_tmp2;
    arg3 = &dimsizes_tmp2;
    arg4 = &data_tmp2;
  }
  if (!PyArg_ParseTuple(args,(char *)"O:SubtensorDescriptor_Float32_getArray",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float32_getArray" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float32_getArray" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        daal_data_management_interface1_SubtensorDescriptor_Sl_float_Sg__getArray(arg1,arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    npy_intp * dims = NULL;
    if( sizeof(npy_intp) == sizeof(size_t) ) {
      dims = (npy_intp*)*arg3;
    } else {
      dims = new npy_intp[*arg2];
      for( size_t i=0; i<*arg2; ++i ) {
        dims[i] = (npy_intp)(*arg3)[i];
      }
    }
    PyObject* obj = PyArray_SimpleNewFromData(*arg2, dims, NPY_FLOAT, (void*)(arg4->get()));
    if( sizeof(npy_intp) != sizeof(size_t) ) delete [] dims;
    if (!obj) SWIG_fail;
    set_sp_base((PyArrayObject*)obj, *arg4);
    resultobj = SWIG_Python_AppendOutput(resultobj, obj);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SubtensorDescriptor_Float32_getSubtensorDimSizes(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< float > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< float > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:SubtensorDescriptor_Float32_getSubtensorDimSizes",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float32_getSubtensorDimSizes" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float32_getSubtensorDimSizes" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (PyObject *)daal_data_management_interface1_SubtensorDescriptor_Sl_float_Sg__getSubtensorDimSizes(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = result;
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SubtensorDescriptor_Float32_getFixedDimNums(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< float > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< float > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:SubtensorDescriptor_Float32_getFixedDimNums",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float32_getFixedDimNums" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Float32_getFixedDimNums" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< float > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (PyObject *)daal_data_management_interface1_SubtensorDescriptor_Sl_float_Sg__getFixedDimNums(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = result;
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *SubtensorDescriptor_Float32_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_SubtensorDescriptor_Intc(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< int > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_SubtensorDescriptor_Intc")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::SubtensorDescriptor< int > *)new daal::data_management::interface1::SubtensorDescriptor< int >();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_SubtensorDescriptor_Intc(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< int > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< int > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_SubtensorDescriptor_Intc",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_SubtensorDescriptor_Intc" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_SubtensorDescriptor_Intc" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SubtensorDescriptor_Intc_getNumberOfDims(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< int > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< int > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< int > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:SubtensorDescriptor_Intc_getNumberOfDims",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Intc_getNumberOfDims" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Intc_getNumberOfDims" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::SubtensorDescriptor< int > const *)arg1)->getNumberOfDims();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SubtensorDescriptor_Intc_getLayout(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< int > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< int > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< int > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::TensorOffsetLayout *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:SubtensorDescriptor_Intc_getLayout",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Intc_getLayout" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Intc_getLayout" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::TensorOffsetLayout *)((daal::data_management::interface1::SubtensorDescriptor< int > const *)arg1)->getLayout();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > *smartresult = result ? new daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout >(result SWIG_NO_NULL_DELETER_0) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, 0 | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SubtensorDescriptor_Intc_getInplaceFlag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< int > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< int > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< int > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:SubtensorDescriptor_Intc_getInplaceFlag",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Intc_getInplaceFlag" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Intc_getInplaceFlag" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (bool)((daal::data_management::interface1::SubtensorDescriptor< int > const *)arg1)->getInplaceFlag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SubtensorDescriptor_Intc_reset(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< int > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< int > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:SubtensorDescriptor_Intc_reset",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Intc_reset" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Intc_reset" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->reset();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SubtensorDescriptor_Intc_resizeBuffer(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< int > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< int > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:SubtensorDescriptor_Intc_resizeBuffer",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Intc_resizeBuffer" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Intc_resizeBuffer" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (bool)(arg1)->resizeBuffer();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SubtensorDescriptor_Intc_setDetails(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< int > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< int > *) 0 ;
  size_t arg2 ;
  size_t *arg3 = (size_t *) 0 ;
  size_t arg4 ;
  size_t *arg5 = (size_t *) 0 ;
  size_t arg6 ;
  size_t arg7 ;
  int arg8 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< int > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  size_t val6 ;
  int ecode6 = 0 ;
  size_t val7 ;
  int ecode7 = 0 ;
  int val8 ;
  int ecode8 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  PyObject * obj6 = 0 ;
  PyObject * obj7 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOOOO:SubtensorDescriptor_Intc_setDetails",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5,&obj6,&obj7)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Intc_setDetails" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Intc_setDetails" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SubtensorDescriptor_Intc_setDetails" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_size_t, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "SubtensorDescriptor_Intc_setDetails" "', argument " "3"" of type '" "size_t const *""'"); 
  }
  arg3 = reinterpret_cast< size_t * >(argp3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "SubtensorDescriptor_Intc_setDetails" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  res5 = SWIG_ConvertPtr(obj4, &argp5,SWIGTYPE_p_size_t, 0 |  0 );
  if (!SWIG_IsOK(res5)) {
    SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "SubtensorDescriptor_Intc_setDetails" "', argument " "5"" of type '" "size_t const *""'"); 
  }
  arg5 = reinterpret_cast< size_t * >(argp5);
  ecode6 = SWIG_AsVal_size_t(obj5, &val6);
  if (!SWIG_IsOK(ecode6)) {
    SWIG_exception_fail(SWIG_ArgError(ecode6), "in method '" "SubtensorDescriptor_Intc_setDetails" "', argument " "6"" of type '" "size_t""'");
  } 
  arg6 = static_cast< size_t >(val6);
  ecode7 = SWIG_AsVal_size_t(obj6, &val7);
  if (!SWIG_IsOK(ecode7)) {
    SWIG_exception_fail(SWIG_ArgError(ecode7), "in method '" "SubtensorDescriptor_Intc_setDetails" "', argument " "7"" of type '" "size_t""'");
  } 
  arg7 = static_cast< size_t >(val7);
  ecode8 = SWIG_AsVal_int(obj7, &val8);
  if (!SWIG_IsOK(ecode8)) {
    SWIG_exception_fail(SWIG_ArgError(ecode8), "in method '" "SubtensorDescriptor_Intc_setDetails" "', argument " "8"" of type '" "int""'");
  } 
  arg8 = static_cast< int >(val8);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->setDetails(arg2,(size_t const *)arg3,arg4,(size_t const *)arg5,arg6,arg7,arg8);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SubtensorDescriptor_Intc_saveOffsetLayout(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< int > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< int > *) 0 ;
  daal::data_management::interface1::TensorOffsetLayout *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< int > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout const > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:SubtensorDescriptor_Intc_saveOffsetLayout",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Intc_saveOffsetLayout" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Intc_saveOffsetLayout" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SubtensorDescriptor_Intc_saveOffsetLayout" "', argument " "2"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SubtensorDescriptor_Intc_saveOffsetLayout" "', argument " "2"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SubtensorDescriptor_Intc_saveOffsetLayout" "', argument " "2"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (bool)(arg1)->saveOffsetLayout((daal::data_management::interface1::TensorOffsetLayout const &)*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SubtensorDescriptor_Intc_saveOffsetLayoutCopy(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< int > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< int > *) 0 ;
  daal::data_management::interface1::TensorOffsetLayout *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< int > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout const > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  bool result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:SubtensorDescriptor_Intc_saveOffsetLayoutCopy",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Intc_saveOffsetLayoutCopy" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Intc_saveOffsetLayoutCopy" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SubtensorDescriptor_Intc_saveOffsetLayoutCopy" "', argument " "2"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SubtensorDescriptor_Intc_saveOffsetLayoutCopy" "', argument " "2"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::TensorOffsetLayout * >(reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::TensorOffsetLayout > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SubtensorDescriptor_Intc_saveOffsetLayoutCopy" "', argument " "2"" of type '" "daal::data_management::interface1::TensorOffsetLayout const &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (bool)(arg1)->saveOffsetLayoutCopy((daal::data_management::interface1::TensorOffsetLayout const &)*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SubtensorDescriptor_Intc_getSize(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< int > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< int > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< int > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:SubtensorDescriptor_Intc_getSize",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Intc_getSize" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Intc_getSize" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::SubtensorDescriptor< int > const *)arg1)->getSize();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SubtensorDescriptor_Intc_getFixedDims(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< int > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< int > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< int > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:SubtensorDescriptor_Intc_getFixedDims",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Intc_getFixedDims" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Intc_getFixedDims" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::SubtensorDescriptor< int > const *)arg1)->getFixedDims();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SubtensorDescriptor_Intc_getRangeDimIdx(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< int > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< int > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< int > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:SubtensorDescriptor_Intc_getRangeDimIdx",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Intc_getRangeDimIdx" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Intc_getRangeDimIdx" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::SubtensorDescriptor< int > const *)arg1)->getRangeDimIdx();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SubtensorDescriptor_Intc_getRangeDimNum(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< int > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< int > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< int > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:SubtensorDescriptor_Intc_getRangeDimNum",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Intc_getRangeDimNum" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Intc_getRangeDimNum" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::SubtensorDescriptor< int > const *)arg1)->getRangeDimNum();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SubtensorDescriptor_Intc_getRWFlag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< int > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< int > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< int > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:SubtensorDescriptor_Intc_getRWFlag",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Intc_getRWFlag" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Intc_getRWFlag" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = ((daal::data_management::interface1::SubtensorDescriptor< int > const *)arg1)->getRWFlag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SubtensorDescriptor_Intc_getArray(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< int > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< int > *) 0 ;
  size_t *arg2 = (size_t *) 0 ;
  size_t **arg3 = (size_t **) 0 ;
  daal::services::SharedPtr< int > *arg4 = (daal::services::SharedPtr< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< int > > *smartarg1 = 0 ;
  size_t ndims_tmp2 ;
  size_t *dimsizes_tmp2 ;
  daal::services::SharedPtr< int > data_tmp2 ;
  PyObject * obj0 = 0 ;
  
  {
    arg2 = &ndims_tmp2;
    arg3 = &dimsizes_tmp2;
    arg4 = &data_tmp2;
  }
  if (!PyArg_ParseTuple(args,(char *)"O:SubtensorDescriptor_Intc_getArray",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Intc_getArray" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Intc_getArray" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        daal_data_management_interface1_SubtensorDescriptor_Sl_int_Sg__getArray(arg1,arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  {
    npy_intp * dims = NULL;
    if( sizeof(npy_intp) == sizeof(size_t) ) {
      dims = (npy_intp*)*arg3;
    } else {
      dims = new npy_intp[*arg2];
      for( size_t i=0; i<*arg2; ++i ) {
        dims[i] = (npy_intp)(*arg3)[i];
      }
    }
    PyObject* obj = PyArray_SimpleNewFromData(*arg2, dims, NPY_INT, (void*)(arg4->get()));
    if( sizeof(npy_intp) != sizeof(size_t) ) delete [] dims;
    if (!obj) SWIG_fail;
    set_sp_base((PyArrayObject*)obj, *arg4);
    resultobj = SWIG_Python_AppendOutput(resultobj, obj);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SubtensorDescriptor_Intc_getSubtensorDimSizes(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< int > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< int > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:SubtensorDescriptor_Intc_getSubtensorDimSizes",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Intc_getSubtensorDimSizes" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Intc_getSubtensorDimSizes" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (PyObject *)daal_data_management_interface1_SubtensorDescriptor_Sl_int_Sg__getSubtensorDimSizes(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = result;
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SubtensorDescriptor_Intc_getFixedDimNums(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SubtensorDescriptor< int > *arg1 = (daal::data_management::interface1::SubtensorDescriptor< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< int > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:SubtensorDescriptor_Intc_getFixedDimNums",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Intc_getFixedDimNums" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SubtensorDescriptor< int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SubtensorDescriptor< int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SubtensorDescriptor_Intc_getFixedDimNums" "', argument " "1"" of type '" "daal::data_management::interface1::SubtensorDescriptor< int > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (PyObject *)daal_data_management_interface1_SubtensorDescriptor_Sl_int_Sg__getFixedDimNums(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = result;
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *SubtensorDescriptor_Intc_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_delete_DataSourceTemplate_HomogenNumericTable_Float64Float64(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< double >,double > *arg1 = (daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< double >,double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< double >,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< double >,double > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_DataSourceTemplate_HomogenNumericTable_Float64Float64",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_DataSourceTemplate_HomogenNumericTable_Float64Float64" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< double >,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable<double>,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable<double>,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< double >,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable<double>,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< double >,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_DataSourceTemplate_HomogenNumericTable_Float64Float64" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< double >,double > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceTemplate_HomogenNumericTable_Float64Float64_freeNumericTable(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< double >,double > *arg1 = (daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< double >,double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< double >,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< double >,double > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataSourceTemplate_HomogenNumericTable_Float64Float64_freeNumericTable",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceTemplate_HomogenNumericTable_Float64Float64_freeNumericTable" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< double >,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable<double>,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable<double>,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< double >,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable<double>,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< double >,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceTemplate_HomogenNumericTable_Float64Float64_freeNumericTable" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< double >,double > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->freeNumericTable();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceTemplate_HomogenNumericTable_Float64Float64_allocateNumericTable(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< double >,double > *arg1 = (daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< double >,double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< double >,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< double >,double > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataSourceTemplate_HomogenNumericTable_Float64Float64_allocateNumericTable",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceTemplate_HomogenNumericTable_Float64Float64_allocateNumericTable" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< double >,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable<double>,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable<double>,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< double >,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable<double>,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< double >,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceTemplate_HomogenNumericTable_Float64Float64_allocateNumericTable" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< double >,double > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->allocateNumericTable();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *DataSourceTemplate_HomogenNumericTable_Float64Float64_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_delete_DataSourceTemplate_HomogenNumericTable_Float32Float64(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< float >,double > *arg1 = (daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< float >,double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< float >,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< float >,double > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_DataSourceTemplate_HomogenNumericTable_Float32Float64",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_float_t_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_DataSourceTemplate_HomogenNumericTable_Float32Float64" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< float >,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable<float>,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable<float>,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< float >,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable<float>,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< float >,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_DataSourceTemplate_HomogenNumericTable_Float32Float64" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< float >,double > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceTemplate_HomogenNumericTable_Float32Float64_freeNumericTable(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< float >,double > *arg1 = (daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< float >,double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< float >,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< float >,double > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataSourceTemplate_HomogenNumericTable_Float32Float64_freeNumericTable",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_float_t_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceTemplate_HomogenNumericTable_Float32Float64_freeNumericTable" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< float >,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable<float>,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable<float>,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< float >,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable<float>,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< float >,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceTemplate_HomogenNumericTable_Float32Float64_freeNumericTable" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< float >,double > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->freeNumericTable();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceTemplate_HomogenNumericTable_Float32Float64_allocateNumericTable(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< float >,double > *arg1 = (daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< float >,double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< float >,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< float >,double > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataSourceTemplate_HomogenNumericTable_Float32Float64_allocateNumericTable",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_float_t_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceTemplate_HomogenNumericTable_Float32Float64_allocateNumericTable" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< float >,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable<float>,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable<float>,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< float >,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable<float>,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< float >,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceTemplate_HomogenNumericTable_Float32Float64_allocateNumericTable" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< float >,double > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->allocateNumericTable();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *DataSourceTemplate_HomogenNumericTable_Float32Float64_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_float_t_double_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_delete_DataSourceTemplate_HomogenNumericTable_IntcFloat64(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< int >,double > *arg1 = (daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< int >,double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< int >,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< int >,double > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_DataSourceTemplate_HomogenNumericTable_IntcFloat64",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_int_t_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_DataSourceTemplate_HomogenNumericTable_IntcFloat64" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< int >,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable<int>,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable<int>,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< int >,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable<int>,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< int >,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_DataSourceTemplate_HomogenNumericTable_IntcFloat64" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< int >,double > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceTemplate_HomogenNumericTable_IntcFloat64_freeNumericTable(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< int >,double > *arg1 = (daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< int >,double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< int >,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< int >,double > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataSourceTemplate_HomogenNumericTable_IntcFloat64_freeNumericTable",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_int_t_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceTemplate_HomogenNumericTable_IntcFloat64_freeNumericTable" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< int >,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable<int>,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable<int>,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< int >,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable<int>,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< int >,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceTemplate_HomogenNumericTable_IntcFloat64_freeNumericTable" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< int >,double > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->freeNumericTable();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DataSourceTemplate_HomogenNumericTable_IntcFloat64_allocateNumericTable(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< int >,double > *arg1 = (daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< int >,double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< int >,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< int >,double > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:DataSourceTemplate_HomogenNumericTable_IntcFloat64_allocateNumericTable",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_int_t_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceTemplate_HomogenNumericTable_IntcFloat64_allocateNumericTable" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< int >,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable<int>,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable<int>,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< int >,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable<int>,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< int >,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DataSourceTemplate_HomogenNumericTable_IntcFloat64_allocateNumericTable" "', argument " "1"" of type '" "daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< int >,double > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->allocateNumericTable();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *DataSourceTemplate_HomogenNumericTable_IntcFloat64_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_int_t_double_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_delete_CsvDataSource_CSVFeatureManagerFloat64(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *arg1 = (daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_CsvDataSource_CSVFeatureManagerFloat64",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_CsvDataSource_CSVFeatureManagerFloat64" "', argument " "1"" of type '" "daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_CsvDataSource_CSVFeatureManagerFloat64" "', argument " "1"" of type '" "daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CsvDataSource_CSVFeatureManagerFloat64_getFeatureManager(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *arg1 = (daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::CSVFeatureManager *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:CsvDataSource_CSVFeatureManagerFloat64_getFeatureManager",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CsvDataSource_CSVFeatureManagerFloat64_getFeatureManager" "', argument " "1"" of type '" "daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CsvDataSource_CSVFeatureManagerFloat64_getFeatureManager" "', argument " "1"" of type '" "daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::CSVFeatureManager *) &(arg1)->getFeatureManager();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::CSVFeatureManager > *smartresult = new daal::services::SharedPtr<  daal::data_management::interface1::CSVFeatureManager >(result SWIG_NO_NULL_DELETER_0);
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CSVFeatureManager_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CsvDataSource_CSVFeatureManagerFloat64_getNumericTableNumberOfColumns(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *arg1 = (daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:CsvDataSource_CSVFeatureManagerFloat64_getNumericTableNumberOfColumns",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CsvDataSource_CSVFeatureManagerFloat64_getNumericTableNumberOfColumns" "', argument " "1"" of type '" "daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CsvDataSource_CSVFeatureManagerFloat64_getNumericTableNumberOfColumns" "', argument " "1"" of type '" "daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getNumericTableNumberOfColumns();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CsvDataSource_CSVFeatureManagerFloat64_setDictionary(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *arg1 = (daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *) 0 ;
  daal::data_management::interface1::DataSourceDictionary *arg2 = (daal::data_management::interface1::DataSourceDictionary *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > > tempshared2 ;
  daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > > *smartarg2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:CsvDataSource_CSVFeatureManagerFloat64_setDictionary",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CsvDataSource_CSVFeatureManagerFloat64_setDictionary" "', argument " "1"" of type '" "daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CsvDataSource_CSVFeatureManagerFloat64_setDictionary" "', argument " "1"" of type '" "daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res2) || !argp2) && obj1 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CsvDataSource_CSVFeatureManagerFloat64_setDictionary" "', argument " "2"" of type '" "daal::data_management::interface1::DataSourceDictionary *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::DataSourceDictionary * >(tempshared2.get());
    } else {
      smartarg2 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,daal::SERIALIZATION_DATADICTIONARY_DS_ID > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::DataSourceDictionary * >((smartarg2 ? smartarg2->get() : 0));
    }
    if(!arg2 && obj1 != Py_None) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CsvDataSource_CSVFeatureManagerFloat64_setDictionary" "', argument " "2"" of type '" "daal::data_management::interface1::DataSourceDictionary *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->setDictionary(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CsvDataSource_CSVFeatureManagerFloat64_loadDataBlock__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *arg1 = (daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *) 0 ;
  daal::data_management::interface1::NumericTable *arg2 = (daal::data_management::interface1::NumericTable *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > tempshared2 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > *smartarg2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:CsvDataSource_CSVFeatureManagerFloat64_loadDataBlock",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CsvDataSource_CSVFeatureManagerFloat64_loadDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CsvDataSource_CSVFeatureManagerFloat64_loadDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res2) || !argp2) && obj1 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CsvDataSource_CSVFeatureManagerFloat64_loadDataBlock" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::NumericTable * >(tempshared2.get());
    } else {
      smartarg2 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::NumericTable * >((smartarg2 ? smartarg2->get() : 0));
    }
    if(!arg2 && obj1 != Py_None) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CsvDataSource_CSVFeatureManagerFloat64_loadDataBlock" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->loadDataBlock(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CsvDataSource_CSVFeatureManagerFloat64_loadDataBlock__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *arg1 = (daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *) 0 ;
  size_t arg2 ;
  daal::data_management::interface1::NumericTable *arg3 = (daal::data_management::interface1::NumericTable *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > tempshared3 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > *smartarg3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:CsvDataSource_CSVFeatureManagerFloat64_loadDataBlock",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CsvDataSource_CSVFeatureManagerFloat64_loadDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CsvDataSource_CSVFeatureManagerFloat64_loadDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CsvDataSource_CSVFeatureManagerFloat64_loadDataBlock" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res3) || !argp3) && obj2 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "CsvDataSource_CSVFeatureManagerFloat64_loadDataBlock" "', argument " "3"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared3 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp3);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp3);
      arg3 = const_cast< daal::data_management::interface1::NumericTable * >(tempshared3.get());
    } else {
      smartarg3 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp3);
      arg3 = const_cast< daal::data_management::interface1::NumericTable * >((smartarg3 ? smartarg3->get() : 0));
    }
    if(!arg3 && obj2 != Py_None) SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "CsvDataSource_CSVFeatureManagerFloat64_loadDataBlock" "', argument " "3"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->loadDataBlock(arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CsvDataSource_CSVFeatureManagerFloat64_loadDataBlock__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *arg1 = (daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::interface1::NumericTable *arg5 = (daal::data_management::interface1::NumericTable *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > tempshared5 ;
  daal::services::SharedPtr< daal::data_management::interface1::NumericTable > *smartarg5 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:CsvDataSource_CSVFeatureManagerFloat64_loadDataBlock",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CsvDataSource_CSVFeatureManagerFloat64_loadDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CsvDataSource_CSVFeatureManagerFloat64_loadDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CsvDataSource_CSVFeatureManagerFloat64_loadDataBlock" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "CsvDataSource_CSVFeatureManagerFloat64_loadDataBlock" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "CsvDataSource_CSVFeatureManagerFloat64_loadDataBlock" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res5) || !argp5) && obj4 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "CsvDataSource_CSVFeatureManagerFloat64_loadDataBlock" "', argument " "5"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::NumericTable * >(tempshared5.get());
    } else {
      smartarg5 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::NumericTable > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::NumericTable * >((smartarg5 ? smartarg5->get() : 0));
    }
    if(!arg5 && obj4 != Py_None) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "CsvDataSource_CSVFeatureManagerFloat64_loadDataBlock" "', argument " "5"" of type '" "daal::data_management::interface1::NumericTable *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->loadDataBlock(arg2,arg3,arg4,arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CsvDataSource_CSVFeatureManagerFloat64_loadDataBlock__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *arg1 = (daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:CsvDataSource_CSVFeatureManagerFloat64_loadDataBlock",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CsvDataSource_CSVFeatureManagerFloat64_loadDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CsvDataSource_CSVFeatureManagerFloat64_loadDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->loadDataBlock();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CsvDataSource_CSVFeatureManagerFloat64_loadDataBlock__SWIG_4(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *arg1 = (daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:CsvDataSource_CSVFeatureManagerFloat64_loadDataBlock",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CsvDataSource_CSVFeatureManagerFloat64_loadDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CsvDataSource_CSVFeatureManagerFloat64_loadDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CsvDataSource_CSVFeatureManagerFloat64_loadDataBlock" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->loadDataBlock(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CsvDataSource_CSVFeatureManagerFloat64_loadDataBlock__SWIG_5(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *arg1 = (daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:CsvDataSource_CSVFeatureManagerFloat64_loadDataBlock",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CsvDataSource_CSVFeatureManagerFloat64_loadDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CsvDataSource_CSVFeatureManagerFloat64_loadDataBlock" "', argument " "1"" of type '" "daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CsvDataSource_CSVFeatureManagerFloat64_loadDataBlock" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "CsvDataSource_CSVFeatureManagerFloat64_loadDataBlock" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "CsvDataSource_CSVFeatureManagerFloat64_loadDataBlock" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->loadDataBlock(arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CsvDataSource_CSVFeatureManagerFloat64_loadDataBlock(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[6];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 5) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_CsvDataSource_CSVFeatureManagerFloat64_loadDataBlock__SWIG_3(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_CsvDataSource_CSVFeatureManagerFloat64_loadDataBlock__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_CsvDataSource_CSVFeatureManagerFloat64_loadDataBlock__SWIG_4(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_CsvDataSource_CSVFeatureManagerFloat64_loadDataBlock__SWIG_1(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            return _wrap_CsvDataSource_CSVFeatureManagerFloat64_loadDataBlock__SWIG_5(self, args);
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_CsvDataSource_CSVFeatureManagerFloat64_loadDataBlock__SWIG_2(self, args);
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'CsvDataSource_CSVFeatureManagerFloat64_loadDataBlock'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double >::loadDataBlock(daal::data_management::interface1::NumericTable *)\n"
    "    daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double >::loadDataBlock(size_t,daal::data_management::interface1::NumericTable *)\n"
    "    daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double >::loadDataBlock(size_t,size_t,size_t,daal::data_management::interface1::NumericTable *)\n"
    "    daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double >::loadDataBlock()\n"
    "    daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double >::loadDataBlock(size_t)\n"
    "    daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double >::loadDataBlock(size_t,size_t,size_t)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_CsvDataSource_CSVFeatureManagerFloat64_createDictionaryFromContext(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *arg1 = (daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:CsvDataSource_CSVFeatureManagerFloat64_createDictionaryFromContext",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CsvDataSource_CSVFeatureManagerFloat64_createDictionaryFromContext" "', argument " "1"" of type '" "daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CsvDataSource_CSVFeatureManagerFloat64_createDictionaryFromContext" "', argument " "1"" of type '" "daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->createDictionaryFromContext();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CsvDataSource_CSVFeatureManagerFloat64_getNumberOfAvailableRows(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *arg1 = (daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  size_t result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:CsvDataSource_CSVFeatureManagerFloat64_getNumberOfAvailableRows",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CsvDataSource_CSVFeatureManagerFloat64_getNumberOfAvailableRows" "', argument " "1"" of type '" "daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CsvDataSource_CSVFeatureManagerFloat64_getNumberOfAvailableRows" "', argument " "1"" of type '" "daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getNumberOfAvailableRows();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *CsvDataSource_CSVFeatureManagerFloat64_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_FileDataSource_CSVFeatureManagerFloat64__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::string *arg1 = 0 ;
  daal::data_management::interface1::DataSourceIface::NumericTableAllocationFlag arg2 ;
  daal::data_management::interface1::DataSourceIface::DictionaryCreationFlag arg3 ;
  size_t arg4 ;
  int res1 = SWIG_OLDOBJ ;
  int val2 ;
  int ecode2 = 0 ;
  int val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:new_FileDataSource_CSVFeatureManagerFloat64",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  {
    std::string *ptr = (std::string *)0;
    res1 = SWIG_AsPtr_std_string(obj0, &ptr);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_FileDataSource_CSVFeatureManagerFloat64" "', argument " "1"" of type '" "std::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_FileDataSource_CSVFeatureManagerFloat64" "', argument " "1"" of type '" "std::string const &""'"); 
    }
    arg1 = ptr;
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "new_FileDataSource_CSVFeatureManagerFloat64" "', argument " "2"" of type '" "daal::data_management::interface1::DataSourceIface::NumericTableAllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::DataSourceIface::NumericTableAllocationFlag >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "new_FileDataSource_CSVFeatureManagerFloat64" "', argument " "3"" of type '" "daal::data_management::interface1::DataSourceIface::DictionaryCreationFlag""'");
  } 
  arg3 = static_cast< daal::data_management::interface1::DataSourceIface::DictionaryCreationFlag >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "new_FileDataSource_CSVFeatureManagerFloat64" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > *)new daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double >((std::string const &)*arg1,arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  if (SWIG_IsNewObj(res1)) delete arg1;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res1)) delete arg1;
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_FileDataSource_CSVFeatureManagerFloat64__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::string *arg1 = 0 ;
  daal::data_management::interface1::DataSourceIface::NumericTableAllocationFlag arg2 ;
  daal::data_management::interface1::DataSourceIface::DictionaryCreationFlag arg3 ;
  int res1 = SWIG_OLDOBJ ;
  int val2 ;
  int ecode2 = 0 ;
  int val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:new_FileDataSource_CSVFeatureManagerFloat64",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    std::string *ptr = (std::string *)0;
    res1 = SWIG_AsPtr_std_string(obj0, &ptr);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_FileDataSource_CSVFeatureManagerFloat64" "', argument " "1"" of type '" "std::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_FileDataSource_CSVFeatureManagerFloat64" "', argument " "1"" of type '" "std::string const &""'"); 
    }
    arg1 = ptr;
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "new_FileDataSource_CSVFeatureManagerFloat64" "', argument " "2"" of type '" "daal::data_management::interface1::DataSourceIface::NumericTableAllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::DataSourceIface::NumericTableAllocationFlag >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "new_FileDataSource_CSVFeatureManagerFloat64" "', argument " "3"" of type '" "daal::data_management::interface1::DataSourceIface::DictionaryCreationFlag""'");
  } 
  arg3 = static_cast< daal::data_management::interface1::DataSourceIface::DictionaryCreationFlag >(val3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > *)new daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double >((std::string const &)*arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  if (SWIG_IsNewObj(res1)) delete arg1;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res1)) delete arg1;
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_FileDataSource_CSVFeatureManagerFloat64__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::string *arg1 = 0 ;
  daal::data_management::interface1::DataSourceIface::NumericTableAllocationFlag arg2 ;
  int res1 = SWIG_OLDOBJ ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:new_FileDataSource_CSVFeatureManagerFloat64",&obj0,&obj1)) SWIG_fail;
  {
    std::string *ptr = (std::string *)0;
    res1 = SWIG_AsPtr_std_string(obj0, &ptr);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_FileDataSource_CSVFeatureManagerFloat64" "', argument " "1"" of type '" "std::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_FileDataSource_CSVFeatureManagerFloat64" "', argument " "1"" of type '" "std::string const &""'"); 
    }
    arg1 = ptr;
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "new_FileDataSource_CSVFeatureManagerFloat64" "', argument " "2"" of type '" "daal::data_management::interface1::DataSourceIface::NumericTableAllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::DataSourceIface::NumericTableAllocationFlag >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > *)new daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double >((std::string const &)*arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  if (SWIG_IsNewObj(res1)) delete arg1;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res1)) delete arg1;
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_FileDataSource_CSVFeatureManagerFloat64__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::string *arg1 = 0 ;
  int res1 = SWIG_OLDOBJ ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:new_FileDataSource_CSVFeatureManagerFloat64",&obj0)) SWIG_fail;
  {
    std::string *ptr = (std::string *)0;
    res1 = SWIG_AsPtr_std_string(obj0, &ptr);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_FileDataSource_CSVFeatureManagerFloat64" "', argument " "1"" of type '" "std::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_FileDataSource_CSVFeatureManagerFloat64" "', argument " "1"" of type '" "std::string const &""'"); 
    }
    arg1 = ptr;
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > *)new daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double >((std::string const &)*arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  if (SWIG_IsNewObj(res1)) delete arg1;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res1)) delete arg1;
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_FileDataSource_CSVFeatureManagerFloat64__SWIG_4(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::string *arg1 = 0 ;
  daal::data_management::interface1::CsvDataSourceOptions arg2 ;
  size_t arg3 ;
  int res1 = SWIG_OLDOBJ ;
  void *argp2 ;
  int res2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:new_FileDataSource_CSVFeatureManagerFloat64",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    std::string *ptr = (std::string *)0;
    res1 = SWIG_AsPtr_std_string(obj0, &ptr);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_FileDataSource_CSVFeatureManagerFloat64" "', argument " "1"" of type '" "std::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_FileDataSource_CSVFeatureManagerFloat64" "', argument " "1"" of type '" "std::string const &""'"); 
    }
    arg1 = ptr;
  }
  {
    res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_daal__data_management__interface1__CsvDataSourceOptions,  0  | 0);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "new_FileDataSource_CSVFeatureManagerFloat64" "', argument " "2"" of type '" "daal::data_management::interface1::CsvDataSourceOptions""'"); 
    }  
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_FileDataSource_CSVFeatureManagerFloat64" "', argument " "2"" of type '" "daal::data_management::interface1::CsvDataSourceOptions""'");
    } else {
      daal::data_management::interface1::CsvDataSourceOptions * temp = reinterpret_cast< daal::data_management::interface1::CsvDataSourceOptions * >(argp2);
      arg2 = *temp;
      if (SWIG_IsNewObj(res2)) delete temp;
    }
  }
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "new_FileDataSource_CSVFeatureManagerFloat64" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > *)new daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double >((std::string const &)*arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  if (SWIG_IsNewObj(res1)) delete arg1;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res1)) delete arg1;
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_FileDataSource_CSVFeatureManagerFloat64__SWIG_5(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::string *arg1 = 0 ;
  daal::data_management::interface1::CsvDataSourceOptions arg2 ;
  int res1 = SWIG_OLDOBJ ;
  void *argp2 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:new_FileDataSource_CSVFeatureManagerFloat64",&obj0,&obj1)) SWIG_fail;
  {
    std::string *ptr = (std::string *)0;
    res1 = SWIG_AsPtr_std_string(obj0, &ptr);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_FileDataSource_CSVFeatureManagerFloat64" "', argument " "1"" of type '" "std::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_FileDataSource_CSVFeatureManagerFloat64" "', argument " "1"" of type '" "std::string const &""'"); 
    }
    arg1 = ptr;
  }
  {
    res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_daal__data_management__interface1__CsvDataSourceOptions,  0  | 0);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "new_FileDataSource_CSVFeatureManagerFloat64" "', argument " "2"" of type '" "daal::data_management::interface1::CsvDataSourceOptions""'"); 
    }  
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_FileDataSource_CSVFeatureManagerFloat64" "', argument " "2"" of type '" "daal::data_management::interface1::CsvDataSourceOptions""'");
    } else {
      daal::data_management::interface1::CsvDataSourceOptions * temp = reinterpret_cast< daal::data_management::interface1::CsvDataSourceOptions * >(argp2);
      arg2 = *temp;
      if (SWIG_IsNewObj(res2)) delete temp;
    }
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > *)new daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double >((std::string const &)*arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  if (SWIG_IsNewObj(res1)) delete arg1;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res1)) delete arg1;
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_FileDataSource_CSVFeatureManagerFloat64(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[5];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 4) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    int res = SWIG_AsPtr_std_string(argv[0], (std::string**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_FileDataSource_CSVFeatureManagerFloat64__SWIG_3(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_AsPtr_std_string(argv[0], (std::string**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__data_management__interface1__CsvDataSourceOptions, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_new_FileDataSource_CSVFeatureManagerFloat64__SWIG_5(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_AsPtr_std_string(argv[0], (std::string**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_new_FileDataSource_CSVFeatureManagerFloat64__SWIG_2(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_AsPtr_std_string(argv[0], (std::string**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__data_management__interface1__CsvDataSourceOptions, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_new_FileDataSource_CSVFeatureManagerFloat64__SWIG_4(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_AsPtr_std_string(argv[0], (std::string**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_new_FileDataSource_CSVFeatureManagerFloat64__SWIG_1(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = SWIG_AsPtr_std_string(argv[0], (std::string**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            return _wrap_new_FileDataSource_CSVFeatureManagerFloat64__SWIG_0(self, args);
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'new_FileDataSource_CSVFeatureManagerFloat64'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double >::FileDataSource(std::string const &,daal::data_management::interface1::DataSourceIface::NumericTableAllocationFlag,daal::data_management::interface1::DataSourceIface::DictionaryCreationFlag,size_t)\n"
    "    daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double >::FileDataSource(std::string const &,daal::data_management::interface1::DataSourceIface::NumericTableAllocationFlag,daal::data_management::interface1::DataSourceIface::DictionaryCreationFlag)\n"
    "    daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double >::FileDataSource(std::string const &,daal::data_management::interface1::DataSourceIface::NumericTableAllocationFlag)\n"
    "    daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double >::FileDataSource(std::string const &)\n"
    "    daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double >::FileDataSource(std::string const &,daal::data_management::interface1::CsvDataSourceOptions,size_t)\n"
    "    daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double >::FileDataSource(std::string const &,daal::data_management::interface1::CsvDataSourceOptions)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_FileDataSource_CSVFeatureManagerFloat64(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > *arg1 = (daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_FileDataSource_CSVFeatureManagerFloat64",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_FileDataSource_CSVFeatureManagerFloat64" "', argument " "1"" of type '" "daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_FileDataSource_CSVFeatureManagerFloat64" "', argument " "1"" of type '" "daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_FileDataSource_CSVFeatureManagerFloat64_createDictionaryFromContext(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > *arg1 = (daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:FileDataSource_CSVFeatureManagerFloat64_createDictionaryFromContext",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "FileDataSource_CSVFeatureManagerFloat64_createDictionaryFromContext" "', argument " "1"" of type '" "daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "FileDataSource_CSVFeatureManagerFloat64_createDictionaryFromContext" "', argument " "1"" of type '" "daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->createDictionaryFromContext();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_FileDataSource_CSVFeatureManagerFloat64_getStatus(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > *arg1 = (daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::DataSourceIface::DataSourceStatus result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:FileDataSource_CSVFeatureManagerFloat64_getStatus",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "FileDataSource_CSVFeatureManagerFloat64_getStatus" "', argument " "1"" of type '" "daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "FileDataSource_CSVFeatureManagerFloat64_getStatus" "', argument " "1"" of type '" "daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::DataSourceIface::DataSourceStatus)(arg1)->getStatus();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *FileDataSource_CSVFeatureManagerFloat64_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_serializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)":PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_serializationTag")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR serializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getSerializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getSerializationTag",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > const *)arg1)->getSerializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  double *arg1 = (double *) (double *)0 ;
  size_t arg2 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_double, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create" "', argument " "1"" of type '" "double *const""'"); 
  }
  arg1 = reinterpret_cast< double * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  double *arg1 = (double *) (double *)0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_double, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create" "', argument " "1"" of type '" "double *const""'"); 
  }
  arg1 = reinterpret_cast< double * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  double *arg1 = (double *) (double *)0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_double, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create" "', argument " "1"" of type '" "double *const""'"); 
  }
  arg1 = reinterpret_cast< double * >(argp1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)":PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create__SWIG_4(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< double > *arg1 = 0 ;
  size_t arg2 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  size_t length1 ;
  daal::services::SharedPtr< double > r4p1 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create",&obj0,&obj1)) SWIG_fail;
  {
    {
      int is_new_object = 0;
      PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
        ? obj_to_array_no_conversion(obj0, NPY_DOUBLE)
        :obj_to_array_contiguous_allow_conversion(obj0, NPY_DOUBLE, &is_new_object));
      if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
      // we provide the SharedPtr with a deleter which decrements the pyref
      r4p1 = daal::services::SharedPtr< double >((double*)array_data(array), NumpyDeleter(array));
      arg1 = &r4p1;
      arg2 = (size_t) array_size(array,0);
      // we need it increment the ref-count if we use the obj0 array in-place
      // if we copied/converted it we already own our own reference
      if((PyObject*)array == obj0) Py_INCREF(array);
    }
    
    // The size should be the the dimension of the square matrix as opposed to the length1 of the array.
    // We must calculate the dimension from the length1.
    length1 = arg2;
    
    if(fmod((sqrt(1 + 8 * length1) - 1) / 2, 1) != 0) {
      SWIG_exception_fail(SWIG_ValueError, "Packed representation does not describe square matrix");
    }
    arg2 = (sqrt(1 + 8 * length1) - 1) / 2;
  }
  res3 = SWIG_ConvertPtr(obj1, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::SharedPtr< double > const &)*arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create__SWIG_5(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< double > *arg1 = 0 ;
  size_t arg2 ;
  size_t length1 ;
  daal::services::SharedPtr< double > r4p1 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create",&obj0)) SWIG_fail;
  {
    {
      int is_new_object = 0;
      PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
        ? obj_to_array_no_conversion(obj0, NPY_DOUBLE)
        :obj_to_array_contiguous_allow_conversion(obj0, NPY_DOUBLE, &is_new_object));
      if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
      // we provide the SharedPtr with a deleter which decrements the pyref
      r4p1 = daal::services::SharedPtr< double >((double*)array_data(array), NumpyDeleter(array));
      arg1 = &r4p1;
      arg2 = (size_t) array_size(array,0);
      // we need it increment the ref-count if we use the obj0 array in-place
      // if we copied/converted it we already own our own reference
      if((PyObject*)array == obj0) Py_INCREF(array);
    }
    
    // The size should be the the dimension of the square matrix as opposed to the length1 of the array.
    // We must calculate the dimension from the length1.
    length1 = arg2;
    
    if(fmod((sqrt(1 + 8 * length1) - 1) / 2, 1) != 0) {
      SWIG_exception_fail(SWIG_ValueError, "Packed representation does not describe square matrix");
    }
    arg2 = (sqrt(1 + 8 * length1) - 1) / 2;
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::SharedPtr< double > const &)*arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create__SWIG_6(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  double *arg1 = (double *) (double *)0 ;
  size_t arg2 ;
  double *arg3 = 0 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  double temp3 ;
  double val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_double, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create" "', argument " "1"" of type '" "double *const""'"); 
  }
  arg1 = reinterpret_cast< double * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_double(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create" "', argument " "3"" of type '" "double""'");
  } 
  temp3 = static_cast< double >(val3);
  arg3 = &temp3;
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(double const &)*arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create__SWIG_7(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  double *arg1 = (double *) (double *)0 ;
  size_t arg2 ;
  double *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  double temp3 ;
  double val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_double, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create" "', argument " "1"" of type '" "double *const""'"); 
  }
  arg1 = reinterpret_cast< double * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_double(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create" "', argument " "3"" of type '" "double""'");
  } 
  temp3 = static_cast< double >(val3);
  arg3 = &temp3;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(double const &)*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create__SWIG_8(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< double > *arg1 = 0 ;
  size_t arg2 ;
  double *arg3 = 0 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  size_t length1 ;
  daal::services::SharedPtr< double > r4p1 ;
  double temp3 ;
  double val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    {
      int is_new_object = 0;
      PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
        ? obj_to_array_no_conversion(obj0, NPY_DOUBLE)
        :obj_to_array_contiguous_allow_conversion(obj0, NPY_DOUBLE, &is_new_object));
      if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
      // we provide the SharedPtr with a deleter which decrements the pyref
      r4p1 = daal::services::SharedPtr< double >((double*)array_data(array), NumpyDeleter(array));
      arg1 = &r4p1;
      arg2 = (size_t) array_size(array,0);
      // we need it increment the ref-count if we use the obj0 array in-place
      // if we copied/converted it we already own our own reference
      if((PyObject*)array == obj0) Py_INCREF(array);
    }
    
    // The size should be the the dimension of the square matrix as opposed to the length1 of the array.
    // We must calculate the dimension from the length1.
    length1 = arg2;
    
    if(fmod((sqrt(1 + 8 * length1) - 1) / 2, 1) != 0) {
      SWIG_exception_fail(SWIG_ValueError, "Packed representation does not describe square matrix");
    }
    arg2 = (sqrt(1 + 8 * length1) - 1) / 2;
  }
  ecode3 = SWIG_AsVal_double(obj1, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create" "', argument " "3"" of type '" "double""'");
  } 
  temp3 = static_cast< double >(val3);
  arg3 = &temp3;
  res4 = SWIG_ConvertPtr(obj2, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::SharedPtr< double > const &)*arg1,arg2,(double const &)*arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create__SWIG_9(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< double > *arg1 = 0 ;
  size_t arg2 ;
  double *arg3 = 0 ;
  size_t length1 ;
  daal::services::SharedPtr< double > r4p1 ;
  double temp3 ;
  double val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create",&obj0,&obj1)) SWIG_fail;
  {
    {
      int is_new_object = 0;
      PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
        ? obj_to_array_no_conversion(obj0, NPY_DOUBLE)
        :obj_to_array_contiguous_allow_conversion(obj0, NPY_DOUBLE, &is_new_object));
      if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
      // we provide the SharedPtr with a deleter which decrements the pyref
      r4p1 = daal::services::SharedPtr< double >((double*)array_data(array), NumpyDeleter(array));
      arg1 = &r4p1;
      arg2 = (size_t) array_size(array,0);
      // we need it increment the ref-count if we use the obj0 array in-place
      // if we copied/converted it we already own our own reference
      if((PyObject*)array == obj0) Py_INCREF(array);
    }
    
    // The size should be the the dimension of the square matrix as opposed to the length1 of the array.
    // We must calculate the dimension from the length1.
    length1 = arg2;
    
    if(fmod((sqrt(1 + 8 * length1) - 1) / 2, 1) != 0) {
      SWIG_exception_fail(SWIG_ValueError, "Packed representation does not describe square matrix");
    }
    arg2 = (sqrt(1 + 8 * length1) - 1) / 2;
  }
  ecode3 = SWIG_AsVal_double(obj1, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create" "', argument " "3"" of type '" "double""'");
  } 
  temp3 = static_cast< double >(val3);
  arg3 = &temp3;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::SharedPtr< double > const &)*arg1,arg2,(double const &)*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create__SWIG_10(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg2 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create__SWIG_11(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg2 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create",&obj0,&obj1)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create__SWIG_12(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::NumericTable::AllocationFlag arg2 ;
  double *arg3 = 0 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  double temp3 ;
  double val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTable::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTable::AllocationFlag >(val2);
  ecode3 = SWIG_AsVal_double(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create" "', argument " "3"" of type '" "double""'");
  } 
  temp3 = static_cast< double >(val3);
  arg3 = &temp3;
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(double const &)*arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create__SWIG_13(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::NumericTable::AllocationFlag arg2 ;
  double *arg3 = 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  double temp3 ;
  double val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTable::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTable::AllocationFlag >(val2);
  ecode3 = SWIG_AsVal_double(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create" "', argument " "3"" of type '" "double""'");
  } 
  temp3 = static_cast< double >(val3);
  arg3 = &temp3;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(double const &)*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[5];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 4) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create__SWIG_3(self, args);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_double, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create__SWIG_2(self, args);
    }
  }
  if (argc == 1) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_DOUBLE))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      if (argc <= 1) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create__SWIG_5(self, args);
      }
      return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create__SWIG_5(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_double, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create__SWIG_11(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_DOUBLE))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create__SWIG_4(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_DOUBLE))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      {
        int res = SWIG_AsVal_double(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create__SWIG_9(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_double, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create__SWIG_0(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_double, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_double(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create__SWIG_7(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create__SWIG_10(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_double(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create__SWIG_13(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_DOUBLE))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      {
        int res = SWIG_AsVal_double(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create__SWIG_8(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_double, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_double(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create__SWIG_6(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_double(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create__SWIG_12(self, args);
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::create(double *const,size_t,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::create(double *const,size_t)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::create(double *const)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::create()\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::create(daal::services::SharedPtr< double > const &,size_t,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::create(daal::services::SharedPtr< double > const &,size_t)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::create(double *const,size_t,double const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::create(double *const,size_t,double const &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::create(daal::services::SharedPtr< double > const &,size_t,double const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::create(daal::services::SharedPtr< double > const &,size_t,double const &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::create(size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::create(size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::create(size_t,daal::data_management::interface1::NumericTable::AllocationFlag,double const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::create(size_t,daal::data_management::interface1::NumericTable::AllocationFlag,double const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_assign__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *) 0 ;
  float arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *smartarg1 = 0 ;
  float val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_float(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_assign" "', argument " "2"" of type '" "float""'");
  } 
  arg2 = static_cast< float >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_assign__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *) 0 ;
  double arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *smartarg1 = 0 ;
  double val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_double(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_assign" "', argument " "2"" of type '" "double""'");
  } 
  arg2 = static_cast< double >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_assign__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_assign" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_assign(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_assign__SWIG_3(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_float(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_assign__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_double(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_assign__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_assign'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::assign(float)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::assign(double)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::assign(int)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfRows__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfRows__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfRows__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfRows(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[6];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 5) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfRows__SWIG_0(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfRows__SWIG_1(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfRows__SWIG_2(self, args);
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfRows'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfRows__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfRows__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfRows__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfRows(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfRows__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfRows__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfRows__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfRows'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfColumnValues__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfColumnValues__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfColumnValues__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfColumnValues(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[7];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 6) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfColumnValues__SWIG_0(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfColumnValues__SWIG_1(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfColumnValues__SWIG_2(self, args);
              }
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfColumnValues'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getPackedArray__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *) 0 ;
  daal::data_management::ReadWriteMode arg2 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared3 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getPackedArray",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getPackedArray" "', argument " "2"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg2 = static_cast< daal::data_management::ReadWriteMode >(val2);
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared3 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp3);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp3);
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared3.get());
    } else {
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp3)->get());
    }
    if(!arg3) SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getPackedArray(arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getPackedArray__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *) 0 ;
  daal::data_management::ReadWriteMode arg2 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared3 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getPackedArray",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getPackedArray" "', argument " "2"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg2 = static_cast< daal::data_management::ReadWriteMode >(val2);
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared3 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp3);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp3);
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared3.get());
    } else {
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp3)->get());
    }
    if(!arg3) SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getPackedArray(arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getPackedArray__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *) 0 ;
  daal::data_management::ReadWriteMode arg2 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared3 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getPackedArray",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getPackedArray" "', argument " "2"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg2 = static_cast< daal::data_management::ReadWriteMode >(val2);
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared3 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp3);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp3);
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared3.get());
    } else {
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp3)->get());
    }
    if(!arg3) SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getPackedArray(arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getPackedArray(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[4];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 3) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getPackedArray__SWIG_0(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getPackedArray__SWIG_1(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getPackedArray__SWIG_2(self, args);
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getPackedArray'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::getPackedArray(daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::getPackedArray(daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::getPackedArray(daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releasePackedArray__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releasePackedArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releasePackedArray(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releasePackedArray__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releasePackedArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releasePackedArray(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releasePackedArray__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releasePackedArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releasePackedArray(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releasePackedArray(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releasePackedArray__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releasePackedArray__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releasePackedArray__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releasePackedArray'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::releasePackedArray(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::releasePackedArray(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double >::releasePackedArray(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_serializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)":PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_serializationTag")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR serializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getSerializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getSerializationTag",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > const *)arg1)->getSerializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  float *arg1 = (float *) (float *)0 ;
  size_t arg2 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_float, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create" "', argument " "1"" of type '" "float *const""'"); 
  }
  arg1 = reinterpret_cast< float * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  float *arg1 = (float *) (float *)0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_float, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create" "', argument " "1"" of type '" "float *const""'"); 
  }
  arg1 = reinterpret_cast< float * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  float *arg1 = (float *) (float *)0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_float, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create" "', argument " "1"" of type '" "float *const""'"); 
  }
  arg1 = reinterpret_cast< float * >(argp1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)":PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create__SWIG_4(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< float > *arg1 = 0 ;
  size_t arg2 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  size_t length1 ;
  daal::services::SharedPtr< float > r4p1 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create",&obj0,&obj1)) SWIG_fail;
  {
    {
      int is_new_object = 0;
      PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
        ? obj_to_array_no_conversion(obj0, NPY_FLOAT)
        :obj_to_array_contiguous_allow_conversion(obj0, NPY_FLOAT, &is_new_object));
      if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
      // we provide the SharedPtr with a deleter which decrements the pyref
      r4p1 = daal::services::SharedPtr< float >((float*)array_data(array), NumpyDeleter(array));
      arg1 = &r4p1;
      arg2 = (size_t) array_size(array,0);
      // we need it increment the ref-count if we use the obj0 array in-place
      // if we copied/converted it we already own our own reference
      if((PyObject*)array == obj0) Py_INCREF(array);
    }
    
    // The size should be the the dimension of the square matrix as opposed to the length1 of the array.
    // We must calculate the dimension from the length1.
    length1 = arg2;
    
    if(fmod((sqrt(1 + 8 * length1) - 1) / 2, 1) != 0) {
      SWIG_exception_fail(SWIG_ValueError, "Packed representation does not describe square matrix");
    }
    arg2 = (sqrt(1 + 8 * length1) - 1) / 2;
  }
  res3 = SWIG_ConvertPtr(obj1, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::SharedPtr< float > const &)*arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create__SWIG_5(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< float > *arg1 = 0 ;
  size_t arg2 ;
  size_t length1 ;
  daal::services::SharedPtr< float > r4p1 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create",&obj0)) SWIG_fail;
  {
    {
      int is_new_object = 0;
      PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
        ? obj_to_array_no_conversion(obj0, NPY_FLOAT)
        :obj_to_array_contiguous_allow_conversion(obj0, NPY_FLOAT, &is_new_object));
      if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
      // we provide the SharedPtr with a deleter which decrements the pyref
      r4p1 = daal::services::SharedPtr< float >((float*)array_data(array), NumpyDeleter(array));
      arg1 = &r4p1;
      arg2 = (size_t) array_size(array,0);
      // we need it increment the ref-count if we use the obj0 array in-place
      // if we copied/converted it we already own our own reference
      if((PyObject*)array == obj0) Py_INCREF(array);
    }
    
    // The size should be the the dimension of the square matrix as opposed to the length1 of the array.
    // We must calculate the dimension from the length1.
    length1 = arg2;
    
    if(fmod((sqrt(1 + 8 * length1) - 1) / 2, 1) != 0) {
      SWIG_exception_fail(SWIG_ValueError, "Packed representation does not describe square matrix");
    }
    arg2 = (sqrt(1 + 8 * length1) - 1) / 2;
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::SharedPtr< float > const &)*arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create__SWIG_6(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  float *arg1 = (float *) (float *)0 ;
  size_t arg2 ;
  float *arg3 = 0 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  float temp3 ;
  float val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_float, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create" "', argument " "1"" of type '" "float *const""'"); 
  }
  arg1 = reinterpret_cast< float * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_float(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create" "', argument " "3"" of type '" "float""'");
  } 
  temp3 = static_cast< float >(val3);
  arg3 = &temp3;
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(float const &)*arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create__SWIG_7(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  float *arg1 = (float *) (float *)0 ;
  size_t arg2 ;
  float *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  float temp3 ;
  float val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_float, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create" "', argument " "1"" of type '" "float *const""'"); 
  }
  arg1 = reinterpret_cast< float * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_float(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create" "', argument " "3"" of type '" "float""'");
  } 
  temp3 = static_cast< float >(val3);
  arg3 = &temp3;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(float const &)*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create__SWIG_8(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< float > *arg1 = 0 ;
  size_t arg2 ;
  float *arg3 = 0 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  size_t length1 ;
  daal::services::SharedPtr< float > r4p1 ;
  float temp3 ;
  float val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    {
      int is_new_object = 0;
      PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
        ? obj_to_array_no_conversion(obj0, NPY_FLOAT)
        :obj_to_array_contiguous_allow_conversion(obj0, NPY_FLOAT, &is_new_object));
      if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
      // we provide the SharedPtr with a deleter which decrements the pyref
      r4p1 = daal::services::SharedPtr< float >((float*)array_data(array), NumpyDeleter(array));
      arg1 = &r4p1;
      arg2 = (size_t) array_size(array,0);
      // we need it increment the ref-count if we use the obj0 array in-place
      // if we copied/converted it we already own our own reference
      if((PyObject*)array == obj0) Py_INCREF(array);
    }
    
    // The size should be the the dimension of the square matrix as opposed to the length1 of the array.
    // We must calculate the dimension from the length1.
    length1 = arg2;
    
    if(fmod((sqrt(1 + 8 * length1) - 1) / 2, 1) != 0) {
      SWIG_exception_fail(SWIG_ValueError, "Packed representation does not describe square matrix");
    }
    arg2 = (sqrt(1 + 8 * length1) - 1) / 2;
  }
  ecode3 = SWIG_AsVal_float(obj1, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create" "', argument " "3"" of type '" "float""'");
  } 
  temp3 = static_cast< float >(val3);
  arg3 = &temp3;
  res4 = SWIG_ConvertPtr(obj2, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::SharedPtr< float > const &)*arg1,arg2,(float const &)*arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create__SWIG_9(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< float > *arg1 = 0 ;
  size_t arg2 ;
  float *arg3 = 0 ;
  size_t length1 ;
  daal::services::SharedPtr< float > r4p1 ;
  float temp3 ;
  float val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create",&obj0,&obj1)) SWIG_fail;
  {
    {
      int is_new_object = 0;
      PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
        ? obj_to_array_no_conversion(obj0, NPY_FLOAT)
        :obj_to_array_contiguous_allow_conversion(obj0, NPY_FLOAT, &is_new_object));
      if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
      // we provide the SharedPtr with a deleter which decrements the pyref
      r4p1 = daal::services::SharedPtr< float >((float*)array_data(array), NumpyDeleter(array));
      arg1 = &r4p1;
      arg2 = (size_t) array_size(array,0);
      // we need it increment the ref-count if we use the obj0 array in-place
      // if we copied/converted it we already own our own reference
      if((PyObject*)array == obj0) Py_INCREF(array);
    }
    
    // The size should be the the dimension of the square matrix as opposed to the length1 of the array.
    // We must calculate the dimension from the length1.
    length1 = arg2;
    
    if(fmod((sqrt(1 + 8 * length1) - 1) / 2, 1) != 0) {
      SWIG_exception_fail(SWIG_ValueError, "Packed representation does not describe square matrix");
    }
    arg2 = (sqrt(1 + 8 * length1) - 1) / 2;
  }
  ecode3 = SWIG_AsVal_float(obj1, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create" "', argument " "3"" of type '" "float""'");
  } 
  temp3 = static_cast< float >(val3);
  arg3 = &temp3;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::SharedPtr< float > const &)*arg1,arg2,(float const &)*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create__SWIG_10(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg2 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create__SWIG_11(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg2 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create",&obj0,&obj1)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create__SWIG_12(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::NumericTable::AllocationFlag arg2 ;
  float *arg3 = 0 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  float temp3 ;
  float val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTable::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTable::AllocationFlag >(val2);
  ecode3 = SWIG_AsVal_float(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create" "', argument " "3"" of type '" "float""'");
  } 
  temp3 = static_cast< float >(val3);
  arg3 = &temp3;
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(float const &)*arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create__SWIG_13(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::NumericTable::AllocationFlag arg2 ;
  float *arg3 = 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  float temp3 ;
  float val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTable::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTable::AllocationFlag >(val2);
  ecode3 = SWIG_AsVal_float(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create" "', argument " "3"" of type '" "float""'");
  } 
  temp3 = static_cast< float >(val3);
  arg3 = &temp3;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(float const &)*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[5];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 4) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create__SWIG_3(self, args);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_float, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create__SWIG_2(self, args);
    }
  }
  if (argc == 1) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_FLOAT))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      if (argc <= 1) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create__SWIG_5(self, args);
      }
      return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create__SWIG_5(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_float, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create__SWIG_11(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_FLOAT))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create__SWIG_4(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_FLOAT))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      {
        int res = SWIG_AsVal_float(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create__SWIG_9(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_float, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create__SWIG_0(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_float, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_float(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create__SWIG_7(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create__SWIG_10(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_float(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create__SWIG_13(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_FLOAT))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      {
        int res = SWIG_AsVal_float(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create__SWIG_8(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_float, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_float(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create__SWIG_6(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_float(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create__SWIG_12(self, args);
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::create(float *const,size_t,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::create(float *const,size_t)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::create(float *const)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::create()\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::create(daal::services::SharedPtr< float > const &,size_t,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::create(daal::services::SharedPtr< float > const &,size_t)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::create(float *const,size_t,float const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::create(float *const,size_t,float const &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::create(daal::services::SharedPtr< float > const &,size_t,float const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::create(daal::services::SharedPtr< float > const &,size_t,float const &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::create(size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::create(size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::create(size_t,daal::data_management::interface1::NumericTable::AllocationFlag,float const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::create(size_t,daal::data_management::interface1::NumericTable::AllocationFlag,float const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_assign__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *) 0 ;
  float arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *smartarg1 = 0 ;
  float val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_float(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_assign" "', argument " "2"" of type '" "float""'");
  } 
  arg2 = static_cast< float >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_assign__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *) 0 ;
  double arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *smartarg1 = 0 ;
  double val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_double(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_assign" "', argument " "2"" of type '" "double""'");
  } 
  arg2 = static_cast< double >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_assign__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_assign" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_assign(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_assign__SWIG_3(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_float(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_assign__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_double(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_assign__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_assign'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::assign(float)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::assign(double)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::assign(int)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfRows__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfRows__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfRows__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfRows(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[6];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 5) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfRows__SWIG_0(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfRows__SWIG_1(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfRows__SWIG_2(self, args);
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfRows'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfRows__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfRows__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfRows__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfRows(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfRows__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfRows__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfRows__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfRows'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfColumnValues__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfColumnValues__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfColumnValues__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfColumnValues(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[7];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 6) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfColumnValues__SWIG_0(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfColumnValues__SWIG_1(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfColumnValues__SWIG_2(self, args);
              }
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfColumnValues'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getPackedArray__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *) 0 ;
  daal::data_management::ReadWriteMode arg2 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared3 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getPackedArray",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getPackedArray" "', argument " "2"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg2 = static_cast< daal::data_management::ReadWriteMode >(val2);
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared3 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp3);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp3);
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared3.get());
    } else {
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp3)->get());
    }
    if(!arg3) SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getPackedArray(arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getPackedArray__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *) 0 ;
  daal::data_management::ReadWriteMode arg2 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared3 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getPackedArray",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getPackedArray" "', argument " "2"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg2 = static_cast< daal::data_management::ReadWriteMode >(val2);
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared3 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp3);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp3);
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared3.get());
    } else {
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp3)->get());
    }
    if(!arg3) SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getPackedArray(arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getPackedArray__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *) 0 ;
  daal::data_management::ReadWriteMode arg2 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared3 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getPackedArray",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getPackedArray" "', argument " "2"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg2 = static_cast< daal::data_management::ReadWriteMode >(val2);
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared3 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp3);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp3);
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared3.get());
    } else {
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp3)->get());
    }
    if(!arg3) SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getPackedArray(arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getPackedArray(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[4];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 3) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getPackedArray__SWIG_0(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getPackedArray__SWIG_1(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getPackedArray__SWIG_2(self, args);
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getPackedArray'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::getPackedArray(daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::getPackedArray(daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::getPackedArray(daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releasePackedArray__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releasePackedArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releasePackedArray(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releasePackedArray__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releasePackedArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releasePackedArray(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releasePackedArray__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releasePackedArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releasePackedArray(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releasePackedArray(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releasePackedArray__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releasePackedArray__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releasePackedArray__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releasePackedArray'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::releasePackedArray(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::releasePackedArray(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float >::releasePackedArray(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_serializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)":PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_serializationTag")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR serializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getSerializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getSerializationTag",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > const *)arg1)->getSerializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int *arg1 = (int *) (int *)0 ;
  size_t arg2 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_int, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create" "', argument " "1"" of type '" "int *const""'"); 
  }
  arg1 = reinterpret_cast< int * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int *arg1 = (int *) (int *)0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_int, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create" "', argument " "1"" of type '" "int *const""'"); 
  }
  arg1 = reinterpret_cast< int * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int *arg1 = (int *) (int *)0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_int, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create" "', argument " "1"" of type '" "int *const""'"); 
  }
  arg1 = reinterpret_cast< int * >(argp1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)":PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create__SWIG_4(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< int > *arg1 = 0 ;
  size_t arg2 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  size_t length1 ;
  daal::services::SharedPtr< int > r4p1 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create",&obj0,&obj1)) SWIG_fail;
  {
    {
      int is_new_object = 0;
      PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
        ? obj_to_array_no_conversion(obj0, NPY_INT)
        :obj_to_array_contiguous_allow_conversion(obj0, NPY_INT, &is_new_object));
      if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
      // we provide the SharedPtr with a deleter which decrements the pyref
      r4p1 = daal::services::SharedPtr< int >((int*)array_data(array), NumpyDeleter(array));
      arg1 = &r4p1;
      arg2 = (size_t) array_size(array,0);
      // we need it increment the ref-count if we use the obj0 array in-place
      // if we copied/converted it we already own our own reference
      if((PyObject*)array == obj0) Py_INCREF(array);
    }
    
    // The size should be the the dimension of the square matrix as opposed to the length1 of the array.
    // We must calculate the dimension from the length1.
    length1 = arg2;
    
    if(fmod((sqrt(1 + 8 * length1) - 1) / 2, 1) != 0) {
      SWIG_exception_fail(SWIG_ValueError, "Packed representation does not describe square matrix");
    }
    arg2 = (sqrt(1 + 8 * length1) - 1) / 2;
  }
  res3 = SWIG_ConvertPtr(obj1, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::SharedPtr< int > const &)*arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create__SWIG_5(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< int > *arg1 = 0 ;
  size_t arg2 ;
  size_t length1 ;
  daal::services::SharedPtr< int > r4p1 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create",&obj0)) SWIG_fail;
  {
    {
      int is_new_object = 0;
      PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
        ? obj_to_array_no_conversion(obj0, NPY_INT)
        :obj_to_array_contiguous_allow_conversion(obj0, NPY_INT, &is_new_object));
      if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
      // we provide the SharedPtr with a deleter which decrements the pyref
      r4p1 = daal::services::SharedPtr< int >((int*)array_data(array), NumpyDeleter(array));
      arg1 = &r4p1;
      arg2 = (size_t) array_size(array,0);
      // we need it increment the ref-count if we use the obj0 array in-place
      // if we copied/converted it we already own our own reference
      if((PyObject*)array == obj0) Py_INCREF(array);
    }
    
    // The size should be the the dimension of the square matrix as opposed to the length1 of the array.
    // We must calculate the dimension from the length1.
    length1 = arg2;
    
    if(fmod((sqrt(1 + 8 * length1) - 1) / 2, 1) != 0) {
      SWIG_exception_fail(SWIG_ValueError, "Packed representation does not describe square matrix");
    }
    arg2 = (sqrt(1 + 8 * length1) - 1) / 2;
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::SharedPtr< int > const &)*arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create__SWIG_6(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int *arg1 = (int *) (int *)0 ;
  size_t arg2 ;
  int *arg3 = 0 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_int, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create" "', argument " "1"" of type '" "int *const""'"); 
  }
  arg1 = reinterpret_cast< int * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(int const &)*arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create__SWIG_7(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int *arg1 = (int *) (int *)0 ;
  size_t arg2 ;
  int *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_int, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create" "', argument " "1"" of type '" "int *const""'"); 
  }
  arg1 = reinterpret_cast< int * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(int const &)*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create__SWIG_8(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< int > *arg1 = 0 ;
  size_t arg2 ;
  int *arg3 = 0 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  size_t length1 ;
  daal::services::SharedPtr< int > r4p1 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    {
      int is_new_object = 0;
      PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
        ? obj_to_array_no_conversion(obj0, NPY_INT)
        :obj_to_array_contiguous_allow_conversion(obj0, NPY_INT, &is_new_object));
      if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
      // we provide the SharedPtr with a deleter which decrements the pyref
      r4p1 = daal::services::SharedPtr< int >((int*)array_data(array), NumpyDeleter(array));
      arg1 = &r4p1;
      arg2 = (size_t) array_size(array,0);
      // we need it increment the ref-count if we use the obj0 array in-place
      // if we copied/converted it we already own our own reference
      if((PyObject*)array == obj0) Py_INCREF(array);
    }
    
    // The size should be the the dimension of the square matrix as opposed to the length1 of the array.
    // We must calculate the dimension from the length1.
    length1 = arg2;
    
    if(fmod((sqrt(1 + 8 * length1) - 1) / 2, 1) != 0) {
      SWIG_exception_fail(SWIG_ValueError, "Packed representation does not describe square matrix");
    }
    arg2 = (sqrt(1 + 8 * length1) - 1) / 2;
  }
  ecode3 = SWIG_AsVal_int(obj1, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  res4 = SWIG_ConvertPtr(obj2, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::SharedPtr< int > const &)*arg1,arg2,(int const &)*arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create__SWIG_9(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< int > *arg1 = 0 ;
  size_t arg2 ;
  int *arg3 = 0 ;
  size_t length1 ;
  daal::services::SharedPtr< int > r4p1 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create",&obj0,&obj1)) SWIG_fail;
  {
    {
      int is_new_object = 0;
      PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
        ? obj_to_array_no_conversion(obj0, NPY_INT)
        :obj_to_array_contiguous_allow_conversion(obj0, NPY_INT, &is_new_object));
      if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
      // we provide the SharedPtr with a deleter which decrements the pyref
      r4p1 = daal::services::SharedPtr< int >((int*)array_data(array), NumpyDeleter(array));
      arg1 = &r4p1;
      arg2 = (size_t) array_size(array,0);
      // we need it increment the ref-count if we use the obj0 array in-place
      // if we copied/converted it we already own our own reference
      if((PyObject*)array == obj0) Py_INCREF(array);
    }
    
    // The size should be the the dimension of the square matrix as opposed to the length1 of the array.
    // We must calculate the dimension from the length1.
    length1 = arg2;
    
    if(fmod((sqrt(1 + 8 * length1) - 1) / 2, 1) != 0) {
      SWIG_exception_fail(SWIG_ValueError, "Packed representation does not describe square matrix");
    }
    arg2 = (sqrt(1 + 8 * length1) - 1) / 2;
  }
  ecode3 = SWIG_AsVal_int(obj1, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::SharedPtr< int > const &)*arg1,arg2,(int const &)*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create__SWIG_10(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg2 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create__SWIG_11(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg2 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create",&obj0,&obj1)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create__SWIG_12(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::NumericTable::AllocationFlag arg2 ;
  int *arg3 = 0 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTable::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTable::AllocationFlag >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(int const &)*arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create__SWIG_13(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::NumericTable::AllocationFlag arg2 ;
  int *arg3 = 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTable::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTable::AllocationFlag >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(int const &)*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[5];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 4) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create__SWIG_3(self, args);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_int, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create__SWIG_2(self, args);
    }
  }
  if (argc == 1) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_INT))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      if (argc <= 1) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create__SWIG_5(self, args);
      }
      return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create__SWIG_5(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_int, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create__SWIG_11(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_INT))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create__SWIG_4(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_INT))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create__SWIG_9(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_int, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create__SWIG_0(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_int, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create__SWIG_7(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create__SWIG_10(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create__SWIG_13(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_INT))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create__SWIG_8(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_int, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create__SWIG_6(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create__SWIG_12(self, args);
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::create(int *const,size_t,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::create(int *const,size_t)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::create(int *const)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::create()\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::create(daal::services::SharedPtr< int > const &,size_t,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::create(daal::services::SharedPtr< int > const &,size_t)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::create(int *const,size_t,int const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::create(int *const,size_t,int const &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::create(daal::services::SharedPtr< int > const &,size_t,int const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::create(daal::services::SharedPtr< int > const &,size_t,int const &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::create(size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::create(size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::create(size_t,daal::data_management::interface1::NumericTable::AllocationFlag,int const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::create(size_t,daal::data_management::interface1::NumericTable::AllocationFlag,int const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_assign__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *) 0 ;
  float arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *smartarg1 = 0 ;
  float val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_float(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_assign" "', argument " "2"" of type '" "float""'");
  } 
  arg2 = static_cast< float >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_assign__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *) 0 ;
  double arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *smartarg1 = 0 ;
  double val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_double(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_assign" "', argument " "2"" of type '" "double""'");
  } 
  arg2 = static_cast< double >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_assign__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_assign" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_assign(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_assign__SWIG_3(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_float(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_assign__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_double(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_assign__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_assign'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::assign(float)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::assign(double)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::assign(int)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfRows__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfRows__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfRows__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfRows(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[6];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 5) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfRows__SWIG_0(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfRows__SWIG_1(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfRows__SWIG_2(self, args);
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfRows'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfRows__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfRows__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfRows__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfRows(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfRows__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfRows__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfRows__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfRows'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfColumnValues__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfColumnValues__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfColumnValues__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfColumnValues(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[7];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 6) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfColumnValues__SWIG_0(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfColumnValues__SWIG_1(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfColumnValues__SWIG_2(self, args);
              }
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfColumnValues'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfColumnValues__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfColumnValues__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfColumnValues__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfColumnValues(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfColumnValues__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfColumnValues__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfColumnValues__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfColumnValues'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getPackedArray__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *) 0 ;
  daal::data_management::ReadWriteMode arg2 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared3 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getPackedArray",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getPackedArray" "', argument " "2"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg2 = static_cast< daal::data_management::ReadWriteMode >(val2);
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared3 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp3);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp3);
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared3.get());
    } else {
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp3)->get());
    }
    if(!arg3) SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getPackedArray(arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getPackedArray__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *) 0 ;
  daal::data_management::ReadWriteMode arg2 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared3 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getPackedArray",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getPackedArray" "', argument " "2"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg2 = static_cast< daal::data_management::ReadWriteMode >(val2);
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared3 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp3);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp3);
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared3.get());
    } else {
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp3)->get());
    }
    if(!arg3) SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getPackedArray(arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getPackedArray__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *) 0 ;
  daal::data_management::ReadWriteMode arg2 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared3 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getPackedArray",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getPackedArray" "', argument " "2"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg2 = static_cast< daal::data_management::ReadWriteMode >(val2);
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared3 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp3);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp3);
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared3.get());
    } else {
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp3)->get());
    }
    if(!arg3) SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getPackedArray(arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getPackedArray(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[4];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 3) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getPackedArray__SWIG_0(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getPackedArray__SWIG_1(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getPackedArray__SWIG_2(self, args);
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getPackedArray'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::getPackedArray(daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::getPackedArray(daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::getPackedArray(daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releasePackedArray__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releasePackedArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releasePackedArray(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releasePackedArray__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releasePackedArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releasePackedArray(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releasePackedArray__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releasePackedArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releasePackedArray(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releasePackedArray(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releasePackedArray__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releasePackedArray__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releasePackedArray__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releasePackedArray'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::releasePackedArray(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::releasePackedArray(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int >::releasePackedArray(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_serializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)":PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_serializationTag")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR serializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getSerializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getSerializationTag",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > const *)arg1)->getSerializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  double *arg1 = (double *) (double *)0 ;
  size_t arg2 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_double, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create" "', argument " "1"" of type '" "double *const""'"); 
  }
  arg1 = reinterpret_cast< double * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  double *arg1 = (double *) (double *)0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_double, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create" "', argument " "1"" of type '" "double *const""'"); 
  }
  arg1 = reinterpret_cast< double * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  double *arg1 = (double *) (double *)0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_double, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create" "', argument " "1"" of type '" "double *const""'"); 
  }
  arg1 = reinterpret_cast< double * >(argp1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)":PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create__SWIG_4(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< double > *arg1 = 0 ;
  size_t arg2 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  size_t length1 ;
  daal::services::SharedPtr< double > r4p1 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create",&obj0,&obj1)) SWIG_fail;
  {
    {
      int is_new_object = 0;
      PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
        ? obj_to_array_no_conversion(obj0, NPY_DOUBLE)
        :obj_to_array_contiguous_allow_conversion(obj0, NPY_DOUBLE, &is_new_object));
      if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
      // we provide the SharedPtr with a deleter which decrements the pyref
      r4p1 = daal::services::SharedPtr< double >((double*)array_data(array), NumpyDeleter(array));
      arg1 = &r4p1;
      arg2 = (size_t) array_size(array,0);
      // we need it increment the ref-count if we use the obj0 array in-place
      // if we copied/converted it we already own our own reference
      if((PyObject*)array == obj0) Py_INCREF(array);
    }
    
    // The size should be the the dimension of the square matrix as opposed to the length1 of the array.
    // We must calculate the dimension from the length1.
    length1 = arg2;
    
    if(fmod((sqrt(1 + 8 * length1) - 1) / 2, 1) != 0) {
      SWIG_exception_fail(SWIG_ValueError, "Packed representation does not describe square matrix");
    }
    arg2 = (sqrt(1 + 8 * length1) - 1) / 2;
  }
  res3 = SWIG_ConvertPtr(obj1, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::SharedPtr< double > const &)*arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create__SWIG_5(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< double > *arg1 = 0 ;
  size_t arg2 ;
  size_t length1 ;
  daal::services::SharedPtr< double > r4p1 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create",&obj0)) SWIG_fail;
  {
    {
      int is_new_object = 0;
      PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
        ? obj_to_array_no_conversion(obj0, NPY_DOUBLE)
        :obj_to_array_contiguous_allow_conversion(obj0, NPY_DOUBLE, &is_new_object));
      if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
      // we provide the SharedPtr with a deleter which decrements the pyref
      r4p1 = daal::services::SharedPtr< double >((double*)array_data(array), NumpyDeleter(array));
      arg1 = &r4p1;
      arg2 = (size_t) array_size(array,0);
      // we need it increment the ref-count if we use the obj0 array in-place
      // if we copied/converted it we already own our own reference
      if((PyObject*)array == obj0) Py_INCREF(array);
    }
    
    // The size should be the the dimension of the square matrix as opposed to the length1 of the array.
    // We must calculate the dimension from the length1.
    length1 = arg2;
    
    if(fmod((sqrt(1 + 8 * length1) - 1) / 2, 1) != 0) {
      SWIG_exception_fail(SWIG_ValueError, "Packed representation does not describe square matrix");
    }
    arg2 = (sqrt(1 + 8 * length1) - 1) / 2;
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::SharedPtr< double > const &)*arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create__SWIG_6(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  double *arg1 = (double *) (double *)0 ;
  size_t arg2 ;
  double *arg3 = 0 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  double temp3 ;
  double val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_double, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create" "', argument " "1"" of type '" "double *const""'"); 
  }
  arg1 = reinterpret_cast< double * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_double(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create" "', argument " "3"" of type '" "double""'");
  } 
  temp3 = static_cast< double >(val3);
  arg3 = &temp3;
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(double const &)*arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create__SWIG_7(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  double *arg1 = (double *) (double *)0 ;
  size_t arg2 ;
  double *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  double temp3 ;
  double val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_double, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create" "', argument " "1"" of type '" "double *const""'"); 
  }
  arg1 = reinterpret_cast< double * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_double(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create" "', argument " "3"" of type '" "double""'");
  } 
  temp3 = static_cast< double >(val3);
  arg3 = &temp3;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(double const &)*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create__SWIG_8(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< double > *arg1 = 0 ;
  size_t arg2 ;
  double *arg3 = 0 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  size_t length1 ;
  daal::services::SharedPtr< double > r4p1 ;
  double temp3 ;
  double val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    {
      int is_new_object = 0;
      PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
        ? obj_to_array_no_conversion(obj0, NPY_DOUBLE)
        :obj_to_array_contiguous_allow_conversion(obj0, NPY_DOUBLE, &is_new_object));
      if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
      // we provide the SharedPtr with a deleter which decrements the pyref
      r4p1 = daal::services::SharedPtr< double >((double*)array_data(array), NumpyDeleter(array));
      arg1 = &r4p1;
      arg2 = (size_t) array_size(array,0);
      // we need it increment the ref-count if we use the obj0 array in-place
      // if we copied/converted it we already own our own reference
      if((PyObject*)array == obj0) Py_INCREF(array);
    }
    
    // The size should be the the dimension of the square matrix as opposed to the length1 of the array.
    // We must calculate the dimension from the length1.
    length1 = arg2;
    
    if(fmod((sqrt(1 + 8 * length1) - 1) / 2, 1) != 0) {
      SWIG_exception_fail(SWIG_ValueError, "Packed representation does not describe square matrix");
    }
    arg2 = (sqrt(1 + 8 * length1) - 1) / 2;
  }
  ecode3 = SWIG_AsVal_double(obj1, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create" "', argument " "3"" of type '" "double""'");
  } 
  temp3 = static_cast< double >(val3);
  arg3 = &temp3;
  res4 = SWIG_ConvertPtr(obj2, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::SharedPtr< double > const &)*arg1,arg2,(double const &)*arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create__SWIG_9(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< double > *arg1 = 0 ;
  size_t arg2 ;
  double *arg3 = 0 ;
  size_t length1 ;
  daal::services::SharedPtr< double > r4p1 ;
  double temp3 ;
  double val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create",&obj0,&obj1)) SWIG_fail;
  {
    {
      int is_new_object = 0;
      PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
        ? obj_to_array_no_conversion(obj0, NPY_DOUBLE)
        :obj_to_array_contiguous_allow_conversion(obj0, NPY_DOUBLE, &is_new_object));
      if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
      // we provide the SharedPtr with a deleter which decrements the pyref
      r4p1 = daal::services::SharedPtr< double >((double*)array_data(array), NumpyDeleter(array));
      arg1 = &r4p1;
      arg2 = (size_t) array_size(array,0);
      // we need it increment the ref-count if we use the obj0 array in-place
      // if we copied/converted it we already own our own reference
      if((PyObject*)array == obj0) Py_INCREF(array);
    }
    
    // The size should be the the dimension of the square matrix as opposed to the length1 of the array.
    // We must calculate the dimension from the length1.
    length1 = arg2;
    
    if(fmod((sqrt(1 + 8 * length1) - 1) / 2, 1) != 0) {
      SWIG_exception_fail(SWIG_ValueError, "Packed representation does not describe square matrix");
    }
    arg2 = (sqrt(1 + 8 * length1) - 1) / 2;
  }
  ecode3 = SWIG_AsVal_double(obj1, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create" "', argument " "3"" of type '" "double""'");
  } 
  temp3 = static_cast< double >(val3);
  arg3 = &temp3;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::SharedPtr< double > const &)*arg1,arg2,(double const &)*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create__SWIG_10(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg2 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create__SWIG_11(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg2 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create",&obj0,&obj1)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create__SWIG_12(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::NumericTable::AllocationFlag arg2 ;
  double *arg3 = 0 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  double temp3 ;
  double val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTable::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTable::AllocationFlag >(val2);
  ecode3 = SWIG_AsVal_double(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create" "', argument " "3"" of type '" "double""'");
  } 
  temp3 = static_cast< double >(val3);
  arg3 = &temp3;
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(double const &)*arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create__SWIG_13(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::NumericTable::AllocationFlag arg2 ;
  double *arg3 = 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  double temp3 ;
  double val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTable::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTable::AllocationFlag >(val2);
  ecode3 = SWIG_AsVal_double(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create" "', argument " "3"" of type '" "double""'");
  } 
  temp3 = static_cast< double >(val3);
  arg3 = &temp3;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(double const &)*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[5];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 4) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create__SWIG_3(self, args);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_double, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create__SWIG_2(self, args);
    }
  }
  if (argc == 1) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_DOUBLE))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      if (argc <= 1) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create__SWIG_5(self, args);
      }
      return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create__SWIG_5(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_double, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create__SWIG_11(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_DOUBLE))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create__SWIG_4(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_DOUBLE))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      {
        int res = SWIG_AsVal_double(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create__SWIG_9(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_double, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create__SWIG_0(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_double, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_double(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create__SWIG_7(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create__SWIG_10(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_double(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create__SWIG_13(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_DOUBLE))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      {
        int res = SWIG_AsVal_double(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create__SWIG_8(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_double, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_double(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create__SWIG_6(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_double(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create__SWIG_12(self, args);
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::create(double *const,size_t,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::create(double *const,size_t)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::create(double *const)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::create()\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::create(daal::services::SharedPtr< double > const &,size_t,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::create(daal::services::SharedPtr< double > const &,size_t)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::create(double *const,size_t,double const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::create(double *const,size_t,double const &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::create(daal::services::SharedPtr< double > const &,size_t,double const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::create(daal::services::SharedPtr< double > const &,size_t,double const &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::create(size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::create(size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::create(size_t,daal::data_management::interface1::NumericTable::AllocationFlag,double const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::create(size_t,daal::data_management::interface1::NumericTable::AllocationFlag,double const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_assign__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *) 0 ;
  float arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *smartarg1 = 0 ;
  float val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_float(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_assign" "', argument " "2"" of type '" "float""'");
  } 
  arg2 = static_cast< float >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_assign__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *) 0 ;
  double arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *smartarg1 = 0 ;
  double val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_double(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_assign" "', argument " "2"" of type '" "double""'");
  } 
  arg2 = static_cast< double >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_assign__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_assign" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_assign(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_assign__SWIG_3(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_float(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_assign__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_double(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_assign__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_assign'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::assign(float)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::assign(double)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::assign(int)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfRows__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfRows__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfRows__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfRows(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[6];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 5) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfRows__SWIG_0(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfRows__SWIG_1(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfRows__SWIG_2(self, args);
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfRows'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfRows__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfRows__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfRows__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfRows(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfRows__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfRows__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfRows__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfRows'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfColumnValues__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfColumnValues__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfColumnValues__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfColumnValues(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[7];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 6) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfColumnValues__SWIG_0(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfColumnValues__SWIG_1(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfColumnValues__SWIG_2(self, args);
              }
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfColumnValues'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getPackedArray__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *) 0 ;
  daal::data_management::ReadWriteMode arg2 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared3 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getPackedArray",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getPackedArray" "', argument " "2"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg2 = static_cast< daal::data_management::ReadWriteMode >(val2);
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared3 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp3);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp3);
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared3.get());
    } else {
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp3)->get());
    }
    if(!arg3) SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getPackedArray(arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getPackedArray__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *) 0 ;
  daal::data_management::ReadWriteMode arg2 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared3 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getPackedArray",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getPackedArray" "', argument " "2"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg2 = static_cast< daal::data_management::ReadWriteMode >(val2);
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared3 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp3);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp3);
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared3.get());
    } else {
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp3)->get());
    }
    if(!arg3) SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getPackedArray(arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getPackedArray__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *) 0 ;
  daal::data_management::ReadWriteMode arg2 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared3 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getPackedArray",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getPackedArray" "', argument " "2"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg2 = static_cast< daal::data_management::ReadWriteMode >(val2);
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared3 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp3);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp3);
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared3.get());
    } else {
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp3)->get());
    }
    if(!arg3) SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getPackedArray(arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getPackedArray(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[4];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 3) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getPackedArray__SWIG_0(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getPackedArray__SWIG_1(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getPackedArray__SWIG_2(self, args);
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getPackedArray'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::getPackedArray(daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::getPackedArray(daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::getPackedArray(daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releasePackedArray__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releasePackedArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releasePackedArray(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releasePackedArray__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releasePackedArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releasePackedArray(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releasePackedArray__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releasePackedArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releasePackedArray(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releasePackedArray(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releasePackedArray__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releasePackedArray__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releasePackedArray__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releasePackedArray'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::releasePackedArray(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::releasePackedArray(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double >::releasePackedArray(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_serializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)":PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_serializationTag")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR serializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getSerializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getSerializationTag",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > const *)arg1)->getSerializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  float *arg1 = (float *) (float *)0 ;
  size_t arg2 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_float, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create" "', argument " "1"" of type '" "float *const""'"); 
  }
  arg1 = reinterpret_cast< float * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  float *arg1 = (float *) (float *)0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_float, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create" "', argument " "1"" of type '" "float *const""'"); 
  }
  arg1 = reinterpret_cast< float * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  float *arg1 = (float *) (float *)0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_float, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create" "', argument " "1"" of type '" "float *const""'"); 
  }
  arg1 = reinterpret_cast< float * >(argp1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)":PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create__SWIG_4(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< float > *arg1 = 0 ;
  size_t arg2 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  size_t length1 ;
  daal::services::SharedPtr< float > r4p1 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create",&obj0,&obj1)) SWIG_fail;
  {
    {
      int is_new_object = 0;
      PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
        ? obj_to_array_no_conversion(obj0, NPY_FLOAT)
        :obj_to_array_contiguous_allow_conversion(obj0, NPY_FLOAT, &is_new_object));
      if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
      // we provide the SharedPtr with a deleter which decrements the pyref
      r4p1 = daal::services::SharedPtr< float >((float*)array_data(array), NumpyDeleter(array));
      arg1 = &r4p1;
      arg2 = (size_t) array_size(array,0);
      // we need it increment the ref-count if we use the obj0 array in-place
      // if we copied/converted it we already own our own reference
      if((PyObject*)array == obj0) Py_INCREF(array);
    }
    
    // The size should be the the dimension of the square matrix as opposed to the length1 of the array.
    // We must calculate the dimension from the length1.
    length1 = arg2;
    
    if(fmod((sqrt(1 + 8 * length1) - 1) / 2, 1) != 0) {
      SWIG_exception_fail(SWIG_ValueError, "Packed representation does not describe square matrix");
    }
    arg2 = (sqrt(1 + 8 * length1) - 1) / 2;
  }
  res3 = SWIG_ConvertPtr(obj1, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::SharedPtr< float > const &)*arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create__SWIG_5(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< float > *arg1 = 0 ;
  size_t arg2 ;
  size_t length1 ;
  daal::services::SharedPtr< float > r4p1 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create",&obj0)) SWIG_fail;
  {
    {
      int is_new_object = 0;
      PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
        ? obj_to_array_no_conversion(obj0, NPY_FLOAT)
        :obj_to_array_contiguous_allow_conversion(obj0, NPY_FLOAT, &is_new_object));
      if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
      // we provide the SharedPtr with a deleter which decrements the pyref
      r4p1 = daal::services::SharedPtr< float >((float*)array_data(array), NumpyDeleter(array));
      arg1 = &r4p1;
      arg2 = (size_t) array_size(array,0);
      // we need it increment the ref-count if we use the obj0 array in-place
      // if we copied/converted it we already own our own reference
      if((PyObject*)array == obj0) Py_INCREF(array);
    }
    
    // The size should be the the dimension of the square matrix as opposed to the length1 of the array.
    // We must calculate the dimension from the length1.
    length1 = arg2;
    
    if(fmod((sqrt(1 + 8 * length1) - 1) / 2, 1) != 0) {
      SWIG_exception_fail(SWIG_ValueError, "Packed representation does not describe square matrix");
    }
    arg2 = (sqrt(1 + 8 * length1) - 1) / 2;
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::SharedPtr< float > const &)*arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create__SWIG_6(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  float *arg1 = (float *) (float *)0 ;
  size_t arg2 ;
  float *arg3 = 0 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  float temp3 ;
  float val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_float, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create" "', argument " "1"" of type '" "float *const""'"); 
  }
  arg1 = reinterpret_cast< float * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_float(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create" "', argument " "3"" of type '" "float""'");
  } 
  temp3 = static_cast< float >(val3);
  arg3 = &temp3;
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(float const &)*arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create__SWIG_7(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  float *arg1 = (float *) (float *)0 ;
  size_t arg2 ;
  float *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  float temp3 ;
  float val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_float, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create" "', argument " "1"" of type '" "float *const""'"); 
  }
  arg1 = reinterpret_cast< float * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_float(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create" "', argument " "3"" of type '" "float""'");
  } 
  temp3 = static_cast< float >(val3);
  arg3 = &temp3;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(float const &)*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create__SWIG_8(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< float > *arg1 = 0 ;
  size_t arg2 ;
  float *arg3 = 0 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  size_t length1 ;
  daal::services::SharedPtr< float > r4p1 ;
  float temp3 ;
  float val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    {
      int is_new_object = 0;
      PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
        ? obj_to_array_no_conversion(obj0, NPY_FLOAT)
        :obj_to_array_contiguous_allow_conversion(obj0, NPY_FLOAT, &is_new_object));
      if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
      // we provide the SharedPtr with a deleter which decrements the pyref
      r4p1 = daal::services::SharedPtr< float >((float*)array_data(array), NumpyDeleter(array));
      arg1 = &r4p1;
      arg2 = (size_t) array_size(array,0);
      // we need it increment the ref-count if we use the obj0 array in-place
      // if we copied/converted it we already own our own reference
      if((PyObject*)array == obj0) Py_INCREF(array);
    }
    
    // The size should be the the dimension of the square matrix as opposed to the length1 of the array.
    // We must calculate the dimension from the length1.
    length1 = arg2;
    
    if(fmod((sqrt(1 + 8 * length1) - 1) / 2, 1) != 0) {
      SWIG_exception_fail(SWIG_ValueError, "Packed representation does not describe square matrix");
    }
    arg2 = (sqrt(1 + 8 * length1) - 1) / 2;
  }
  ecode3 = SWIG_AsVal_float(obj1, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create" "', argument " "3"" of type '" "float""'");
  } 
  temp3 = static_cast< float >(val3);
  arg3 = &temp3;
  res4 = SWIG_ConvertPtr(obj2, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::SharedPtr< float > const &)*arg1,arg2,(float const &)*arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create__SWIG_9(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< float > *arg1 = 0 ;
  size_t arg2 ;
  float *arg3 = 0 ;
  size_t length1 ;
  daal::services::SharedPtr< float > r4p1 ;
  float temp3 ;
  float val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create",&obj0,&obj1)) SWIG_fail;
  {
    {
      int is_new_object = 0;
      PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
        ? obj_to_array_no_conversion(obj0, NPY_FLOAT)
        :obj_to_array_contiguous_allow_conversion(obj0, NPY_FLOAT, &is_new_object));
      if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
      // we provide the SharedPtr with a deleter which decrements the pyref
      r4p1 = daal::services::SharedPtr< float >((float*)array_data(array), NumpyDeleter(array));
      arg1 = &r4p1;
      arg2 = (size_t) array_size(array,0);
      // we need it increment the ref-count if we use the obj0 array in-place
      // if we copied/converted it we already own our own reference
      if((PyObject*)array == obj0) Py_INCREF(array);
    }
    
    // The size should be the the dimension of the square matrix as opposed to the length1 of the array.
    // We must calculate the dimension from the length1.
    length1 = arg2;
    
    if(fmod((sqrt(1 + 8 * length1) - 1) / 2, 1) != 0) {
      SWIG_exception_fail(SWIG_ValueError, "Packed representation does not describe square matrix");
    }
    arg2 = (sqrt(1 + 8 * length1) - 1) / 2;
  }
  ecode3 = SWIG_AsVal_float(obj1, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create" "', argument " "3"" of type '" "float""'");
  } 
  temp3 = static_cast< float >(val3);
  arg3 = &temp3;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::SharedPtr< float > const &)*arg1,arg2,(float const &)*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create__SWIG_10(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg2 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create__SWIG_11(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg2 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create",&obj0,&obj1)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create__SWIG_12(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::NumericTable::AllocationFlag arg2 ;
  float *arg3 = 0 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  float temp3 ;
  float val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTable::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTable::AllocationFlag >(val2);
  ecode3 = SWIG_AsVal_float(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create" "', argument " "3"" of type '" "float""'");
  } 
  temp3 = static_cast< float >(val3);
  arg3 = &temp3;
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(float const &)*arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create__SWIG_13(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::NumericTable::AllocationFlag arg2 ;
  float *arg3 = 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  float temp3 ;
  float val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTable::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTable::AllocationFlag >(val2);
  ecode3 = SWIG_AsVal_float(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create" "', argument " "3"" of type '" "float""'");
  } 
  temp3 = static_cast< float >(val3);
  arg3 = &temp3;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(float const &)*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[5];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 4) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create__SWIG_3(self, args);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_float, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create__SWIG_2(self, args);
    }
  }
  if (argc == 1) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_FLOAT))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      if (argc <= 1) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create__SWIG_5(self, args);
      }
      return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create__SWIG_5(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_float, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create__SWIG_11(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_FLOAT))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create__SWIG_4(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_FLOAT))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      {
        int res = SWIG_AsVal_float(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create__SWIG_9(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_float, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create__SWIG_0(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_float, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_float(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create__SWIG_7(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create__SWIG_10(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_float(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create__SWIG_13(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_FLOAT))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      {
        int res = SWIG_AsVal_float(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create__SWIG_8(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_float, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_float(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create__SWIG_6(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_float(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create__SWIG_12(self, args);
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::create(float *const,size_t,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::create(float *const,size_t)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::create(float *const)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::create()\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::create(daal::services::SharedPtr< float > const &,size_t,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::create(daal::services::SharedPtr< float > const &,size_t)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::create(float *const,size_t,float const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::create(float *const,size_t,float const &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::create(daal::services::SharedPtr< float > const &,size_t,float const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::create(daal::services::SharedPtr< float > const &,size_t,float const &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::create(size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::create(size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::create(size_t,daal::data_management::interface1::NumericTable::AllocationFlag,float const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::create(size_t,daal::data_management::interface1::NumericTable::AllocationFlag,float const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_assign__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *) 0 ;
  float arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *smartarg1 = 0 ;
  float val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_float(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_assign" "', argument " "2"" of type '" "float""'");
  } 
  arg2 = static_cast< float >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_assign__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *) 0 ;
  double arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *smartarg1 = 0 ;
  double val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_double(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_assign" "', argument " "2"" of type '" "double""'");
  } 
  arg2 = static_cast< double >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_assign__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_assign" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_assign(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_assign__SWIG_3(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_float(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_assign__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_double(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_assign__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_assign'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::assign(float)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::assign(double)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::assign(int)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfRows__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfRows__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfRows__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfRows(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[6];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 5) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfRows__SWIG_0(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfRows__SWIG_1(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfRows__SWIG_2(self, args);
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfRows'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfRows__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfRows__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfRows__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfRows(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfRows__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfRows__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfRows__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfRows'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfColumnValues__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfColumnValues__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfColumnValues__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfColumnValues(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[7];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 6) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfColumnValues__SWIG_0(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfColumnValues__SWIG_1(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfColumnValues__SWIG_2(self, args);
              }
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfColumnValues'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getPackedArray__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *) 0 ;
  daal::data_management::ReadWriteMode arg2 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared3 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getPackedArray",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getPackedArray" "', argument " "2"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg2 = static_cast< daal::data_management::ReadWriteMode >(val2);
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared3 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp3);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp3);
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared3.get());
    } else {
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp3)->get());
    }
    if(!arg3) SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getPackedArray(arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getPackedArray__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *) 0 ;
  daal::data_management::ReadWriteMode arg2 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared3 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getPackedArray",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getPackedArray" "', argument " "2"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg2 = static_cast< daal::data_management::ReadWriteMode >(val2);
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared3 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp3);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp3);
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared3.get());
    } else {
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp3)->get());
    }
    if(!arg3) SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getPackedArray(arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getPackedArray__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *) 0 ;
  daal::data_management::ReadWriteMode arg2 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared3 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getPackedArray",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getPackedArray" "', argument " "2"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg2 = static_cast< daal::data_management::ReadWriteMode >(val2);
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared3 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp3);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp3);
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared3.get());
    } else {
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp3)->get());
    }
    if(!arg3) SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getPackedArray(arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getPackedArray(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[4];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 3) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getPackedArray__SWIG_0(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getPackedArray__SWIG_1(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getPackedArray__SWIG_2(self, args);
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getPackedArray'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::getPackedArray(daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::getPackedArray(daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::getPackedArray(daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releasePackedArray__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releasePackedArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releasePackedArray(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releasePackedArray__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releasePackedArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releasePackedArray(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releasePackedArray__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releasePackedArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releasePackedArray(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releasePackedArray(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releasePackedArray__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releasePackedArray__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releasePackedArray__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releasePackedArray'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::releasePackedArray(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::releasePackedArray(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float >::releasePackedArray(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_serializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)":PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_serializationTag")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR serializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getSerializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getSerializationTag",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > const *)arg1)->getSerializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int *arg1 = (int *) (int *)0 ;
  size_t arg2 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_int, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create" "', argument " "1"" of type '" "int *const""'"); 
  }
  arg1 = reinterpret_cast< int * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int *arg1 = (int *) (int *)0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_int, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create" "', argument " "1"" of type '" "int *const""'"); 
  }
  arg1 = reinterpret_cast< int * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int *arg1 = (int *) (int *)0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_int, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create" "', argument " "1"" of type '" "int *const""'"); 
  }
  arg1 = reinterpret_cast< int * >(argp1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)":PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create__SWIG_4(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< int > *arg1 = 0 ;
  size_t arg2 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  size_t length1 ;
  daal::services::SharedPtr< int > r4p1 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create",&obj0,&obj1)) SWIG_fail;
  {
    {
      int is_new_object = 0;
      PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
        ? obj_to_array_no_conversion(obj0, NPY_INT)
        :obj_to_array_contiguous_allow_conversion(obj0, NPY_INT, &is_new_object));
      if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
      // we provide the SharedPtr with a deleter which decrements the pyref
      r4p1 = daal::services::SharedPtr< int >((int*)array_data(array), NumpyDeleter(array));
      arg1 = &r4p1;
      arg2 = (size_t) array_size(array,0);
      // we need it increment the ref-count if we use the obj0 array in-place
      // if we copied/converted it we already own our own reference
      if((PyObject*)array == obj0) Py_INCREF(array);
    }
    
    // The size should be the the dimension of the square matrix as opposed to the length1 of the array.
    // We must calculate the dimension from the length1.
    length1 = arg2;
    
    if(fmod((sqrt(1 + 8 * length1) - 1) / 2, 1) != 0) {
      SWIG_exception_fail(SWIG_ValueError, "Packed representation does not describe square matrix");
    }
    arg2 = (sqrt(1 + 8 * length1) - 1) / 2;
  }
  res3 = SWIG_ConvertPtr(obj1, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::SharedPtr< int > const &)*arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create__SWIG_5(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< int > *arg1 = 0 ;
  size_t arg2 ;
  size_t length1 ;
  daal::services::SharedPtr< int > r4p1 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create",&obj0)) SWIG_fail;
  {
    {
      int is_new_object = 0;
      PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
        ? obj_to_array_no_conversion(obj0, NPY_INT)
        :obj_to_array_contiguous_allow_conversion(obj0, NPY_INT, &is_new_object));
      if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
      // we provide the SharedPtr with a deleter which decrements the pyref
      r4p1 = daal::services::SharedPtr< int >((int*)array_data(array), NumpyDeleter(array));
      arg1 = &r4p1;
      arg2 = (size_t) array_size(array,0);
      // we need it increment the ref-count if we use the obj0 array in-place
      // if we copied/converted it we already own our own reference
      if((PyObject*)array == obj0) Py_INCREF(array);
    }
    
    // The size should be the the dimension of the square matrix as opposed to the length1 of the array.
    // We must calculate the dimension from the length1.
    length1 = arg2;
    
    if(fmod((sqrt(1 + 8 * length1) - 1) / 2, 1) != 0) {
      SWIG_exception_fail(SWIG_ValueError, "Packed representation does not describe square matrix");
    }
    arg2 = (sqrt(1 + 8 * length1) - 1) / 2;
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::SharedPtr< int > const &)*arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create__SWIG_6(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int *arg1 = (int *) (int *)0 ;
  size_t arg2 ;
  int *arg3 = 0 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_int, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create" "', argument " "1"" of type '" "int *const""'"); 
  }
  arg1 = reinterpret_cast< int * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(int const &)*arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create__SWIG_7(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int *arg1 = (int *) (int *)0 ;
  size_t arg2 ;
  int *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_int, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create" "', argument " "1"" of type '" "int *const""'"); 
  }
  arg1 = reinterpret_cast< int * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(int const &)*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create__SWIG_8(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< int > *arg1 = 0 ;
  size_t arg2 ;
  int *arg3 = 0 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  size_t length1 ;
  daal::services::SharedPtr< int > r4p1 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    {
      int is_new_object = 0;
      PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
        ? obj_to_array_no_conversion(obj0, NPY_INT)
        :obj_to_array_contiguous_allow_conversion(obj0, NPY_INT, &is_new_object));
      if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
      // we provide the SharedPtr with a deleter which decrements the pyref
      r4p1 = daal::services::SharedPtr< int >((int*)array_data(array), NumpyDeleter(array));
      arg1 = &r4p1;
      arg2 = (size_t) array_size(array,0);
      // we need it increment the ref-count if we use the obj0 array in-place
      // if we copied/converted it we already own our own reference
      if((PyObject*)array == obj0) Py_INCREF(array);
    }
    
    // The size should be the the dimension of the square matrix as opposed to the length1 of the array.
    // We must calculate the dimension from the length1.
    length1 = arg2;
    
    if(fmod((sqrt(1 + 8 * length1) - 1) / 2, 1) != 0) {
      SWIG_exception_fail(SWIG_ValueError, "Packed representation does not describe square matrix");
    }
    arg2 = (sqrt(1 + 8 * length1) - 1) / 2;
  }
  ecode3 = SWIG_AsVal_int(obj1, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  res4 = SWIG_ConvertPtr(obj2, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::SharedPtr< int > const &)*arg1,arg2,(int const &)*arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create__SWIG_9(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< int > *arg1 = 0 ;
  size_t arg2 ;
  int *arg3 = 0 ;
  size_t length1 ;
  daal::services::SharedPtr< int > r4p1 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create",&obj0,&obj1)) SWIG_fail;
  {
    {
      int is_new_object = 0;
      PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
        ? obj_to_array_no_conversion(obj0, NPY_INT)
        :obj_to_array_contiguous_allow_conversion(obj0, NPY_INT, &is_new_object));
      if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
      // we provide the SharedPtr with a deleter which decrements the pyref
      r4p1 = daal::services::SharedPtr< int >((int*)array_data(array), NumpyDeleter(array));
      arg1 = &r4p1;
      arg2 = (size_t) array_size(array,0);
      // we need it increment the ref-count if we use the obj0 array in-place
      // if we copied/converted it we already own our own reference
      if((PyObject*)array == obj0) Py_INCREF(array);
    }
    
    // The size should be the the dimension of the square matrix as opposed to the length1 of the array.
    // We must calculate the dimension from the length1.
    length1 = arg2;
    
    if(fmod((sqrt(1 + 8 * length1) - 1) / 2, 1) != 0) {
      SWIG_exception_fail(SWIG_ValueError, "Packed representation does not describe square matrix");
    }
    arg2 = (sqrt(1 + 8 * length1) - 1) / 2;
  }
  ecode3 = SWIG_AsVal_int(obj1, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::SharedPtr< int > const &)*arg1,arg2,(int const &)*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create__SWIG_10(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg2 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create__SWIG_11(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg2 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create",&obj0,&obj1)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create__SWIG_12(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::NumericTable::AllocationFlag arg2 ;
  int *arg3 = 0 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTable::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTable::AllocationFlag >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(int const &)*arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create__SWIG_13(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::NumericTable::AllocationFlag arg2 ;
  int *arg3 = 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTable::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTable::AllocationFlag >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(int const &)*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[5];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 4) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create__SWIG_3(self, args);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_int, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create__SWIG_2(self, args);
    }
  }
  if (argc == 1) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_INT))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      if (argc <= 1) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create__SWIG_5(self, args);
      }
      return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create__SWIG_5(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_int, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create__SWIG_11(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_INT))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create__SWIG_4(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_INT))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create__SWIG_9(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_int, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create__SWIG_0(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_int, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create__SWIG_7(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create__SWIG_10(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create__SWIG_13(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_INT))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create__SWIG_8(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_int, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create__SWIG_6(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create__SWIG_12(self, args);
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::create(int *const,size_t,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::create(int *const,size_t)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::create(int *const)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::create()\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::create(daal::services::SharedPtr< int > const &,size_t,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::create(daal::services::SharedPtr< int > const &,size_t)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::create(int *const,size_t,int const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::create(int *const,size_t,int const &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::create(daal::services::SharedPtr< int > const &,size_t,int const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::create(daal::services::SharedPtr< int > const &,size_t,int const &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::create(size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::create(size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::create(size_t,daal::data_management::interface1::NumericTable::AllocationFlag,int const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::create(size_t,daal::data_management::interface1::NumericTable::AllocationFlag,int const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_assign__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *) 0 ;
  float arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *smartarg1 = 0 ;
  float val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_float(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_assign" "', argument " "2"" of type '" "float""'");
  } 
  arg2 = static_cast< float >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_assign__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *) 0 ;
  double arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *smartarg1 = 0 ;
  double val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_double(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_assign" "', argument " "2"" of type '" "double""'");
  } 
  arg2 = static_cast< double >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_assign__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_assign" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_assign(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_assign__SWIG_3(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_float(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_assign__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_double(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_assign__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_assign'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::assign(float)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::assign(double)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::assign(int)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfRows__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfRows__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfRows__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfRows(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[6];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 5) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfRows__SWIG_0(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfRows__SWIG_1(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfRows__SWIG_2(self, args);
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfRows'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfRows__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfRows__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfRows__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfRows(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfRows__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfRows__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfRows__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfRows'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfColumnValues__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfColumnValues__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfColumnValues__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfColumnValues(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[7];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 6) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfColumnValues__SWIG_0(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfColumnValues__SWIG_1(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfColumnValues__SWIG_2(self, args);
              }
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfColumnValues'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfColumnValues__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfColumnValues__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfColumnValues__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfColumnValues(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfColumnValues__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfColumnValues__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfColumnValues__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfColumnValues'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getPackedArray__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *) 0 ;
  daal::data_management::ReadWriteMode arg2 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared3 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getPackedArray",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getPackedArray" "', argument " "2"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg2 = static_cast< daal::data_management::ReadWriteMode >(val2);
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared3 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp3);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp3);
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared3.get());
    } else {
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp3)->get());
    }
    if(!arg3) SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getPackedArray(arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getPackedArray__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *) 0 ;
  daal::data_management::ReadWriteMode arg2 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared3 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getPackedArray",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getPackedArray" "', argument " "2"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg2 = static_cast< daal::data_management::ReadWriteMode >(val2);
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared3 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp3);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp3);
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared3.get());
    } else {
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp3)->get());
    }
    if(!arg3) SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getPackedArray(arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getPackedArray__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *) 0 ;
  daal::data_management::ReadWriteMode arg2 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared3 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getPackedArray",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getPackedArray" "', argument " "2"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg2 = static_cast< daal::data_management::ReadWriteMode >(val2);
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared3 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp3);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp3);
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared3.get());
    } else {
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp3)->get());
    }
    if(!arg3) SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getPackedArray(arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getPackedArray(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[4];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 3) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getPackedArray__SWIG_0(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getPackedArray__SWIG_1(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getPackedArray__SWIG_2(self, args);
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getPackedArray'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::getPackedArray(daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::getPackedArray(daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::getPackedArray(daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releasePackedArray__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releasePackedArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releasePackedArray(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releasePackedArray__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releasePackedArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releasePackedArray(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releasePackedArray__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *arg1 = (daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releasePackedArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releasePackedArray(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releasePackedArray(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releasePackedArray__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releasePackedArray__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releasePackedArray__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releasePackedArray'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::releasePackedArray(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::releasePackedArray(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int >::releasePackedArray(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_serializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)":PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_serializationTag")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR serializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getSerializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getSerializationTag",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > const *)arg1)->getSerializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  double *arg1 = (double *) (double *)0 ;
  size_t arg2 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_double, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create" "', argument " "1"" of type '" "double *const""'"); 
  }
  arg1 = reinterpret_cast< double * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  double *arg1 = (double *) (double *)0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_double, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create" "', argument " "1"" of type '" "double *const""'"); 
  }
  arg1 = reinterpret_cast< double * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  double *arg1 = (double *) (double *)0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_double, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create" "', argument " "1"" of type '" "double *const""'"); 
  }
  arg1 = reinterpret_cast< double * >(argp1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)":PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create__SWIG_4(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< double > *arg1 = 0 ;
  size_t arg2 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  size_t length1 ;
  daal::services::SharedPtr< double > r4p1 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create",&obj0,&obj1)) SWIG_fail;
  {
    {
      int is_new_object = 0;
      PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
        ? obj_to_array_no_conversion(obj0, NPY_DOUBLE)
        :obj_to_array_contiguous_allow_conversion(obj0, NPY_DOUBLE, &is_new_object));
      if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
      // we provide the SharedPtr with a deleter which decrements the pyref
      r4p1 = daal::services::SharedPtr< double >((double*)array_data(array), NumpyDeleter(array));
      arg1 = &r4p1;
      arg2 = (size_t) array_size(array,0);
      // we need it increment the ref-count if we use the obj0 array in-place
      // if we copied/converted it we already own our own reference
      if((PyObject*)array == obj0) Py_INCREF(array);
    }
    
    // The size should be the the dimension of the square matrix as opposed to the length1 of the array.
    // We must calculate the dimension from the length1.
    length1 = arg2;
    
    if(fmod((sqrt(1 + 8 * length1) - 1) / 2, 1) != 0) {
      SWIG_exception_fail(SWIG_ValueError, "Packed representation does not describe square matrix");
    }
    arg2 = (sqrt(1 + 8 * length1) - 1) / 2;
  }
  res3 = SWIG_ConvertPtr(obj1, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::SharedPtr< double > const &)*arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create__SWIG_5(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< double > *arg1 = 0 ;
  size_t arg2 ;
  size_t length1 ;
  daal::services::SharedPtr< double > r4p1 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create",&obj0)) SWIG_fail;
  {
    {
      int is_new_object = 0;
      PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
        ? obj_to_array_no_conversion(obj0, NPY_DOUBLE)
        :obj_to_array_contiguous_allow_conversion(obj0, NPY_DOUBLE, &is_new_object));
      if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
      // we provide the SharedPtr with a deleter which decrements the pyref
      r4p1 = daal::services::SharedPtr< double >((double*)array_data(array), NumpyDeleter(array));
      arg1 = &r4p1;
      arg2 = (size_t) array_size(array,0);
      // we need it increment the ref-count if we use the obj0 array in-place
      // if we copied/converted it we already own our own reference
      if((PyObject*)array == obj0) Py_INCREF(array);
    }
    
    // The size should be the the dimension of the square matrix as opposed to the length1 of the array.
    // We must calculate the dimension from the length1.
    length1 = arg2;
    
    if(fmod((sqrt(1 + 8 * length1) - 1) / 2, 1) != 0) {
      SWIG_exception_fail(SWIG_ValueError, "Packed representation does not describe square matrix");
    }
    arg2 = (sqrt(1 + 8 * length1) - 1) / 2;
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::SharedPtr< double > const &)*arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create__SWIG_6(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  double *arg1 = (double *) (double *)0 ;
  size_t arg2 ;
  double *arg3 = 0 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  double temp3 ;
  double val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_double, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create" "', argument " "1"" of type '" "double *const""'"); 
  }
  arg1 = reinterpret_cast< double * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_double(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create" "', argument " "3"" of type '" "double""'");
  } 
  temp3 = static_cast< double >(val3);
  arg3 = &temp3;
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(double const &)*arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create__SWIG_7(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  double *arg1 = (double *) (double *)0 ;
  size_t arg2 ;
  double *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  double temp3 ;
  double val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_double, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create" "', argument " "1"" of type '" "double *const""'"); 
  }
  arg1 = reinterpret_cast< double * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_double(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create" "', argument " "3"" of type '" "double""'");
  } 
  temp3 = static_cast< double >(val3);
  arg3 = &temp3;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(double const &)*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create__SWIG_8(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< double > *arg1 = 0 ;
  size_t arg2 ;
  double *arg3 = 0 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  double temp3 ;
  double val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_double_t,  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create" "', argument " "1"" of type '" "daal::services::SharedPtr< double > &""'"); 
  }
  if (!argp1) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create" "', argument " "1"" of type '" "daal::services::SharedPtr< double > &""'"); 
  }
  arg1 = reinterpret_cast< daal::services::SharedPtr< double > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_double(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create" "', argument " "3"" of type '" "double""'");
  } 
  temp3 = static_cast< double >(val3);
  arg3 = &temp3;
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create(*arg1,arg2,(double const &)*arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create__SWIG_9(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< double > *arg1 = 0 ;
  size_t arg2 ;
  double *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  double temp3 ;
  double val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_double_t,  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create" "', argument " "1"" of type '" "daal::services::SharedPtr< double > &""'"); 
  }
  if (!argp1) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create" "', argument " "1"" of type '" "daal::services::SharedPtr< double > &""'"); 
  }
  arg1 = reinterpret_cast< daal::services::SharedPtr< double > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_double(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create" "', argument " "3"" of type '" "double""'");
  } 
  temp3 = static_cast< double >(val3);
  arg3 = &temp3;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create(*arg1,arg2,(double const &)*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create__SWIG_10(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg2 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create__SWIG_11(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg2 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create",&obj0,&obj1)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create__SWIG_12(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::NumericTable::AllocationFlag arg2 ;
  double *arg3 = 0 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  double temp3 ;
  double val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTable::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTable::AllocationFlag >(val2);
  ecode3 = SWIG_AsVal_double(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create" "', argument " "3"" of type '" "double""'");
  } 
  temp3 = static_cast< double >(val3);
  arg3 = &temp3;
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(double const &)*arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create__SWIG_13(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::NumericTable::AllocationFlag arg2 ;
  double *arg3 = 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  double temp3 ;
  double val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTable::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTable::AllocationFlag >(val2);
  ecode3 = SWIG_AsVal_double(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create" "', argument " "3"" of type '" "double""'");
  } 
  temp3 = static_cast< double >(val3);
  arg3 = &temp3;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(double const &)*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[5];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 4) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create__SWIG_3(self, args);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_double, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create__SWIG_2(self, args);
    }
  }
  if (argc == 1) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_DOUBLE))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      if (argc <= 1) {
        return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create__SWIG_5(self, args);
      }
      return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create__SWIG_5(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_double, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create__SWIG_11(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_DOUBLE))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create__SWIG_4(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_double, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create__SWIG_0(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_daal__services__SharedPtrT_double_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_double(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create__SWIG_9(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_double, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_double(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create__SWIG_7(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create__SWIG_10(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_double(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create__SWIG_13(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_double, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_double(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create__SWIG_6(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_daal__services__SharedPtrT_double_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_double(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create__SWIG_8(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_double(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create__SWIG_12(self, args);
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::create(double *const,size_t,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::create(double *const,size_t)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::create(double *const)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::create()\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::create(daal::services::SharedPtr< double > const &,size_t,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::create(daal::services::SharedPtr< double > const &,size_t)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::create(double *const,size_t,double const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::create(double *const,size_t,double const &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::create(daal::services::SharedPtr< double > &,size_t,double const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::create(daal::services::SharedPtr< double > &,size_t,double const &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::create(size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::create(size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::create(size_t,daal::data_management::interface1::NumericTable::AllocationFlag,double const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::create(size_t,daal::data_management::interface1::NumericTable::AllocationFlag,double const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_setNumberOfColumns(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_setNumberOfColumns",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_setNumberOfColumns" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_setNumberOfColumns" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_setNumberOfColumns" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->setNumberOfColumns(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_setNumberOfRows(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_setNumberOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_setNumberOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_setNumberOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_setNumberOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->setNumberOfRows(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_assign__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *) 0 ;
  float arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *smartarg1 = 0 ;
  float val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_float(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_assign" "', argument " "2"" of type '" "float""'");
  } 
  arg2 = static_cast< float >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_assign__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *) 0 ;
  double arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *smartarg1 = 0 ;
  double val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_double(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_assign" "', argument " "2"" of type '" "double""'");
  } 
  arg2 = static_cast< double >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_assign__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_assign" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_assign(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_assign__SWIG_3(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_float(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_assign__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_double(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_assign__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_assign'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::assign(float)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::assign(double)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::assign(int)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfRows__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfRows__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfRows__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfRows(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[6];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 5) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfRows__SWIG_0(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfRows__SWIG_1(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfRows__SWIG_2(self, args);
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfRows'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfRows__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfRows__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfRows__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfRows(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfRows__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfRows__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfRows__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfRows'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfColumnValues__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfColumnValues__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfColumnValues__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfColumnValues(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[7];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 6) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfColumnValues__SWIG_0(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfColumnValues__SWIG_1(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfColumnValues__SWIG_2(self, args);
              }
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfColumnValues'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfColumnValues__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfColumnValues__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfColumnValues__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfColumnValues(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfColumnValues__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfColumnValues__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfColumnValues__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfColumnValues'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getPackedArray__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *) 0 ;
  daal::data_management::ReadWriteMode arg2 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared3 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getPackedArray",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getPackedArray" "', argument " "2"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg2 = static_cast< daal::data_management::ReadWriteMode >(val2);
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared3 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp3);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp3);
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared3.get());
    } else {
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp3)->get());
    }
    if(!arg3) SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getPackedArray(arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getPackedArray__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *) 0 ;
  daal::data_management::ReadWriteMode arg2 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared3 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getPackedArray",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getPackedArray" "', argument " "2"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg2 = static_cast< daal::data_management::ReadWriteMode >(val2);
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared3 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp3);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp3);
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared3.get());
    } else {
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp3)->get());
    }
    if(!arg3) SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getPackedArray(arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getPackedArray__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *) 0 ;
  daal::data_management::ReadWriteMode arg2 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared3 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getPackedArray",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getPackedArray" "', argument " "2"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg2 = static_cast< daal::data_management::ReadWriteMode >(val2);
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared3 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp3);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp3);
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared3.get());
    } else {
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp3)->get());
    }
    if(!arg3) SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getPackedArray(arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getPackedArray(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[4];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 3) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getPackedArray__SWIG_0(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getPackedArray__SWIG_1(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getPackedArray__SWIG_2(self, args);
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getPackedArray'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::getPackedArray(daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::getPackedArray(daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::getPackedArray(daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releasePackedArray__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releasePackedArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releasePackedArray(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releasePackedArray__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releasePackedArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releasePackedArray(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releasePackedArray__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releasePackedArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releasePackedArray(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releasePackedArray(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releasePackedArray__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releasePackedArray__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releasePackedArray__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releasePackedArray'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::releasePackedArray(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::releasePackedArray(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double >::releasePackedArray(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_serializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)":PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_serializationTag")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR serializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getSerializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getSerializationTag",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > const *)arg1)->getSerializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  float *arg1 = (float *) (float *)0 ;
  size_t arg2 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_float, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create" "', argument " "1"" of type '" "float *const""'"); 
  }
  arg1 = reinterpret_cast< float * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  float *arg1 = (float *) (float *)0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_float, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create" "', argument " "1"" of type '" "float *const""'"); 
  }
  arg1 = reinterpret_cast< float * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  float *arg1 = (float *) (float *)0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_float, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create" "', argument " "1"" of type '" "float *const""'"); 
  }
  arg1 = reinterpret_cast< float * >(argp1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)":PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create__SWIG_4(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< float > *arg1 = 0 ;
  size_t arg2 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  size_t length1 ;
  daal::services::SharedPtr< float > r4p1 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create",&obj0,&obj1)) SWIG_fail;
  {
    {
      int is_new_object = 0;
      PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
        ? obj_to_array_no_conversion(obj0, NPY_FLOAT)
        :obj_to_array_contiguous_allow_conversion(obj0, NPY_FLOAT, &is_new_object));
      if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
      // we provide the SharedPtr with a deleter which decrements the pyref
      r4p1 = daal::services::SharedPtr< float >((float*)array_data(array), NumpyDeleter(array));
      arg1 = &r4p1;
      arg2 = (size_t) array_size(array,0);
      // we need it increment the ref-count if we use the obj0 array in-place
      // if we copied/converted it we already own our own reference
      if((PyObject*)array == obj0) Py_INCREF(array);
    }
    
    // The size should be the the dimension of the square matrix as opposed to the length1 of the array.
    // We must calculate the dimension from the length1.
    length1 = arg2;
    
    if(fmod((sqrt(1 + 8 * length1) - 1) / 2, 1) != 0) {
      SWIG_exception_fail(SWIG_ValueError, "Packed representation does not describe square matrix");
    }
    arg2 = (sqrt(1 + 8 * length1) - 1) / 2;
  }
  res3 = SWIG_ConvertPtr(obj1, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::SharedPtr< float > const &)*arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create__SWIG_5(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< float > *arg1 = 0 ;
  size_t arg2 ;
  size_t length1 ;
  daal::services::SharedPtr< float > r4p1 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create",&obj0)) SWIG_fail;
  {
    {
      int is_new_object = 0;
      PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
        ? obj_to_array_no_conversion(obj0, NPY_FLOAT)
        :obj_to_array_contiguous_allow_conversion(obj0, NPY_FLOAT, &is_new_object));
      if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
      // we provide the SharedPtr with a deleter which decrements the pyref
      r4p1 = daal::services::SharedPtr< float >((float*)array_data(array), NumpyDeleter(array));
      arg1 = &r4p1;
      arg2 = (size_t) array_size(array,0);
      // we need it increment the ref-count if we use the obj0 array in-place
      // if we copied/converted it we already own our own reference
      if((PyObject*)array == obj0) Py_INCREF(array);
    }
    
    // The size should be the the dimension of the square matrix as opposed to the length1 of the array.
    // We must calculate the dimension from the length1.
    length1 = arg2;
    
    if(fmod((sqrt(1 + 8 * length1) - 1) / 2, 1) != 0) {
      SWIG_exception_fail(SWIG_ValueError, "Packed representation does not describe square matrix");
    }
    arg2 = (sqrt(1 + 8 * length1) - 1) / 2;
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::SharedPtr< float > const &)*arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create__SWIG_6(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  float *arg1 = (float *) (float *)0 ;
  size_t arg2 ;
  float *arg3 = 0 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  float temp3 ;
  float val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_float, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create" "', argument " "1"" of type '" "float *const""'"); 
  }
  arg1 = reinterpret_cast< float * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_float(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create" "', argument " "3"" of type '" "float""'");
  } 
  temp3 = static_cast< float >(val3);
  arg3 = &temp3;
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(float const &)*arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create__SWIG_7(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  float *arg1 = (float *) (float *)0 ;
  size_t arg2 ;
  float *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  float temp3 ;
  float val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_float, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create" "', argument " "1"" of type '" "float *const""'"); 
  }
  arg1 = reinterpret_cast< float * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_float(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create" "', argument " "3"" of type '" "float""'");
  } 
  temp3 = static_cast< float >(val3);
  arg3 = &temp3;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(float const &)*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create__SWIG_8(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< float > *arg1 = 0 ;
  size_t arg2 ;
  float *arg3 = 0 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  float temp3 ;
  float val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_float_t,  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create" "', argument " "1"" of type '" "daal::services::SharedPtr< float > &""'"); 
  }
  if (!argp1) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create" "', argument " "1"" of type '" "daal::services::SharedPtr< float > &""'"); 
  }
  arg1 = reinterpret_cast< daal::services::SharedPtr< float > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_float(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create" "', argument " "3"" of type '" "float""'");
  } 
  temp3 = static_cast< float >(val3);
  arg3 = &temp3;
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create(*arg1,arg2,(float const &)*arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create__SWIG_9(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< float > *arg1 = 0 ;
  size_t arg2 ;
  float *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  float temp3 ;
  float val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_float_t,  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create" "', argument " "1"" of type '" "daal::services::SharedPtr< float > &""'"); 
  }
  if (!argp1) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create" "', argument " "1"" of type '" "daal::services::SharedPtr< float > &""'"); 
  }
  arg1 = reinterpret_cast< daal::services::SharedPtr< float > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_float(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create" "', argument " "3"" of type '" "float""'");
  } 
  temp3 = static_cast< float >(val3);
  arg3 = &temp3;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create(*arg1,arg2,(float const &)*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create__SWIG_10(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg2 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create__SWIG_11(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg2 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create",&obj0,&obj1)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create__SWIG_12(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::NumericTable::AllocationFlag arg2 ;
  float *arg3 = 0 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  float temp3 ;
  float val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTable::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTable::AllocationFlag >(val2);
  ecode3 = SWIG_AsVal_float(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create" "', argument " "3"" of type '" "float""'");
  } 
  temp3 = static_cast< float >(val3);
  arg3 = &temp3;
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(float const &)*arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create__SWIG_13(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::NumericTable::AllocationFlag arg2 ;
  float *arg3 = 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  float temp3 ;
  float val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTable::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTable::AllocationFlag >(val2);
  ecode3 = SWIG_AsVal_float(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create" "', argument " "3"" of type '" "float""'");
  } 
  temp3 = static_cast< float >(val3);
  arg3 = &temp3;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(float const &)*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[5];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 4) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create__SWIG_3(self, args);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_float, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create__SWIG_2(self, args);
    }
  }
  if (argc == 1) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_FLOAT))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      if (argc <= 1) {
        return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create__SWIG_5(self, args);
      }
      return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create__SWIG_5(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_float, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create__SWIG_11(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_FLOAT))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create__SWIG_4(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_float, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create__SWIG_0(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_daal__services__SharedPtrT_float_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_float(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create__SWIG_9(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_float, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_float(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create__SWIG_7(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create__SWIG_10(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_float(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create__SWIG_13(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_float, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_float(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create__SWIG_6(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_daal__services__SharedPtrT_float_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_float(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create__SWIG_8(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_float(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create__SWIG_12(self, args);
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::create(float *const,size_t,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::create(float *const,size_t)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::create(float *const)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::create()\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::create(daal::services::SharedPtr< float > const &,size_t,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::create(daal::services::SharedPtr< float > const &,size_t)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::create(float *const,size_t,float const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::create(float *const,size_t,float const &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::create(daal::services::SharedPtr< float > &,size_t,float const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::create(daal::services::SharedPtr< float > &,size_t,float const &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::create(size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::create(size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::create(size_t,daal::data_management::interface1::NumericTable::AllocationFlag,float const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::create(size_t,daal::data_management::interface1::NumericTable::AllocationFlag,float const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_setNumberOfColumns(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_setNumberOfColumns",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_setNumberOfColumns" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_setNumberOfColumns" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_setNumberOfColumns" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->setNumberOfColumns(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_setNumberOfRows(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_setNumberOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_setNumberOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_setNumberOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_setNumberOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->setNumberOfRows(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_assign__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *) 0 ;
  float arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *smartarg1 = 0 ;
  float val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_float(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_assign" "', argument " "2"" of type '" "float""'");
  } 
  arg2 = static_cast< float >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_assign__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *) 0 ;
  double arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *smartarg1 = 0 ;
  double val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_double(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_assign" "', argument " "2"" of type '" "double""'");
  } 
  arg2 = static_cast< double >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_assign__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_assign" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_assign(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_assign__SWIG_3(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_float(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_assign__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_double(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_assign__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_assign'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::assign(float)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::assign(double)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::assign(int)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfRows__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfRows__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfRows__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfRows(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[6];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 5) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfRows__SWIG_0(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfRows__SWIG_1(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfRows__SWIG_2(self, args);
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfRows'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfRows__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfRows__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfRows__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfRows(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfRows__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfRows__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfRows__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfRows'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfColumnValues__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfColumnValues__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfColumnValues__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfColumnValues(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[7];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 6) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfColumnValues__SWIG_0(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfColumnValues__SWIG_1(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfColumnValues__SWIG_2(self, args);
              }
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfColumnValues'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfColumnValues__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfColumnValues__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfColumnValues__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfColumnValues(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfColumnValues__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfColumnValues__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfColumnValues__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfColumnValues'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getPackedArray__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *) 0 ;
  daal::data_management::ReadWriteMode arg2 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared3 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getPackedArray",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getPackedArray" "', argument " "2"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg2 = static_cast< daal::data_management::ReadWriteMode >(val2);
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared3 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp3);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp3);
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared3.get());
    } else {
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp3)->get());
    }
    if(!arg3) SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getPackedArray(arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getPackedArray__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *) 0 ;
  daal::data_management::ReadWriteMode arg2 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared3 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getPackedArray",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getPackedArray" "', argument " "2"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg2 = static_cast< daal::data_management::ReadWriteMode >(val2);
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared3 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp3);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp3);
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared3.get());
    } else {
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp3)->get());
    }
    if(!arg3) SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getPackedArray(arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getPackedArray__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *) 0 ;
  daal::data_management::ReadWriteMode arg2 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared3 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getPackedArray",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getPackedArray" "', argument " "2"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg2 = static_cast< daal::data_management::ReadWriteMode >(val2);
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared3 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp3);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp3);
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared3.get());
    } else {
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp3)->get());
    }
    if(!arg3) SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getPackedArray(arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getPackedArray(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[4];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 3) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getPackedArray__SWIG_0(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getPackedArray__SWIG_1(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getPackedArray__SWIG_2(self, args);
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getPackedArray'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::getPackedArray(daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::getPackedArray(daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::getPackedArray(daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releasePackedArray__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releasePackedArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releasePackedArray(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releasePackedArray__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releasePackedArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releasePackedArray(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releasePackedArray__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releasePackedArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releasePackedArray(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releasePackedArray(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releasePackedArray__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releasePackedArray__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releasePackedArray__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releasePackedArray'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::releasePackedArray(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::releasePackedArray(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float >::releasePackedArray(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_serializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)":PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_serializationTag")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR serializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getSerializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getSerializationTag",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > const *)arg1)->getSerializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int *arg1 = (int *) (int *)0 ;
  size_t arg2 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_int, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create" "', argument " "1"" of type '" "int *const""'"); 
  }
  arg1 = reinterpret_cast< int * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int *arg1 = (int *) (int *)0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_int, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create" "', argument " "1"" of type '" "int *const""'"); 
  }
  arg1 = reinterpret_cast< int * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int *arg1 = (int *) (int *)0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_int, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create" "', argument " "1"" of type '" "int *const""'"); 
  }
  arg1 = reinterpret_cast< int * >(argp1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)":PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create__SWIG_4(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< int > *arg1 = 0 ;
  size_t arg2 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  size_t length1 ;
  daal::services::SharedPtr< int > r4p1 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create",&obj0,&obj1)) SWIG_fail;
  {
    {
      int is_new_object = 0;
      PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
        ? obj_to_array_no_conversion(obj0, NPY_INT)
        :obj_to_array_contiguous_allow_conversion(obj0, NPY_INT, &is_new_object));
      if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
      // we provide the SharedPtr with a deleter which decrements the pyref
      r4p1 = daal::services::SharedPtr< int >((int*)array_data(array), NumpyDeleter(array));
      arg1 = &r4p1;
      arg2 = (size_t) array_size(array,0);
      // we need it increment the ref-count if we use the obj0 array in-place
      // if we copied/converted it we already own our own reference
      if((PyObject*)array == obj0) Py_INCREF(array);
    }
    
    // The size should be the the dimension of the square matrix as opposed to the length1 of the array.
    // We must calculate the dimension from the length1.
    length1 = arg2;
    
    if(fmod((sqrt(1 + 8 * length1) - 1) / 2, 1) != 0) {
      SWIG_exception_fail(SWIG_ValueError, "Packed representation does not describe square matrix");
    }
    arg2 = (sqrt(1 + 8 * length1) - 1) / 2;
  }
  res3 = SWIG_ConvertPtr(obj1, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::SharedPtr< int > const &)*arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create__SWIG_5(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< int > *arg1 = 0 ;
  size_t arg2 ;
  size_t length1 ;
  daal::services::SharedPtr< int > r4p1 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create",&obj0)) SWIG_fail;
  {
    {
      int is_new_object = 0;
      PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
        ? obj_to_array_no_conversion(obj0, NPY_INT)
        :obj_to_array_contiguous_allow_conversion(obj0, NPY_INT, &is_new_object));
      if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
      // we provide the SharedPtr with a deleter which decrements the pyref
      r4p1 = daal::services::SharedPtr< int >((int*)array_data(array), NumpyDeleter(array));
      arg1 = &r4p1;
      arg2 = (size_t) array_size(array,0);
      // we need it increment the ref-count if we use the obj0 array in-place
      // if we copied/converted it we already own our own reference
      if((PyObject*)array == obj0) Py_INCREF(array);
    }
    
    // The size should be the the dimension of the square matrix as opposed to the length1 of the array.
    // We must calculate the dimension from the length1.
    length1 = arg2;
    
    if(fmod((sqrt(1 + 8 * length1) - 1) / 2, 1) != 0) {
      SWIG_exception_fail(SWIG_ValueError, "Packed representation does not describe square matrix");
    }
    arg2 = (sqrt(1 + 8 * length1) - 1) / 2;
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::SharedPtr< int > const &)*arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create__SWIG_6(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int *arg1 = (int *) (int *)0 ;
  size_t arg2 ;
  int *arg3 = 0 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_int, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create" "', argument " "1"" of type '" "int *const""'"); 
  }
  arg1 = reinterpret_cast< int * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(int const &)*arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create__SWIG_7(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int *arg1 = (int *) (int *)0 ;
  size_t arg2 ;
  int *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_int, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create" "', argument " "1"" of type '" "int *const""'"); 
  }
  arg1 = reinterpret_cast< int * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(int const &)*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create__SWIG_8(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< int > *arg1 = 0 ;
  size_t arg2 ;
  int *arg3 = 0 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_int_t,  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create" "', argument " "1"" of type '" "daal::services::SharedPtr< int > &""'"); 
  }
  if (!argp1) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create" "', argument " "1"" of type '" "daal::services::SharedPtr< int > &""'"); 
  }
  arg1 = reinterpret_cast< daal::services::SharedPtr< int > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create(*arg1,arg2,(int const &)*arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create__SWIG_9(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< int > *arg1 = 0 ;
  size_t arg2 ;
  int *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_int_t,  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create" "', argument " "1"" of type '" "daal::services::SharedPtr< int > &""'"); 
  }
  if (!argp1) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create" "', argument " "1"" of type '" "daal::services::SharedPtr< int > &""'"); 
  }
  arg1 = reinterpret_cast< daal::services::SharedPtr< int > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create(*arg1,arg2,(int const &)*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create__SWIG_10(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg2 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create__SWIG_11(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg2 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create",&obj0,&obj1)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create__SWIG_12(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::NumericTable::AllocationFlag arg2 ;
  int *arg3 = 0 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTable::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTable::AllocationFlag >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(int const &)*arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create__SWIG_13(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::NumericTable::AllocationFlag arg2 ;
  int *arg3 = 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTable::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTable::AllocationFlag >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(int const &)*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[5];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 4) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create__SWIG_3(self, args);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_int, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create__SWIG_2(self, args);
    }
  }
  if (argc == 1) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_INT))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      if (argc <= 1) {
        return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create__SWIG_5(self, args);
      }
      return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create__SWIG_5(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_int, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create__SWIG_11(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_INT))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create__SWIG_4(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_int, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create__SWIG_0(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_daal__services__SharedPtrT_int_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create__SWIG_9(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_int, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create__SWIG_7(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create__SWIG_10(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create__SWIG_13(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_int, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create__SWIG_6(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_daal__services__SharedPtrT_int_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create__SWIG_8(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create__SWIG_12(self, args);
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::create(int *const,size_t,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::create(int *const,size_t)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::create(int *const)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::create()\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::create(daal::services::SharedPtr< int > const &,size_t,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::create(daal::services::SharedPtr< int > const &,size_t)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::create(int *const,size_t,int const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::create(int *const,size_t,int const &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::create(daal::services::SharedPtr< int > &,size_t,int const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::create(daal::services::SharedPtr< int > &,size_t,int const &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::create(size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::create(size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::create(size_t,daal::data_management::interface1::NumericTable::AllocationFlag,int const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::create(size_t,daal::data_management::interface1::NumericTable::AllocationFlag,int const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_setNumberOfColumns(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_setNumberOfColumns",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_setNumberOfColumns" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_setNumberOfColumns" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_setNumberOfColumns" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->setNumberOfColumns(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_setNumberOfRows(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_setNumberOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_setNumberOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_setNumberOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_setNumberOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->setNumberOfRows(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_assign__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *) 0 ;
  float arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *smartarg1 = 0 ;
  float val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_float(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_assign" "', argument " "2"" of type '" "float""'");
  } 
  arg2 = static_cast< float >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_assign__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *) 0 ;
  double arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *smartarg1 = 0 ;
  double val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_double(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_assign" "', argument " "2"" of type '" "double""'");
  } 
  arg2 = static_cast< double >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_assign__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_assign" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_assign(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_assign__SWIG_3(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_float(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_assign__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_double(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_assign__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_assign'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::assign(float)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::assign(double)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::assign(int)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfRows__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfRows__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfRows__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfRows(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[6];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 5) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfRows__SWIG_0(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfRows__SWIG_1(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfRows__SWIG_2(self, args);
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfRows'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfRows__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfRows__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfRows__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfRows(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfRows__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfRows__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfRows__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfRows'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfColumnValues__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfColumnValues__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfColumnValues__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfColumnValues(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[7];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 6) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfColumnValues__SWIG_0(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfColumnValues__SWIG_1(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfColumnValues__SWIG_2(self, args);
              }
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfColumnValues'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfColumnValues__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfColumnValues__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfColumnValues__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfColumnValues(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfColumnValues__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfColumnValues__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfColumnValues__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfColumnValues'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getPackedArray__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *) 0 ;
  daal::data_management::ReadWriteMode arg2 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared3 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getPackedArray",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getPackedArray" "', argument " "2"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg2 = static_cast< daal::data_management::ReadWriteMode >(val2);
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared3 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp3);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp3);
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared3.get());
    } else {
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp3)->get());
    }
    if(!arg3) SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getPackedArray(arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getPackedArray__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *) 0 ;
  daal::data_management::ReadWriteMode arg2 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared3 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getPackedArray",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getPackedArray" "', argument " "2"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg2 = static_cast< daal::data_management::ReadWriteMode >(val2);
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared3 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp3);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp3);
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared3.get());
    } else {
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp3)->get());
    }
    if(!arg3) SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getPackedArray(arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getPackedArray__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *) 0 ;
  daal::data_management::ReadWriteMode arg2 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared3 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getPackedArray",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getPackedArray" "', argument " "2"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg2 = static_cast< daal::data_management::ReadWriteMode >(val2);
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared3 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp3);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp3);
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared3.get());
    } else {
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp3)->get());
    }
    if(!arg3) SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getPackedArray(arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getPackedArray(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[4];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 3) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getPackedArray__SWIG_0(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getPackedArray__SWIG_1(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getPackedArray__SWIG_2(self, args);
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getPackedArray'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::getPackedArray(daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::getPackedArray(daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::getPackedArray(daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releasePackedArray__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releasePackedArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releasePackedArray(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releasePackedArray__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releasePackedArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releasePackedArray(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releasePackedArray__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releasePackedArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releasePackedArray(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releasePackedArray(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releasePackedArray__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releasePackedArray__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releasePackedArray__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releasePackedArray'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::releasePackedArray(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::releasePackedArray(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int >::releasePackedArray(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_serializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)":PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_serializationTag")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR serializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getSerializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getSerializationTag",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > const *)arg1)->getSerializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  double *arg1 = (double *) (double *)0 ;
  size_t arg2 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_double, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create" "', argument " "1"" of type '" "double *const""'"); 
  }
  arg1 = reinterpret_cast< double * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  double *arg1 = (double *) (double *)0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_double, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create" "', argument " "1"" of type '" "double *const""'"); 
  }
  arg1 = reinterpret_cast< double * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  double *arg1 = (double *) (double *)0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_double, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create" "', argument " "1"" of type '" "double *const""'"); 
  }
  arg1 = reinterpret_cast< double * >(argp1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)":PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create__SWIG_4(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< double > *arg1 = 0 ;
  size_t arg2 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  size_t length1 ;
  daal::services::SharedPtr< double > r4p1 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create",&obj0,&obj1)) SWIG_fail;
  {
    {
      int is_new_object = 0;
      PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
        ? obj_to_array_no_conversion(obj0, NPY_DOUBLE)
        :obj_to_array_contiguous_allow_conversion(obj0, NPY_DOUBLE, &is_new_object));
      if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
      // we provide the SharedPtr with a deleter which decrements the pyref
      r4p1 = daal::services::SharedPtr< double >((double*)array_data(array), NumpyDeleter(array));
      arg1 = &r4p1;
      arg2 = (size_t) array_size(array,0);
      // we need it increment the ref-count if we use the obj0 array in-place
      // if we copied/converted it we already own our own reference
      if((PyObject*)array == obj0) Py_INCREF(array);
    }
    
    // The size should be the the dimension of the square matrix as opposed to the length1 of the array.
    // We must calculate the dimension from the length1.
    length1 = arg2;
    
    if(fmod((sqrt(1 + 8 * length1) - 1) / 2, 1) != 0) {
      SWIG_exception_fail(SWIG_ValueError, "Packed representation does not describe square matrix");
    }
    arg2 = (sqrt(1 + 8 * length1) - 1) / 2;
  }
  res3 = SWIG_ConvertPtr(obj1, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::SharedPtr< double > const &)*arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create__SWIG_5(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< double > *arg1 = 0 ;
  size_t arg2 ;
  size_t length1 ;
  daal::services::SharedPtr< double > r4p1 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create",&obj0)) SWIG_fail;
  {
    {
      int is_new_object = 0;
      PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
        ? obj_to_array_no_conversion(obj0, NPY_DOUBLE)
        :obj_to_array_contiguous_allow_conversion(obj0, NPY_DOUBLE, &is_new_object));
      if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
      // we provide the SharedPtr with a deleter which decrements the pyref
      r4p1 = daal::services::SharedPtr< double >((double*)array_data(array), NumpyDeleter(array));
      arg1 = &r4p1;
      arg2 = (size_t) array_size(array,0);
      // we need it increment the ref-count if we use the obj0 array in-place
      // if we copied/converted it we already own our own reference
      if((PyObject*)array == obj0) Py_INCREF(array);
    }
    
    // The size should be the the dimension of the square matrix as opposed to the length1 of the array.
    // We must calculate the dimension from the length1.
    length1 = arg2;
    
    if(fmod((sqrt(1 + 8 * length1) - 1) / 2, 1) != 0) {
      SWIG_exception_fail(SWIG_ValueError, "Packed representation does not describe square matrix");
    }
    arg2 = (sqrt(1 + 8 * length1) - 1) / 2;
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::SharedPtr< double > const &)*arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create__SWIG_6(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  double *arg1 = (double *) (double *)0 ;
  size_t arg2 ;
  double *arg3 = 0 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  double temp3 ;
  double val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_double, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create" "', argument " "1"" of type '" "double *const""'"); 
  }
  arg1 = reinterpret_cast< double * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_double(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create" "', argument " "3"" of type '" "double""'");
  } 
  temp3 = static_cast< double >(val3);
  arg3 = &temp3;
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(double const &)*arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create__SWIG_7(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  double *arg1 = (double *) (double *)0 ;
  size_t arg2 ;
  double *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  double temp3 ;
  double val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_double, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create" "', argument " "1"" of type '" "double *const""'"); 
  }
  arg1 = reinterpret_cast< double * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_double(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create" "', argument " "3"" of type '" "double""'");
  } 
  temp3 = static_cast< double >(val3);
  arg3 = &temp3;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(double const &)*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create__SWIG_8(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< double > *arg1 = 0 ;
  size_t arg2 ;
  double *arg3 = 0 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  double temp3 ;
  double val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_double_t,  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create" "', argument " "1"" of type '" "daal::services::SharedPtr< double > &""'"); 
  }
  if (!argp1) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create" "', argument " "1"" of type '" "daal::services::SharedPtr< double > &""'"); 
  }
  arg1 = reinterpret_cast< daal::services::SharedPtr< double > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_double(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create" "', argument " "3"" of type '" "double""'");
  } 
  temp3 = static_cast< double >(val3);
  arg3 = &temp3;
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create(*arg1,arg2,(double const &)*arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create__SWIG_9(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< double > *arg1 = 0 ;
  size_t arg2 ;
  double *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  double temp3 ;
  double val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_double_t,  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create" "', argument " "1"" of type '" "daal::services::SharedPtr< double > &""'"); 
  }
  if (!argp1) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create" "', argument " "1"" of type '" "daal::services::SharedPtr< double > &""'"); 
  }
  arg1 = reinterpret_cast< daal::services::SharedPtr< double > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_double(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create" "', argument " "3"" of type '" "double""'");
  } 
  temp3 = static_cast< double >(val3);
  arg3 = &temp3;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create(*arg1,arg2,(double const &)*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create__SWIG_10(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg2 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create__SWIG_11(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg2 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create",&obj0,&obj1)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create__SWIG_12(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::NumericTable::AllocationFlag arg2 ;
  double *arg3 = 0 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  double temp3 ;
  double val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTable::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTable::AllocationFlag >(val2);
  ecode3 = SWIG_AsVal_double(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create" "', argument " "3"" of type '" "double""'");
  } 
  temp3 = static_cast< double >(val3);
  arg3 = &temp3;
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(double const &)*arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create__SWIG_13(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::NumericTable::AllocationFlag arg2 ;
  double *arg3 = 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  double temp3 ;
  double val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTable::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTable::AllocationFlag >(val2);
  ecode3 = SWIG_AsVal_double(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create" "', argument " "3"" of type '" "double""'");
  } 
  temp3 = static_cast< double >(val3);
  arg3 = &temp3;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(double const &)*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[5];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 4) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create__SWIG_3(self, args);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_double, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create__SWIG_2(self, args);
    }
  }
  if (argc == 1) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_DOUBLE))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      if (argc <= 1) {
        return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create__SWIG_5(self, args);
      }
      return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create__SWIG_5(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_double, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create__SWIG_11(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_DOUBLE))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create__SWIG_4(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_double, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create__SWIG_0(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_daal__services__SharedPtrT_double_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_double(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create__SWIG_9(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_double, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_double(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create__SWIG_7(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create__SWIG_10(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_double(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create__SWIG_13(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_double, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_double(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create__SWIG_6(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_daal__services__SharedPtrT_double_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_double(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create__SWIG_8(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_double(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create__SWIG_12(self, args);
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::create(double *const,size_t,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::create(double *const,size_t)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::create(double *const)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::create()\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::create(daal::services::SharedPtr< double > const &,size_t,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::create(daal::services::SharedPtr< double > const &,size_t)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::create(double *const,size_t,double const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::create(double *const,size_t,double const &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::create(daal::services::SharedPtr< double > &,size_t,double const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::create(daal::services::SharedPtr< double > &,size_t,double const &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::create(size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::create(size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::create(size_t,daal::data_management::interface1::NumericTable::AllocationFlag,double const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::create(size_t,daal::data_management::interface1::NumericTable::AllocationFlag,double const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_setNumberOfColumns(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_setNumberOfColumns",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_setNumberOfColumns" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_setNumberOfColumns" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_setNumberOfColumns" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->setNumberOfColumns(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_setNumberOfRows(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_setNumberOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_setNumberOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_setNumberOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_setNumberOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->setNumberOfRows(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_assign__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *) 0 ;
  float arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *smartarg1 = 0 ;
  float val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_float(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_assign" "', argument " "2"" of type '" "float""'");
  } 
  arg2 = static_cast< float >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_assign__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *) 0 ;
  double arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *smartarg1 = 0 ;
  double val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_double(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_assign" "', argument " "2"" of type '" "double""'");
  } 
  arg2 = static_cast< double >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_assign__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_assign" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_assign(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_assign__SWIG_3(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_float(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_assign__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_double(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_assign__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_assign'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::assign(float)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::assign(double)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::assign(int)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfRows__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfRows__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfRows__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfRows(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[6];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 5) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfRows__SWIG_0(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfRows__SWIG_1(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfRows__SWIG_2(self, args);
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfRows'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfRows__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfRows__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfRows__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfRows(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfRows__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfRows__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfRows__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfRows'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfColumnValues__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfColumnValues__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfColumnValues__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfColumnValues(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[7];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 6) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfColumnValues__SWIG_0(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfColumnValues__SWIG_1(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfColumnValues__SWIG_2(self, args);
              }
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfColumnValues'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfColumnValues__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfColumnValues__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfColumnValues__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfColumnValues(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfColumnValues__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfColumnValues__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfColumnValues__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfColumnValues'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getPackedArray__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *) 0 ;
  daal::data_management::ReadWriteMode arg2 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared3 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getPackedArray",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getPackedArray" "', argument " "2"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg2 = static_cast< daal::data_management::ReadWriteMode >(val2);
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared3 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp3);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp3);
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared3.get());
    } else {
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp3)->get());
    }
    if(!arg3) SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getPackedArray(arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getPackedArray__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *) 0 ;
  daal::data_management::ReadWriteMode arg2 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared3 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getPackedArray",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getPackedArray" "', argument " "2"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg2 = static_cast< daal::data_management::ReadWriteMode >(val2);
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared3 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp3);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp3);
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared3.get());
    } else {
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp3)->get());
    }
    if(!arg3) SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getPackedArray(arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getPackedArray__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *) 0 ;
  daal::data_management::ReadWriteMode arg2 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared3 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getPackedArray",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getPackedArray" "', argument " "2"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg2 = static_cast< daal::data_management::ReadWriteMode >(val2);
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared3 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp3);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp3);
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared3.get());
    } else {
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp3)->get());
    }
    if(!arg3) SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getPackedArray(arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getPackedArray(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[4];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 3) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getPackedArray__SWIG_0(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getPackedArray__SWIG_1(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getPackedArray__SWIG_2(self, args);
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getPackedArray'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::getPackedArray(daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::getPackedArray(daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::getPackedArray(daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releasePackedArray__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releasePackedArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releasePackedArray(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releasePackedArray__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releasePackedArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releasePackedArray(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releasePackedArray__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releasePackedArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releasePackedArray(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releasePackedArray(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releasePackedArray__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releasePackedArray__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releasePackedArray__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releasePackedArray'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::releasePackedArray(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::releasePackedArray(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double >::releasePackedArray(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_serializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)":PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_serializationTag")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR serializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getSerializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getSerializationTag",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > const *)arg1)->getSerializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  float *arg1 = (float *) (float *)0 ;
  size_t arg2 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_float, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create" "', argument " "1"" of type '" "float *const""'"); 
  }
  arg1 = reinterpret_cast< float * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  float *arg1 = (float *) (float *)0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_float, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create" "', argument " "1"" of type '" "float *const""'"); 
  }
  arg1 = reinterpret_cast< float * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  float *arg1 = (float *) (float *)0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_float, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create" "', argument " "1"" of type '" "float *const""'"); 
  }
  arg1 = reinterpret_cast< float * >(argp1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)":PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create__SWIG_4(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< float > *arg1 = 0 ;
  size_t arg2 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  size_t length1 ;
  daal::services::SharedPtr< float > r4p1 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create",&obj0,&obj1)) SWIG_fail;
  {
    {
      int is_new_object = 0;
      PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
        ? obj_to_array_no_conversion(obj0, NPY_FLOAT)
        :obj_to_array_contiguous_allow_conversion(obj0, NPY_FLOAT, &is_new_object));
      if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
      // we provide the SharedPtr with a deleter which decrements the pyref
      r4p1 = daal::services::SharedPtr< float >((float*)array_data(array), NumpyDeleter(array));
      arg1 = &r4p1;
      arg2 = (size_t) array_size(array,0);
      // we need it increment the ref-count if we use the obj0 array in-place
      // if we copied/converted it we already own our own reference
      if((PyObject*)array == obj0) Py_INCREF(array);
    }
    
    // The size should be the the dimension of the square matrix as opposed to the length1 of the array.
    // We must calculate the dimension from the length1.
    length1 = arg2;
    
    if(fmod((sqrt(1 + 8 * length1) - 1) / 2, 1) != 0) {
      SWIG_exception_fail(SWIG_ValueError, "Packed representation does not describe square matrix");
    }
    arg2 = (sqrt(1 + 8 * length1) - 1) / 2;
  }
  res3 = SWIG_ConvertPtr(obj1, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::SharedPtr< float > const &)*arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create__SWIG_5(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< float > *arg1 = 0 ;
  size_t arg2 ;
  size_t length1 ;
  daal::services::SharedPtr< float > r4p1 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create",&obj0)) SWIG_fail;
  {
    {
      int is_new_object = 0;
      PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
        ? obj_to_array_no_conversion(obj0, NPY_FLOAT)
        :obj_to_array_contiguous_allow_conversion(obj0, NPY_FLOAT, &is_new_object));
      if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
      // we provide the SharedPtr with a deleter which decrements the pyref
      r4p1 = daal::services::SharedPtr< float >((float*)array_data(array), NumpyDeleter(array));
      arg1 = &r4p1;
      arg2 = (size_t) array_size(array,0);
      // we need it increment the ref-count if we use the obj0 array in-place
      // if we copied/converted it we already own our own reference
      if((PyObject*)array == obj0) Py_INCREF(array);
    }
    
    // The size should be the the dimension of the square matrix as opposed to the length1 of the array.
    // We must calculate the dimension from the length1.
    length1 = arg2;
    
    if(fmod((sqrt(1 + 8 * length1) - 1) / 2, 1) != 0) {
      SWIG_exception_fail(SWIG_ValueError, "Packed representation does not describe square matrix");
    }
    arg2 = (sqrt(1 + 8 * length1) - 1) / 2;
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::SharedPtr< float > const &)*arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create__SWIG_6(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  float *arg1 = (float *) (float *)0 ;
  size_t arg2 ;
  float *arg3 = 0 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  float temp3 ;
  float val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_float, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create" "', argument " "1"" of type '" "float *const""'"); 
  }
  arg1 = reinterpret_cast< float * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_float(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create" "', argument " "3"" of type '" "float""'");
  } 
  temp3 = static_cast< float >(val3);
  arg3 = &temp3;
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(float const &)*arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create__SWIG_7(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  float *arg1 = (float *) (float *)0 ;
  size_t arg2 ;
  float *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  float temp3 ;
  float val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_float, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create" "', argument " "1"" of type '" "float *const""'"); 
  }
  arg1 = reinterpret_cast< float * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_float(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create" "', argument " "3"" of type '" "float""'");
  } 
  temp3 = static_cast< float >(val3);
  arg3 = &temp3;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(float const &)*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create__SWIG_8(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< float > *arg1 = 0 ;
  size_t arg2 ;
  float *arg3 = 0 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  float temp3 ;
  float val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_float_t,  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create" "', argument " "1"" of type '" "daal::services::SharedPtr< float > &""'"); 
  }
  if (!argp1) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create" "', argument " "1"" of type '" "daal::services::SharedPtr< float > &""'"); 
  }
  arg1 = reinterpret_cast< daal::services::SharedPtr< float > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_float(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create" "', argument " "3"" of type '" "float""'");
  } 
  temp3 = static_cast< float >(val3);
  arg3 = &temp3;
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create(*arg1,arg2,(float const &)*arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create__SWIG_9(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< float > *arg1 = 0 ;
  size_t arg2 ;
  float *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  float temp3 ;
  float val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_float_t,  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create" "', argument " "1"" of type '" "daal::services::SharedPtr< float > &""'"); 
  }
  if (!argp1) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create" "', argument " "1"" of type '" "daal::services::SharedPtr< float > &""'"); 
  }
  arg1 = reinterpret_cast< daal::services::SharedPtr< float > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_float(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create" "', argument " "3"" of type '" "float""'");
  } 
  temp3 = static_cast< float >(val3);
  arg3 = &temp3;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create(*arg1,arg2,(float const &)*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create__SWIG_10(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg2 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create__SWIG_11(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg2 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create",&obj0,&obj1)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create__SWIG_12(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::NumericTable::AllocationFlag arg2 ;
  float *arg3 = 0 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  float temp3 ;
  float val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTable::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTable::AllocationFlag >(val2);
  ecode3 = SWIG_AsVal_float(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create" "', argument " "3"" of type '" "float""'");
  } 
  temp3 = static_cast< float >(val3);
  arg3 = &temp3;
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(float const &)*arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create__SWIG_13(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::NumericTable::AllocationFlag arg2 ;
  float *arg3 = 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  float temp3 ;
  float val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTable::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTable::AllocationFlag >(val2);
  ecode3 = SWIG_AsVal_float(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create" "', argument " "3"" of type '" "float""'");
  } 
  temp3 = static_cast< float >(val3);
  arg3 = &temp3;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(float const &)*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[5];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 4) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create__SWIG_3(self, args);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_float, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create__SWIG_2(self, args);
    }
  }
  if (argc == 1) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_FLOAT))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      if (argc <= 1) {
        return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create__SWIG_5(self, args);
      }
      return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create__SWIG_5(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_float, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create__SWIG_11(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_FLOAT))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create__SWIG_4(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_float, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create__SWIG_0(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_daal__services__SharedPtrT_float_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_float(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create__SWIG_9(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_float, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_float(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create__SWIG_7(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create__SWIG_10(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_float(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create__SWIG_13(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_float, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_float(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create__SWIG_6(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_daal__services__SharedPtrT_float_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_float(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create__SWIG_8(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_float(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create__SWIG_12(self, args);
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::create(float *const,size_t,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::create(float *const,size_t)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::create(float *const)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::create()\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::create(daal::services::SharedPtr< float > const &,size_t,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::create(daal::services::SharedPtr< float > const &,size_t)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::create(float *const,size_t,float const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::create(float *const,size_t,float const &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::create(daal::services::SharedPtr< float > &,size_t,float const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::create(daal::services::SharedPtr< float > &,size_t,float const &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::create(size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::create(size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::create(size_t,daal::data_management::interface1::NumericTable::AllocationFlag,float const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::create(size_t,daal::data_management::interface1::NumericTable::AllocationFlag,float const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_setNumberOfColumns(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_setNumberOfColumns",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_setNumberOfColumns" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_setNumberOfColumns" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_setNumberOfColumns" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->setNumberOfColumns(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_setNumberOfRows(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_setNumberOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_setNumberOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_setNumberOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_setNumberOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->setNumberOfRows(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_assign__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *) 0 ;
  float arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *smartarg1 = 0 ;
  float val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_float(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_assign" "', argument " "2"" of type '" "float""'");
  } 
  arg2 = static_cast< float >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_assign__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *) 0 ;
  double arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *smartarg1 = 0 ;
  double val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_double(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_assign" "', argument " "2"" of type '" "double""'");
  } 
  arg2 = static_cast< double >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_assign__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_assign" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_assign(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_assign__SWIG_3(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_float(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_assign__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_double(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_assign__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_assign'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::assign(float)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::assign(double)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::assign(int)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfRows__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfRows__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfRows__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfRows(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[6];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 5) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfRows__SWIG_0(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfRows__SWIG_1(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfRows__SWIG_2(self, args);
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfRows'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfRows__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfRows__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfRows__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfRows(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfRows__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfRows__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfRows__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfRows'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfColumnValues__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfColumnValues__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfColumnValues__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfColumnValues(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[7];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 6) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfColumnValues__SWIG_0(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfColumnValues__SWIG_1(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfColumnValues__SWIG_2(self, args);
              }
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfColumnValues'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfColumnValues__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfColumnValues__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfColumnValues__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfColumnValues(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfColumnValues__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfColumnValues__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfColumnValues__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfColumnValues'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getPackedArray__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *) 0 ;
  daal::data_management::ReadWriteMode arg2 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared3 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getPackedArray",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getPackedArray" "', argument " "2"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg2 = static_cast< daal::data_management::ReadWriteMode >(val2);
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared3 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp3);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp3);
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared3.get());
    } else {
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp3)->get());
    }
    if(!arg3) SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getPackedArray(arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getPackedArray__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *) 0 ;
  daal::data_management::ReadWriteMode arg2 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared3 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getPackedArray",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getPackedArray" "', argument " "2"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg2 = static_cast< daal::data_management::ReadWriteMode >(val2);
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared3 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp3);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp3);
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared3.get());
    } else {
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp3)->get());
    }
    if(!arg3) SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getPackedArray(arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getPackedArray__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *) 0 ;
  daal::data_management::ReadWriteMode arg2 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared3 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getPackedArray",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getPackedArray" "', argument " "2"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg2 = static_cast< daal::data_management::ReadWriteMode >(val2);
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared3 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp3);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp3);
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared3.get());
    } else {
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp3)->get());
    }
    if(!arg3) SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getPackedArray(arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getPackedArray(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[4];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 3) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getPackedArray__SWIG_0(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getPackedArray__SWIG_1(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getPackedArray__SWIG_2(self, args);
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getPackedArray'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::getPackedArray(daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::getPackedArray(daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::getPackedArray(daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releasePackedArray__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releasePackedArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releasePackedArray(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releasePackedArray__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releasePackedArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releasePackedArray(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releasePackedArray__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releasePackedArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releasePackedArray(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releasePackedArray(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releasePackedArray__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releasePackedArray__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releasePackedArray__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releasePackedArray'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::releasePackedArray(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::releasePackedArray(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float >::releasePackedArray(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_serializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)":PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_serializationTag")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR serializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getSerializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getSerializationTag",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > const *)arg1)->getSerializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int *arg1 = (int *) (int *)0 ;
  size_t arg2 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_int, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create" "', argument " "1"" of type '" "int *const""'"); 
  }
  arg1 = reinterpret_cast< int * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int *arg1 = (int *) (int *)0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_int, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create" "', argument " "1"" of type '" "int *const""'"); 
  }
  arg1 = reinterpret_cast< int * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int *arg1 = (int *) (int *)0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create",&obj0)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_int, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create" "', argument " "1"" of type '" "int *const""'"); 
  }
  arg1 = reinterpret_cast< int * >(argp1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)":PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create__SWIG_4(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< int > *arg1 = 0 ;
  size_t arg2 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  size_t length1 ;
  daal::services::SharedPtr< int > r4p1 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create",&obj0,&obj1)) SWIG_fail;
  {
    {
      int is_new_object = 0;
      PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
        ? obj_to_array_no_conversion(obj0, NPY_INT)
        :obj_to_array_contiguous_allow_conversion(obj0, NPY_INT, &is_new_object));
      if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
      // we provide the SharedPtr with a deleter which decrements the pyref
      r4p1 = daal::services::SharedPtr< int >((int*)array_data(array), NumpyDeleter(array));
      arg1 = &r4p1;
      arg2 = (size_t) array_size(array,0);
      // we need it increment the ref-count if we use the obj0 array in-place
      // if we copied/converted it we already own our own reference
      if((PyObject*)array == obj0) Py_INCREF(array);
    }
    
    // The size should be the the dimension of the square matrix as opposed to the length1 of the array.
    // We must calculate the dimension from the length1.
    length1 = arg2;
    
    if(fmod((sqrt(1 + 8 * length1) - 1) / 2, 1) != 0) {
      SWIG_exception_fail(SWIG_ValueError, "Packed representation does not describe square matrix");
    }
    arg2 = (sqrt(1 + 8 * length1) - 1) / 2;
  }
  res3 = SWIG_ConvertPtr(obj1, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::SharedPtr< int > const &)*arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create__SWIG_5(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< int > *arg1 = 0 ;
  size_t arg2 ;
  size_t length1 ;
  daal::services::SharedPtr< int > r4p1 ;
  PyObject * obj0 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create",&obj0)) SWIG_fail;
  {
    {
      int is_new_object = 0;
      PyArrayObject* array = (ALLOW_CONVERSION == FORCE_INPLACE
        ? obj_to_array_no_conversion(obj0, NPY_INT)
        :obj_to_array_contiguous_allow_conversion(obj0, NPY_INT, &is_new_object));
      if (!array || !require_dimensions(array, 1) || !require_contiguous(array) || !require_native(array)) SWIG_fail;
      // we provide the SharedPtr with a deleter which decrements the pyref
      r4p1 = daal::services::SharedPtr< int >((int*)array_data(array), NumpyDeleter(array));
      arg1 = &r4p1;
      arg2 = (size_t) array_size(array,0);
      // we need it increment the ref-count if we use the obj0 array in-place
      // if we copied/converted it we already own our own reference
      if((PyObject*)array == obj0) Py_INCREF(array);
    }
    
    // The size should be the the dimension of the square matrix as opposed to the length1 of the array.
    // We must calculate the dimension from the length1.
    length1 = arg2;
    
    if(fmod((sqrt(1 + 8 * length1) - 1) / 2, 1) != 0) {
      SWIG_exception_fail(SWIG_ValueError, "Packed representation does not describe square matrix");
    }
    arg2 = (sqrt(1 + 8 * length1) - 1) / 2;
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create((daal::services::SharedPtr< int > const &)*arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create__SWIG_6(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int *arg1 = (int *) (int *)0 ;
  size_t arg2 ;
  int *arg3 = 0 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_int, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create" "', argument " "1"" of type '" "int *const""'"); 
  }
  arg1 = reinterpret_cast< int * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(int const &)*arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create__SWIG_7(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int *arg1 = (int *) (int *)0 ;
  size_t arg2 ;
  int *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1,SWIGTYPE_p_int, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create" "', argument " "1"" of type '" "int *const""'"); 
  }
  arg1 = reinterpret_cast< int * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(int const &)*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create__SWIG_8(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< int > *arg1 = 0 ;
  size_t arg2 ;
  int *arg3 = 0 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_int_t,  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create" "', argument " "1"" of type '" "daal::services::SharedPtr< int > &""'"); 
  }
  if (!argp1) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create" "', argument " "1"" of type '" "daal::services::SharedPtr< int > &""'"); 
  }
  arg1 = reinterpret_cast< daal::services::SharedPtr< int > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create(*arg1,arg2,(int const &)*arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create__SWIG_9(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::SharedPtr< int > *arg1 = 0 ;
  size_t arg2 ;
  int *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_int_t,  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create" "', argument " "1"" of type '" "daal::services::SharedPtr< int > &""'"); 
  }
  if (!argp1) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create" "', argument " "1"" of type '" "daal::services::SharedPtr< int > &""'"); 
  }
  arg1 = reinterpret_cast< daal::services::SharedPtr< int > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create(*arg1,arg2,(int const &)*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create__SWIG_10(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg2 ;
  daal::services::Status *arg3 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val2);
  res3 = SWIG_ConvertPtr(obj2, &argp3,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create" "', argument " "3"" of type '" "daal::services::Status *""'"); 
  }
  arg3 = reinterpret_cast< daal::services::Status * >(argp3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create__SWIG_11(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::NumericTableIface::AllocationFlag arg2 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create",&obj0,&obj1)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTableIface::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTableIface::AllocationFlag >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create__SWIG_12(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::NumericTable::AllocationFlag arg2 ;
  int *arg3 = 0 ;
  daal::services::Status *arg4 = (daal::services::Status *) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTable::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTable::AllocationFlag >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  res4 = SWIG_ConvertPtr(obj3, &argp4,SWIGTYPE_p_daal__services__interface1__Status, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create" "', argument " "4"" of type '" "daal::services::Status *""'"); 
  }
  arg4 = reinterpret_cast< daal::services::Status * >(argp4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(int const &)*arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create__SWIG_13(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  size_t arg1 ;
  daal::data_management::interface1::NumericTable::AllocationFlag arg2 ;
  int *arg3 = 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  int temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create",&obj0,&obj1,&obj2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(obj0, &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create" "', argument " "1"" of type '" "size_t""'");
  } 
  arg1 = static_cast< size_t >(val1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create" "', argument " "2"" of type '" "daal::data_management::interface1::NumericTable::AllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::NumericTable::AllocationFlag >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create" "', argument " "3"" of type '" "int""'");
  } 
  temp3 = static_cast< int >(val3);
  arg3 = &temp3;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::SWIGTEMPLATEDISAMBIGUATOR create(arg1,arg2,(int const &)*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > >(result) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[5];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 4) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create__SWIG_3(self, args);
  }
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_int, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create__SWIG_2(self, args);
    }
  }
  if (argc == 1) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_INT))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      if (argc <= 1) {
        return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create__SWIG_5(self, args);
      }
      return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create__SWIG_5(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_int, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create__SWIG_11(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    {
      _v = (ALLOW_CONVERSION == FORCE_INPLACE
        ? (is_array(argv[0]) && PyArray_EquivTypenums(array_type(argv[0]), NPY_INT))
        :(is_array(argv[0]) || PySequence_Check(argv[0])));
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create__SWIG_4(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_int, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create__SWIG_0(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_daal__services__SharedPtrT_int_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create__SWIG_9(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_int, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create__SWIG_7(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create__SWIG_10(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create__SWIG_13(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_int, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create__SWIG_6(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_daal__services__SharedPtrT_int_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create__SWIG_8(self, args);
          }
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_daal__services__interface1__Status, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create__SWIG_12(self, args);
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::create(int *const,size_t,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::create(int *const,size_t)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::create(int *const)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::create()\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::create(daal::services::SharedPtr< int > const &,size_t,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::create(daal::services::SharedPtr< int > const &,size_t)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::create(int *const,size_t,int const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::create(int *const,size_t,int const &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::create(daal::services::SharedPtr< int > &,size_t,int const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::create(daal::services::SharedPtr< int > &,size_t,int const &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::create(size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::create(size_t,daal::data_management::interface1::NumericTableIface::AllocationFlag)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::create(size_t,daal::data_management::interface1::NumericTable::AllocationFlag,int const &,daal::services::Status *)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::create(size_t,daal::data_management::interface1::NumericTable::AllocationFlag,int const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_setNumberOfColumns(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_setNumberOfColumns",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_setNumberOfColumns" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_setNumberOfColumns" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_setNumberOfColumns" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->setNumberOfColumns(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_setNumberOfRows(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_setNumberOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_setNumberOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_setNumberOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_setNumberOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->setNumberOfRows(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_assign__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *) 0 ;
  float arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *smartarg1 = 0 ;
  float val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_float(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_assign" "', argument " "2"" of type '" "float""'");
  } 
  arg2 = static_cast< float >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_assign__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *) 0 ;
  double arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *smartarg1 = 0 ;
  double val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_double(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_assign" "', argument " "2"" of type '" "double""'");
  } 
  arg2 = static_cast< double >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_assign__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_assign",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_assign" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_assign" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->assign(arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_assign(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_assign__SWIG_3(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_float(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_assign__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_double(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_assign__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_assign'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::assign(float)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::assign(double)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::assign(int)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfRows__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfRows__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfRows__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  daal::data_management::ReadWriteMode arg4 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg5 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  void *argp5 = 0 ;
  int res5 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared5 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOO:PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfRows",&obj0,&obj1,&obj2,&obj3,&obj4)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfRows" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfRows" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_int(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfRows" "', argument " "4"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg4 = static_cast< daal::data_management::ReadWriteMode >(val4);
  {
    int newmem = 0;
    res5 = SWIG_ConvertPtrAndOwn(obj4, &argp5, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared5 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5);
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared5.get());
    } else {
      arg5 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp5)->get());
    }
    if(!arg5) SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfRows" "', argument " "5"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfRows(arg2,arg3,arg4,*arg5);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfRows(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[6];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 5) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfRows__SWIG_0(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfRows__SWIG_1(self, args);
            }
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_ConvertPtr(argv[4], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfRows__SWIG_2(self, args);
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfRows'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::getBlockOfRows(size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfRows__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfRows__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfRows__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfRows",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfRows" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfRows" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfRows(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfRows(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfRows__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfRows__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfRows__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfRows'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::releaseBlockOfRows(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfColumnValues__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfColumnValues__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfColumnValues__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *) 0 ;
  size_t arg2 ;
  size_t arg3 ;
  size_t arg4 ;
  daal::data_management::ReadWriteMode arg5 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg6 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *smartarg1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  size_t val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  void *argp6 = 0 ;
  int res6 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared6 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  PyObject * obj4 = 0 ;
  PyObject * obj5 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOOOO:PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfColumnValues",&obj0,&obj1,&obj2,&obj3,&obj4,&obj5)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_size_t(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  ecode3 = SWIG_AsVal_size_t(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "3"" of type '" "size_t""'");
  } 
  arg3 = static_cast< size_t >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  ecode5 = SWIG_AsVal_int(obj4, &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "5"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg5 = static_cast< daal::data_management::ReadWriteMode >(val5);
  {
    int newmem = 0;
    res6 = SWIG_ConvertPtrAndOwn(obj5, &argp6, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res6)) {
      SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp6) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared6 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6);
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared6.get());
    } else {
      arg6 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp6)->get());
    }
    if(!arg6) SWIG_exception_fail(SWIG_ArgError(res6), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfColumnValues" "', argument " "6"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getBlockOfColumnValues(arg2,arg3,arg4,arg5,*arg6);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfColumnValues(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[7];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 6) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfColumnValues__SWIG_0(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfColumnValues__SWIG_1(self, args);
              }
            }
          }
        }
      }
    }
  }
  if (argc == 6) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              int res = SWIG_ConvertPtr(argv[5], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
              _v = SWIG_CheckState(res);
              if (_v) {
                return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfColumnValues__SWIG_2(self, args);
              }
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfColumnValues'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::getBlockOfColumnValues(size_t,size_t,size_t,daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfColumnValues__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfColumnValues__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfColumnValues__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfColumnValues",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfColumnValues" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfColumnValues" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releaseBlockOfColumnValues(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfColumnValues(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfColumnValues__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfColumnValues__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfColumnValues__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfColumnValues'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::releaseBlockOfColumnValues(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getPackedArray__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *) 0 ;
  daal::data_management::ReadWriteMode arg2 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared3 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getPackedArray",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getPackedArray" "', argument " "2"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg2 = static_cast< daal::data_management::ReadWriteMode >(val2);
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared3 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp3);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp3);
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared3.get());
    } else {
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp3)->get());
    }
    if(!arg3) SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getPackedArray(arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getPackedArray__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *) 0 ;
  daal::data_management::ReadWriteMode arg2 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared3 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getPackedArray",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getPackedArray" "', argument " "2"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg2 = static_cast< daal::data_management::ReadWriteMode >(val2);
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared3 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp3);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp3);
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared3.get());
    } else {
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp3)->get());
    }
    if(!arg3) SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getPackedArray(arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getPackedArray__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *) 0 ;
  daal::data_management::ReadWriteMode arg2 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *smartarg1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared3 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getPackedArray",&obj0,&obj1,&obj2)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getPackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *""'"); 
  }
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getPackedArray" "', argument " "2"" of type '" "daal::data_management::ReadWriteMode""'");
  } 
  arg2 = static_cast< daal::data_management::ReadWriteMode >(val2);
  {
    int newmem = 0;
    res3 = SWIG_ConvertPtrAndOwn(obj2, &argp3, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared3 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp3);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp3);
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared3.get());
    } else {
      arg3 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp3)->get());
    }
    if(!arg3) SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getPackedArray" "', argument " "3"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->getPackedArray(arg2,*arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getPackedArray(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[4];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 3) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getPackedArray__SWIG_0(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getPackedArray__SWIG_1(self, args);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getPackedArray__SWIG_2(self, args);
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getPackedArray'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::getPackedArray(daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::getPackedArray(daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::getPackedArray(daal::data_management::ReadWriteMode,daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releasePackedArray__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< double > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releasePackedArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< double > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< double > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< double > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releasePackedArray(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releasePackedArray__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< float > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releasePackedArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< float > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< float > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< float > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releasePackedArray(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releasePackedArray__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *arg1 = (daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *) 0 ;
  daal::data_management::interface1::BlockDescriptor< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *smartarg1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > tempshared2 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releasePackedArray",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releasePackedArray" "', argument " "1"" of type '" "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *""'"); 
  }
  {
    int newmem = 0;
    res2 = SWIG_ConvertPtrAndOwn(obj1, &argp2, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared2 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2);
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(tempshared2.get());
    } else {
      arg2 = const_cast< daal::data_management::interface1::BlockDescriptor< int > * >(reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::BlockDescriptor< int > > * >(argp2)->get());
    }
    if(!arg2) SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releasePackedArray" "', argument " "2"" of type '" "daal::data_management::interface1::BlockDescriptor< int > &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->releasePackedArray(*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releasePackedArray(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releasePackedArray__SWIG_0(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releasePackedArray__SWIG_1(self, args);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releasePackedArray__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releasePackedArray'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::releasePackedArray(daal::data_management::interface1::BlockDescriptor< double > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::releasePackedArray(daal::data_management::interface1::BlockDescriptor< float > &)\n"
    "    daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int >::releasePackedArray(daal::data_management::interface1::BlockDescriptor< int > &)\n");
  return 0;
}


SWIGINTERN PyObject *PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_StringDataSource_CSVFeatureManagerFloat64__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::byte *arg1 = (daal::byte *) 0 ;
  daal::data_management::interface1::DataSourceIface::NumericTableAllocationFlag arg2 ;
  daal::data_management::interface1::DataSourceIface::DictionaryCreationFlag arg3 ;
  size_t arg4 ;
  int res1 ;
  char *buf1 = 0 ;
  int alloc1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  int val3 ;
  int ecode3 = 0 ;
  size_t val4 ;
  int ecode4 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  PyObject * obj3 = 0 ;
  daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOOO:new_StringDataSource_CSVFeatureManagerFloat64",&obj0,&obj1,&obj2,&obj3)) SWIG_fail;
  res1 = SWIG_AsCharPtrAndSize(obj0, &buf1, NULL, &alloc1);
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_StringDataSource_CSVFeatureManagerFloat64" "', argument " "1"" of type '" "daal::byte const *""'");
  }
  arg1 = reinterpret_cast< daal::byte * >(buf1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "new_StringDataSource_CSVFeatureManagerFloat64" "', argument " "2"" of type '" "daal::data_management::interface1::DataSourceIface::NumericTableAllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::DataSourceIface::NumericTableAllocationFlag >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "new_StringDataSource_CSVFeatureManagerFloat64" "', argument " "3"" of type '" "daal::data_management::interface1::DataSourceIface::DictionaryCreationFlag""'");
  } 
  arg3 = static_cast< daal::data_management::interface1::DataSourceIface::DictionaryCreationFlag >(val3);
  ecode4 = SWIG_AsVal_size_t(obj3, &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "new_StringDataSource_CSVFeatureManagerFloat64" "', argument " "4"" of type '" "size_t""'");
  } 
  arg4 = static_cast< size_t >(val4);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > *)new daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double >((daal::byte const *)arg1,arg2,arg3,arg4);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  if (alloc1 == SWIG_NEWOBJ) delete[] buf1;
  return resultobj;
fail:
  if (alloc1 == SWIG_NEWOBJ) delete[] buf1;
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_StringDataSource_CSVFeatureManagerFloat64__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::byte *arg1 = (daal::byte *) 0 ;
  daal::data_management::interface1::DataSourceIface::NumericTableAllocationFlag arg2 ;
  daal::data_management::interface1::DataSourceIface::DictionaryCreationFlag arg3 ;
  int res1 ;
  char *buf1 = 0 ;
  int alloc1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  int val3 ;
  int ecode3 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  PyObject * obj2 = 0 ;
  daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OOO:new_StringDataSource_CSVFeatureManagerFloat64",&obj0,&obj1,&obj2)) SWIG_fail;
  res1 = SWIG_AsCharPtrAndSize(obj0, &buf1, NULL, &alloc1);
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_StringDataSource_CSVFeatureManagerFloat64" "', argument " "1"" of type '" "daal::byte const *""'");
  }
  arg1 = reinterpret_cast< daal::byte * >(buf1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "new_StringDataSource_CSVFeatureManagerFloat64" "', argument " "2"" of type '" "daal::data_management::interface1::DataSourceIface::NumericTableAllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::DataSourceIface::NumericTableAllocationFlag >(val2);
  ecode3 = SWIG_AsVal_int(obj2, &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "new_StringDataSource_CSVFeatureManagerFloat64" "', argument " "3"" of type '" "daal::data_management::interface1::DataSourceIface::DictionaryCreationFlag""'");
  } 
  arg3 = static_cast< daal::data_management::interface1::DataSourceIface::DictionaryCreationFlag >(val3);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > *)new daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double >((daal::byte const *)arg1,arg2,arg3);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  if (alloc1 == SWIG_NEWOBJ) delete[] buf1;
  return resultobj;
fail:
  if (alloc1 == SWIG_NEWOBJ) delete[] buf1;
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_StringDataSource_CSVFeatureManagerFloat64__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::byte *arg1 = (daal::byte *) 0 ;
  daal::data_management::interface1::DataSourceIface::NumericTableAllocationFlag arg2 ;
  int res1 ;
  char *buf1 = 0 ;
  int alloc1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:new_StringDataSource_CSVFeatureManagerFloat64",&obj0,&obj1)) SWIG_fail;
  res1 = SWIG_AsCharPtrAndSize(obj0, &buf1, NULL, &alloc1);
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_StringDataSource_CSVFeatureManagerFloat64" "', argument " "1"" of type '" "daal::byte const *""'");
  }
  arg1 = reinterpret_cast< daal::byte * >(buf1);
  ecode2 = SWIG_AsVal_int(obj1, &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "new_StringDataSource_CSVFeatureManagerFloat64" "', argument " "2"" of type '" "daal::data_management::interface1::DataSourceIface::NumericTableAllocationFlag""'");
  } 
  arg2 = static_cast< daal::data_management::interface1::DataSourceIface::NumericTableAllocationFlag >(val2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > *)new daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double >((daal::byte const *)arg1,arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  if (alloc1 == SWIG_NEWOBJ) delete[] buf1;
  return resultobj;
fail:
  if (alloc1 == SWIG_NEWOBJ) delete[] buf1;
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_StringDataSource_CSVFeatureManagerFloat64__SWIG_3(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::byte *arg1 = (daal::byte *) 0 ;
  int res1 ;
  char *buf1 = 0 ;
  int alloc1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:new_StringDataSource_CSVFeatureManagerFloat64",&obj0)) SWIG_fail;
  res1 = SWIG_AsCharPtrAndSize(obj0, &buf1, NULL, &alloc1);
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_StringDataSource_CSVFeatureManagerFloat64" "', argument " "1"" of type '" "daal::byte const *""'");
  }
  arg1 = reinterpret_cast< daal::byte * >(buf1);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > *)new daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double >((daal::byte const *)arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  if (alloc1 == SWIG_NEWOBJ) delete[] buf1;
  return resultobj;
fail:
  if (alloc1 == SWIG_NEWOBJ) delete[] buf1;
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_StringDataSource_CSVFeatureManagerFloat64(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[5];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 4) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 1) {
    int _v;
    int res = SWIG_AsCharPtrAndSize(argv[0], 0, NULL, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_StringDataSource_CSVFeatureManagerFloat64__SWIG_3(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    int res = SWIG_AsCharPtrAndSize(argv[0], 0, NULL, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_new_StringDataSource_CSVFeatureManagerFloat64__SWIG_2(self, args);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = SWIG_AsCharPtrAndSize(argv[0], 0, NULL, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_new_StringDataSource_CSVFeatureManagerFloat64__SWIG_1(self, args);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = SWIG_AsCharPtrAndSize(argv[0], 0, NULL, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_size_t(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            return _wrap_new_StringDataSource_CSVFeatureManagerFloat64__SWIG_0(self, args);
          }
        }
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'new_StringDataSource_CSVFeatureManagerFloat64'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double >::StringDataSource(daal::byte const *,daal::data_management::interface1::DataSourceIface::NumericTableAllocationFlag,daal::data_management::interface1::DataSourceIface::DictionaryCreationFlag,size_t)\n"
    "    daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double >::StringDataSource(daal::byte const *,daal::data_management::interface1::DataSourceIface::NumericTableAllocationFlag,daal::data_management::interface1::DataSourceIface::DictionaryCreationFlag)\n"
    "    daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double >::StringDataSource(daal::byte const *,daal::data_management::interface1::DataSourceIface::NumericTableAllocationFlag)\n"
    "    daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double >::StringDataSource(daal::byte const *)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_StringDataSource_CSVFeatureManagerFloat64_setData(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > *arg1 = (daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > *) 0 ;
  daal::byte *arg2 = (daal::byte *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *smartarg1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:StringDataSource_CSVFeatureManagerFloat64_setData",&obj0,&obj1)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringDataSource_CSVFeatureManagerFloat64_setData" "', argument " "1"" of type '" "daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringDataSource_CSVFeatureManagerFloat64_setData" "', argument " "1"" of type '" "daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > *""'"); 
  }
  res2 = SWIG_AsCharPtrAndSize(obj1, &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "StringDataSource_CSVFeatureManagerFloat64_setData" "', argument " "2"" of type '" "daal::byte const *""'");
  }
  arg2 = reinterpret_cast< daal::byte * >(buf2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->setData((daal::byte const *)arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
  return resultobj;
fail:
  if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringDataSource_CSVFeatureManagerFloat64_getData(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > *arg1 = (daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::byte *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:StringDataSource_CSVFeatureManagerFloat64_getData",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringDataSource_CSVFeatureManagerFloat64_getData" "', argument " "1"" of type '" "daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringDataSource_CSVFeatureManagerFloat64_getData" "', argument " "1"" of type '" "daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::byte *)(arg1)->getData();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_unsigned_char, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringDataSource_CSVFeatureManagerFloat64_resetData(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > *arg1 = (daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:StringDataSource_CSVFeatureManagerFloat64_resetData",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringDataSource_CSVFeatureManagerFloat64_resetData" "', argument " "1"" of type '" "daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringDataSource_CSVFeatureManagerFloat64_resetData" "', argument " "1"" of type '" "daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        (arg1)->resetData();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringDataSource_CSVFeatureManagerFloat64_createDictionaryFromContext(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > *arg1 = (daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::services::Status result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:StringDataSource_CSVFeatureManagerFloat64_createDictionaryFromContext",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringDataSource_CSVFeatureManagerFloat64_createDictionaryFromContext" "', argument " "1"" of type '" "daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringDataSource_CSVFeatureManagerFloat64_createDictionaryFromContext" "', argument " "1"" of type '" "daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (arg1)->createDictionaryFromContext();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_NewPointerObj((new daal::services::Status(static_cast< const daal::services::Status& >(result))), SWIGTYPE_p_daal__services__interface1__Status, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringDataSource_CSVFeatureManagerFloat64_getStatus(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > *arg1 = (daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::DataSourceIface::DataSourceStatus result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:StringDataSource_CSVFeatureManagerFloat64_getStatus",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringDataSource_CSVFeatureManagerFloat64_getStatus" "', argument " "1"" of type '" "daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringDataSource_CSVFeatureManagerFloat64_getStatus" "', argument " "1"" of type '" "daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::DataSourceIface::DataSourceStatus)(arg1)->getStatus();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_StringDataSource_CSVFeatureManagerFloat64(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > *arg1 = (daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_StringDataSource_CSVFeatureManagerFloat64",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_StringDataSource_CSVFeatureManagerFloat64" "', argument " "1"" of type '" "daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_StringDataSource_CSVFeatureManagerFloat64" "', argument " "1"" of type '" "daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *StringDataSource_CSVFeatureManagerFloat64_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_KeyValueDataCollection_serializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)":KeyValueDataCollection_serializationTag")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface >::SWIGTEMPLATEDISAMBIGUATOR serializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_KeyValueDataCollection_getSerializationTag(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > *arg1 = (daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > const > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > const > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  int result;
  
  if (!PyArg_ParseTuple(args,(char *)"O:KeyValueDataCollection_getSerializationTag",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "KeyValueDataCollection_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > const *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "KeyValueDataCollection_getSerializationTag" "', argument " "1"" of type '" "daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > const *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (int)((daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > const *)arg1)->getSerializationTag();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_KeyValueDataCollection__SWIG_0(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)":new_KeyValueDataCollection")) SWIG_fail;
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > *)new daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface >();
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_KeyValueDataCollection__SWIG_1(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > const > tempshared1 ;
  PyObject * obj0 = 0 ;
  daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:new_KeyValueDataCollection",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t,  0 , &newmem);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_KeyValueDataCollection" "', argument " "1"" of type '" "daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > const &""'"); 
    }
    if (!argp1) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_KeyValueDataCollection" "', argument " "1"" of type '" "daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > const &""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > * >(tempshared1.get());
    } else {
      arg1 = const_cast< daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > * >(reinterpret_cast< daal::services::SharedPtr< const daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > > * >(argp1)->get());
    }
    if(!arg1) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_KeyValueDataCollection" "', argument " "1"" of type '" "daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > const &""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > *)new daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface >((daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > const &)*arg1);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_KeyValueDataCollection__SWIG_2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::services::Collection< size_t > *arg1 = 0 ;
  daal::services::Collection< daal::services::SharedPtr< daal::data_management::interface1::SerializationIface > > *arg2 = 0 ;
  daal::services::Collection< size_t > *col_szt1 = NULL ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject * obj0 = 0 ;
  PyObject * obj1 = 0 ;
  daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > *result = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"OO:new_KeyValueDataCollection",&obj0,&obj1)) SWIG_fail;
  {
    Py_ssize_t n = PySequence_Length(obj0);
    if( n == 0 ) SWIG_fail;
    col_szt1 = new daal::services::Collection<size_t>(n);
    for( Py_ssize_t i=0; i<n; ++i ) {
      PyObject * o = PySequence_GetItem(obj0, i);
      size_t tmp = PyInt_AsSsize_t(o);
      if(PyErr_Occurred()) {
        PyErr_Format(PyExc_TypeError, "Sequence of integer values required");
        SWIG_fail;
      }
      (*col_szt1)[i] = tmp;
    }
    arg1 = col_szt1;
  }
  res2 = SWIG_ConvertPtr(obj1, &argp2, SWIGTYPE_p_daal__services__CollectionT_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t_t,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "new_KeyValueDataCollection" "', argument " "2"" of type '" "daal::services::Collection< daal::services::SharedPtr< daal::data_management::interface1::SerializationIface > > const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_KeyValueDataCollection" "', argument " "2"" of type '" "daal::services::Collection< daal::services::SharedPtr< daal::data_management::interface1::SerializationIface > > const &""'"); 
  }
  arg2 = reinterpret_cast< daal::services::Collection< daal::services::SharedPtr< daal::data_management::interface1::SerializationIface > > * >(argp2);
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        result = (daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > *)new daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface >((daal::services::Collection< size_t > const &)*arg1,(daal::services::Collection< daal::services::SharedPtr< daal::data_management::interface1::SerializationIface > > const &)*arg2);
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  {
    daal::services::SharedPtr<  daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > > *smartresult = result ? new daal::services::SharedPtr<  daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > >(result SWIG_NO_NULL_DELETER_SWIG_POINTER_NEW) : 0;
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(smartresult), SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t, SWIG_POINTER_NEW | SWIG_POINTER_OWN);
  }
  {
    if( col_szt1 ) delete col_szt1;
  }
  return resultobj;
fail:
  {
    if( col_szt1 ) delete col_szt1;
  }
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_KeyValueDataCollection(PyObject *self, PyObject *args) {
  int argc;
  PyObject *argv[3];
  int ii;
  
  if (args && !PyTuple_Check(args)) SWIG_fail;
  argc = args ? (int)PyObject_Length(args) : 0;
  for (ii = 0; (ii < 2) && (ii < argc); ii++) {
    argv[ii] = PyTuple_GET_ITEM(args,ii);
  }
  if (argc == 0) {
    return _wrap_new_KeyValueDataCollection__SWIG_0(self, args);
  }
  if (argc == 1) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_KeyValueDataCollection__SWIG_1(self, args);
    }
  }
  if (argc == 2) {
    int _v;
    {
      _v = PySequence_Check(argv[0]);
    }
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_daal__services__CollectionT_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t_t, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_new_KeyValueDataCollection__SWIG_2(self, args);
      }
    }
  }
  
fail:
  SWIG_SetErrorMsg(PyExc_NotImplementedError,"Wrong number or type of arguments for overloaded function 'new_KeyValueDataCollection'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface >::SerializableKeyValueCollection()\n"
    "    daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface >::SerializableKeyValueCollection(daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > const &)\n"
    "    daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface >::SerializableKeyValueCollection(daal::services::Collection< size_t > const &,daal::services::Collection< daal::services::SharedPtr< daal::data_management::interface1::SerializationIface > > const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_KeyValueDataCollection(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > *arg1 = (daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  daal::services::SharedPtr< daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > > tempshared1 ;
  daal::services::SharedPtr< daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > > *smartarg1 = 0 ;
  PyObject * obj0 = 0 ;
  
  if (!PyArg_ParseTuple(args,(char *)"O:delete_KeyValueDataCollection",&obj0)) SWIG_fail;
  {
    int newmem = 0;
    res1 = SWIG_ConvertPtrAndOwn(obj0, &argp1, SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t, 0 |  0 , &newmem);
    if ((!SWIG_IsOK(res1) || !argp1) && obj0 != Py_None) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_KeyValueDataCollection" "', argument " "1"" of type '" "daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > *""'"); 
    }
    if (newmem & SWIG_CAST_NEW_MEMORY) {
      tempshared1 = *reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > > * >(argp1);
      delete reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > * >(tempshared1.get());
    } else {
      smartarg1 = reinterpret_cast< daal::services::SharedPtr<  daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > > * >(argp1);
      arg1 = const_cast< daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > * >((smartarg1 ? smartarg1->get() : 0));
    }
    if(!arg1 && obj0 != Py_None) SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_KeyValueDataCollection" "', argument " "1"" of type '" "daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > *""'"); 
  }
  {
    try {
      {
        SWIG_PYTHON_THREAD_BEGIN_ALLOW;
        delete smartarg1;
        SWIG_PYTHON_THREAD_END_ALLOW;
      }
    }
    /*@SWIG:/export/users/cache/swig/lnx/3.0.6.patched7/Lib/typemaps/exception.swg,58,SWIG_CATCH_STDEXCEPT@*/  /* catching std::exception  */
    catch (std::invalid_argument& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::domain_error& e) {
      SWIG_exception_fail(SWIG_ValueError, e.what() );
    } catch (std::overflow_error& e) {
      SWIG_exception_fail(SWIG_OverflowError, e.what() );
    } catch (std::out_of_range& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::length_error& e) {
      SWIG_exception_fail(SWIG_IndexError, e.what() );
    } catch (std::runtime_error& e) {
      SWIG_exception_fail(SWIG_RuntimeError, e.what() );
    } catch (std::exception& e) {
      SWIG_exception_fail(SWIG_SystemError, e.what() );
    }
    /*@SWIG@*/ // catch std::exception
    catch (...) {
      SWIG_exception_fail(SWIG_UnknownError, "unknown exception from Intel(R) DAAL");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *KeyValueDataCollection_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!PyArg_ParseTuple(args,(char*)"O:swigregister", &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

static PyMethodDef SwigMethods[] = {
	 { (char *)"SWIG_PyInstanceMethod_New", (PyCFunction)SWIG_PyInstanceMethod_New, METH_O, NULL},
	 { (char *)"delete_SerializationIface", _wrap_delete_SerializationIface, METH_VARARGS, NULL},
	 { (char *)"SerializationIface_serialize", _wrap_SerializationIface_serialize, METH_VARARGS, NULL},
	 { (char *)"SerializationIface_deserialize", _wrap_SerializationIface_deserialize, METH_VARARGS, NULL},
	 { (char *)"SerializationIface_getSerializationTag", _wrap_SerializationIface_getSerializationTag, METH_VARARGS, NULL},
	 { (char *)"SerializationIface_swigregister", SerializationIface_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_SerializationDesc", _wrap_new_SerializationDesc, METH_VARARGS, NULL},
	 { (char *)"SerializationDesc_tag", _wrap_SerializationDesc_tag, METH_VARARGS, NULL},
	 { (char *)"SerializationDesc_creator", _wrap_SerializationDesc_creator, METH_VARARGS, NULL},
	 { (char *)"SerializationDesc_next", _wrap_SerializationDesc_next, METH_VARARGS, NULL},
	 { (char *)"SerializationDesc_first", _wrap_SerializationDesc_first, METH_VARARGS, NULL},
	 { (char *)"delete_SerializationDesc", _wrap_delete_SerializationDesc, METH_VARARGS, NULL},
	 { (char *)"SerializationDesc_swigregister", SerializationDesc_swigregister, METH_VARARGS, NULL},
	 { (char *)"delete_DataBlock", _wrap_delete_DataBlock, METH_VARARGS, NULL},
	 { (char *)"DataBlock_getSize", _wrap_DataBlock_getSize, METH_VARARGS, NULL},
	 { (char *)"new_DataBlock", _wrap_new_DataBlock, METH_VARARGS, NULL},
	 { (char *)"DataBlock_getArray", _wrap_DataBlock_getArray, METH_VARARGS, NULL},
	 { (char *)"DataBlock_setArray", _wrap_DataBlock_setArray, METH_VARARGS, NULL},
	 { (char *)"DataBlock_swigregister", DataBlock_swigregister, METH_VARARGS, NULL},
	 { (char *)"defaultLevel_swigconstant", defaultLevel_swigconstant, METH_VARARGS, NULL},
	 { (char *)"level0_swigconstant", level0_swigconstant, METH_VARARGS, NULL},
	 { (char *)"level1_swigconstant", level1_swigconstant, METH_VARARGS, NULL},
	 { (char *)"level2_swigconstant", level2_swigconstant, METH_VARARGS, NULL},
	 { (char *)"level3_swigconstant", level3_swigconstant, METH_VARARGS, NULL},
	 { (char *)"level4_swigconstant", level4_swigconstant, METH_VARARGS, NULL},
	 { (char *)"level5_swigconstant", level5_swigconstant, METH_VARARGS, NULL},
	 { (char *)"level6_swigconstant", level6_swigconstant, METH_VARARGS, NULL},
	 { (char *)"level7_swigconstant", level7_swigconstant, METH_VARARGS, NULL},
	 { (char *)"level8_swigconstant", level8_swigconstant, METH_VARARGS, NULL},
	 { (char *)"level9_swigconstant", level9_swigconstant, METH_VARARGS, NULL},
	 { (char *)"lastCompressionLevel_swigconstant", lastCompressionLevel_swigconstant, METH_VARARGS, NULL},
	 { (char *)"zlib_swigconstant", zlib_swigconstant, METH_VARARGS, NULL},
	 { (char *)"lzo_swigconstant", lzo_swigconstant, METH_VARARGS, NULL},
	 { (char *)"rle_swigconstant", rle_swigconstant, METH_VARARGS, NULL},
	 { (char *)"bzip2_swigconstant", bzip2_swigconstant, METH_VARARGS, NULL},
	 { (char *)"CompressionParameter_level_set", _wrap_CompressionParameter_level_set, METH_VARARGS, NULL},
	 { (char *)"CompressionParameter_level_get", _wrap_CompressionParameter_level_get, METH_VARARGS, NULL},
	 { (char *)"new_CompressionParameter", _wrap_new_CompressionParameter, METH_VARARGS, NULL},
	 { (char *)"delete_CompressionParameter", _wrap_delete_CompressionParameter, METH_VARARGS, NULL},
	 { (char *)"CompressionParameter_swigregister", CompressionParameter_swigregister, METH_VARARGS, NULL},
	 { (char *)"CompressionIface_setInputDataBlock", _wrap_CompressionIface_setInputDataBlock, METH_VARARGS, NULL},
	 { (char *)"CompressionIface_isOutputDataBlockFull", _wrap_CompressionIface_isOutputDataBlockFull, METH_VARARGS, NULL},
	 { (char *)"CompressionIface_getUsedOutputDataBlockSize", _wrap_CompressionIface_getUsedOutputDataBlockSize, METH_VARARGS, NULL},
	 { (char *)"CompressionIface_run", _wrap_CompressionIface_run, METH_VARARGS, NULL},
	 { (char *)"delete_CompressionIface", _wrap_delete_CompressionIface, METH_VARARGS, NULL},
	 { (char *)"CompressionIface_swigregister", CompressionIface_swigregister, METH_VARARGS, NULL},
	 { (char *)"Compression_setInputDataBlock", _wrap_Compression_setInputDataBlock, METH_VARARGS, NULL},
	 { (char *)"Compression_isOutputDataBlockFull", _wrap_Compression_isOutputDataBlockFull, METH_VARARGS, NULL},
	 { (char *)"Compression_getUsedOutputDataBlockSize", _wrap_Compression_getUsedOutputDataBlockSize, METH_VARARGS, NULL},
	 { (char *)"Compression_run", _wrap_Compression_run, METH_VARARGS, NULL},
	 { (char *)"delete_Compression", _wrap_delete_Compression, METH_VARARGS, NULL},
	 { (char *)"Compression_checkInputParams", _wrap_Compression_checkInputParams, METH_VARARGS, NULL},
	 { (char *)"Compression_checkOutputParams", _wrap_Compression_checkOutputParams, METH_VARARGS, NULL},
	 { (char *)"Compression_swigregister", Compression_swigregister, METH_VARARGS, NULL},
	 { (char *)"delete_CompressorImpl", _wrap_delete_CompressorImpl, METH_VARARGS, NULL},
	 { (char *)"CompressorImpl_swigregister", CompressorImpl_swigregister, METH_VARARGS, NULL},
	 { (char *)"delete_DecompressorImpl", _wrap_delete_DecompressorImpl, METH_VARARGS, NULL},
	 { (char *)"DecompressorImpl_swigregister", DecompressorImpl_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_CompressionStream", _wrap_new_CompressionStream, METH_VARARGS, NULL},
	 { (char *)"delete_CompressionStream", _wrap_delete_CompressionStream, METH_VARARGS, NULL},
	 { (char *)"CompressionStream___lshift__", _wrap_CompressionStream___lshift__, METH_VARARGS, NULL},
	 { (char *)"CompressionStream_getCompressedBlocksCollection", _wrap_CompressionStream_getCompressedBlocksCollection, METH_VARARGS, NULL},
	 { (char *)"CompressionStream_getCompressedDataSize", _wrap_CompressionStream_getCompressedDataSize, METH_VARARGS, NULL},
	 { (char *)"CompressionStream_copyCompressedArray", _wrap_CompressionStream_copyCompressedArray, METH_VARARGS, NULL},
	 { (char *)"CompressionStream_push_back", _wrap_CompressionStream_push_back, METH_VARARGS, NULL},
	 { (char *)"CompressionStream_swigregister", CompressionStream_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_DecompressionStream", _wrap_new_DecompressionStream, METH_VARARGS, NULL},
	 { (char *)"delete_DecompressionStream", _wrap_delete_DecompressionStream, METH_VARARGS, NULL},
	 { (char *)"DecompressionStream___lshift__", _wrap_DecompressionStream___lshift__, METH_VARARGS, NULL},
	 { (char *)"DecompressionStream_getDecompressedBlocksCollection", _wrap_DecompressionStream_getDecompressedBlocksCollection, METH_VARARGS, NULL},
	 { (char *)"DecompressionStream_getDecompressedDataSize", _wrap_DecompressionStream_getDecompressedDataSize, METH_VARARGS, NULL},
	 { (char *)"DecompressionStream_copyDecompressedArray", _wrap_DecompressionStream_copyDecompressedArray, METH_VARARGS, NULL},
	 { (char *)"DecompressionStream_push_back", _wrap_DecompressionStream_push_back, METH_VARARGS, NULL},
	 { (char *)"DecompressionStream_swigregister", DecompressionStream_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_Bzip2CompressionParameter", _wrap_new_Bzip2CompressionParameter, METH_VARARGS, NULL},
	 { (char *)"delete_Bzip2CompressionParameter", _wrap_delete_Bzip2CompressionParameter, METH_VARARGS, NULL},
	 { (char *)"Bzip2CompressionParameter_swigregister", Bzip2CompressionParameter_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_LzoCompressionParameter", _wrap_new_LzoCompressionParameter, METH_VARARGS, NULL},
	 { (char *)"delete_LzoCompressionParameter", _wrap_delete_LzoCompressionParameter, METH_VARARGS, NULL},
	 { (char *)"LzoCompressionParameter_preHeadBytes_set", _wrap_LzoCompressionParameter_preHeadBytes_set, METH_VARARGS, NULL},
	 { (char *)"LzoCompressionParameter_preHeadBytes_get", _wrap_LzoCompressionParameter_preHeadBytes_get, METH_VARARGS, NULL},
	 { (char *)"LzoCompressionParameter_postHeadBytes_set", _wrap_LzoCompressionParameter_postHeadBytes_set, METH_VARARGS, NULL},
	 { (char *)"LzoCompressionParameter_postHeadBytes_get", _wrap_LzoCompressionParameter_postHeadBytes_get, METH_VARARGS, NULL},
	 { (char *)"LzoCompressionParameter_swigregister", LzoCompressionParameter_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_RleCompressionParameter", _wrap_new_RleCompressionParameter, METH_VARARGS, NULL},
	 { (char *)"delete_RleCompressionParameter", _wrap_delete_RleCompressionParameter, METH_VARARGS, NULL},
	 { (char *)"RleCompressionParameter_isBlockHeader_set", _wrap_RleCompressionParameter_isBlockHeader_set, METH_VARARGS, NULL},
	 { (char *)"RleCompressionParameter_isBlockHeader_get", _wrap_RleCompressionParameter_isBlockHeader_get, METH_VARARGS, NULL},
	 { (char *)"RleCompressionParameter_swigregister", RleCompressionParameter_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_ZlibCompressionParameter", _wrap_new_ZlibCompressionParameter, METH_VARARGS, NULL},
	 { (char *)"delete_ZlibCompressionParameter", _wrap_delete_ZlibCompressionParameter, METH_VARARGS, NULL},
	 { (char *)"ZlibCompressionParameter_gzHeader_set", _wrap_ZlibCompressionParameter_gzHeader_set, METH_VARARGS, NULL},
	 { (char *)"ZlibCompressionParameter_gzHeader_get", _wrap_ZlibCompressionParameter_gzHeader_get, METH_VARARGS, NULL},
	 { (char *)"ZlibCompressionParameter_swigregister", ZlibCompressionParameter_swigregister, METH_VARARGS, NULL},
	 { (char *)"readOnly_swigconstant", readOnly_swigconstant, METH_VARARGS, NULL},
	 { (char *)"writeOnly_swigconstant", writeOnly_swigconstant, METH_VARARGS, NULL},
	 { (char *)"readWrite_swigconstant", readWrite_swigconstant, METH_VARARGS, NULL},
	 { (char *)"delete_DataArchiveIface", _wrap_delete_DataArchiveIface, METH_VARARGS, NULL},
	 { (char *)"DataArchiveIface_write", _wrap_DataArchiveIface_write, METH_VARARGS, NULL},
	 { (char *)"DataArchiveIface_read", _wrap_DataArchiveIface_read, METH_VARARGS, NULL},
	 { (char *)"DataArchiveIface_getSizeOfArchive", _wrap_DataArchiveIface_getSizeOfArchive, METH_VARARGS, NULL},
	 { (char *)"DataArchiveIface_getArchiveAsString", _wrap_DataArchiveIface_getArchiveAsString, METH_VARARGS, NULL},
	 { (char *)"DataArchiveIface_copyArchiveToArray", _wrap_DataArchiveIface_copyArchiveToArray, METH_VARARGS, NULL},
	 { (char *)"DataArchiveIface_setMajorVersion", _wrap_DataArchiveIface_setMajorVersion, METH_VARARGS, NULL},
	 { (char *)"DataArchiveIface_setMinorVersion", _wrap_DataArchiveIface_setMinorVersion, METH_VARARGS, NULL},
	 { (char *)"DataArchiveIface_setUpdateVersion", _wrap_DataArchiveIface_setUpdateVersion, METH_VARARGS, NULL},
	 { (char *)"DataArchiveIface_getMajorVersion", _wrap_DataArchiveIface_getMajorVersion, METH_VARARGS, NULL},
	 { (char *)"DataArchiveIface_getMinorVersion", _wrap_DataArchiveIface_getMinorVersion, METH_VARARGS, NULL},
	 { (char *)"DataArchiveIface_getUpdateVersion", _wrap_DataArchiveIface_getUpdateVersion, METH_VARARGS, NULL},
	 { (char *)"DataArchiveIface_swigregister", DataArchiveIface_swigregister, METH_VARARGS, NULL},
	 { (char *)"delete_DataArchiveImpl", _wrap_delete_DataArchiveImpl, METH_VARARGS, NULL},
	 { (char *)"DataArchiveImpl_setMajorVersion", _wrap_DataArchiveImpl_setMajorVersion, METH_VARARGS, NULL},
	 { (char *)"DataArchiveImpl_setMinorVersion", _wrap_DataArchiveImpl_setMinorVersion, METH_VARARGS, NULL},
	 { (char *)"DataArchiveImpl_setUpdateVersion", _wrap_DataArchiveImpl_setUpdateVersion, METH_VARARGS, NULL},
	 { (char *)"DataArchiveImpl_getMajorVersion", _wrap_DataArchiveImpl_getMajorVersion, METH_VARARGS, NULL},
	 { (char *)"DataArchiveImpl_getMinorVersion", _wrap_DataArchiveImpl_getMinorVersion, METH_VARARGS, NULL},
	 { (char *)"DataArchiveImpl_getUpdateVersion", _wrap_DataArchiveImpl_getUpdateVersion, METH_VARARGS, NULL},
	 { (char *)"DataArchiveImpl_swigregister", DataArchiveImpl_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_DataArchive", _wrap_new_DataArchive, METH_VARARGS, NULL},
	 { (char *)"delete_DataArchive", _wrap_delete_DataArchive, METH_VARARGS, NULL},
	 { (char *)"DataArchive_write", _wrap_DataArchive_write, METH_VARARGS, NULL},
	 { (char *)"DataArchive_read", _wrap_DataArchive_read, METH_VARARGS, NULL},
	 { (char *)"DataArchive_getSizeOfArchive", _wrap_DataArchive_getSizeOfArchive, METH_VARARGS, NULL},
	 { (char *)"DataArchive_getArchiveAsString", _wrap_DataArchive_getArchiveAsString, METH_VARARGS, NULL},
	 { (char *)"DataArchive_copyArchiveToArray", _wrap_DataArchive_copyArchiveToArray, METH_VARARGS, NULL},
	 { (char *)"DataArchive_getArchiveAsArray", _wrap_DataArchive_getArchiveAsArray, METH_VARARGS, NULL},
	 { (char *)"DataArchive_swigregister", DataArchive_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_CompressedDataArchive", _wrap_new_CompressedDataArchive, METH_VARARGS, NULL},
	 { (char *)"delete_CompressedDataArchive", _wrap_delete_CompressedDataArchive, METH_VARARGS, NULL},
	 { (char *)"CompressedDataArchive_write", _wrap_CompressedDataArchive_write, METH_VARARGS, NULL},
	 { (char *)"CompressedDataArchive_read", _wrap_CompressedDataArchive_read, METH_VARARGS, NULL},
	 { (char *)"CompressedDataArchive_getSizeOfArchive", _wrap_CompressedDataArchive_getSizeOfArchive, METH_VARARGS, NULL},
	 { (char *)"CompressedDataArchive_getArchiveAsString", _wrap_CompressedDataArchive_getArchiveAsString, METH_VARARGS, NULL},
	 { (char *)"CompressedDataArchive_copyArchiveToArray", _wrap_CompressedDataArchive_copyArchiveToArray, METH_VARARGS, NULL},
	 { (char *)"CompressedDataArchive_swigregister", CompressedDataArchive_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_DecompressedDataArchive", _wrap_new_DecompressedDataArchive, METH_VARARGS, NULL},
	 { (char *)"delete_DecompressedDataArchive", _wrap_delete_DecompressedDataArchive, METH_VARARGS, NULL},
	 { (char *)"DecompressedDataArchive_write", _wrap_DecompressedDataArchive_write, METH_VARARGS, NULL},
	 { (char *)"DecompressedDataArchive_read", _wrap_DecompressedDataArchive_read, METH_VARARGS, NULL},
	 { (char *)"DecompressedDataArchive_getSizeOfArchive", _wrap_DecompressedDataArchive_getSizeOfArchive, METH_VARARGS, NULL},
	 { (char *)"DecompressedDataArchive_getArchiveAsString", _wrap_DecompressedDataArchive_getArchiveAsString, METH_VARARGS, NULL},
	 { (char *)"DecompressedDataArchive_copyArchiveToArray", _wrap_DecompressedDataArchive_copyArchiveToArray, METH_VARARGS, NULL},
	 { (char *)"DecompressedDataArchive_swigregister", DecompressedDataArchive_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_InputDataArchive", _wrap_new_InputDataArchive, METH_VARARGS, NULL},
	 { (char *)"delete_InputDataArchive", _wrap_delete_InputDataArchive, METH_VARARGS, NULL},
	 { (char *)"InputDataArchive_archiveHeader", _wrap_InputDataArchive_archiveHeader, METH_VARARGS, NULL},
	 { (char *)"InputDataArchive_archiveFooter", _wrap_InputDataArchive_archiveFooter, METH_VARARGS, NULL},
	 { (char *)"InputDataArchive_segmentHeader", _wrap_InputDataArchive_segmentHeader, METH_VARARGS, NULL},
	 { (char *)"InputDataArchive_segmentFooter", _wrap_InputDataArchive_segmentFooter, METH_VARARGS, NULL},
	 { (char *)"InputDataArchive_setSingleObj", _wrap_InputDataArchive_setSingleObj, METH_VARARGS, NULL},
	 { (char *)"InputDataArchive_getSizeOfArchive", _wrap_InputDataArchive_getSizeOfArchive, METH_VARARGS, NULL},
	 { (char *)"InputDataArchive_getArchiveAsString", _wrap_InputDataArchive_getArchiveAsString, METH_VARARGS, NULL},
	 { (char *)"InputDataArchive_copyArchiveToArray", _wrap_InputDataArchive_copyArchiveToArray, METH_VARARGS, NULL},
	 { (char *)"InputDataArchive_getDataArchive", _wrap_InputDataArchive_getDataArchive, METH_VARARGS, NULL},
	 { (char *)"InputDataArchive_getArchiveAsArray", _wrap_InputDataArchive_getArchiveAsArray, METH_VARARGS, NULL},
	 { (char *)"InputDataArchive_swigregister", InputDataArchive_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_OutputDataArchive", _wrap_new_OutputDataArchive, METH_VARARGS, NULL},
	 { (char *)"delete_OutputDataArchive", _wrap_delete_OutputDataArchive, METH_VARARGS, NULL},
	 { (char *)"OutputDataArchive_archiveHeader", _wrap_OutputDataArchive_archiveHeader, METH_VARARGS, NULL},
	 { (char *)"OutputDataArchive_archiveFooter", _wrap_OutputDataArchive_archiveFooter, METH_VARARGS, NULL},
	 { (char *)"OutputDataArchive_segmentHeader", _wrap_OutputDataArchive_segmentHeader, METH_VARARGS, NULL},
	 { (char *)"OutputDataArchive_segmentFooter", _wrap_OutputDataArchive_segmentFooter, METH_VARARGS, NULL},
	 { (char *)"OutputDataArchive_setSingleObj", _wrap_OutputDataArchive_setSingleObj, METH_VARARGS, NULL},
	 { (char *)"OutputDataArchive_get", _wrap_OutputDataArchive_get, METH_VARARGS, NULL},
	 { (char *)"OutputDataArchive_getMajorVersion", _wrap_OutputDataArchive_getMajorVersion, METH_VARARGS, NULL},
	 { (char *)"OutputDataArchive_getMinorVersion", _wrap_OutputDataArchive_getMinorVersion, METH_VARARGS, NULL},
	 { (char *)"OutputDataArchive_getUpdateVersion", _wrap_OutputDataArchive_getUpdateVersion, METH_VARARGS, NULL},
	 { (char *)"OutputDataArchive_swigregister", OutputDataArchive_swigregister, METH_VARARGS, NULL},
	 { (char *)"DataCollection_serializationTag", _wrap_DataCollection_serializationTag, METH_VARARGS, NULL},
	 { (char *)"DataCollection_getSerializationTag", _wrap_DataCollection_getSerializationTag, METH_VARARGS, NULL},
	 { (char *)"new_DataCollection", _wrap_new_DataCollection, METH_VARARGS, NULL},
	 { (char *)"delete_DataCollection", _wrap_delete_DataCollection, METH_VARARGS, NULL},
	 { (char *)"DataCollection_get", _wrap_DataCollection_get, METH_VARARGS, NULL},
	 { (char *)"DataCollection_push_back", _wrap_DataCollection_push_back, METH_VARARGS, NULL},
	 { (char *)"DataCollection___lshift__", _wrap_DataCollection___lshift__, METH_VARARGS, NULL},
	 { (char *)"DataCollection_size", _wrap_DataCollection_size, METH_VARARGS, NULL},
	 { (char *)"DataCollection_clear", _wrap_DataCollection_clear, METH_VARARGS, NULL},
	 { (char *)"DataCollection_erase", _wrap_DataCollection_erase, METH_VARARGS, NULL},
	 { (char *)"DataCollection_resize", _wrap_DataCollection_resize, METH_VARARGS, NULL},
	 { (char *)"DataCollection___getitem__", _wrap_DataCollection___getitem__, METH_VARARGS, NULL},
	 { (char *)"DataCollection___setitem__", _wrap_DataCollection___setitem__, METH_VARARGS, NULL},
	 { (char *)"DataCollection_swigregister", DataCollection_swigregister, METH_VARARGS, NULL},
	 { (char *)"NumericTableFeature_indexType_set", _wrap_NumericTableFeature_indexType_set, METH_VARARGS, NULL},
	 { (char *)"NumericTableFeature_indexType_get", _wrap_NumericTableFeature_indexType_get, METH_VARARGS, NULL},
	 { (char *)"NumericTableFeature_pmmlType_set", _wrap_NumericTableFeature_pmmlType_set, METH_VARARGS, NULL},
	 { (char *)"NumericTableFeature_pmmlType_get", _wrap_NumericTableFeature_pmmlType_get, METH_VARARGS, NULL},
	 { (char *)"NumericTableFeature_featureType_set", _wrap_NumericTableFeature_featureType_set, METH_VARARGS, NULL},
	 { (char *)"NumericTableFeature_featureType_get", _wrap_NumericTableFeature_featureType_get, METH_VARARGS, NULL},
	 { (char *)"NumericTableFeature_typeSize_set", _wrap_NumericTableFeature_typeSize_set, METH_VARARGS, NULL},
	 { (char *)"NumericTableFeature_typeSize_get", _wrap_NumericTableFeature_typeSize_get, METH_VARARGS, NULL},
	 { (char *)"NumericTableFeature_categoryNumber_set", _wrap_NumericTableFeature_categoryNumber_set, METH_VARARGS, NULL},
	 { (char *)"NumericTableFeature_categoryNumber_get", _wrap_NumericTableFeature_categoryNumber_get, METH_VARARGS, NULL},
	 { (char *)"new_NumericTableFeature", _wrap_new_NumericTableFeature, METH_VARARGS, NULL},
	 { (char *)"delete_NumericTableFeature", _wrap_delete_NumericTableFeature, METH_VARARGS, NULL},
	 { (char *)"NumericTableFeature_getSerializationTag", _wrap_NumericTableFeature_getSerializationTag, METH_VARARGS, NULL},
	 { (char *)"NumericTableFeature_getIndexType", _wrap_NumericTableFeature_getIndexType, METH_VARARGS, NULL},
	 { (char *)"NumericTableFeature_setType_Float64", _wrap_NumericTableFeature_setType_Float64, METH_VARARGS, (char *)"\n"
	"    This function is specialized for float64"},
	 { (char *)"NumericTableFeature_setType_Float32", _wrap_NumericTableFeature_setType_Float32, METH_VARARGS, (char *)"\n"
	"    This function is specialized for float32"},
	 { (char *)"NumericTableFeature_setType_Intc", _wrap_NumericTableFeature_setType_Intc, METH_VARARGS, (char *)"\n"
	"    This function is specialized for intc"},
	 { (char *)"NumericTableFeature_swigregister", NumericTableFeature_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_DictionaryIface", _wrap_new_DictionaryIface, METH_VARARGS, NULL},
	 { (char *)"delete_DictionaryIface", _wrap_delete_DictionaryIface, METH_VARARGS, NULL},
	 { (char *)"DictionaryIface_swigregister", DictionaryIface_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_CategoricalFeatureDictionary", _wrap_new_CategoricalFeatureDictionary, METH_VARARGS, NULL},
	 { (char *)"delete_CategoricalFeatureDictionary", _wrap_delete_CategoricalFeatureDictionary, METH_VARARGS, NULL},
	 { (char *)"CategoricalFeatureDictionary_swigregister", CategoricalFeatureDictionary_swigregister, METH_VARARGS, NULL},
	 { (char *)"DataSourceFeature_ntFeature_set", _wrap_DataSourceFeature_ntFeature_set, METH_VARARGS, NULL},
	 { (char *)"DataSourceFeature_ntFeature_get", _wrap_DataSourceFeature_ntFeature_get, METH_VARARGS, NULL},
	 { (char *)"DataSourceFeature_name_length_set", _wrap_DataSourceFeature_name_length_set, METH_VARARGS, NULL},
	 { (char *)"DataSourceFeature_name_length_get", _wrap_DataSourceFeature_name_length_get, METH_VARARGS, NULL},
	 { (char *)"DataSourceFeature_name_set", _wrap_DataSourceFeature_name_set, METH_VARARGS, NULL},
	 { (char *)"DataSourceFeature_name_get", _wrap_DataSourceFeature_name_get, METH_VARARGS, NULL},
	 { (char *)"DataSourceFeature_cat_dict_set", _wrap_DataSourceFeature_cat_dict_set, METH_VARARGS, NULL},
	 { (char *)"DataSourceFeature_cat_dict_get", _wrap_DataSourceFeature_cat_dict_get, METH_VARARGS, NULL},
	 { (char *)"new_DataSourceFeature", _wrap_new_DataSourceFeature, METH_VARARGS, NULL},
	 { (char *)"delete_DataSourceFeature", _wrap_delete_DataSourceFeature, METH_VARARGS, NULL},
	 { (char *)"DataSourceFeature_getFeatureName", _wrap_DataSourceFeature_getFeatureName, METH_VARARGS, NULL},
	 { (char *)"DataSourceFeature_getCategoricalDictionary", _wrap_DataSourceFeature_getCategoricalDictionary, METH_VARARGS, NULL},
	 { (char *)"DataSourceFeature_setCategoricalDictionary", _wrap_DataSourceFeature_setCategoricalDictionary, METH_VARARGS, NULL},
	 { (char *)"DataSourceFeature_setFeatureName", _wrap_DataSourceFeature_setFeatureName, METH_VARARGS, NULL},
	 { (char *)"DataSourceFeature_getSerializationTag", _wrap_DataSourceFeature_getSerializationTag, METH_VARARGS, NULL},
	 { (char *)"DataSourceFeature_getIndexType", _wrap_DataSourceFeature_getIndexType, METH_VARARGS, NULL},
	 { (char *)"DataSourceFeature_setType_Float64", _wrap_DataSourceFeature_setType_Float64, METH_VARARGS, (char *)"\n"
	"    This function is specialized for float64"},
	 { (char *)"DataSourceFeature_setType_Float32", _wrap_DataSourceFeature_setType_Float32, METH_VARARGS, (char *)"\n"
	"    This function is specialized for float32"},
	 { (char *)"DataSourceFeature_setType_Intc", _wrap_DataSourceFeature_setType_Intc, METH_VARARGS, (char *)"\n"
	"    This function is specialized for intc"},
	 { (char *)"DataSourceFeature_swigregister", DataSourceFeature_swigregister, METH_VARARGS, NULL},
	 { (char *)"delete_NumericTableIface", _wrap_delete_NumericTableIface, METH_VARARGS, NULL},
	 { (char *)"NumericTableIface_setDictionary", _wrap_NumericTableIface_setDictionary, METH_VARARGS, NULL},
	 { (char *)"NumericTableIface_getDictionary", _wrap_NumericTableIface_getDictionary, METH_VARARGS, NULL},
	 { (char *)"NumericTableIface_resetDictionary", _wrap_NumericTableIface_resetDictionary, METH_VARARGS, NULL},
	 { (char *)"NumericTableIface_getFeatureType", _wrap_NumericTableIface_getFeatureType, METH_VARARGS, NULL},
	 { (char *)"NumericTableIface_getNumberOfCategories", _wrap_NumericTableIface_getNumberOfCategories, METH_VARARGS, NULL},
	 { (char *)"NumericTableIface_getDataLayout", _wrap_NumericTableIface_getDataLayout, METH_VARARGS, NULL},
	 { (char *)"NumericTableIface_resize", _wrap_NumericTableIface_resize, METH_VARARGS, NULL},
	 { (char *)"NumericTableIface_setNumberOfColumns", _wrap_NumericTableIface_setNumberOfColumns, METH_VARARGS, NULL},
	 { (char *)"NumericTableIface_setNumberOfRows", _wrap_NumericTableIface_setNumberOfRows, METH_VARARGS, NULL},
	 { (char *)"NumericTableIface_allocateDataMemory", _wrap_NumericTableIface_allocateDataMemory, METH_VARARGS, NULL},
	 { (char *)"NumericTableIface_freeDataMemory", _wrap_NumericTableIface_freeDataMemory, METH_VARARGS, NULL},
	 { (char *)"NumericTableIface_allocateBasicStatistics", _wrap_NumericTableIface_allocateBasicStatistics, METH_VARARGS, NULL},
	 { (char *)"NumericTableIface_check", _wrap_NumericTableIface_check, METH_VARARGS, NULL},
	 { (char *)"NumericTableIface_swigregister", NumericTableIface_swigregister, METH_VARARGS, NULL},
	 { (char *)"delete_DenseNumericTableIface", _wrap_delete_DenseNumericTableIface, METH_VARARGS, NULL},
	 { (char *)"DenseNumericTableIface_getBlockOfRows", _wrap_DenseNumericTableIface_getBlockOfRows, METH_VARARGS, NULL},
	 { (char *)"DenseNumericTableIface_releaseBlockOfRows", _wrap_DenseNumericTableIface_releaseBlockOfRows, METH_VARARGS, NULL},
	 { (char *)"DenseNumericTableIface_getBlockOfColumnValues", _wrap_DenseNumericTableIface_getBlockOfColumnValues, METH_VARARGS, NULL},
	 { (char *)"DenseNumericTableIface_releaseBlockOfColumnValues", _wrap_DenseNumericTableIface_releaseBlockOfColumnValues, METH_VARARGS, NULL},
	 { (char *)"DenseNumericTableIface_getBlockOfRowsAsDouble", _wrap_DenseNumericTableIface_getBlockOfRowsAsDouble, METH_VARARGS, NULL},
	 { (char *)"DenseNumericTableIface_getBlockOfColumnValuesAsDouble", _wrap_DenseNumericTableIface_getBlockOfColumnValuesAsDouble, METH_VARARGS, NULL},
	 { (char *)"DenseNumericTableIface_getBlockOfRowsAsFloat", _wrap_DenseNumericTableIface_getBlockOfRowsAsFloat, METH_VARARGS, NULL},
	 { (char *)"DenseNumericTableIface_getBlockOfColumnValuesAsFloat", _wrap_DenseNumericTableIface_getBlockOfColumnValuesAsFloat, METH_VARARGS, NULL},
	 { (char *)"DenseNumericTableIface_getBlockOfRowsAsInt", _wrap_DenseNumericTableIface_getBlockOfRowsAsInt, METH_VARARGS, NULL},
	 { (char *)"DenseNumericTableIface_getBlockOfColumnValuesAsInt", _wrap_DenseNumericTableIface_getBlockOfColumnValuesAsInt, METH_VARARGS, NULL},
	 { (char *)"DenseNumericTableIface_swigregister", DenseNumericTableIface_swigregister, METH_VARARGS, NULL},
	 { (char *)"delete_NumericTable", _wrap_delete_NumericTable, METH_VARARGS, NULL},
	 { (char *)"NumericTable_setDictionary", _wrap_NumericTable_setDictionary, METH_VARARGS, NULL},
	 { (char *)"NumericTable_getDictionary", _wrap_NumericTable_getDictionary, METH_VARARGS, NULL},
	 { (char *)"NumericTable_resetDictionary", _wrap_NumericTable_resetDictionary, METH_VARARGS, NULL},
	 { (char *)"NumericTable_resize", _wrap_NumericTable_resize, METH_VARARGS, NULL},
	 { (char *)"NumericTable_getNumberOfColumns", _wrap_NumericTable_getNumberOfColumns, METH_VARARGS, NULL},
	 { (char *)"NumericTable_getNumberOfRows", _wrap_NumericTable_getNumberOfRows, METH_VARARGS, NULL},
	 { (char *)"NumericTable_setNumberOfColumns", _wrap_NumericTable_setNumberOfColumns, METH_VARARGS, NULL},
	 { (char *)"NumericTable_setNumberOfRows", _wrap_NumericTable_setNumberOfRows, METH_VARARGS, NULL},
	 { (char *)"NumericTable_allocateDataMemory", _wrap_NumericTable_allocateDataMemory, METH_VARARGS, NULL},
	 { (char *)"NumericTable_freeDataMemory", _wrap_NumericTable_freeDataMemory, METH_VARARGS, NULL},
	 { (char *)"NumericTable_getDataLayout", _wrap_NumericTable_getDataLayout, METH_VARARGS, NULL},
	 { (char *)"NumericTable_getFeatureType", _wrap_NumericTable_getFeatureType, METH_VARARGS, NULL},
	 { (char *)"NumericTable_getNumberOfCategories", _wrap_NumericTable_getNumberOfCategories, METH_VARARGS, NULL},
	 { (char *)"NumericTable_getDataMemoryStatus", _wrap_NumericTable_getDataMemoryStatus, METH_VARARGS, NULL},
	 { (char *)"NumericTable_isNormalized", _wrap_NumericTable_isNormalized, METH_VARARGS, NULL},
	 { (char *)"NumericTable_setNormalizationFlag", _wrap_NumericTable_setNormalizationFlag, METH_VARARGS, NULL},
	 { (char *)"NumericTable_allocateBasicStatistics", _wrap_NumericTable_allocateBasicStatistics, METH_VARARGS, NULL},
	 { (char *)"NumericTable_check", _wrap_NumericTable_check, METH_VARARGS, NULL},
	 { (char *)"NumericTable_assign", _wrap_NumericTable_assign, METH_VARARGS, NULL},
	 { (char *)"NumericTable_basicStatistics_set", _wrap_NumericTable_basicStatistics_set, METH_VARARGS, NULL},
	 { (char *)"NumericTable_basicStatistics_get", _wrap_NumericTable_basicStatistics_get, METH_VARARGS, NULL},
	 { (char *)"NumericTable_getValue_Float64", _wrap_NumericTable_getValue_Float64, METH_VARARGS, (char *)"\n"
	"    This function is specialized for float64"},
	 { (char *)"NumericTable_getValue_Float32", _wrap_NumericTable_getValue_Float32, METH_VARARGS, (char *)"\n"
	"    This function is specialized for float32"},
	 { (char *)"NumericTable_getValue_Intc", _wrap_NumericTable_getValue_Intc, METH_VARARGS, (char *)"\n"
	"    This function is specialized for intc"},
	 { (char *)"NumericTable_swigregister", NumericTable_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_BasicStatisticsDataCollection", _wrap_new_BasicStatisticsDataCollection, METH_VARARGS, NULL},
	 { (char *)"BasicStatisticsDataCollection_get", _wrap_BasicStatisticsDataCollection_get, METH_VARARGS, NULL},
	 { (char *)"BasicStatisticsDataCollection_set", _wrap_BasicStatisticsDataCollection_set, METH_VARARGS, NULL},
	 { (char *)"delete_BasicStatisticsDataCollection", _wrap_delete_BasicStatisticsDataCollection, METH_VARARGS, NULL},
	 { (char *)"BasicStatisticsDataCollection_swigregister", BasicStatisticsDataCollection_swigregister, METH_VARARGS, NULL},
	 { (char *)"checkNumericTable", _wrap_checkNumericTable, METH_VARARGS, NULL},
	 { (char *)"delete_TensorIface", _wrap_delete_TensorIface, METH_VARARGS, NULL},
	 { (char *)"TensorIface_setDimensions", _wrap_TensorIface_setDimensions, METH_VARARGS, NULL},
	 { (char *)"TensorIface_allocateDataMemory", _wrap_TensorIface_allocateDataMemory, METH_VARARGS, NULL},
	 { (char *)"TensorIface_freeDataMemory", _wrap_TensorIface_freeDataMemory, METH_VARARGS, NULL},
	 { (char *)"TensorIface_resize", _wrap_TensorIface_resize, METH_VARARGS, NULL},
	 { (char *)"TensorIface_check", _wrap_TensorIface_check, METH_VARARGS, NULL},
	 { (char *)"TensorIface_getSampleTensor", _wrap_TensorIface_getSampleTensor, METH_VARARGS, NULL},
	 { (char *)"TensorIface_swigregister", TensorIface_swigregister, METH_VARARGS, NULL},
	 { (char *)"delete_TensorLayoutIface", _wrap_delete_TensorLayoutIface, METH_VARARGS, NULL},
	 { (char *)"TensorLayoutIface_shuffleDimensions", _wrap_TensorLayoutIface_shuffleDimensions, METH_VARARGS, NULL},
	 { (char *)"TensorLayoutIface_swigregister", TensorLayoutIface_swigregister, METH_VARARGS, NULL},
	 { (char *)"delete_TensorLayout", _wrap_delete_TensorLayout, METH_VARARGS, NULL},
	 { (char *)"TensorLayout_getDimensions", _wrap_TensorLayout_getDimensions, METH_VARARGS, NULL},
	 { (char *)"TensorLayout_swigregister", TensorLayout_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_TensorOffsetLayout", _wrap_new_TensorOffsetLayout, METH_VARARGS, NULL},
	 { (char *)"delete_TensorOffsetLayout", _wrap_delete_TensorOffsetLayout, METH_VARARGS, NULL},
	 { (char *)"TensorOffsetLayout_getOffsets", _wrap_TensorOffsetLayout_getOffsets, METH_VARARGS, NULL},
	 { (char *)"TensorOffsetLayout_getIndices", _wrap_TensorOffsetLayout_getIndices, METH_VARARGS, NULL},
	 { (char *)"TensorOffsetLayout_isLayout", _wrap_TensorOffsetLayout_isLayout, METH_VARARGS, NULL},
	 { (char *)"TensorOffsetLayout_isDefaultLayout", _wrap_TensorOffsetLayout_isDefaultLayout, METH_VARARGS, NULL},
	 { (char *)"TensorOffsetLayout_isRawLayout", _wrap_TensorOffsetLayout_isRawLayout, METH_VARARGS, NULL},
	 { (char *)"TensorOffsetLayout_shuffleDimensions", _wrap_TensorOffsetLayout_shuffleDimensions, METH_VARARGS, NULL},
	 { (char *)"TensorOffsetLayout_sortOffsets", _wrap_TensorOffsetLayout_sortOffsets, METH_VARARGS, NULL},
	 { (char *)"TensorOffsetLayout_getSerializationTag", _wrap_TensorOffsetLayout_getSerializationTag, METH_VARARGS, NULL},
	 { (char *)"TensorOffsetLayout_swigregister", TensorOffsetLayout_swigregister, METH_VARARGS, NULL},
	 { (char *)"delete_DenseTensorIface", _wrap_delete_DenseTensorIface, METH_VARARGS, NULL},
	 { (char *)"DenseTensorIface_getSubtensorEx", _wrap_DenseTensorIface_getSubtensorEx, METH_VARARGS, NULL},
	 { (char *)"DenseTensorIface_releaseSubtensor", _wrap_DenseTensorIface_releaseSubtensor, METH_VARARGS, NULL},
	 { (char *)"DenseTensorIface_getSubtensor", _wrap_DenseTensorIface_getSubtensor, METH_VARARGS, NULL},
	 { (char *)"DenseTensorIface_createDefaultSubtensorLayout", _wrap_DenseTensorIface_createDefaultSubtensorLayout, METH_VARARGS, NULL},
	 { (char *)"DenseTensorIface_createRawSubtensorLayout", _wrap_DenseTensorIface_createRawSubtensorLayout, METH_VARARGS, NULL},
	 { (char *)"DenseTensorIface_swigregister", DenseTensorIface_swigregister, METH_VARARGS, NULL},
	 { (char *)"delete_Tensor", _wrap_delete_Tensor, METH_VARARGS, NULL},
	 { (char *)"Tensor_getDataMemoryStatus", _wrap_Tensor_getDataMemoryStatus, METH_VARARGS, NULL},
	 { (char *)"Tensor_getNumberOfDimensions", _wrap_Tensor_getNumberOfDimensions, METH_VARARGS, NULL},
	 { (char *)"Tensor_getDimensionSize", _wrap_Tensor_getDimensionSize, METH_VARARGS, NULL},
	 { (char *)"Tensor_getDimensions", _wrap_Tensor_getDimensions, METH_VARARGS, NULL},
	 { (char *)"Tensor_getSize", _wrap_Tensor_getSize, METH_VARARGS, NULL},
	 { (char *)"Tensor_check", _wrap_Tensor_check, METH_VARARGS, NULL},
	 { (char *)"Tensor_getLayoutPtr", _wrap_Tensor_getLayoutPtr, METH_VARARGS, NULL},
	 { (char *)"Tensor_allocateDataMemory", _wrap_Tensor_allocateDataMemory, METH_VARARGS, NULL},
	 { (char *)"Tensor_freeDataMemory", _wrap_Tensor_freeDataMemory, METH_VARARGS, NULL},
	 { (char *)"Tensor_resize", _wrap_Tensor_resize, METH_VARARGS, NULL},
	 { (char *)"Tensor_swigregister", Tensor_swigregister, METH_VARARGS, NULL},
	 { (char *)"checkTensor", _wrap_checkTensor, METH_VARARGS, NULL},
	 { (char *)"new_AOSNumericTable", _wrap_new_AOSNumericTable, METH_VARARGS, NULL},
	 { (char *)"delete_AOSNumericTable", _wrap_delete_AOSNumericTable, METH_VARARGS, NULL},
	 { (char *)"AOSNumericTable_getSerializationTag", _wrap_AOSNumericTable_getSerializationTag, METH_VARARGS, NULL},
	 { (char *)"AOSNumericTable_getBlockOfRows", _wrap_AOSNumericTable_getBlockOfRows, METH_VARARGS, NULL},
	 { (char *)"AOSNumericTable_releaseBlockOfRows", _wrap_AOSNumericTable_releaseBlockOfRows, METH_VARARGS, NULL},
	 { (char *)"AOSNumericTable_getBlockOfColumnValues", _wrap_AOSNumericTable_getBlockOfColumnValues, METH_VARARGS, NULL},
	 { (char *)"AOSNumericTable_releaseBlockOfColumnValues", _wrap_AOSNumericTable_releaseBlockOfColumnValues, METH_VARARGS, NULL},
	 { (char *)"AOSNumericTable_allocateDataMemory", _wrap_AOSNumericTable_allocateDataMemory, METH_VARARGS, NULL},
	 { (char *)"AOSNumericTable_freeDataMemory", _wrap_AOSNumericTable_freeDataMemory, METH_VARARGS, NULL},
	 { (char *)"AOSNumericTable_swigregister", AOSNumericTable_swigregister, METH_VARARGS, NULL},
	 { (char *)"SOANumericTable_serializationTag", _wrap_SOANumericTable_serializationTag, METH_VARARGS, NULL},
	 { (char *)"SOANumericTable_getSerializationTag", _wrap_SOANumericTable_getSerializationTag, METH_VARARGS, NULL},
	 { (char *)"new_SOANumericTable", _wrap_new_SOANumericTable, METH_VARARGS, NULL},
	 { (char *)"delete_SOANumericTable", _wrap_delete_SOANumericTable, METH_VARARGS, NULL},
	 { (char *)"SOANumericTable_getBlockOfRows", _wrap_SOANumericTable_getBlockOfRows, METH_VARARGS, NULL},
	 { (char *)"SOANumericTable_releaseBlockOfRows", _wrap_SOANumericTable_releaseBlockOfRows, METH_VARARGS, NULL},
	 { (char *)"SOANumericTable_getBlockOfColumnValues", _wrap_SOANumericTable_getBlockOfColumnValues, METH_VARARGS, NULL},
	 { (char *)"SOANumericTable_releaseBlockOfColumnValues", _wrap_SOANumericTable_releaseBlockOfColumnValues, METH_VARARGS, NULL},
	 { (char *)"SOANumericTable_setDictionary", _wrap_SOANumericTable_setDictionary, METH_VARARGS, NULL},
	 { (char *)"SOANumericTable_setArray", _wrap_SOANumericTable_setArray, METH_VARARGS, NULL},
	 { (char *)"SOANumericTable_getArray", _wrap_SOANumericTable_getArray, METH_VARARGS, NULL},
	 { (char *)"SOANumericTable_swigregister", SOANumericTable_swigregister, METH_VARARGS, NULL},
	 { (char *)"delete_CSRNumericTableIface", _wrap_delete_CSRNumericTableIface, METH_VARARGS, NULL},
	 { (char *)"CSRNumericTableIface_getDataSize", _wrap_CSRNumericTableIface_getDataSize, METH_VARARGS, NULL},
	 { (char *)"CSRNumericTableIface_getSparseBlock", _wrap_CSRNumericTableIface_getSparseBlock, METH_VARARGS, NULL},
	 { (char *)"CSRNumericTableIface_releaseSparseBlock", _wrap_CSRNumericTableIface_releaseSparseBlock, METH_VARARGS, NULL},
	 { (char *)"CSRNumericTableIface_swigregister", CSRNumericTableIface_swigregister, METH_VARARGS, NULL},
	 { (char *)"CSRNumericTable_serializationTag", _wrap_CSRNumericTable_serializationTag, METH_VARARGS, NULL},
	 { (char *)"CSRNumericTable_getSerializationTag", _wrap_CSRNumericTable_getSerializationTag, METH_VARARGS, NULL},
	 { (char *)"delete_CSRNumericTable", _wrap_delete_CSRNumericTable, METH_VARARGS, NULL},
	 { (char *)"CSRNumericTable_resize", _wrap_CSRNumericTable_resize, METH_VARARGS, NULL},
	 { (char *)"CSRNumericTable_getBlockOfRows", _wrap_CSRNumericTable_getBlockOfRows, METH_VARARGS, NULL},
	 { (char *)"CSRNumericTable_releaseBlockOfRows", _wrap_CSRNumericTable_releaseBlockOfRows, METH_VARARGS, NULL},
	 { (char *)"CSRNumericTable_getBlockOfColumnValues", _wrap_CSRNumericTable_getBlockOfColumnValues, METH_VARARGS, NULL},
	 { (char *)"CSRNumericTable_releaseBlockOfColumnValues", _wrap_CSRNumericTable_releaseBlockOfColumnValues, METH_VARARGS, NULL},
	 { (char *)"CSRNumericTable_getSparseBlock", _wrap_CSRNumericTable_getSparseBlock, METH_VARARGS, NULL},
	 { (char *)"CSRNumericTable_releaseSparseBlock", _wrap_CSRNumericTable_releaseSparseBlock, METH_VARARGS, NULL},
	 { (char *)"CSRNumericTable_allocateDataMemory", _wrap_CSRNumericTable_allocateDataMemory, METH_VARARGS, NULL},
	 { (char *)"CSRNumericTable_getCSRIndexing", _wrap_CSRNumericTable_getCSRIndexing, METH_VARARGS, NULL},
	 { (char *)"CSRNumericTable_check", _wrap_CSRNumericTable_check, METH_VARARGS, NULL},
	 { (char *)"CSRNumericTable_getDataSize", _wrap_CSRNumericTable_getDataSize, METH_VARARGS, NULL},
	 { (char *)"new_CSRNumericTable", _wrap_new_CSRNumericTable, METH_VARARGS, NULL},
	 { (char *)"CSRNumericTable_setArrays", _wrap_CSRNumericTable_setArrays, METH_VARARGS, NULL},
	 { (char *)"CSRNumericTable_getArrays", _wrap_CSRNumericTable_getArrays, METH_VARARGS, NULL},
	 { (char *)"CSRNumericTable_swigregister", CSRNumericTable_swigregister, METH_VARARGS, NULL},
	 { (char *)"MergedNumericTable_serializationTag", _wrap_MergedNumericTable_serializationTag, METH_VARARGS, NULL},
	 { (char *)"MergedNumericTable_getSerializationTag", _wrap_MergedNumericTable_getSerializationTag, METH_VARARGS, NULL},
	 { (char *)"new_MergedNumericTable", _wrap_new_MergedNumericTable, METH_VARARGS, NULL},
	 { (char *)"MergedNumericTable_addNumericTable", _wrap_MergedNumericTable_addNumericTable, METH_VARARGS, NULL},
	 { (char *)"MergedNumericTable_resize", _wrap_MergedNumericTable_resize, METH_VARARGS, NULL},
	 { (char *)"MergedNumericTable_getDataMemoryStatus", _wrap_MergedNumericTable_getDataMemoryStatus, METH_VARARGS, NULL},
	 { (char *)"MergedNumericTable_getBlockOfRows", _wrap_MergedNumericTable_getBlockOfRows, METH_VARARGS, NULL},
	 { (char *)"MergedNumericTable_releaseBlockOfRows", _wrap_MergedNumericTable_releaseBlockOfRows, METH_VARARGS, NULL},
	 { (char *)"MergedNumericTable_getBlockOfColumnValues", _wrap_MergedNumericTable_getBlockOfColumnValues, METH_VARARGS, NULL},
	 { (char *)"MergedNumericTable_releaseBlockOfColumnValues", _wrap_MergedNumericTable_releaseBlockOfColumnValues, METH_VARARGS, NULL},
	 { (char *)"MergedNumericTable_allocateBasicStatistics", _wrap_MergedNumericTable_allocateBasicStatistics, METH_VARARGS, NULL},
	 { (char *)"delete_MergedNumericTable", _wrap_delete_MergedNumericTable, METH_VARARGS, NULL},
	 { (char *)"MergedNumericTable_swigregister", MergedNumericTable_swigregister, METH_VARARGS, NULL},
	 { (char *)"RowMergedNumericTable_serializationTag", _wrap_RowMergedNumericTable_serializationTag, METH_VARARGS, NULL},
	 { (char *)"RowMergedNumericTable_getSerializationTag", _wrap_RowMergedNumericTable_getSerializationTag, METH_VARARGS, NULL},
	 { (char *)"new_RowMergedNumericTable", _wrap_new_RowMergedNumericTable, METH_VARARGS, NULL},
	 { (char *)"RowMergedNumericTable_addNumericTable", _wrap_RowMergedNumericTable_addNumericTable, METH_VARARGS, NULL},
	 { (char *)"RowMergedNumericTable_resize", _wrap_RowMergedNumericTable_resize, METH_VARARGS, NULL},
	 { (char *)"RowMergedNumericTable_getDataMemoryStatus", _wrap_RowMergedNumericTable_getDataMemoryStatus, METH_VARARGS, NULL},
	 { (char *)"RowMergedNumericTable_getBlockOfRows", _wrap_RowMergedNumericTable_getBlockOfRows, METH_VARARGS, NULL},
	 { (char *)"RowMergedNumericTable_releaseBlockOfRows", _wrap_RowMergedNumericTable_releaseBlockOfRows, METH_VARARGS, NULL},
	 { (char *)"RowMergedNumericTable_getBlockOfColumnValues", _wrap_RowMergedNumericTable_getBlockOfColumnValues, METH_VARARGS, NULL},
	 { (char *)"RowMergedNumericTable_releaseBlockOfColumnValues", _wrap_RowMergedNumericTable_releaseBlockOfColumnValues, METH_VARARGS, NULL},
	 { (char *)"delete_RowMergedNumericTable", _wrap_delete_RowMergedNumericTable, METH_VARARGS, NULL},
	 { (char *)"RowMergedNumericTable_swigregister", RowMergedNumericTable_swigregister, METH_VARARGS, NULL},
	 { (char *)"delete_PackedArrayNumericTableIface", _wrap_delete_PackedArrayNumericTableIface, METH_VARARGS, NULL},
	 { (char *)"PackedArrayNumericTableIface_getPackedArray", _wrap_PackedArrayNumericTableIface_getPackedArray, METH_VARARGS, NULL},
	 { (char *)"PackedArrayNumericTableIface_releasePackedArray", _wrap_PackedArrayNumericTableIface_releasePackedArray, METH_VARARGS, NULL},
	 { (char *)"PackedArrayNumericTableIface_swigregister", PackedArrayNumericTableIface_swigregister, METH_VARARGS, NULL},
	 { (char *)"DataSourceIface_getDictionary", _wrap_DataSourceIface_getDictionary, METH_VARARGS, NULL},
	 { (char *)"DataSourceIface_setDictionary", _wrap_DataSourceIface_setDictionary, METH_VARARGS, NULL},
	 { (char *)"DataSourceIface_createDictionaryFromContext", _wrap_DataSourceIface_createDictionaryFromContext, METH_VARARGS, NULL},
	 { (char *)"DataSourceIface_getStatus", _wrap_DataSourceIface_getStatus, METH_VARARGS, NULL},
	 { (char *)"DataSourceIface_getNumberOfColumns", _wrap_DataSourceIface_getNumberOfColumns, METH_VARARGS, NULL},
	 { (char *)"DataSourceIface_getNumericTableNumberOfColumns", _wrap_DataSourceIface_getNumericTableNumberOfColumns, METH_VARARGS, NULL},
	 { (char *)"DataSourceIface_getNumberOfAvailableRows", _wrap_DataSourceIface_getNumberOfAvailableRows, METH_VARARGS, NULL},
	 { (char *)"DataSourceIface_allocateNumericTable", _wrap_DataSourceIface_allocateNumericTable, METH_VARARGS, NULL},
	 { (char *)"DataSourceIface_getNumericTable", _wrap_DataSourceIface_getNumericTable, METH_VARARGS, NULL},
	 { (char *)"DataSourceIface_freeNumericTable", _wrap_DataSourceIface_freeNumericTable, METH_VARARGS, NULL},
	 { (char *)"DataSourceIface_loadDataBlock", _wrap_DataSourceIface_loadDataBlock, METH_VARARGS, NULL},
	 { (char *)"delete_DataSourceIface", _wrap_delete_DataSourceIface, METH_VARARGS, NULL},
	 { (char *)"DataSourceIface_swigregister", DataSourceIface_swigregister, METH_VARARGS, NULL},
	 { (char *)"delete_DataSource", _wrap_delete_DataSource, METH_VARARGS, NULL},
	 { (char *)"DataSource_getDictionary", _wrap_DataSource_getDictionary, METH_VARARGS, NULL},
	 { (char *)"DataSource_setDictionary", _wrap_DataSource_setDictionary, METH_VARARGS, NULL},
	 { (char *)"DataSource_createDictionaryFromContext", _wrap_DataSource_createDictionaryFromContext, METH_VARARGS, NULL},
	 { (char *)"DataSource_loadDataBlock", _wrap_DataSource_loadDataBlock, METH_VARARGS, NULL},
	 { (char *)"DataSource_getNumericTable", _wrap_DataSource_getNumericTable, METH_VARARGS, NULL},
	 { (char *)"DataSource_getNumberOfColumns", _wrap_DataSource_getNumberOfColumns, METH_VARARGS, NULL},
	 { (char *)"DataSource_status", _wrap_DataSource_status, METH_VARARGS, NULL},
	 { (char *)"DataSource_getNumericTableNumberOfColumns", _wrap_DataSource_getNumericTableNumberOfColumns, METH_VARARGS, NULL},
	 { (char *)"DataSource_swigregister", DataSource_swigregister, METH_VARARGS, NULL},
	 { (char *)"CsvDataSourceOptions_unite", _wrap_CsvDataSourceOptions_unite, METH_VARARGS, NULL},
	 { (char *)"new_CsvDataSourceOptions", _wrap_new_CsvDataSourceOptions, METH_VARARGS, NULL},
	 { (char *)"CsvDataSourceOptions_getNumericTableAllocationFlag", _wrap_CsvDataSourceOptions_getNumericTableAllocationFlag, METH_VARARGS, NULL},
	 { (char *)"CsvDataSourceOptions_getDictionaryCreationFlag", _wrap_CsvDataSourceOptions_getDictionaryCreationFlag, METH_VARARGS, NULL},
	 { (char *)"CsvDataSourceOptions_getParseHeaderFlag", _wrap_CsvDataSourceOptions_getParseHeaderFlag, METH_VARARGS, NULL},
	 { (char *)"delete_CsvDataSourceOptions", _wrap_delete_CsvDataSourceOptions, METH_VARARGS, NULL},
	 { (char *)"CsvDataSourceOptions_swigregister", CsvDataSourceOptions_swigregister, METH_VARARGS, NULL},
	 { (char *)"__or__", _wrap___or__, METH_VARARGS, NULL},
	 { (char *)"new_FeatureAuxData", _wrap_new_FeatureAuxData, METH_VARARGS, NULL},
	 { (char *)"FeatureAuxData_idx_set", _wrap_FeatureAuxData_idx_set, METH_VARARGS, NULL},
	 { (char *)"FeatureAuxData_idx_get", _wrap_FeatureAuxData_idx_get, METH_VARARGS, NULL},
	 { (char *)"FeatureAuxData_wide_set", _wrap_FeatureAuxData_wide_set, METH_VARARGS, NULL},
	 { (char *)"FeatureAuxData_wide_get", _wrap_FeatureAuxData_wide_get, METH_VARARGS, NULL},
	 { (char *)"FeatureAuxData_nCats_set", _wrap_FeatureAuxData_nCats_set, METH_VARARGS, NULL},
	 { (char *)"FeatureAuxData_nCats_get", _wrap_FeatureAuxData_nCats_get, METH_VARARGS, NULL},
	 { (char *)"FeatureAuxData_dsFeat_set", _wrap_FeatureAuxData_dsFeat_set, METH_VARARGS, NULL},
	 { (char *)"FeatureAuxData_dsFeat_get", _wrap_FeatureAuxData_dsFeat_get, METH_VARARGS, NULL},
	 { (char *)"FeatureAuxData_ntFeat_set", _wrap_FeatureAuxData_ntFeat_set, METH_VARARGS, NULL},
	 { (char *)"FeatureAuxData_ntFeat_get", _wrap_FeatureAuxData_ntFeat_get, METH_VARARGS, NULL},
	 { (char *)"FeatureAuxData_buffer_set", _wrap_FeatureAuxData_buffer_set, METH_VARARGS, NULL},
	 { (char *)"FeatureAuxData_buffer_get", _wrap_FeatureAuxData_buffer_get, METH_VARARGS, NULL},
	 { (char *)"delete_FeatureAuxData", _wrap_delete_FeatureAuxData, METH_VARARGS, NULL},
	 { (char *)"FeatureAuxData_swigregister", FeatureAuxData_swigregister, METH_VARARGS, NULL},
	 { (char *)"ModifierIface_apply", _wrap_ModifierIface_apply, METH_VARARGS, NULL},
	 { (char *)"delete_ModifierIface", _wrap_delete_ModifierIface, METH_VARARGS, NULL},
	 { (char *)"ModifierIface_contFunc", _wrap_ModifierIface_contFunc, METH_VARARGS, NULL},
	 { (char *)"ModifierIface_catFunc", _wrap_ModifierIface_catFunc, METH_VARARGS, NULL},
	 { (char *)"ModifierIface_nullFunc", _wrap_ModifierIface_nullFunc, METH_VARARGS, NULL},
	 { (char *)"ModifierIface_swigregister", ModifierIface_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_MakeCategorical", _wrap_new_MakeCategorical, METH_VARARGS, NULL},
	 { (char *)"delete_MakeCategorical", _wrap_delete_MakeCategorical, METH_VARARGS, NULL},
	 { (char *)"MakeCategorical_apply", _wrap_MakeCategorical_apply, METH_VARARGS, NULL},
	 { (char *)"MakeCategorical_swigregister", MakeCategorical_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_OneHotEncoder", _wrap_new_OneHotEncoder, METH_VARARGS, NULL},
	 { (char *)"delete_OneHotEncoder", _wrap_delete_OneHotEncoder, METH_VARARGS, NULL},
	 { (char *)"OneHotEncoder_apply", _wrap_OneHotEncoder_apply, METH_VARARGS, NULL},
	 { (char *)"OneHotEncoder_swigregister", OneHotEncoder_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_ColumnFilter", _wrap_new_ColumnFilter, METH_VARARGS, NULL},
	 { (char *)"delete_ColumnFilter", _wrap_delete_ColumnFilter, METH_VARARGS, NULL},
	 { (char *)"ColumnFilter_odd", _wrap_ColumnFilter_odd, METH_VARARGS, NULL},
	 { (char *)"ColumnFilter_even", _wrap_ColumnFilter_even, METH_VARARGS, NULL},
	 { (char *)"ColumnFilter_none", _wrap_ColumnFilter_none, METH_VARARGS, NULL},
	 { (char *)"ColumnFilter_list", _wrap_ColumnFilter_list, METH_VARARGS, NULL},
	 { (char *)"ColumnFilter_apply", _wrap_ColumnFilter_apply, METH_VARARGS, NULL},
	 { (char *)"ColumnFilter_swigregister", ColumnFilter_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_CSVFeatureManager", _wrap_new_CSVFeatureManager, METH_VARARGS, NULL},
	 { (char *)"delete_CSVFeatureManager", _wrap_delete_CSVFeatureManager, METH_VARARGS, NULL},
	 { (char *)"CSVFeatureManager_setDelimiter", _wrap_CSVFeatureManager_setDelimiter, METH_VARARGS, NULL},
	 { (char *)"CSVFeatureManager_getNumericTableNumberOfColumns", _wrap_CSVFeatureManager_getNumericTableNumberOfColumns, METH_VARARGS, NULL},
	 { (char *)"CSVFeatureManager_setFeatureDetailsFromDictionary", _wrap_CSVFeatureManager_setFeatureDetailsFromDictionary, METH_VARARGS, NULL},
	 { (char *)"CSVFeatureManager_addModifier", _wrap_CSVFeatureManager_addModifier, METH_VARARGS, NULL},
	 { (char *)"CSVFeatureManager_parseRowAsHeader", _wrap_CSVFeatureManager_parseRowAsHeader, METH_VARARGS, NULL},
	 { (char *)"CSVFeatureManager_parseRowAsDictionary", _wrap_CSVFeatureManager_parseRowAsDictionary, METH_VARARGS, NULL},
	 { (char *)"CSVFeatureManager_parseRowIn", _wrap_CSVFeatureManager_parseRowIn, METH_VARARGS, NULL},
	 { (char *)"CSVFeatureManager_finalize", _wrap_CSVFeatureManager_finalize, METH_VARARGS, NULL},
	 { (char *)"CSVFeatureManager_swigregister", CSVFeatureManager_swigregister, METH_VARARGS, NULL},
	 { (char *)"convertToHomogen_Float64", _wrap_convertToHomogen_Float64, METH_VARARGS, NULL},
	 { (char *)"convertToHomogen_Float32", _wrap_convertToHomogen_Float32, METH_VARARGS, NULL},
	 { (char *)"convertToHomogen_Intc", _wrap_convertToHomogen_Intc, METH_VARARGS, NULL},
	 { (char *)"NumericTableDictionary_serializationTag", _wrap_NumericTableDictionary_serializationTag, METH_VARARGS, NULL},
	 { (char *)"NumericTableDictionary_getSerializationTag", _wrap_NumericTableDictionary_getSerializationTag, METH_VARARGS, NULL},
	 { (char *)"new_NumericTableDictionary", _wrap_new_NumericTableDictionary, METH_VARARGS, NULL},
	 { (char *)"NumericTableDictionary_create", _wrap_NumericTableDictionary_create, METH_VARARGS, NULL},
	 { (char *)"delete_NumericTableDictionary", _wrap_delete_NumericTableDictionary, METH_VARARGS, NULL},
	 { (char *)"NumericTableDictionary_resetDictionary", _wrap_NumericTableDictionary_resetDictionary, METH_VARARGS, NULL},
	 { (char *)"NumericTableDictionary_setAllFeatures", _wrap_NumericTableDictionary_setAllFeatures, METH_VARARGS, NULL},
	 { (char *)"NumericTableDictionary_setNumberOfFeatures", _wrap_NumericTableDictionary_setNumberOfFeatures, METH_VARARGS, NULL},
	 { (char *)"NumericTableDictionary_getNumberOfFeatures", _wrap_NumericTableDictionary_getNumberOfFeatures, METH_VARARGS, NULL},
	 { (char *)"NumericTableDictionary_getFeaturesEqual", _wrap_NumericTableDictionary_getFeaturesEqual, METH_VARARGS, NULL},
	 { (char *)"NumericTableDictionary_setFeature", _wrap_NumericTableDictionary_setFeature, METH_VARARGS, NULL},
	 { (char *)"NumericTableDictionary_checkDictionary", _wrap_NumericTableDictionary_checkDictionary, METH_VARARGS, NULL},
	 { (char *)"NumericTableDictionary___getitem__", _wrap_NumericTableDictionary___getitem__, METH_VARARGS, NULL},
	 { (char *)"NumericTableDictionary___setitem__", _wrap_NumericTableDictionary___setitem__, METH_VARARGS, NULL},
	 { (char *)"NumericTableDictionary_swigregister", NumericTableDictionary_swigregister, METH_VARARGS, NULL},
	 { (char *)"DataSourceDictionary_serializationTag", _wrap_DataSourceDictionary_serializationTag, METH_VARARGS, NULL},
	 { (char *)"DataSourceDictionary_getSerializationTag", _wrap_DataSourceDictionary_getSerializationTag, METH_VARARGS, NULL},
	 { (char *)"new_DataSourceDictionary", _wrap_new_DataSourceDictionary, METH_VARARGS, NULL},
	 { (char *)"DataSourceDictionary_create", _wrap_DataSourceDictionary_create, METH_VARARGS, NULL},
	 { (char *)"delete_DataSourceDictionary", _wrap_delete_DataSourceDictionary, METH_VARARGS, NULL},
	 { (char *)"DataSourceDictionary_resetDictionary", _wrap_DataSourceDictionary_resetDictionary, METH_VARARGS, NULL},
	 { (char *)"DataSourceDictionary_setAllFeatures", _wrap_DataSourceDictionary_setAllFeatures, METH_VARARGS, NULL},
	 { (char *)"DataSourceDictionary_setNumberOfFeatures", _wrap_DataSourceDictionary_setNumberOfFeatures, METH_VARARGS, NULL},
	 { (char *)"DataSourceDictionary_getNumberOfFeatures", _wrap_DataSourceDictionary_getNumberOfFeatures, METH_VARARGS, NULL},
	 { (char *)"DataSourceDictionary_getFeaturesEqual", _wrap_DataSourceDictionary_getFeaturesEqual, METH_VARARGS, NULL},
	 { (char *)"DataSourceDictionary_setFeature", _wrap_DataSourceDictionary_setFeature, METH_VARARGS, NULL},
	 { (char *)"DataSourceDictionary_checkDictionary", _wrap_DataSourceDictionary_checkDictionary, METH_VARARGS, NULL},
	 { (char *)"DataSourceDictionary___getitem__", _wrap_DataSourceDictionary___getitem__, METH_VARARGS, NULL},
	 { (char *)"DataSourceDictionary___setitem__", _wrap_DataSourceDictionary___setitem__, METH_VARARGS, NULL},
	 { (char *)"DataSourceDictionary_swigregister", DataSourceDictionary_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_BlockDescriptor_Float64", _wrap_new_BlockDescriptor_Float64, METH_VARARGS, NULL},
	 { (char *)"delete_BlockDescriptor_Float64", _wrap_delete_BlockDescriptor_Float64, METH_VARARGS, NULL},
	 { (char *)"BlockDescriptor_Float64_getBlockSharedPtr", _wrap_BlockDescriptor_Float64_getBlockSharedPtr, METH_VARARGS, NULL},
	 { (char *)"BlockDescriptor_Float64_getNumberOfColumns", _wrap_BlockDescriptor_Float64_getNumberOfColumns, METH_VARARGS, NULL},
	 { (char *)"BlockDescriptor_Float64_getNumberOfRows", _wrap_BlockDescriptor_Float64_getNumberOfRows, METH_VARARGS, NULL},
	 { (char *)"BlockDescriptor_Float64_reset", _wrap_BlockDescriptor_Float64_reset, METH_VARARGS, NULL},
	 { (char *)"BlockDescriptor_Float64_resizeBuffer", _wrap_BlockDescriptor_Float64_resizeBuffer, METH_VARARGS, NULL},
	 { (char *)"BlockDescriptor_Float64_setDetails", _wrap_BlockDescriptor_Float64_setDetails, METH_VARARGS, NULL},
	 { (char *)"BlockDescriptor_Float64_getColumnsOffset", _wrap_BlockDescriptor_Float64_getColumnsOffset, METH_VARARGS, NULL},
	 { (char *)"BlockDescriptor_Float64_getRowsOffset", _wrap_BlockDescriptor_Float64_getRowsOffset, METH_VARARGS, NULL},
	 { (char *)"BlockDescriptor_Float64_getRWFlag", _wrap_BlockDescriptor_Float64_getRWFlag, METH_VARARGS, NULL},
	 { (char *)"BlockDescriptor_Float64_getAdditionalBufferPtr", _wrap_BlockDescriptor_Float64_getAdditionalBufferPtr, METH_VARARGS, NULL},
	 { (char *)"BlockDescriptor_Float64_getAdditionalBufferSharedPtr", _wrap_BlockDescriptor_Float64_getAdditionalBufferSharedPtr, METH_VARARGS, NULL},
	 { (char *)"BlockDescriptor_Float64_getArray", _wrap_BlockDescriptor_Float64_getArray, METH_VARARGS, NULL},
	 { (char *)"BlockDescriptor_Float64_swigregister", BlockDescriptor_Float64_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_BlockDescriptor_Float32", _wrap_new_BlockDescriptor_Float32, METH_VARARGS, NULL},
	 { (char *)"delete_BlockDescriptor_Float32", _wrap_delete_BlockDescriptor_Float32, METH_VARARGS, NULL},
	 { (char *)"BlockDescriptor_Float32_getBlockSharedPtr", _wrap_BlockDescriptor_Float32_getBlockSharedPtr, METH_VARARGS, NULL},
	 { (char *)"BlockDescriptor_Float32_getNumberOfColumns", _wrap_BlockDescriptor_Float32_getNumberOfColumns, METH_VARARGS, NULL},
	 { (char *)"BlockDescriptor_Float32_getNumberOfRows", _wrap_BlockDescriptor_Float32_getNumberOfRows, METH_VARARGS, NULL},
	 { (char *)"BlockDescriptor_Float32_reset", _wrap_BlockDescriptor_Float32_reset, METH_VARARGS, NULL},
	 { (char *)"BlockDescriptor_Float32_resizeBuffer", _wrap_BlockDescriptor_Float32_resizeBuffer, METH_VARARGS, NULL},
	 { (char *)"BlockDescriptor_Float32_setDetails", _wrap_BlockDescriptor_Float32_setDetails, METH_VARARGS, NULL},
	 { (char *)"BlockDescriptor_Float32_getColumnsOffset", _wrap_BlockDescriptor_Float32_getColumnsOffset, METH_VARARGS, NULL},
	 { (char *)"BlockDescriptor_Float32_getRowsOffset", _wrap_BlockDescriptor_Float32_getRowsOffset, METH_VARARGS, NULL},
	 { (char *)"BlockDescriptor_Float32_getRWFlag", _wrap_BlockDescriptor_Float32_getRWFlag, METH_VARARGS, NULL},
	 { (char *)"BlockDescriptor_Float32_getAdditionalBufferPtr", _wrap_BlockDescriptor_Float32_getAdditionalBufferPtr, METH_VARARGS, NULL},
	 { (char *)"BlockDescriptor_Float32_getAdditionalBufferSharedPtr", _wrap_BlockDescriptor_Float32_getAdditionalBufferSharedPtr, METH_VARARGS, NULL},
	 { (char *)"BlockDescriptor_Float32_getArray", _wrap_BlockDescriptor_Float32_getArray, METH_VARARGS, NULL},
	 { (char *)"BlockDescriptor_Float32_swigregister", BlockDescriptor_Float32_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_BlockDescriptor_Intc", _wrap_new_BlockDescriptor_Intc, METH_VARARGS, NULL},
	 { (char *)"delete_BlockDescriptor_Intc", _wrap_delete_BlockDescriptor_Intc, METH_VARARGS, NULL},
	 { (char *)"BlockDescriptor_Intc_getBlockSharedPtr", _wrap_BlockDescriptor_Intc_getBlockSharedPtr, METH_VARARGS, NULL},
	 { (char *)"BlockDescriptor_Intc_getNumberOfColumns", _wrap_BlockDescriptor_Intc_getNumberOfColumns, METH_VARARGS, NULL},
	 { (char *)"BlockDescriptor_Intc_getNumberOfRows", _wrap_BlockDescriptor_Intc_getNumberOfRows, METH_VARARGS, NULL},
	 { (char *)"BlockDescriptor_Intc_reset", _wrap_BlockDescriptor_Intc_reset, METH_VARARGS, NULL},
	 { (char *)"BlockDescriptor_Intc_resizeBuffer", _wrap_BlockDescriptor_Intc_resizeBuffer, METH_VARARGS, NULL},
	 { (char *)"BlockDescriptor_Intc_setDetails", _wrap_BlockDescriptor_Intc_setDetails, METH_VARARGS, NULL},
	 { (char *)"BlockDescriptor_Intc_getColumnsOffset", _wrap_BlockDescriptor_Intc_getColumnsOffset, METH_VARARGS, NULL},
	 { (char *)"BlockDescriptor_Intc_getRowsOffset", _wrap_BlockDescriptor_Intc_getRowsOffset, METH_VARARGS, NULL},
	 { (char *)"BlockDescriptor_Intc_getRWFlag", _wrap_BlockDescriptor_Intc_getRWFlag, METH_VARARGS, NULL},
	 { (char *)"BlockDescriptor_Intc_getAdditionalBufferPtr", _wrap_BlockDescriptor_Intc_getAdditionalBufferPtr, METH_VARARGS, NULL},
	 { (char *)"BlockDescriptor_Intc_getAdditionalBufferSharedPtr", _wrap_BlockDescriptor_Intc_getAdditionalBufferSharedPtr, METH_VARARGS, NULL},
	 { (char *)"BlockDescriptor_Intc_getArray", _wrap_BlockDescriptor_Intc_getArray, METH_VARARGS, NULL},
	 { (char *)"BlockDescriptor_Intc_swigregister", BlockDescriptor_Intc_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_CSRBlockDescriptor_Float64", _wrap_new_CSRBlockDescriptor_Float64, METH_VARARGS, NULL},
	 { (char *)"delete_CSRBlockDescriptor_Float64", _wrap_delete_CSRBlockDescriptor_Float64, METH_VARARGS, NULL},
	 { (char *)"CSRBlockDescriptor_Float64_getBlockValuesPtr", _wrap_CSRBlockDescriptor_Float64_getBlockValuesPtr, METH_VARARGS, NULL},
	 { (char *)"CSRBlockDescriptor_Float64_getBlockValuesSharedPtr", _wrap_CSRBlockDescriptor_Float64_getBlockValuesSharedPtr, METH_VARARGS, NULL},
	 { (char *)"CSRBlockDescriptor_Float64_getNumberOfColumns", _wrap_CSRBlockDescriptor_Float64_getNumberOfColumns, METH_VARARGS, NULL},
	 { (char *)"CSRBlockDescriptor_Float64_getNumberOfRows", _wrap_CSRBlockDescriptor_Float64_getNumberOfRows, METH_VARARGS, NULL},
	 { (char *)"CSRBlockDescriptor_Float64_getDataSize", _wrap_CSRBlockDescriptor_Float64_getDataSize, METH_VARARGS, NULL},
	 { (char *)"CSRBlockDescriptor_Float64_reset", _wrap_CSRBlockDescriptor_Float64_reset, METH_VARARGS, NULL},
	 { (char *)"CSRBlockDescriptor_Float64_resizeValuesBuffer", _wrap_CSRBlockDescriptor_Float64_resizeValuesBuffer, METH_VARARGS, NULL},
	 { (char *)"CSRBlockDescriptor_Float64_resizeRowsBuffer", _wrap_CSRBlockDescriptor_Float64_resizeRowsBuffer, METH_VARARGS, NULL},
	 { (char *)"CSRBlockDescriptor_Float64_setDetails", _wrap_CSRBlockDescriptor_Float64_setDetails, METH_VARARGS, NULL},
	 { (char *)"CSRBlockDescriptor_Float64_getRowsOffset", _wrap_CSRBlockDescriptor_Float64_getRowsOffset, METH_VARARGS, NULL},
	 { (char *)"CSRBlockDescriptor_Float64_getRWFlag", _wrap_CSRBlockDescriptor_Float64_getRWFlag, METH_VARARGS, NULL},
	 { (char *)"CSRBlockDescriptor_Float64_getBlockColumnIndices", _wrap_CSRBlockDescriptor_Float64_getBlockColumnIndices, METH_VARARGS, NULL},
	 { (char *)"CSRBlockDescriptor_Float64_getBlockRowIndices", _wrap_CSRBlockDescriptor_Float64_getBlockRowIndices, METH_VARARGS, NULL},
	 { (char *)"CSRBlockDescriptor_Float64_getBlockValues", _wrap_CSRBlockDescriptor_Float64_getBlockValues, METH_VARARGS, NULL},
	 { (char *)"CSRBlockDescriptor_Float64_swigregister", CSRBlockDescriptor_Float64_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_CSRBlockDescriptor_Float32", _wrap_new_CSRBlockDescriptor_Float32, METH_VARARGS, NULL},
	 { (char *)"delete_CSRBlockDescriptor_Float32", _wrap_delete_CSRBlockDescriptor_Float32, METH_VARARGS, NULL},
	 { (char *)"CSRBlockDescriptor_Float32_getBlockValuesPtr", _wrap_CSRBlockDescriptor_Float32_getBlockValuesPtr, METH_VARARGS, NULL},
	 { (char *)"CSRBlockDescriptor_Float32_getBlockValuesSharedPtr", _wrap_CSRBlockDescriptor_Float32_getBlockValuesSharedPtr, METH_VARARGS, NULL},
	 { (char *)"CSRBlockDescriptor_Float32_getNumberOfColumns", _wrap_CSRBlockDescriptor_Float32_getNumberOfColumns, METH_VARARGS, NULL},
	 { (char *)"CSRBlockDescriptor_Float32_getNumberOfRows", _wrap_CSRBlockDescriptor_Float32_getNumberOfRows, METH_VARARGS, NULL},
	 { (char *)"CSRBlockDescriptor_Float32_getDataSize", _wrap_CSRBlockDescriptor_Float32_getDataSize, METH_VARARGS, NULL},
	 { (char *)"CSRBlockDescriptor_Float32_reset", _wrap_CSRBlockDescriptor_Float32_reset, METH_VARARGS, NULL},
	 { (char *)"CSRBlockDescriptor_Float32_resizeValuesBuffer", _wrap_CSRBlockDescriptor_Float32_resizeValuesBuffer, METH_VARARGS, NULL},
	 { (char *)"CSRBlockDescriptor_Float32_resizeRowsBuffer", _wrap_CSRBlockDescriptor_Float32_resizeRowsBuffer, METH_VARARGS, NULL},
	 { (char *)"CSRBlockDescriptor_Float32_setDetails", _wrap_CSRBlockDescriptor_Float32_setDetails, METH_VARARGS, NULL},
	 { (char *)"CSRBlockDescriptor_Float32_getRowsOffset", _wrap_CSRBlockDescriptor_Float32_getRowsOffset, METH_VARARGS, NULL},
	 { (char *)"CSRBlockDescriptor_Float32_getRWFlag", _wrap_CSRBlockDescriptor_Float32_getRWFlag, METH_VARARGS, NULL},
	 { (char *)"CSRBlockDescriptor_Float32_getBlockColumnIndices", _wrap_CSRBlockDescriptor_Float32_getBlockColumnIndices, METH_VARARGS, NULL},
	 { (char *)"CSRBlockDescriptor_Float32_getBlockRowIndices", _wrap_CSRBlockDescriptor_Float32_getBlockRowIndices, METH_VARARGS, NULL},
	 { (char *)"CSRBlockDescriptor_Float32_getBlockValues", _wrap_CSRBlockDescriptor_Float32_getBlockValues, METH_VARARGS, NULL},
	 { (char *)"CSRBlockDescriptor_Float32_swigregister", CSRBlockDescriptor_Float32_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_CSRBlockDescriptor_Intc", _wrap_new_CSRBlockDescriptor_Intc, METH_VARARGS, NULL},
	 { (char *)"delete_CSRBlockDescriptor_Intc", _wrap_delete_CSRBlockDescriptor_Intc, METH_VARARGS, NULL},
	 { (char *)"CSRBlockDescriptor_Intc_getBlockValuesPtr", _wrap_CSRBlockDescriptor_Intc_getBlockValuesPtr, METH_VARARGS, NULL},
	 { (char *)"CSRBlockDescriptor_Intc_getBlockValuesSharedPtr", _wrap_CSRBlockDescriptor_Intc_getBlockValuesSharedPtr, METH_VARARGS, NULL},
	 { (char *)"CSRBlockDescriptor_Intc_getNumberOfColumns", _wrap_CSRBlockDescriptor_Intc_getNumberOfColumns, METH_VARARGS, NULL},
	 { (char *)"CSRBlockDescriptor_Intc_getNumberOfRows", _wrap_CSRBlockDescriptor_Intc_getNumberOfRows, METH_VARARGS, NULL},
	 { (char *)"CSRBlockDescriptor_Intc_getDataSize", _wrap_CSRBlockDescriptor_Intc_getDataSize, METH_VARARGS, NULL},
	 { (char *)"CSRBlockDescriptor_Intc_reset", _wrap_CSRBlockDescriptor_Intc_reset, METH_VARARGS, NULL},
	 { (char *)"CSRBlockDescriptor_Intc_resizeValuesBuffer", _wrap_CSRBlockDescriptor_Intc_resizeValuesBuffer, METH_VARARGS, NULL},
	 { (char *)"CSRBlockDescriptor_Intc_resizeRowsBuffer", _wrap_CSRBlockDescriptor_Intc_resizeRowsBuffer, METH_VARARGS, NULL},
	 { (char *)"CSRBlockDescriptor_Intc_setDetails", _wrap_CSRBlockDescriptor_Intc_setDetails, METH_VARARGS, NULL},
	 { (char *)"CSRBlockDescriptor_Intc_getRowsOffset", _wrap_CSRBlockDescriptor_Intc_getRowsOffset, METH_VARARGS, NULL},
	 { (char *)"CSRBlockDescriptor_Intc_getRWFlag", _wrap_CSRBlockDescriptor_Intc_getRWFlag, METH_VARARGS, NULL},
	 { (char *)"CSRBlockDescriptor_Intc_getBlockColumnIndices", _wrap_CSRBlockDescriptor_Intc_getBlockColumnIndices, METH_VARARGS, NULL},
	 { (char *)"CSRBlockDescriptor_Intc_getBlockRowIndices", _wrap_CSRBlockDescriptor_Intc_getBlockRowIndices, METH_VARARGS, NULL},
	 { (char *)"CSRBlockDescriptor_Intc_getBlockValues", _wrap_CSRBlockDescriptor_Intc_getBlockValues, METH_VARARGS, NULL},
	 { (char *)"CSRBlockDescriptor_Intc_swigregister", CSRBlockDescriptor_Intc_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_Compressor_Bzip2", _wrap_new_Compressor_Bzip2, METH_VARARGS, NULL},
	 { (char *)"delete_Compressor_Bzip2", _wrap_delete_Compressor_Bzip2, METH_VARARGS, NULL},
	 { (char *)"Compressor_Bzip2_setInputDataBlock", _wrap_Compressor_Bzip2_setInputDataBlock, METH_VARARGS, NULL},
	 { (char *)"Compressor_Bzip2_run", _wrap_Compressor_Bzip2_run, METH_VARARGS, NULL},
	 { (char *)"Compressor_Bzip2_parameter_set", _wrap_Compressor_Bzip2_parameter_set, METH_VARARGS, NULL},
	 { (char *)"Compressor_Bzip2_parameter_get", _wrap_Compressor_Bzip2_parameter_get, METH_VARARGS, NULL},
	 { (char *)"Compressor_Bzip2_swigregister", Compressor_Bzip2_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_Compressor_Lzo", _wrap_new_Compressor_Lzo, METH_VARARGS, NULL},
	 { (char *)"delete_Compressor_Lzo", _wrap_delete_Compressor_Lzo, METH_VARARGS, NULL},
	 { (char *)"Compressor_Lzo_setInputDataBlock", _wrap_Compressor_Lzo_setInputDataBlock, METH_VARARGS, NULL},
	 { (char *)"Compressor_Lzo_run", _wrap_Compressor_Lzo_run, METH_VARARGS, NULL},
	 { (char *)"Compressor_Lzo_parameter_set", _wrap_Compressor_Lzo_parameter_set, METH_VARARGS, NULL},
	 { (char *)"Compressor_Lzo_parameter_get", _wrap_Compressor_Lzo_parameter_get, METH_VARARGS, NULL},
	 { (char *)"Compressor_Lzo_swigregister", Compressor_Lzo_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_Compressor_Rle", _wrap_new_Compressor_Rle, METH_VARARGS, NULL},
	 { (char *)"delete_Compressor_Rle", _wrap_delete_Compressor_Rle, METH_VARARGS, NULL},
	 { (char *)"Compressor_Rle_setInputDataBlock", _wrap_Compressor_Rle_setInputDataBlock, METH_VARARGS, NULL},
	 { (char *)"Compressor_Rle_run", _wrap_Compressor_Rle_run, METH_VARARGS, NULL},
	 { (char *)"Compressor_Rle_parameter_set", _wrap_Compressor_Rle_parameter_set, METH_VARARGS, NULL},
	 { (char *)"Compressor_Rle_parameter_get", _wrap_Compressor_Rle_parameter_get, METH_VARARGS, NULL},
	 { (char *)"Compressor_Rle_swigregister", Compressor_Rle_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_Compressor_Zlib", _wrap_new_Compressor_Zlib, METH_VARARGS, NULL},
	 { (char *)"delete_Compressor_Zlib", _wrap_delete_Compressor_Zlib, METH_VARARGS, NULL},
	 { (char *)"Compressor_Zlib_setInputDataBlock", _wrap_Compressor_Zlib_setInputDataBlock, METH_VARARGS, NULL},
	 { (char *)"Compressor_Zlib_run", _wrap_Compressor_Zlib_run, METH_VARARGS, NULL},
	 { (char *)"Compressor_Zlib_parameter_set", _wrap_Compressor_Zlib_parameter_set, METH_VARARGS, NULL},
	 { (char *)"Compressor_Zlib_parameter_get", _wrap_Compressor_Zlib_parameter_get, METH_VARARGS, NULL},
	 { (char *)"Compressor_Zlib_swigregister", Compressor_Zlib_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_Decompressor_Bzip2", _wrap_new_Decompressor_Bzip2, METH_VARARGS, NULL},
	 { (char *)"delete_Decompressor_Bzip2", _wrap_delete_Decompressor_Bzip2, METH_VARARGS, NULL},
	 { (char *)"Decompressor_Bzip2_setInputDataBlock", _wrap_Decompressor_Bzip2_setInputDataBlock, METH_VARARGS, NULL},
	 { (char *)"Decompressor_Bzip2_run", _wrap_Decompressor_Bzip2_run, METH_VARARGS, NULL},
	 { (char *)"Decompressor_Bzip2_parameter_set", _wrap_Decompressor_Bzip2_parameter_set, METH_VARARGS, NULL},
	 { (char *)"Decompressor_Bzip2_parameter_get", _wrap_Decompressor_Bzip2_parameter_get, METH_VARARGS, NULL},
	 { (char *)"Decompressor_Bzip2_swigregister", Decompressor_Bzip2_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_Decompressor_Lzo", _wrap_new_Decompressor_Lzo, METH_VARARGS, NULL},
	 { (char *)"delete_Decompressor_Lzo", _wrap_delete_Decompressor_Lzo, METH_VARARGS, NULL},
	 { (char *)"Decompressor_Lzo_setInputDataBlock", _wrap_Decompressor_Lzo_setInputDataBlock, METH_VARARGS, NULL},
	 { (char *)"Decompressor_Lzo_run", _wrap_Decompressor_Lzo_run, METH_VARARGS, NULL},
	 { (char *)"Decompressor_Lzo_parameter_set", _wrap_Decompressor_Lzo_parameter_set, METH_VARARGS, NULL},
	 { (char *)"Decompressor_Lzo_parameter_get", _wrap_Decompressor_Lzo_parameter_get, METH_VARARGS, NULL},
	 { (char *)"Decompressor_Lzo_swigregister", Decompressor_Lzo_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_Decompressor_Rle", _wrap_new_Decompressor_Rle, METH_VARARGS, NULL},
	 { (char *)"delete_Decompressor_Rle", _wrap_delete_Decompressor_Rle, METH_VARARGS, NULL},
	 { (char *)"Decompressor_Rle_setInputDataBlock", _wrap_Decompressor_Rle_setInputDataBlock, METH_VARARGS, NULL},
	 { (char *)"Decompressor_Rle_run", _wrap_Decompressor_Rle_run, METH_VARARGS, NULL},
	 { (char *)"Decompressor_Rle_parameter_set", _wrap_Decompressor_Rle_parameter_set, METH_VARARGS, NULL},
	 { (char *)"Decompressor_Rle_parameter_get", _wrap_Decompressor_Rle_parameter_get, METH_VARARGS, NULL},
	 { (char *)"Decompressor_Rle_swigregister", Decompressor_Rle_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_Decompressor_Zlib", _wrap_new_Decompressor_Zlib, METH_VARARGS, NULL},
	 { (char *)"delete_Decompressor_Zlib", _wrap_delete_Decompressor_Zlib, METH_VARARGS, NULL},
	 { (char *)"Decompressor_Zlib_setInputDataBlock", _wrap_Decompressor_Zlib_setInputDataBlock, METH_VARARGS, NULL},
	 { (char *)"Decompressor_Zlib_run", _wrap_Decompressor_Zlib_run, METH_VARARGS, NULL},
	 { (char *)"Decompressor_Zlib_parameter_set", _wrap_Decompressor_Zlib_parameter_set, METH_VARARGS, NULL},
	 { (char *)"Decompressor_Zlib_parameter_get", _wrap_Decompressor_Zlib_parameter_get, METH_VARARGS, NULL},
	 { (char *)"Decompressor_Zlib_swigregister", Decompressor_Zlib_swigregister, METH_VARARGS, NULL},
	 { (char *)"HomogenNumericTable_Float64_serializationTag", _wrap_HomogenNumericTable_Float64_serializationTag, METH_VARARGS, NULL},
	 { (char *)"HomogenNumericTable_Float64_getSerializationTag", _wrap_HomogenNumericTable_Float64_getSerializationTag, METH_VARARGS, NULL},
	 { (char *)"HomogenNumericTable_Float64_create", _wrap_HomogenNumericTable_Float64_create, METH_VARARGS, NULL},
	 { (char *)"delete_HomogenNumericTable_Float64", _wrap_delete_HomogenNumericTable_Float64, METH_VARARGS, NULL},
	 { (char *)"HomogenNumericTable_Float64_assign", _wrap_HomogenNumericTable_Float64_assign, METH_VARARGS, NULL},
	 { (char *)"HomogenNumericTable_Float64_getBlockOfRows", _wrap_HomogenNumericTable_Float64_getBlockOfRows, METH_VARARGS, NULL},
	 { (char *)"HomogenNumericTable_Float64_releaseBlockOfRows", _wrap_HomogenNumericTable_Float64_releaseBlockOfRows, METH_VARARGS, NULL},
	 { (char *)"HomogenNumericTable_Float64_getBlockOfColumnValues", _wrap_HomogenNumericTable_Float64_getBlockOfColumnValues, METH_VARARGS, NULL},
	 { (char *)"HomogenNumericTable_Float64_releaseBlockOfColumnValues", _wrap_HomogenNumericTable_Float64_releaseBlockOfColumnValues, METH_VARARGS, NULL},
	 { (char *)"HomogenNumericTable_Float64___getitem__", _wrap_HomogenNumericTable_Float64___getitem__, METH_VARARGS, NULL},
	 { (char *)"HomogenNumericTable_Float64_getArray", _wrap_HomogenNumericTable_Float64_getArray, METH_VARARGS, NULL},
	 { (char *)"HomogenNumericTable_Float64_swigregister", HomogenNumericTable_Float64_swigregister, METH_VARARGS, NULL},
	 { (char *)"HomogenNumericTable_Float32_serializationTag", _wrap_HomogenNumericTable_Float32_serializationTag, METH_VARARGS, NULL},
	 { (char *)"HomogenNumericTable_Float32_getSerializationTag", _wrap_HomogenNumericTable_Float32_getSerializationTag, METH_VARARGS, NULL},
	 { (char *)"HomogenNumericTable_Float32_create", _wrap_HomogenNumericTable_Float32_create, METH_VARARGS, NULL},
	 { (char *)"delete_HomogenNumericTable_Float32", _wrap_delete_HomogenNumericTable_Float32, METH_VARARGS, NULL},
	 { (char *)"HomogenNumericTable_Float32_assign", _wrap_HomogenNumericTable_Float32_assign, METH_VARARGS, NULL},
	 { (char *)"HomogenNumericTable_Float32_getBlockOfRows", _wrap_HomogenNumericTable_Float32_getBlockOfRows, METH_VARARGS, NULL},
	 { (char *)"HomogenNumericTable_Float32_releaseBlockOfRows", _wrap_HomogenNumericTable_Float32_releaseBlockOfRows, METH_VARARGS, NULL},
	 { (char *)"HomogenNumericTable_Float32_getBlockOfColumnValues", _wrap_HomogenNumericTable_Float32_getBlockOfColumnValues, METH_VARARGS, NULL},
	 { (char *)"HomogenNumericTable_Float32_releaseBlockOfColumnValues", _wrap_HomogenNumericTable_Float32_releaseBlockOfColumnValues, METH_VARARGS, NULL},
	 { (char *)"HomogenNumericTable_Float32___getitem__", _wrap_HomogenNumericTable_Float32___getitem__, METH_VARARGS, NULL},
	 { (char *)"HomogenNumericTable_Float32_getArray", _wrap_HomogenNumericTable_Float32_getArray, METH_VARARGS, NULL},
	 { (char *)"HomogenNumericTable_Float32_swigregister", HomogenNumericTable_Float32_swigregister, METH_VARARGS, NULL},
	 { (char *)"HomogenNumericTable_Intc_serializationTag", _wrap_HomogenNumericTable_Intc_serializationTag, METH_VARARGS, NULL},
	 { (char *)"HomogenNumericTable_Intc_getSerializationTag", _wrap_HomogenNumericTable_Intc_getSerializationTag, METH_VARARGS, NULL},
	 { (char *)"HomogenNumericTable_Intc_create", _wrap_HomogenNumericTable_Intc_create, METH_VARARGS, NULL},
	 { (char *)"delete_HomogenNumericTable_Intc", _wrap_delete_HomogenNumericTable_Intc, METH_VARARGS, NULL},
	 { (char *)"HomogenNumericTable_Intc_assign", _wrap_HomogenNumericTable_Intc_assign, METH_VARARGS, NULL},
	 { (char *)"HomogenNumericTable_Intc_getBlockOfRows", _wrap_HomogenNumericTable_Intc_getBlockOfRows, METH_VARARGS, NULL},
	 { (char *)"HomogenNumericTable_Intc_releaseBlockOfRows", _wrap_HomogenNumericTable_Intc_releaseBlockOfRows, METH_VARARGS, NULL},
	 { (char *)"HomogenNumericTable_Intc_getBlockOfColumnValues", _wrap_HomogenNumericTable_Intc_getBlockOfColumnValues, METH_VARARGS, NULL},
	 { (char *)"HomogenNumericTable_Intc_releaseBlockOfColumnValues", _wrap_HomogenNumericTable_Intc_releaseBlockOfColumnValues, METH_VARARGS, NULL},
	 { (char *)"HomogenNumericTable_Intc___getitem__", _wrap_HomogenNumericTable_Intc___getitem__, METH_VARARGS, NULL},
	 { (char *)"HomogenNumericTable_Intc_getArray", _wrap_HomogenNumericTable_Intc_getArray, METH_VARARGS, NULL},
	 { (char *)"HomogenNumericTable_Intc_swigregister", HomogenNumericTable_Intc_swigregister, METH_VARARGS, NULL},
	 { (char *)"HomogenTensor_Float64_serializationTag", _wrap_HomogenTensor_Float64_serializationTag, METH_VARARGS, NULL},
	 { (char *)"HomogenTensor_Float64_getSerializationTag", _wrap_HomogenTensor_Float64_getSerializationTag, METH_VARARGS, NULL},
	 { (char *)"HomogenTensor_Float64_create", _wrap_HomogenTensor_Float64_create, METH_VARARGS, NULL},
	 { (char *)"delete_HomogenTensor_Float64", _wrap_delete_HomogenTensor_Float64, METH_VARARGS, NULL},
	 { (char *)"HomogenTensor_Float64_getTensorLayout", _wrap_HomogenTensor_Float64_getTensorLayout, METH_VARARGS, NULL},
	 { (char *)"HomogenTensor_Float64_createDefaultSubtensorLayout", _wrap_HomogenTensor_Float64_createDefaultSubtensorLayout, METH_VARARGS, NULL},
	 { (char *)"HomogenTensor_Float64_createRawSubtensorLayout", _wrap_HomogenTensor_Float64_createRawSubtensorLayout, METH_VARARGS, NULL},
	 { (char *)"HomogenTensor_Float64_setDimensions", _wrap_HomogenTensor_Float64_setDimensions, METH_VARARGS, NULL},
	 { (char *)"HomogenTensor_Float64_assign", _wrap_HomogenTensor_Float64_assign, METH_VARARGS, NULL},
	 { (char *)"HomogenTensor_Float64_getSubtensorEx", _wrap_HomogenTensor_Float64_getSubtensorEx, METH_VARARGS, NULL},
	 { (char *)"HomogenTensor_Float64_getSubtensor", _wrap_HomogenTensor_Float64_getSubtensor, METH_VARARGS, NULL},
	 { (char *)"HomogenTensor_Float64_releaseSubtensor", _wrap_HomogenTensor_Float64_releaseSubtensor, METH_VARARGS, NULL},
	 { (char *)"HomogenTensor_Float64_getSampleTensor", _wrap_HomogenTensor_Float64_getSampleTensor, METH_VARARGS, NULL},
	 { (char *)"HomogenTensor_Float64_getArray", _wrap_HomogenTensor_Float64_getArray, METH_VARARGS, NULL},
	 { (char *)"HomogenTensor_Float64_swigregister", HomogenTensor_Float64_swigregister, METH_VARARGS, NULL},
	 { (char *)"HomogenTensor_Float32_serializationTag", _wrap_HomogenTensor_Float32_serializationTag, METH_VARARGS, NULL},
	 { (char *)"HomogenTensor_Float32_getSerializationTag", _wrap_HomogenTensor_Float32_getSerializationTag, METH_VARARGS, NULL},
	 { (char *)"HomogenTensor_Float32_create", _wrap_HomogenTensor_Float32_create, METH_VARARGS, NULL},
	 { (char *)"delete_HomogenTensor_Float32", _wrap_delete_HomogenTensor_Float32, METH_VARARGS, NULL},
	 { (char *)"HomogenTensor_Float32_getTensorLayout", _wrap_HomogenTensor_Float32_getTensorLayout, METH_VARARGS, NULL},
	 { (char *)"HomogenTensor_Float32_createDefaultSubtensorLayout", _wrap_HomogenTensor_Float32_createDefaultSubtensorLayout, METH_VARARGS, NULL},
	 { (char *)"HomogenTensor_Float32_createRawSubtensorLayout", _wrap_HomogenTensor_Float32_createRawSubtensorLayout, METH_VARARGS, NULL},
	 { (char *)"HomogenTensor_Float32_setDimensions", _wrap_HomogenTensor_Float32_setDimensions, METH_VARARGS, NULL},
	 { (char *)"HomogenTensor_Float32_assign", _wrap_HomogenTensor_Float32_assign, METH_VARARGS, NULL},
	 { (char *)"HomogenTensor_Float32_getSubtensorEx", _wrap_HomogenTensor_Float32_getSubtensorEx, METH_VARARGS, NULL},
	 { (char *)"HomogenTensor_Float32_getSubtensor", _wrap_HomogenTensor_Float32_getSubtensor, METH_VARARGS, NULL},
	 { (char *)"HomogenTensor_Float32_releaseSubtensor", _wrap_HomogenTensor_Float32_releaseSubtensor, METH_VARARGS, NULL},
	 { (char *)"HomogenTensor_Float32_getSampleTensor", _wrap_HomogenTensor_Float32_getSampleTensor, METH_VARARGS, NULL},
	 { (char *)"HomogenTensor_Float32_getArray", _wrap_HomogenTensor_Float32_getArray, METH_VARARGS, NULL},
	 { (char *)"HomogenTensor_Float32_swigregister", HomogenTensor_Float32_swigregister, METH_VARARGS, NULL},
	 { (char *)"HomogenTensor_Intc_serializationTag", _wrap_HomogenTensor_Intc_serializationTag, METH_VARARGS, NULL},
	 { (char *)"HomogenTensor_Intc_getSerializationTag", _wrap_HomogenTensor_Intc_getSerializationTag, METH_VARARGS, NULL},
	 { (char *)"HomogenTensor_Intc_create", _wrap_HomogenTensor_Intc_create, METH_VARARGS, NULL},
	 { (char *)"delete_HomogenTensor_Intc", _wrap_delete_HomogenTensor_Intc, METH_VARARGS, NULL},
	 { (char *)"HomogenTensor_Intc_getTensorLayout", _wrap_HomogenTensor_Intc_getTensorLayout, METH_VARARGS, NULL},
	 { (char *)"HomogenTensor_Intc_createDefaultSubtensorLayout", _wrap_HomogenTensor_Intc_createDefaultSubtensorLayout, METH_VARARGS, NULL},
	 { (char *)"HomogenTensor_Intc_createRawSubtensorLayout", _wrap_HomogenTensor_Intc_createRawSubtensorLayout, METH_VARARGS, NULL},
	 { (char *)"HomogenTensor_Intc_setDimensions", _wrap_HomogenTensor_Intc_setDimensions, METH_VARARGS, NULL},
	 { (char *)"HomogenTensor_Intc_assign", _wrap_HomogenTensor_Intc_assign, METH_VARARGS, NULL},
	 { (char *)"HomogenTensor_Intc_getSubtensorEx", _wrap_HomogenTensor_Intc_getSubtensorEx, METH_VARARGS, NULL},
	 { (char *)"HomogenTensor_Intc_getSubtensor", _wrap_HomogenTensor_Intc_getSubtensor, METH_VARARGS, NULL},
	 { (char *)"HomogenTensor_Intc_releaseSubtensor", _wrap_HomogenTensor_Intc_releaseSubtensor, METH_VARARGS, NULL},
	 { (char *)"HomogenTensor_Intc_getSampleTensor", _wrap_HomogenTensor_Intc_getSampleTensor, METH_VARARGS, NULL},
	 { (char *)"HomogenTensor_Intc_getArray", _wrap_HomogenTensor_Intc_getArray, METH_VARARGS, NULL},
	 { (char *)"HomogenTensor_Intc_swigregister", HomogenTensor_Intc_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_KeyValueCollection_SerializationIface", _wrap_new_KeyValueCollection_SerializationIface, METH_VARARGS, NULL},
	 { (char *)"delete_KeyValueCollection_SerializationIface", _wrap_delete_KeyValueCollection_SerializationIface, METH_VARARGS, NULL},
	 { (char *)"KeyValueCollection_SerializationIface_getKeyByIndex", _wrap_KeyValueCollection_SerializationIface_getKeyByIndex, METH_VARARGS, NULL},
	 { (char *)"KeyValueCollection_SerializationIface_getValueByIndex", _wrap_KeyValueCollection_SerializationIface_getValueByIndex, METH_VARARGS, NULL},
	 { (char *)"KeyValueCollection_SerializationIface_getValueByIndexConst", _wrap_KeyValueCollection_SerializationIface_getValueByIndexConst, METH_VARARGS, NULL},
	 { (char *)"KeyValueCollection_SerializationIface_size", _wrap_KeyValueCollection_SerializationIface_size, METH_VARARGS, NULL},
	 { (char *)"KeyValueCollection_SerializationIface_clear", _wrap_KeyValueCollection_SerializationIface_clear, METH_VARARGS, NULL},
	 { (char *)"KeyValueCollection_SerializationIface___getitem__", _wrap_KeyValueCollection_SerializationIface___getitem__, METH_VARARGS, NULL},
	 { (char *)"KeyValueCollection_SerializationIface___setitem__", _wrap_KeyValueCollection_SerializationIface___setitem__, METH_VARARGS, NULL},
	 { (char *)"KeyValueCollection_SerializationIface_swigregister", KeyValueCollection_SerializationIface_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_KeyValueCollection_Input", _wrap_new_KeyValueCollection_Input, METH_VARARGS, NULL},
	 { (char *)"delete_KeyValueCollection_Input", _wrap_delete_KeyValueCollection_Input, METH_VARARGS, NULL},
	 { (char *)"KeyValueCollection_Input_getKeyByIndex", _wrap_KeyValueCollection_Input_getKeyByIndex, METH_VARARGS, NULL},
	 { (char *)"KeyValueCollection_Input_getValueByIndex", _wrap_KeyValueCollection_Input_getValueByIndex, METH_VARARGS, NULL},
	 { (char *)"KeyValueCollection_Input_getValueByIndexConst", _wrap_KeyValueCollection_Input_getValueByIndexConst, METH_VARARGS, NULL},
	 { (char *)"KeyValueCollection_Input_size", _wrap_KeyValueCollection_Input_size, METH_VARARGS, NULL},
	 { (char *)"KeyValueCollection_Input_clear", _wrap_KeyValueCollection_Input_clear, METH_VARARGS, NULL},
	 { (char *)"KeyValueCollection_Input___getitem__", _wrap_KeyValueCollection_Input___getitem__, METH_VARARGS, NULL},
	 { (char *)"KeyValueCollection_Input___setitem__", _wrap_KeyValueCollection_Input___setitem__, METH_VARARGS, NULL},
	 { (char *)"KeyValueCollection_Input_swigregister", KeyValueCollection_Input_swigregister, METH_VARARGS, NULL},
	 { (char *)"Matrix_Float64_serializationTag", _wrap_Matrix_Float64_serializationTag, METH_VARARGS, NULL},
	 { (char *)"Matrix_Float64_getSerializationTag", _wrap_Matrix_Float64_getSerializationTag, METH_VARARGS, NULL},
	 { (char *)"delete_Matrix_Float64", _wrap_delete_Matrix_Float64, METH_VARARGS, NULL},
	 { (char *)"Matrix_Float64_create", _wrap_Matrix_Float64_create, METH_VARARGS, NULL},
	 { (char *)"Matrix_Float64_swigregister", Matrix_Float64_swigregister, METH_VARARGS, NULL},
	 { (char *)"Matrix_Float32_serializationTag", _wrap_Matrix_Float32_serializationTag, METH_VARARGS, NULL},
	 { (char *)"Matrix_Float32_getSerializationTag", _wrap_Matrix_Float32_getSerializationTag, METH_VARARGS, NULL},
	 { (char *)"delete_Matrix_Float32", _wrap_delete_Matrix_Float32, METH_VARARGS, NULL},
	 { (char *)"Matrix_Float32_create", _wrap_Matrix_Float32_create, METH_VARARGS, NULL},
	 { (char *)"Matrix_Float32_swigregister", Matrix_Float32_swigregister, METH_VARARGS, NULL},
	 { (char *)"Matrix_Intc_serializationTag", _wrap_Matrix_Intc_serializationTag, METH_VARARGS, NULL},
	 { (char *)"Matrix_Intc_getSerializationTag", _wrap_Matrix_Intc_getSerializationTag, METH_VARARGS, NULL},
	 { (char *)"delete_Matrix_Intc", _wrap_delete_Matrix_Intc, METH_VARARGS, NULL},
	 { (char *)"Matrix_Intc_create", _wrap_Matrix_Intc_create, METH_VARARGS, NULL},
	 { (char *)"Matrix_Intc_swigregister", Matrix_Intc_swigregister, METH_VARARGS, NULL},
	 { (char *)"SerializableKeyValueCollection_SerializationIface_serializationTag", _wrap_SerializableKeyValueCollection_SerializationIface_serializationTag, METH_VARARGS, NULL},
	 { (char *)"SerializableKeyValueCollection_SerializationIface_getSerializationTag", _wrap_SerializableKeyValueCollection_SerializationIface_getSerializationTag, METH_VARARGS, NULL},
	 { (char *)"new_SerializableKeyValueCollection_SerializationIface", _wrap_new_SerializableKeyValueCollection_SerializationIface, METH_VARARGS, NULL},
	 { (char *)"delete_SerializableKeyValueCollection_SerializationIface", _wrap_delete_SerializableKeyValueCollection_SerializationIface, METH_VARARGS, NULL},
	 { (char *)"SerializableKeyValueCollection_SerializationIface_swigregister", SerializableKeyValueCollection_SerializationIface_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_SubtensorDescriptor_Float64", _wrap_new_SubtensorDescriptor_Float64, METH_VARARGS, NULL},
	 { (char *)"delete_SubtensorDescriptor_Float64", _wrap_delete_SubtensorDescriptor_Float64, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Float64_getNumberOfDims", _wrap_SubtensorDescriptor_Float64_getNumberOfDims, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Float64_getLayout", _wrap_SubtensorDescriptor_Float64_getLayout, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Float64_getInplaceFlag", _wrap_SubtensorDescriptor_Float64_getInplaceFlag, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Float64_reset", _wrap_SubtensorDescriptor_Float64_reset, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Float64_resizeBuffer", _wrap_SubtensorDescriptor_Float64_resizeBuffer, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Float64_setDetails", _wrap_SubtensorDescriptor_Float64_setDetails, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Float64_saveOffsetLayout", _wrap_SubtensorDescriptor_Float64_saveOffsetLayout, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Float64_saveOffsetLayoutCopy", _wrap_SubtensorDescriptor_Float64_saveOffsetLayoutCopy, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Float64_getSize", _wrap_SubtensorDescriptor_Float64_getSize, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Float64_getFixedDims", _wrap_SubtensorDescriptor_Float64_getFixedDims, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Float64_getRangeDimIdx", _wrap_SubtensorDescriptor_Float64_getRangeDimIdx, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Float64_getRangeDimNum", _wrap_SubtensorDescriptor_Float64_getRangeDimNum, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Float64_getRWFlag", _wrap_SubtensorDescriptor_Float64_getRWFlag, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Float64_getArray", _wrap_SubtensorDescriptor_Float64_getArray, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Float64_getSubtensorDimSizes", _wrap_SubtensorDescriptor_Float64_getSubtensorDimSizes, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Float64_getFixedDimNums", _wrap_SubtensorDescriptor_Float64_getFixedDimNums, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Float64_swigregister", SubtensorDescriptor_Float64_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_SubtensorDescriptor_Float32", _wrap_new_SubtensorDescriptor_Float32, METH_VARARGS, NULL},
	 { (char *)"delete_SubtensorDescriptor_Float32", _wrap_delete_SubtensorDescriptor_Float32, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Float32_getNumberOfDims", _wrap_SubtensorDescriptor_Float32_getNumberOfDims, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Float32_getLayout", _wrap_SubtensorDescriptor_Float32_getLayout, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Float32_getInplaceFlag", _wrap_SubtensorDescriptor_Float32_getInplaceFlag, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Float32_reset", _wrap_SubtensorDescriptor_Float32_reset, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Float32_resizeBuffer", _wrap_SubtensorDescriptor_Float32_resizeBuffer, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Float32_setDetails", _wrap_SubtensorDescriptor_Float32_setDetails, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Float32_saveOffsetLayout", _wrap_SubtensorDescriptor_Float32_saveOffsetLayout, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Float32_saveOffsetLayoutCopy", _wrap_SubtensorDescriptor_Float32_saveOffsetLayoutCopy, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Float32_getSize", _wrap_SubtensorDescriptor_Float32_getSize, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Float32_getFixedDims", _wrap_SubtensorDescriptor_Float32_getFixedDims, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Float32_getRangeDimIdx", _wrap_SubtensorDescriptor_Float32_getRangeDimIdx, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Float32_getRangeDimNum", _wrap_SubtensorDescriptor_Float32_getRangeDimNum, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Float32_getRWFlag", _wrap_SubtensorDescriptor_Float32_getRWFlag, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Float32_getArray", _wrap_SubtensorDescriptor_Float32_getArray, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Float32_getSubtensorDimSizes", _wrap_SubtensorDescriptor_Float32_getSubtensorDimSizes, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Float32_getFixedDimNums", _wrap_SubtensorDescriptor_Float32_getFixedDimNums, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Float32_swigregister", SubtensorDescriptor_Float32_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_SubtensorDescriptor_Intc", _wrap_new_SubtensorDescriptor_Intc, METH_VARARGS, NULL},
	 { (char *)"delete_SubtensorDescriptor_Intc", _wrap_delete_SubtensorDescriptor_Intc, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Intc_getNumberOfDims", _wrap_SubtensorDescriptor_Intc_getNumberOfDims, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Intc_getLayout", _wrap_SubtensorDescriptor_Intc_getLayout, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Intc_getInplaceFlag", _wrap_SubtensorDescriptor_Intc_getInplaceFlag, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Intc_reset", _wrap_SubtensorDescriptor_Intc_reset, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Intc_resizeBuffer", _wrap_SubtensorDescriptor_Intc_resizeBuffer, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Intc_setDetails", _wrap_SubtensorDescriptor_Intc_setDetails, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Intc_saveOffsetLayout", _wrap_SubtensorDescriptor_Intc_saveOffsetLayout, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Intc_saveOffsetLayoutCopy", _wrap_SubtensorDescriptor_Intc_saveOffsetLayoutCopy, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Intc_getSize", _wrap_SubtensorDescriptor_Intc_getSize, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Intc_getFixedDims", _wrap_SubtensorDescriptor_Intc_getFixedDims, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Intc_getRangeDimIdx", _wrap_SubtensorDescriptor_Intc_getRangeDimIdx, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Intc_getRangeDimNum", _wrap_SubtensorDescriptor_Intc_getRangeDimNum, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Intc_getRWFlag", _wrap_SubtensorDescriptor_Intc_getRWFlag, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Intc_getArray", _wrap_SubtensorDescriptor_Intc_getArray, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Intc_getSubtensorDimSizes", _wrap_SubtensorDescriptor_Intc_getSubtensorDimSizes, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Intc_getFixedDimNums", _wrap_SubtensorDescriptor_Intc_getFixedDimNums, METH_VARARGS, NULL},
	 { (char *)"SubtensorDescriptor_Intc_swigregister", SubtensorDescriptor_Intc_swigregister, METH_VARARGS, NULL},
	 { (char *)"delete_DataSourceTemplate_HomogenNumericTable_Float64Float64", _wrap_delete_DataSourceTemplate_HomogenNumericTable_Float64Float64, METH_VARARGS, NULL},
	 { (char *)"DataSourceTemplate_HomogenNumericTable_Float64Float64_freeNumericTable", _wrap_DataSourceTemplate_HomogenNumericTable_Float64Float64_freeNumericTable, METH_VARARGS, NULL},
	 { (char *)"DataSourceTemplate_HomogenNumericTable_Float64Float64_allocateNumericTable", _wrap_DataSourceTemplate_HomogenNumericTable_Float64Float64_allocateNumericTable, METH_VARARGS, NULL},
	 { (char *)"DataSourceTemplate_HomogenNumericTable_Float64Float64_swigregister", DataSourceTemplate_HomogenNumericTable_Float64Float64_swigregister, METH_VARARGS, NULL},
	 { (char *)"delete_DataSourceTemplate_HomogenNumericTable_Float32Float64", _wrap_delete_DataSourceTemplate_HomogenNumericTable_Float32Float64, METH_VARARGS, NULL},
	 { (char *)"DataSourceTemplate_HomogenNumericTable_Float32Float64_freeNumericTable", _wrap_DataSourceTemplate_HomogenNumericTable_Float32Float64_freeNumericTable, METH_VARARGS, NULL},
	 { (char *)"DataSourceTemplate_HomogenNumericTable_Float32Float64_allocateNumericTable", _wrap_DataSourceTemplate_HomogenNumericTable_Float32Float64_allocateNumericTable, METH_VARARGS, NULL},
	 { (char *)"DataSourceTemplate_HomogenNumericTable_Float32Float64_swigregister", DataSourceTemplate_HomogenNumericTable_Float32Float64_swigregister, METH_VARARGS, NULL},
	 { (char *)"delete_DataSourceTemplate_HomogenNumericTable_IntcFloat64", _wrap_delete_DataSourceTemplate_HomogenNumericTable_IntcFloat64, METH_VARARGS, NULL},
	 { (char *)"DataSourceTemplate_HomogenNumericTable_IntcFloat64_freeNumericTable", _wrap_DataSourceTemplate_HomogenNumericTable_IntcFloat64_freeNumericTable, METH_VARARGS, NULL},
	 { (char *)"DataSourceTemplate_HomogenNumericTable_IntcFloat64_allocateNumericTable", _wrap_DataSourceTemplate_HomogenNumericTable_IntcFloat64_allocateNumericTable, METH_VARARGS, NULL},
	 { (char *)"DataSourceTemplate_HomogenNumericTable_IntcFloat64_swigregister", DataSourceTemplate_HomogenNumericTable_IntcFloat64_swigregister, METH_VARARGS, NULL},
	 { (char *)"delete_CsvDataSource_CSVFeatureManagerFloat64", _wrap_delete_CsvDataSource_CSVFeatureManagerFloat64, METH_VARARGS, NULL},
	 { (char *)"CsvDataSource_CSVFeatureManagerFloat64_getFeatureManager", _wrap_CsvDataSource_CSVFeatureManagerFloat64_getFeatureManager, METH_VARARGS, NULL},
	 { (char *)"CsvDataSource_CSVFeatureManagerFloat64_getNumericTableNumberOfColumns", _wrap_CsvDataSource_CSVFeatureManagerFloat64_getNumericTableNumberOfColumns, METH_VARARGS, NULL},
	 { (char *)"CsvDataSource_CSVFeatureManagerFloat64_setDictionary", _wrap_CsvDataSource_CSVFeatureManagerFloat64_setDictionary, METH_VARARGS, NULL},
	 { (char *)"CsvDataSource_CSVFeatureManagerFloat64_loadDataBlock", _wrap_CsvDataSource_CSVFeatureManagerFloat64_loadDataBlock, METH_VARARGS, NULL},
	 { (char *)"CsvDataSource_CSVFeatureManagerFloat64_createDictionaryFromContext", _wrap_CsvDataSource_CSVFeatureManagerFloat64_createDictionaryFromContext, METH_VARARGS, NULL},
	 { (char *)"CsvDataSource_CSVFeatureManagerFloat64_getNumberOfAvailableRows", _wrap_CsvDataSource_CSVFeatureManagerFloat64_getNumberOfAvailableRows, METH_VARARGS, NULL},
	 { (char *)"CsvDataSource_CSVFeatureManagerFloat64_swigregister", CsvDataSource_CSVFeatureManagerFloat64_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_FileDataSource_CSVFeatureManagerFloat64", _wrap_new_FileDataSource_CSVFeatureManagerFloat64, METH_VARARGS, NULL},
	 { (char *)"delete_FileDataSource_CSVFeatureManagerFloat64", _wrap_delete_FileDataSource_CSVFeatureManagerFloat64, METH_VARARGS, NULL},
	 { (char *)"FileDataSource_CSVFeatureManagerFloat64_createDictionaryFromContext", _wrap_FileDataSource_CSVFeatureManagerFloat64_createDictionaryFromContext, METH_VARARGS, NULL},
	 { (char *)"FileDataSource_CSVFeatureManagerFloat64_getStatus", _wrap_FileDataSource_CSVFeatureManagerFloat64_getStatus, METH_VARARGS, NULL},
	 { (char *)"FileDataSource_CSVFeatureManagerFloat64_swigregister", FileDataSource_CSVFeatureManagerFloat64_swigregister, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_serializationTag", _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_serializationTag, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getSerializationTag", _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getSerializationTag, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create", _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_create, METH_VARARGS, NULL},
	 { (char *)"delete_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64", _wrap_delete_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_assign", _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_assign, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfRows", _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfRows, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfRows", _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfRows, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfColumnValues", _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getBlockOfColumnValues, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues", _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getPackedArray", _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_getPackedArray, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releasePackedArray", _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_releasePackedArray, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_swigregister", PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat64_swigregister, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_serializationTag", _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_serializationTag, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getSerializationTag", _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getSerializationTag, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create", _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_create, METH_VARARGS, NULL},
	 { (char *)"delete_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32", _wrap_delete_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_assign", _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_assign, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfRows", _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfRows, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfRows", _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfRows, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfColumnValues", _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getBlockOfColumnValues, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues", _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getPackedArray", _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_getPackedArray, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releasePackedArray", _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_releasePackedArray, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_swigregister", PackedSymmetricMatrix_UpperPackedSymmetricMatrixFloat32_swigregister, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_serializationTag", _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_serializationTag, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getSerializationTag", _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getSerializationTag, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create", _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_create, METH_VARARGS, NULL},
	 { (char *)"delete_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc", _wrap_delete_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_assign", _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_assign, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfRows", _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfRows, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfRows", _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfRows, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfColumnValues", _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getBlockOfColumnValues, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfColumnValues", _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releaseBlockOfColumnValues, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getPackedArray", _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_getPackedArray, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releasePackedArray", _wrap_PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_releasePackedArray, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_swigregister", PackedSymmetricMatrix_UpperPackedSymmetricMatrixIntc_swigregister, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_serializationTag", _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_serializationTag, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getSerializationTag", _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getSerializationTag, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create", _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_create, METH_VARARGS, NULL},
	 { (char *)"delete_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64", _wrap_delete_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_assign", _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_assign, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfRows", _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfRows, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfRows", _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfRows, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfColumnValues", _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getBlockOfColumnValues, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues", _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releaseBlockOfColumnValues, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getPackedArray", _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_getPackedArray, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releasePackedArray", _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_releasePackedArray, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_swigregister", PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat64_swigregister, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_serializationTag", _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_serializationTag, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getSerializationTag", _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getSerializationTag, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create", _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_create, METH_VARARGS, NULL},
	 { (char *)"delete_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32", _wrap_delete_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_assign", _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_assign, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfRows", _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfRows, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfRows", _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfRows, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfColumnValues", _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getBlockOfColumnValues, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues", _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releaseBlockOfColumnValues, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getPackedArray", _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_getPackedArray, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releasePackedArray", _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_releasePackedArray, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_swigregister", PackedSymmetricMatrix_LowerPackedSymmetricMatrixFloat32_swigregister, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_serializationTag", _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_serializationTag, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getSerializationTag", _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getSerializationTag, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create", _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_create, METH_VARARGS, NULL},
	 { (char *)"delete_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc", _wrap_delete_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_assign", _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_assign, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfRows", _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfRows, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfRows", _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfRows, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfColumnValues", _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getBlockOfColumnValues, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfColumnValues", _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releaseBlockOfColumnValues, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getPackedArray", _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_getPackedArray, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releasePackedArray", _wrap_PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_releasePackedArray, METH_VARARGS, NULL},
	 { (char *)"PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_swigregister", PackedSymmetricMatrix_LowerPackedSymmetricMatrixIntc_swigregister, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_serializationTag", _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_serializationTag, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getSerializationTag", _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getSerializationTag, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create", _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_create, METH_VARARGS, NULL},
	 { (char *)"delete_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64", _wrap_delete_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_setNumberOfColumns", _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_setNumberOfColumns, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_setNumberOfRows", _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_setNumberOfRows, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_assign", _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_assign, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfRows", _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfRows, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfRows", _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfRows, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfColumnValues", _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getBlockOfColumnValues, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfColumnValues", _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releaseBlockOfColumnValues, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getPackedArray", _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_getPackedArray, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releasePackedArray", _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_releasePackedArray, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_swigregister", PackedTriangularMatrix_UpperPackedTriangularMatrixFloat64_swigregister, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_serializationTag", _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_serializationTag, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getSerializationTag", _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getSerializationTag, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create", _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_create, METH_VARARGS, NULL},
	 { (char *)"delete_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32", _wrap_delete_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_setNumberOfColumns", _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_setNumberOfColumns, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_setNumberOfRows", _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_setNumberOfRows, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_assign", _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_assign, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfRows", _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfRows, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfRows", _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfRows, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfColumnValues", _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getBlockOfColumnValues, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfColumnValues", _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releaseBlockOfColumnValues, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getPackedArray", _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_getPackedArray, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releasePackedArray", _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_releasePackedArray, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_swigregister", PackedTriangularMatrix_UpperPackedTriangularMatrixFloat32_swigregister, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_serializationTag", _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_serializationTag, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getSerializationTag", _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getSerializationTag, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create", _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_create, METH_VARARGS, NULL},
	 { (char *)"delete_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc", _wrap_delete_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_setNumberOfColumns", _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_setNumberOfColumns, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_setNumberOfRows", _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_setNumberOfRows, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_assign", _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_assign, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfRows", _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfRows, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfRows", _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfRows, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfColumnValues", _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getBlockOfColumnValues, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfColumnValues", _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releaseBlockOfColumnValues, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getPackedArray", _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_getPackedArray, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releasePackedArray", _wrap_PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_releasePackedArray, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_swigregister", PackedTriangularMatrix_UpperPackedTriangularMatrixIntc_swigregister, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_serializationTag", _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_serializationTag, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getSerializationTag", _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getSerializationTag, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create", _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_create, METH_VARARGS, NULL},
	 { (char *)"delete_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64", _wrap_delete_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_setNumberOfColumns", _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_setNumberOfColumns, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_setNumberOfRows", _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_setNumberOfRows, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_assign", _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_assign, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfRows", _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfRows, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfRows", _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfRows, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfColumnValues", _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getBlockOfColumnValues, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfColumnValues", _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releaseBlockOfColumnValues, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getPackedArray", _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_getPackedArray, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releasePackedArray", _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_releasePackedArray, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_swigregister", PackedTriangularMatrix_LowerPackedTriangularMatrixFloat64_swigregister, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_serializationTag", _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_serializationTag, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getSerializationTag", _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getSerializationTag, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create", _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_create, METH_VARARGS, NULL},
	 { (char *)"delete_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32", _wrap_delete_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_setNumberOfColumns", _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_setNumberOfColumns, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_setNumberOfRows", _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_setNumberOfRows, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_assign", _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_assign, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfRows", _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfRows, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfRows", _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfRows, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfColumnValues", _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getBlockOfColumnValues, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfColumnValues", _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releaseBlockOfColumnValues, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getPackedArray", _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_getPackedArray, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releasePackedArray", _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_releasePackedArray, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_swigregister", PackedTriangularMatrix_LowerPackedTriangularMatrixFloat32_swigregister, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_serializationTag", _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_serializationTag, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getSerializationTag", _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getSerializationTag, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create", _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_create, METH_VARARGS, NULL},
	 { (char *)"delete_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc", _wrap_delete_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_setNumberOfColumns", _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_setNumberOfColumns, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_setNumberOfRows", _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_setNumberOfRows, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_assign", _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_assign, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfRows", _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfRows, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfRows", _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfRows, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfColumnValues", _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getBlockOfColumnValues, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfColumnValues", _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releaseBlockOfColumnValues, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getPackedArray", _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_getPackedArray, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releasePackedArray", _wrap_PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_releasePackedArray, METH_VARARGS, NULL},
	 { (char *)"PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_swigregister", PackedTriangularMatrix_LowerPackedTriangularMatrixIntc_swigregister, METH_VARARGS, NULL},
	 { (char *)"new_StringDataSource_CSVFeatureManagerFloat64", _wrap_new_StringDataSource_CSVFeatureManagerFloat64, METH_VARARGS, NULL},
	 { (char *)"StringDataSource_CSVFeatureManagerFloat64_setData", _wrap_StringDataSource_CSVFeatureManagerFloat64_setData, METH_VARARGS, NULL},
	 { (char *)"StringDataSource_CSVFeatureManagerFloat64_getData", _wrap_StringDataSource_CSVFeatureManagerFloat64_getData, METH_VARARGS, NULL},
	 { (char *)"StringDataSource_CSVFeatureManagerFloat64_resetData", _wrap_StringDataSource_CSVFeatureManagerFloat64_resetData, METH_VARARGS, NULL},
	 { (char *)"StringDataSource_CSVFeatureManagerFloat64_createDictionaryFromContext", _wrap_StringDataSource_CSVFeatureManagerFloat64_createDictionaryFromContext, METH_VARARGS, NULL},
	 { (char *)"StringDataSource_CSVFeatureManagerFloat64_getStatus", _wrap_StringDataSource_CSVFeatureManagerFloat64_getStatus, METH_VARARGS, NULL},
	 { (char *)"delete_StringDataSource_CSVFeatureManagerFloat64", _wrap_delete_StringDataSource_CSVFeatureManagerFloat64, METH_VARARGS, NULL},
	 { (char *)"StringDataSource_CSVFeatureManagerFloat64_swigregister", StringDataSource_CSVFeatureManagerFloat64_swigregister, METH_VARARGS, NULL},
	 { (char *)"KeyValueDataCollection_serializationTag", _wrap_KeyValueDataCollection_serializationTag, METH_VARARGS, NULL},
	 { (char *)"KeyValueDataCollection_getSerializationTag", _wrap_KeyValueDataCollection_getSerializationTag, METH_VARARGS, NULL},
	 { (char *)"new_KeyValueDataCollection", _wrap_new_KeyValueDataCollection, METH_VARARGS, NULL},
	 { (char *)"delete_KeyValueDataCollection", _wrap_delete_KeyValueDataCollection, METH_VARARGS, NULL},
	 { (char *)"KeyValueDataCollection_swigregister", KeyValueDataCollection_swigregister, METH_VARARGS, NULL},
	 { NULL, NULL, 0, NULL }
};


/* -------- TYPE CONVERSION AND EQUIVALENCE RULES (BEGIN) -------- */

static void *_p_f___p_daal__data_management__interface1__TensorTo_p_f___p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *(*)())  ((daal::data_management::interface1::Tensor *(*)()) x));
}
static void *_p_f___p_daal__data_management__interface1__MatrixT_double_tTo_p_f___p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *(*)()) (daal::data_management::interface1::NumericTable *)(daal::data_management::interface1::HomogenNumericTable< double > *) ((daal::data_management::interface1::Matrix< double > *(*)()) x));
}
static void *_p_f___p_daal__data_management__interface1__HomogenTensorT_int_tTo_p_f___p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *(*)()) (daal::data_management::interface1::Tensor *) ((daal::data_management::interface1::HomogenTensor< int > *(*)()) x));
}
static void *_p_f___p_daal__data_management__interface1__HomogenTensorT_float_tTo_p_f___p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *(*)()) (daal::data_management::interface1::Tensor *) ((daal::data_management::interface1::HomogenTensor< float > *(*)()) x));
}
static void *_p_f___p_daal__data_management__interface1__HomogenTensorT_double_tTo_p_f___p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *(*)()) (daal::data_management::interface1::Tensor *) ((daal::data_management::interface1::HomogenTensor< double > *(*)()) x));
}
static void *_p_f___p_daal__data_management__interface1__MatrixT_int_tTo_p_f___p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *(*)()) (daal::data_management::interface1::NumericTable *)(daal::data_management::interface1::HomogenNumericTable< int > *) ((daal::data_management::interface1::Matrix< int > *(*)()) x));
}
static void *_p_f___p_daal__data_management__interface1__NumericTableTo_p_f___p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *(*)())  ((daal::data_management::interface1::NumericTable *(*)()) x));
}
static void *_p_f___p_daal__data_management__interface1__SOANumericTableTo_p_f___p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *(*)()) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::SOANumericTable *(*)()) x));
}
static void *_p_f___p_daal__data_management__interface1__CSRNumericTableTo_p_f___p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *(*)()) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::CSRNumericTable *(*)()) x));
}
static void *_p_f___p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_tTo_p_f___p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *(*)())  ((daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *(*)()) x));
}
static void *_p_f___p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_tTo_p_f___p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *(*)())  ((daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *(*)()) x));
}
static void *_p_f___p_daal__data_management__interface1__TensorOffsetLayoutTo_p_f___p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *(*)()) (daal::data_management::interface1::TensorLayout *) ((daal::data_management::interface1::TensorOffsetLayout *(*)()) x));
}
static void *_p_f___p_daal__data_management__interface1__DataCollectionTo_p_f___p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *(*)())  ((daal::data_management::interface1::DataCollection *(*)()) x));
}
static void *_p_f___p_daal__data_management__interface1__RowMergedNumericTableTo_p_f___p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *(*)()) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::RowMergedNumericTable *(*)()) x));
}
static void *_p_f___p_daal__data_management__interface1__NumericTableFeatureTo_p_f___p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *(*)())  ((daal::data_management::interface1::NumericTableFeature *(*)()) x));
}
static void *_p_f___p_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_tTo_p_f___p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *(*)())  ((daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > *(*)()) x));
}
static void *_p_f___p_daal__data_management__interface1__TensorLayoutTo_p_f___p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *(*)())  ((daal::data_management::interface1::TensorLayout *(*)()) x));
}
static void *_p_f___p_daal__data_management__interface1__MatrixT_float_tTo_p_f___p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *(*)()) (daal::data_management::interface1::NumericTable *)(daal::data_management::interface1::HomogenNumericTable< float > *) ((daal::data_management::interface1::Matrix< float > *(*)()) x));
}
static void *_p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_tTo_p_f___p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *(*)()) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *(*)()) x));
}
static void *_p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_tTo_p_f___p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *(*)()) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *(*)()) x));
}
static void *_p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_tTo_p_f___p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *(*)()) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *(*)()) x));
}
static void *_p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_tTo_p_f___p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *(*)()) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *(*)()) x));
}
static void *_p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_tTo_p_f___p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *(*)()) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *(*)()) x));
}
static void *_p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_tTo_p_f___p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *(*)()) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *(*)()) x));
}
static void *_p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_tTo_p_f___p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *(*)()) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *(*)()) x));
}
static void *_p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_tTo_p_f___p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *(*)()) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *(*)()) x));
}
static void *_p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_tTo_p_f___p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *(*)()) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *(*)()) x));
}
static void *_p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_tTo_p_f___p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *(*)()) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *(*)()) x));
}
static void *_p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_tTo_p_f___p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *(*)()) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *(*)()) x));
}
static void *_p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_tTo_p_f___p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *(*)()) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *(*)()) x));
}
static void *_p_f___p_daal__data_management__interface1__HomogenNumericTableT_int_tTo_p_f___p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *(*)()) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::HomogenNumericTable< int > *(*)()) x));
}
static void *_p_f___p_daal__data_management__interface1__HomogenNumericTableT_float_tTo_p_f___p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *(*)()) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::HomogenNumericTable< float > *(*)()) x));
}
static void *_p_f___p_daal__data_management__interface1__HomogenNumericTableT_double_tTo_p_f___p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *(*)()) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::HomogenNumericTable< double > *(*)()) x));
}
static void *_p_f___p_daal__data_management__interface1__NpyAOSNumericTableTo_p_f___p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *(*)()) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::NpyAOSNumericTable *(*)()) x));
}
static void *_p_f___p_daal__data_management__interface1__MergedNumericTableTo_p_f___p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *(*)()) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::MergedNumericTable *(*)()) x));
}
static void *_p_f___p_daal__data_management__interface1__DataSourceFeatureTo_p_f___p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *(*)())  ((daal::data_management::interface1::DataSourceFeature *(*)()) x));
}
static void *_p_daal__data_management__interface1__Bzip2CompressionParameterTo_p_daal__data_management__interface1__CompressionParameter(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::CompressionParameter *)  ((daal::data_management::interface1::Bzip2CompressionParameter *) x));
}
static void *_p_daal__data_management__interface1__LzoCompressionParameterTo_p_daal__data_management__interface1__CompressionParameter(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::CompressionParameter *)  ((daal::data_management::interface1::LzoCompressionParameter *) x));
}
static void *_p_daal__data_management__interface1__RleCompressionParameterTo_p_daal__data_management__interface1__CompressionParameter(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::CompressionParameter *)  ((daal::data_management::interface1::RleCompressionParameter *) x));
}
static void *_p_daal__data_management__interface1__ZlibCompressionParameterTo_p_daal__data_management__interface1__CompressionParameter(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::CompressionParameter *)  ((daal::data_management::interface1::ZlibCompressionParameter *) x));
}
static void *_p_daal__data_management__interface1__CSVFeatureManagerTo_p_daal__data_management__interface1__StringRowFeatureManagerIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::StringRowFeatureManagerIface *)  ((daal::data_management::interface1::CSVFeatureManager *) x));
}
static void *_p_daal__data_management__interface1__DataCollectionTo_p_daal__services__CollectionT_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t_t(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::services::Collection< daal::services::SharedPtr< daal::data_management::interface1::SerializationIface > > *)  ((daal::data_management::interface1::DataCollection *) x));
}
static void *_p_daal__data_management__interface1__TensorOffsetLayoutTo_p_daal__data_management__interface1__TensorLayout(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::TensorLayout *)  ((daal::data_management::interface1::TensorOffsetLayout *) x));
}
static void *_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_tTo_p_daal__data_management__interface1__PackedArrayNumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::PackedArrayNumericTableIface *)  ((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *) x));
}
static void *_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_tTo_p_daal__data_management__interface1__PackedArrayNumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::PackedArrayNumericTableIface *)  ((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *) x));
}
static void *_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_tTo_p_daal__data_management__interface1__PackedArrayNumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::PackedArrayNumericTableIface *)  ((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *) x));
}
static void *_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_tTo_p_daal__data_management__interface1__PackedArrayNumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::PackedArrayNumericTableIface *)  ((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *) x));
}
static void *_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_tTo_p_daal__data_management__interface1__PackedArrayNumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::PackedArrayNumericTableIface *)  ((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *) x));
}
static void *_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_tTo_p_daal__data_management__interface1__PackedArrayNumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::PackedArrayNumericTableIface *)  ((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *) x));
}
static void *_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_tTo_p_daal__data_management__interface1__PackedArrayNumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::PackedArrayNumericTableIface *)  ((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *) x));
}
static void *_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_tTo_p_daal__data_management__interface1__PackedArrayNumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::PackedArrayNumericTableIface *)  ((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *) x));
}
static void *_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_tTo_p_daal__data_management__interface1__PackedArrayNumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::PackedArrayNumericTableIface *)  ((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *) x));
}
static void *_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_tTo_p_daal__data_management__interface1__PackedArrayNumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::PackedArrayNumericTableIface *)  ((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *) x));
}
static void *_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_tTo_p_daal__data_management__interface1__PackedArrayNumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::PackedArrayNumericTableIface *)  ((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *) x));
}
static void *_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_tTo_p_daal__data_management__interface1__PackedArrayNumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::PackedArrayNumericTableIface *)  ((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *) x));
}
static void *_p_daal__data_management__interface1__RowMergedNumericTableTo_p_daal__data_management__interface1__NumericTable(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::NumericTable *)  ((daal::data_management::interface1::RowMergedNumericTable *) x));
}
static void *_p_daal__data_management__interface1__CSRNumericTableTo_p_daal__data_management__interface1__NumericTable(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::NumericTable *)  ((daal::data_management::interface1::CSRNumericTable *) x));
}
static void *_p_daal__data_management__interface1__SOANumericTableTo_p_daal__data_management__interface1__NumericTable(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::NumericTable *)  ((daal::data_management::interface1::SOANumericTable *) x));
}
static void *_p_daal__data_management__interface1__MatrixT_float_tTo_p_daal__data_management__interface1__NumericTable(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::NumericTable *) (daal::data_management::interface1::HomogenNumericTable< float > *) ((daal::data_management::interface1::Matrix< float > *) x));
}
static void *_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_tTo_p_daal__data_management__interface1__NumericTable(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::NumericTable *)  ((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *) x));
}
static void *_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_tTo_p_daal__data_management__interface1__NumericTable(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::NumericTable *)  ((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *) x));
}
static void *_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_tTo_p_daal__data_management__interface1__NumericTable(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::NumericTable *)  ((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *) x));
}
static void *_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_tTo_p_daal__data_management__interface1__NumericTable(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::NumericTable *)  ((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *) x));
}
static void *_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_tTo_p_daal__data_management__interface1__NumericTable(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::NumericTable *)  ((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *) x));
}
static void *_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_tTo_p_daal__data_management__interface1__NumericTable(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::NumericTable *)  ((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *) x));
}
static void *_p_daal__data_management__interface1__MatrixT_double_tTo_p_daal__data_management__interface1__NumericTable(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::NumericTable *) (daal::data_management::interface1::HomogenNumericTable< double > *) ((daal::data_management::interface1::Matrix< double > *) x));
}
static void *_p_daal__data_management__interface1__MergedNumericTableTo_p_daal__data_management__interface1__NumericTable(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::NumericTable *)  ((daal::data_management::interface1::MergedNumericTable *) x));
}
static void *_p_daal__data_management__interface1__NpyAOSNumericTableTo_p_daal__data_management__interface1__NumericTable(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::NumericTable *)  ((daal::data_management::interface1::NpyAOSNumericTable *) x));
}
static void *_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_tTo_p_daal__data_management__interface1__NumericTable(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::NumericTable *)  ((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *) x));
}
static void *_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_tTo_p_daal__data_management__interface1__NumericTable(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::NumericTable *)  ((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *) x));
}
static void *_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_tTo_p_daal__data_management__interface1__NumericTable(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::NumericTable *)  ((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *) x));
}
static void *_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_tTo_p_daal__data_management__interface1__NumericTable(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::NumericTable *)  ((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *) x));
}
static void *_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_tTo_p_daal__data_management__interface1__NumericTable(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::NumericTable *)  ((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *) x));
}
static void *_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_tTo_p_daal__data_management__interface1__NumericTable(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::NumericTable *)  ((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *) x));
}
static void *_p_daal__data_management__interface1__MatrixT_int_tTo_p_daal__data_management__interface1__NumericTable(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::NumericTable *) (daal::data_management::interface1::HomogenNumericTable< int > *) ((daal::data_management::interface1::Matrix< int > *) x));
}
static void *_p_daal__data_management__interface1__HomogenNumericTableT_int_tTo_p_daal__data_management__interface1__NumericTable(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::NumericTable *)  ((daal::data_management::interface1::HomogenNumericTable< int > *) x));
}
static void *_p_daal__data_management__interface1__HomogenNumericTableT_float_tTo_p_daal__data_management__interface1__NumericTable(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::NumericTable *)  ((daal::data_management::interface1::HomogenNumericTable< float > *) x));
}
static void *_p_daal__data_management__interface1__HomogenNumericTableT_double_tTo_p_daal__data_management__interface1__NumericTable(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::NumericTable *)  ((daal::data_management::interface1::HomogenNumericTable< double > *) x));
}
static void *_p_daal__data_management__features__interface1__FeatureIdMappingTo_p_daal__data_management__features__interface1__FeatureIdMappingIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::features::interface1::FeatureIdMappingIface *)  ((daal::data_management::features::interface1::FeatureIdMapping *) x));
}
static void *_p_daal__data_management__features__interface1__FeatureIdTo_p_daal__data_management__features__interface1__FeatureIdIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::features::interface1::FeatureIdIface *)  ((daal::data_management::features::interface1::FeatureId *) x));
}
static void *_p_daal__data_management__features__interface1__FeatureIdCollectionTo_p_daal__data_management__features__interface1__FeatureIdCollectionIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::features::interface1::FeatureIdCollectionIface *)  ((daal::data_management::features::interface1::FeatureIdCollection *) x));
}
static void *_p_daal__data_management__features__interface1__FeatureIndicesTo_p_daal__data_management__features__interface1__FeatureIndicesIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::features::interface1::FeatureIndicesIface *)  ((daal::data_management::features::interface1::FeatureIndices *) x));
}
static void *_p_daal__data_management__interface1__TensorLayoutTo_p_daal__data_management__interface1__TensorLayoutIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::TensorLayoutIface *)  ((daal::data_management::interface1::TensorLayout *) x));
}
static void *_p_daal__data_management__interface1__TensorOffsetLayoutTo_p_daal__data_management__interface1__TensorLayoutIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::TensorLayoutIface *) (daal::data_management::interface1::TensorLayout *) ((daal::data_management::interface1::TensorOffsetLayout *) x));
}
static void *_p_daal__data_management__interface1__TensorTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *) (daal::data_management::interface1::SerializationIface *) ((daal::data_management::interface1::Tensor *) x));
}
static void *_p_daal__data_management__interface1__MatrixT_double_tTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *) (daal::data_management::interface1::SerializationIface *)(daal::data_management::interface1::NumericTable *)(daal::data_management::interface1::HomogenNumericTable< double > *) ((daal::data_management::interface1::Matrix< double > *) x));
}
static void *_p_daal__data_management__interface1__CompressedDataArchiveTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *) (daal::data_management::interface1::DataArchiveIface *)(daal::data_management::interface1::DataArchiveImpl *) ((daal::data_management::interface1::CompressedDataArchive *) x));
}
static void *_p_daal__services__interface1__LibraryVersionInfoTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *)  ((daal::services::interface1::LibraryVersionInfo *) x));
}
static void *_p_daal__data_management__interface1__HomogenTensorT_double_tTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *) (daal::data_management::interface1::SerializationIface *)(daal::data_management::interface1::Tensor *) ((daal::data_management::interface1::HomogenTensor< double > *) x));
}
static void *_p_daal__data_management__interface1__HomogenTensorT_float_tTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *) (daal::data_management::interface1::SerializationIface *)(daal::data_management::interface1::Tensor *) ((daal::data_management::interface1::HomogenTensor< float > *) x));
}
static void *_p_daal__data_management__interface1__HomogenTensorT_int_tTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *) (daal::data_management::interface1::SerializationIface *)(daal::data_management::interface1::Tensor *) ((daal::data_management::interface1::HomogenTensor< int > *) x));
}
static void *_p_daal__data_management__interface1__DecompressionStreamTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *)  ((daal::data_management::interface1::DecompressionStream *) x));
}
static void *_p_daal__data_management__interface1__MatrixT_int_tTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *) (daal::data_management::interface1::SerializationIface *)(daal::data_management::interface1::NumericTable *)(daal::data_management::interface1::HomogenNumericTable< int > *) ((daal::data_management::interface1::Matrix< int > *) x));
}
static void *_p_daal__data_management__interface1__CSRNumericTableTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *) (daal::data_management::interface1::SerializationIface *)(daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::CSRNumericTable *) x));
}
static void *_p_daal__data_management__interface1__SOANumericTableTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *) (daal::data_management::interface1::SerializationIface *)(daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::SOANumericTable *) x));
}
static void *_p_daal__data_management__interface1__NumericTableTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *) (daal::data_management::interface1::SerializationIface *) ((daal::data_management::interface1::NumericTable *) x));
}
static void *_p_daal__data_management__interface1__TensorOffsetLayoutTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *) (daal::data_management::interface1::SerializationIface *)(daal::data_management::interface1::TensorLayout *) ((daal::data_management::interface1::TensorOffsetLayout *) x));
}
static void *_p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_tTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *) (daal::data_management::interface1::SerializationIface *) ((daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *) x));
}
static void *_p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_tTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *) (daal::data_management::interface1::SerializationIface *) ((daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *) x));
}
static void *_p_daal__data_management__interface1__InputDataArchiveTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *)  ((daal::data_management::interface1::InputDataArchive *) x));
}
static void *_p_daal__data_management__interface1__DataCollectionTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *) (daal::data_management::interface1::SerializationIface *) ((daal::data_management::interface1::DataCollection *) x));
}
static void *_p_daal__data_management__interface1__DataBlockTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *) (daal::data_management::interface1::DataBlockIface *) ((daal::data_management::interface1::DataBlock *) x));
}
static void *_p_daal__data_management__interface1__OutputDataArchiveTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *)  ((daal::data_management::interface1::OutputDataArchive *) x));
}
static void *_p_daal__data_management__interface1__DataBlockIfaceTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *)  ((daal::data_management::interface1::DataBlockIface *) x));
}
static void *_p_daal__data_management__interface1__RowMergedNumericTableTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *) (daal::data_management::interface1::SerializationIface *)(daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::RowMergedNumericTable *) x));
}
static void *_p_daal__data_management__interface1__DataArchiveTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *) (daal::data_management::interface1::DataArchiveIface *)(daal::data_management::interface1::DataArchiveImpl *) ((daal::data_management::interface1::DataArchive *) x));
}
static void *_p_daal__data_management__interface1__NumericTableFeatureTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *) (daal::data_management::interface1::SerializationIface *) ((daal::data_management::interface1::NumericTableFeature *) x));
}
static void *_p_daal__data_management__interface1__DecompressedDataArchiveTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *) (daal::data_management::interface1::DataArchiveIface *)(daal::data_management::interface1::DataArchiveImpl *) ((daal::data_management::interface1::DecompressedDataArchive *) x));
}
static void *_p_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_tTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *) (daal::data_management::interface1::SerializationIface *) ((daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > *) x));
}
static void *_p_daal__data_management__interface1__CompressionStreamTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *)  ((daal::data_management::interface1::CompressionStream *) x));
}
static void *_p_daal__data_management__interface1__TensorLayoutTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *) (daal::data_management::interface1::SerializationIface *) ((daal::data_management::interface1::TensorLayout *) x));
}
static void *_p_daal__data_management__features__interface1__FeatureIndicesTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *)  ((daal::data_management::features::interface1::FeatureIndices *) x));
}
static void *_p_daal__data_management__features__interface1__FeatureIdCollectionTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *)  ((daal::data_management::features::interface1::FeatureIdCollection *) x));
}
static void *_p_daal__data_management__features__interface1__FeatureIdTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *)  ((daal::data_management::features::interface1::FeatureId *) x));
}
static void *_p_daal__data_management__features__interface1__FeatureIdMappingTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *)  ((daal::data_management::features::interface1::FeatureIdMapping *) x));
}
static void *_p_daal__data_management__interface1__MatrixT_float_tTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *) (daal::data_management::interface1::SerializationIface *)(daal::data_management::interface1::NumericTable *)(daal::data_management::interface1::HomogenNumericTable< float > *) ((daal::data_management::interface1::Matrix< float > *) x));
}
static void *_p_daal__data_management__interface1__SerializationIfaceTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *)  ((daal::data_management::interface1::SerializationIface *) x));
}
static void *_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_tTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *) (daal::data_management::interface1::SerializationIface *)(daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *) x));
}
static void *_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_tTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *) (daal::data_management::interface1::SerializationIface *)(daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *) x));
}
static void *_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_tTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *) (daal::data_management::interface1::SerializationIface *)(daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *) x));
}
static void *_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_tTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *) (daal::data_management::interface1::SerializationIface *)(daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *) x));
}
static void *_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_tTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *) (daal::data_management::interface1::SerializationIface *)(daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *) x));
}
static void *_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_tTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *) (daal::data_management::interface1::SerializationIface *)(daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *) x));
}
static void *_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_tTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *) (daal::data_management::interface1::SerializationIface *)(daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *) x));
}
static void *_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_tTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *) (daal::data_management::interface1::SerializationIface *)(daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *) x));
}
static void *_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_tTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *) (daal::data_management::interface1::SerializationIface *)(daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *) x));
}
static void *_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_tTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *) (daal::data_management::interface1::SerializationIface *)(daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *) x));
}
static void *_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_tTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *) (daal::data_management::interface1::SerializationIface *)(daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *) x));
}
static void *_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_tTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *) (daal::data_management::interface1::SerializationIface *)(daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *) x));
}
static void *_p_daal__data_management__modifiers__csv__interface1__ConfigTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *)  ((daal::data_management::modifiers::csv::interface1::Config *) x));
}
static void *_p_daal__data_management__modifiers__csv__interface1__ContextTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *)  ((daal::data_management::modifiers::csv::interface1::Context *) x));
}
static void *_p_daal__data_management__modifiers__csv__interface1__FeatureModifierTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *)  ((daal::data_management::modifiers::csv::interface1::FeatureModifier *) x));
}
static void *_p_daal__data_management__modifiers__csv__interface1__PyFeatureModifierTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *) (daal::data_management::modifiers::csv::interface1::FeatureModifier *) ((daal::data_management::modifiers::csv::interface1::PyFeatureModifier *) x));
}
static void *_p_daal__services__interface1__EnvironmentTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *)  ((daal::services::interface1::Environment *) x));
}
static void *_p_daal__data_management__interface1__DataArchiveImplTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *) (daal::data_management::interface1::DataArchiveIface *) ((daal::data_management::interface1::DataArchiveImpl *) x));
}
static void *_p_daal__data_management__interface1__MergedNumericTableTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *) (daal::data_management::interface1::SerializationIface *)(daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::MergedNumericTable *) x));
}
static void *_p_daal__data_management__interface1__NpyAOSNumericTableTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *) (daal::data_management::interface1::SerializationIface *)(daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::NpyAOSNumericTable *) x));
}
static void *_p_daal__data_management__interface1__HomogenNumericTableT_double_tTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *) (daal::data_management::interface1::SerializationIface *)(daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::HomogenNumericTable< double > *) x));
}
static void *_p_daal__data_management__interface1__HomogenNumericTableT_float_tTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *) (daal::data_management::interface1::SerializationIface *)(daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::HomogenNumericTable< float > *) x));
}
static void *_p_daal__data_management__interface1__HomogenNumericTableT_int_tTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *) (daal::data_management::interface1::SerializationIface *)(daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::HomogenNumericTable< int > *) x));
}
static void *_p_daal__data_management__interface1__DataArchiveIfaceTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *)  ((daal::data_management::interface1::DataArchiveIface *) x));
}
static void *_p_daal__data_management__interface1__DataSourceFeatureTo_p_daal__Base(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::Base *) (daal::data_management::interface1::SerializationIface *) ((daal::data_management::interface1::DataSourceFeature *) x));
}
static void *_p_daal__data_management__interface1__HomogenTensorT_double_tTo_p_daal__data_management__interface1__DenseTensorIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DenseTensorIface *) (daal::data_management::interface1::Tensor *) ((daal::data_management::interface1::HomogenTensor< double > *) x));
}
static void *_p_daal__data_management__interface1__HomogenTensorT_float_tTo_p_daal__data_management__interface1__DenseTensorIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DenseTensorIface *) (daal::data_management::interface1::Tensor *) ((daal::data_management::interface1::HomogenTensor< float > *) x));
}
static void *_p_daal__data_management__interface1__HomogenTensorT_int_tTo_p_daal__data_management__interface1__DenseTensorIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DenseTensorIface *) (daal::data_management::interface1::Tensor *) ((daal::data_management::interface1::HomogenTensor< int > *) x));
}
static void *_p_daal__data_management__interface1__TensorTo_p_daal__data_management__interface1__DenseTensorIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DenseTensorIface *)  ((daal::data_management::interface1::Tensor *) x));
}
static void *_p_daal__data_management__interface1__RowMergedNumericTableTo_p_daal__data_management__interface1__DenseNumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DenseNumericTableIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::RowMergedNumericTable *) x));
}
static void *_p_daal__data_management__interface1__CSRNumericTableTo_p_daal__data_management__interface1__DenseNumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DenseNumericTableIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::CSRNumericTable *) x));
}
static void *_p_daal__data_management__interface1__SOANumericTableTo_p_daal__data_management__interface1__DenseNumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DenseNumericTableIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::SOANumericTable *) x));
}
static void *_p_daal__data_management__interface1__NumericTableTo_p_daal__data_management__interface1__DenseNumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DenseNumericTableIface *)  ((daal::data_management::interface1::NumericTable *) x));
}
static void *_p_daal__data_management__interface1__MatrixT_float_tTo_p_daal__data_management__interface1__DenseNumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DenseNumericTableIface *) (daal::data_management::interface1::NumericTable *)(daal::data_management::interface1::HomogenNumericTable< float > *) ((daal::data_management::interface1::Matrix< float > *) x));
}
static void *_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_tTo_p_daal__data_management__interface1__DenseNumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DenseNumericTableIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *) x));
}
static void *_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_tTo_p_daal__data_management__interface1__DenseNumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DenseNumericTableIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *) x));
}
static void *_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_tTo_p_daal__data_management__interface1__DenseNumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DenseNumericTableIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *) x));
}
static void *_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_tTo_p_daal__data_management__interface1__DenseNumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DenseNumericTableIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *) x));
}
static void *_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_tTo_p_daal__data_management__interface1__DenseNumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DenseNumericTableIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *) x));
}
static void *_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_tTo_p_daal__data_management__interface1__DenseNumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DenseNumericTableIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *) x));
}
static void *_p_daal__data_management__interface1__MatrixT_double_tTo_p_daal__data_management__interface1__DenseNumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DenseNumericTableIface *) (daal::data_management::interface1::NumericTable *)(daal::data_management::interface1::HomogenNumericTable< double > *) ((daal::data_management::interface1::Matrix< double > *) x));
}
static void *_p_daal__data_management__interface1__MergedNumericTableTo_p_daal__data_management__interface1__DenseNumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DenseNumericTableIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::MergedNumericTable *) x));
}
static void *_p_daal__data_management__interface1__NpyAOSNumericTableTo_p_daal__data_management__interface1__DenseNumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DenseNumericTableIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::NpyAOSNumericTable *) x));
}
static void *_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_tTo_p_daal__data_management__interface1__DenseNumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DenseNumericTableIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *) x));
}
static void *_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_tTo_p_daal__data_management__interface1__DenseNumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DenseNumericTableIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *) x));
}
static void *_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_tTo_p_daal__data_management__interface1__DenseNumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DenseNumericTableIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *) x));
}
static void *_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_tTo_p_daal__data_management__interface1__DenseNumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DenseNumericTableIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *) x));
}
static void *_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_tTo_p_daal__data_management__interface1__DenseNumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DenseNumericTableIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *) x));
}
static void *_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_tTo_p_daal__data_management__interface1__DenseNumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DenseNumericTableIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *) x));
}
static void *_p_daal__data_management__interface1__MatrixT_int_tTo_p_daal__data_management__interface1__DenseNumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DenseNumericTableIface *) (daal::data_management::interface1::NumericTable *)(daal::data_management::interface1::HomogenNumericTable< int > *) ((daal::data_management::interface1::Matrix< int > *) x));
}
static void *_p_daal__data_management__interface1__HomogenNumericTableT_int_tTo_p_daal__data_management__interface1__DenseNumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DenseNumericTableIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::HomogenNumericTable< int > *) x));
}
static void *_p_daal__data_management__interface1__HomogenNumericTableT_float_tTo_p_daal__data_management__interface1__DenseNumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DenseNumericTableIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::HomogenNumericTable< float > *) x));
}
static void *_p_daal__data_management__interface1__HomogenNumericTableT_double_tTo_p_daal__data_management__interface1__DenseNumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DenseNumericTableIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::HomogenNumericTable< double > *) x));
}
static void *_p_daal__data_management__interface1__DataBlockTo_p_daal__data_management__interface1__DataBlockIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DataBlockIface *)  ((daal::data_management::interface1::DataBlock *) x));
}
static void *_p_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_tTo_p_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< double >,double > *) (daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *) ((daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > *) x));
}
static void *_p_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_tTo_p_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< double >,double > *)  ((daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *) x));
}
static void *_p_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_tTo_p_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< double >,double > *) (daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *) ((daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > *) x));
}
static void *_p_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_tTo_p_daal__data_management__interface1__CompressionIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::CompressionIface *) (daal::data_management::interface1::Compression *)(daal::data_management::interface1::CompressorImpl *) ((daal::data_management::interface1::Compressor< daal::data_management::bzip2 > *) x));
}
static void *_p_daal__data_management__interface1__CompressorT_daal__data_management__lzo_tTo_p_daal__data_management__interface1__CompressionIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::CompressionIface *) (daal::data_management::interface1::Compression *)(daal::data_management::interface1::CompressorImpl *) ((daal::data_management::interface1::Compressor< daal::data_management::lzo > *) x));
}
static void *_p_daal__data_management__interface1__CompressorT_daal__data_management__rle_tTo_p_daal__data_management__interface1__CompressionIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::CompressionIface *) (daal::data_management::interface1::Compression *)(daal::data_management::interface1::CompressorImpl *) ((daal::data_management::interface1::Compressor< daal::data_management::rle > *) x));
}
static void *_p_daal__data_management__interface1__CompressorT_daal__data_management__zlib_tTo_p_daal__data_management__interface1__CompressionIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::CompressionIface *) (daal::data_management::interface1::Compression *)(daal::data_management::interface1::CompressorImpl *) ((daal::data_management::interface1::Compressor< daal::data_management::zlib > *) x));
}
static void *_p_daal__data_management__interface1__DecompressorImplTo_p_daal__data_management__interface1__CompressionIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::CompressionIface *) (daal::data_management::interface1::Compression *) ((daal::data_management::interface1::DecompressorImpl *) x));
}
static void *_p_daal__data_management__interface1__CompressorImplTo_p_daal__data_management__interface1__CompressionIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::CompressionIface *) (daal::data_management::interface1::Compression *) ((daal::data_management::interface1::CompressorImpl *) x));
}
static void *_p_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_tTo_p_daal__data_management__interface1__CompressionIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::CompressionIface *) (daal::data_management::interface1::Compression *)(daal::data_management::interface1::DecompressorImpl *) ((daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > *) x));
}
static void *_p_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_tTo_p_daal__data_management__interface1__CompressionIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::CompressionIface *) (daal::data_management::interface1::Compression *)(daal::data_management::interface1::DecompressorImpl *) ((daal::data_management::interface1::Decompressor< daal::data_management::lzo > *) x));
}
static void *_p_daal__data_management__interface1__DecompressorT_daal__data_management__rle_tTo_p_daal__data_management__interface1__CompressionIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::CompressionIface *) (daal::data_management::interface1::Compression *)(daal::data_management::interface1::DecompressorImpl *) ((daal::data_management::interface1::Decompressor< daal::data_management::rle > *) x));
}
static void *_p_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_tTo_p_daal__data_management__interface1__CompressionIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::CompressionIface *) (daal::data_management::interface1::Compression *)(daal::data_management::interface1::DecompressorImpl *) ((daal::data_management::interface1::Decompressor< daal::data_management::zlib > *) x));
}
static void *_p_daal__data_management__interface1__CompressionTo_p_daal__data_management__interface1__CompressionIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::CompressionIface *)  ((daal::data_management::interface1::Compression *) x));
}
static void *_p_daal__data_management__interface1__CSRNumericTableTo_p_daal__data_management__interface1__CSRNumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::CSRNumericTableIface *)  ((daal::data_management::interface1::CSRNumericTable *) x));
}
static void *_p_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_tTo_p_daal__data_management__interface1__DataSourceIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DataSourceIface *) (daal::data_management::interface1::DataSource *)(daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< double >,double > *)(daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *) ((daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > *) x));
}
static void *_p_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_tTo_p_daal__data_management__interface1__DataSourceIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DataSourceIface *) (daal::data_management::interface1::DataSource *)(daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< double >,double > *) ((daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *) x));
}
static void *_p_daal__data_management__interface1__DataSourceTo_p_daal__data_management__interface1__DataSourceIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DataSourceIface *)  ((daal::data_management::interface1::DataSource *) x));
}
static void *_p_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_tTo_p_daal__data_management__interface1__DataSourceIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DataSourceIface *) (daal::data_management::interface1::DataSource *) ((daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< double >,double > *) x));
}
static void *_p_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_float_t_double_tTo_p_daal__data_management__interface1__DataSourceIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DataSourceIface *) (daal::data_management::interface1::DataSource *) ((daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< float >,double > *) x));
}
static void *_p_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_int_t_double_tTo_p_daal__data_management__interface1__DataSourceIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DataSourceIface *) (daal::data_management::interface1::DataSource *) ((daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< int >,double > *) x));
}
static void *_p_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_tTo_p_daal__data_management__interface1__DataSourceIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DataSourceIface *) (daal::data_management::interface1::DataSource *)(daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< double >,double > *)(daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *) ((daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > *) x));
}
static void *_p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_tTo_p_daal__data_management__interface1__DictionaryIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DictionaryIface *)  ((daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *) x));
}
static void *_p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_tTo_p_daal__data_management__interface1__DictionaryIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DictionaryIface *)  ((daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *) x));
}
static void *_p_daal__data_management__interface1__RowMergedNumericTableTo_p_daal__data_management__interface1__NumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::NumericTableIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::RowMergedNumericTable *) x));
}
static void *_p_daal__data_management__interface1__CSRNumericTableTo_p_daal__data_management__interface1__NumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::NumericTableIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::CSRNumericTable *) x));
}
static void *_p_daal__data_management__interface1__SOANumericTableTo_p_daal__data_management__interface1__NumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::NumericTableIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::SOANumericTable *) x));
}
static void *_p_daal__data_management__interface1__NumericTableTo_p_daal__data_management__interface1__NumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::NumericTableIface *)  ((daal::data_management::interface1::NumericTable *) x));
}
static void *_p_daal__data_management__interface1__MatrixT_float_tTo_p_daal__data_management__interface1__NumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::NumericTableIface *) (daal::data_management::interface1::NumericTable *)(daal::data_management::interface1::HomogenNumericTable< float > *) ((daal::data_management::interface1::Matrix< float > *) x));
}
static void *_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_tTo_p_daal__data_management__interface1__NumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::NumericTableIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *) x));
}
static void *_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_tTo_p_daal__data_management__interface1__NumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::NumericTableIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *) x));
}
static void *_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_tTo_p_daal__data_management__interface1__NumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::NumericTableIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *) x));
}
static void *_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_tTo_p_daal__data_management__interface1__NumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::NumericTableIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *) x));
}
static void *_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_tTo_p_daal__data_management__interface1__NumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::NumericTableIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *) x));
}
static void *_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_tTo_p_daal__data_management__interface1__NumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::NumericTableIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *) x));
}
static void *_p_daal__data_management__interface1__MatrixT_double_tTo_p_daal__data_management__interface1__NumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::NumericTableIface *) (daal::data_management::interface1::NumericTable *)(daal::data_management::interface1::HomogenNumericTable< double > *) ((daal::data_management::interface1::Matrix< double > *) x));
}
static void *_p_daal__data_management__interface1__MergedNumericTableTo_p_daal__data_management__interface1__NumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::NumericTableIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::MergedNumericTable *) x));
}
static void *_p_daal__data_management__interface1__NpyAOSNumericTableTo_p_daal__data_management__interface1__NumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::NumericTableIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::NpyAOSNumericTable *) x));
}
static void *_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_tTo_p_daal__data_management__interface1__NumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::NumericTableIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *) x));
}
static void *_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_tTo_p_daal__data_management__interface1__NumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::NumericTableIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *) x));
}
static void *_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_tTo_p_daal__data_management__interface1__NumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::NumericTableIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *) x));
}
static void *_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_tTo_p_daal__data_management__interface1__NumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::NumericTableIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *) x));
}
static void *_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_tTo_p_daal__data_management__interface1__NumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::NumericTableIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *) x));
}
static void *_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_tTo_p_daal__data_management__interface1__NumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::NumericTableIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *) x));
}
static void *_p_daal__data_management__interface1__MatrixT_int_tTo_p_daal__data_management__interface1__NumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::NumericTableIface *) (daal::data_management::interface1::NumericTable *)(daal::data_management::interface1::HomogenNumericTable< int > *) ((daal::data_management::interface1::Matrix< int > *) x));
}
static void *_p_daal__data_management__interface1__HomogenNumericTableT_int_tTo_p_daal__data_management__interface1__NumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::NumericTableIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::HomogenNumericTable< int > *) x));
}
static void *_p_daal__data_management__interface1__HomogenNumericTableT_float_tTo_p_daal__data_management__interface1__NumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::NumericTableIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::HomogenNumericTable< float > *) x));
}
static void *_p_daal__data_management__interface1__HomogenNumericTableT_double_tTo_p_daal__data_management__interface1__NumericTableIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::NumericTableIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::HomogenNumericTable< double > *) x));
}
static void *_p_daal__data_management__interface1__CategoricalFeatureDictionaryTo_p_std__mapT_std__string_std__pairT_int_int_t_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__pairT_int_int_t_t_t_t(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((std::map< std::string,std::pair< int,int >,std::less< std::string >,std::allocator< std::pair< std::string const,std::pair< int,int > > > > *)  ((daal::data_management::interface1::CategoricalFeatureDictionary *) x));
}
static void *_p_daal__data_management__interface1__DataArchiveImplTo_p_daal__data_management__interface1__DataArchiveIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DataArchiveIface *)  ((daal::data_management::interface1::DataArchiveImpl *) x));
}
static void *_p_daal__data_management__interface1__DataArchiveTo_p_daal__data_management__interface1__DataArchiveIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DataArchiveIface *) (daal::data_management::interface1::DataArchiveImpl *) ((daal::data_management::interface1::DataArchive *) x));
}
static void *_p_daal__data_management__interface1__CompressedDataArchiveTo_p_daal__data_management__interface1__DataArchiveIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DataArchiveIface *) (daal::data_management::interface1::DataArchiveImpl *) ((daal::data_management::interface1::CompressedDataArchive *) x));
}
static void *_p_daal__data_management__interface1__DecompressedDataArchiveTo_p_daal__data_management__interface1__DataArchiveIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DataArchiveIface *) (daal::data_management::interface1::DataArchiveImpl *) ((daal::data_management::interface1::DecompressedDataArchive *) x));
}
static void *_p_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_tTo_p_daal__data_management__interface1__KeyValueCollectionT_daal__data_management__interface1__SerializationIface_t(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > *)  ((daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > *) x));
}
static void *_p_daal__data_management__interface1__DataArchiveTo_p_daal__data_management__interface1__DataArchiveImpl(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DataArchiveImpl *)  ((daal::data_management::interface1::DataArchive *) x));
}
static void *_p_daal__data_management__interface1__CompressedDataArchiveTo_p_daal__data_management__interface1__DataArchiveImpl(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DataArchiveImpl *)  ((daal::data_management::interface1::CompressedDataArchive *) x));
}
static void *_p_daal__data_management__interface1__DecompressedDataArchiveTo_p_daal__data_management__interface1__DataArchiveImpl(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DataArchiveImpl *)  ((daal::data_management::interface1::DecompressedDataArchive *) x));
}
static void *_p_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_tTo_p_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *)  ((daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > *) x));
}
static void *_p_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_tTo_p_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *)  ((daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > *) x));
}
static void *_p_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_tTo_p_daal__data_management__interface1__DataSource(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DataSource *) (daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< double >,double > *)(daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *) ((daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > *) x));
}
static void *_p_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_tTo_p_daal__data_management__interface1__DataSource(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DataSource *) (daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< double >,double > *) ((daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *) x));
}
static void *_p_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_tTo_p_daal__data_management__interface1__DataSource(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DataSource *)  ((daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< double >,double > *) x));
}
static void *_p_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_float_t_double_tTo_p_daal__data_management__interface1__DataSource(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DataSource *)  ((daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< float >,double > *) x));
}
static void *_p_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_int_t_double_tTo_p_daal__data_management__interface1__DataSource(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DataSource *)  ((daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< int >,double > *) x));
}
static void *_p_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_tTo_p_daal__data_management__interface1__DataSource(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DataSource *) (daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< double >,double > *)(daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *) ((daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > *) x));
}
static void *_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__PyFeatureModifier_tTo_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifier_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::FeatureModifier >(*(daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::PyFeatureModifier > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifier_tTo_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifierIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::FeatureModifierIface >(*(daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::FeatureModifier > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__PyFeatureModifier_tTo_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifierIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::FeatureModifierIface >(*(daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::PyFeatureModifier > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Context_tTo_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__ContextIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::ContextIface >(*(daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::Context > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DictionaryIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DictionaryIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseTensorIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Tensor > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseTensorIface >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseTensorIface >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseTensorIface >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::RowMergedNumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::MergedNumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::SOANumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::NpyAOSNumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::NumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DecompressorImpl >(*(daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DecompressorImpl >(*(daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::lzo > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__rle_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DecompressorImpl >(*(daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::rle > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DecompressorImpl >(*(daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::zlib > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface >(*(daal::services::SharedPtr< daal::data_management::interface1::DataSource > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface >(*(daal::services::SharedPtr< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< double >,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_float_t_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface >(*(daal::services::SharedPtr< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< float >,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_int_t_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface >(*(daal::services::SharedPtr< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< int >,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface >(*(daal::services::SharedPtr< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface >(*(daal::services::SharedPtr< daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface >(*(daal::services::SharedPtr< daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DataSource >(*(daal::services::SharedPtr< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< double >,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_float_t_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DataSource >(*(daal::services::SharedPtr< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< float >,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_int_t_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DataSource >(*(daal::services::SharedPtr< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< int >,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DataSource >(*(daal::services::SharedPtr< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DataSource >(*(daal::services::SharedPtr< daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DataSource >(*(daal::services::SharedPtr< daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlockIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DataBlockIface >(*(daal::services::SharedPtr< daal::data_management::interface1::DataBlock > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchive_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveImpl_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DataArchiveImpl >(*(daal::services::SharedPtr< daal::data_management::interface1::DataArchive > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressedDataArchive_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveImpl_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DataArchiveImpl >(*(daal::services::SharedPtr< daal::data_management::interface1::CompressedDataArchive > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressedDataArchive_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveImpl_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DataArchiveImpl >(*(daal::services::SharedPtr< daal::data_management::interface1::DecompressedDataArchive > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveImpl_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DataArchiveIface >(*(daal::services::SharedPtr< daal::data_management::interface1::DataArchiveImpl > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchive_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DataArchiveIface >(*(daal::services::SharedPtr< daal::data_management::interface1::DataArchive > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressedDataArchive_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DataArchiveIface >(*(daal::services::SharedPtr< daal::data_management::interface1::CompressedDataArchive > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressedDataArchive_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DataArchiveIface >(*(daal::services::SharedPtr< daal::data_management::interface1::DecompressedDataArchive > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::CompressorImpl >(*(daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::bzip2 > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__lzo_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::CompressorImpl >(*(daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::lzo > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__rle_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::CompressorImpl >(*(daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::rle > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__zlib_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::CompressorImpl >(*(daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::zlib > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::CompressionIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Compression > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::CompressionIface >(*(daal::services::SharedPtr< daal::data_management::interface1::CompressorImpl > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::CompressionIface >(*(daal::services::SharedPtr< daal::data_management::interface1::DecompressorImpl > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::CompressionIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::bzip2 > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__lzo_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::CompressionIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::lzo > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__rle_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::CompressionIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::rle > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__zlib_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::CompressionIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::zlib > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::CompressionIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::CompressionIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::lzo > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__rle_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::CompressionIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::rle > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::CompressionIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::zlib > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::Compression >(*(daal::services::SharedPtr< daal::data_management::interface1::CompressorImpl > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::Compression >(*(daal::services::SharedPtr< daal::data_management::interface1::DecompressorImpl > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::Compression >(*(daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::bzip2 > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__lzo_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::Compression >(*(daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::lzo > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__rle_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::Compression >(*(daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::rle > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__zlib_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::Compression >(*(daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::zlib > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::Compression >(*(daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::Compression >(*(daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::lzo > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__rle_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::Compression >(*(daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::rle > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::Compression >(*(daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::zlib > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTable >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTable >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTable >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTable >(*(daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTable >(*(daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTable >(*(daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTable >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTable >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTable >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTable >(*(daal::services::SharedPtr< daal::data_management::interface1::RowMergedNumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTable >(*(daal::services::SharedPtr< daal::data_management::interface1::MergedNumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTable >(*(daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTable >(*(daal::services::SharedPtr< daal::data_management::interface1::SOANumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTable >(*(daal::services::SharedPtr< daal::data_management::interface1::NpyAOSNumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTable >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTable >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTable >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTable >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTable >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTable >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTable >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTable >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTable >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::RowMergedNumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::MergedNumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::SOANumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::NpyAOSNumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::NumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::PackedArrayNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::PackedArrayNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::PackedArrayNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::PackedArrayNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::PackedArrayNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::PackedArrayNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::PackedArrayNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::PackedArrayNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::PackedArrayNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::PackedArrayNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::PackedArrayNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::PackedArrayNumericTableIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DataCollection_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::DataCollection > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::NumericTableFeature > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::NumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayout_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::TensorLayout > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Tensor > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::NpyAOSNumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::SOANumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::MergedNumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::RowMergedNumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::SerializationIface >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CSVFeatureManager_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__StringRowFeatureManagerIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::StringRowFeatureManagerIface >(*(daal::services::SharedPtr< daal::data_management::interface1::CSVFeatureManager > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::Tensor >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::Tensor >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::Tensor >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::TensorIface >(*(daal::services::SharedPtr< daal::data_management::interface1::Tensor > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::TensorIface >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::TensorIface >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::TensorIface >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayout_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayoutIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::TensorLayoutIface >(*(daal::services::SharedPtr< daal::data_management::interface1::TensorLayout > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayoutIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::TensorLayoutIface >(*(daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayout_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::TensorLayout >(*(daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > >(*(daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > >(*(daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > >(*(daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > >(*(daal::services::SharedPtr< daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< double >,double > >(*(daal::services::SharedPtr< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< double >,double > >(*(daal::services::SharedPtr< daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< double >,double > >(*(daal::services::SharedPtr< daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > >(*(daal::services::SharedPtr< daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > >(*(daal::services::SharedPtr< daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdMapping_tTo_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdMappingIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::features::interface1::FeatureIdMappingIface >(*(daal::services::SharedPtr< daal::data_management::features::interface1::FeatureIdMapping > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureId_tTo_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::features::interface1::FeatureIdIface >(*(daal::services::SharedPtr< daal::data_management::features::interface1::FeatureId > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdCollection_tTo_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdCollectionIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::features::interface1::FeatureIdCollectionIface >(*(daal::services::SharedPtr< daal::data_management::features::interface1::FeatureIdCollection > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndices_tTo_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndicesIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::features::interface1::FeatureIndicesIface >(*(daal::services::SharedPtr< daal::data_management::features::interface1::FeatureIndices > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__ConfigIface_tTo_p_daal__services__SharedPtrT_daal__data_management__modifiers__interface1__ConfigIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::modifiers::interface1::ConfigIface >(*(daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::ConfigIface > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Config_tTo_p_daal__services__SharedPtrT_daal__data_management__modifiers__interface1__ConfigIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::modifiers::interface1::ConfigIface >(*(daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::Config > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__ContextIface_tTo_p_daal__services__SharedPtrT_daal__data_management__modifiers__interface1__ContextIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::modifiers::interface1::ContextIface >(*(daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::ContextIface > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Context_tTo_p_daal__services__SharedPtrT_daal__data_management__modifiers__interface1__ContextIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::modifiers::interface1::ContextIface >(*(daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::Context > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Config_tTo_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__ConfigIface_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::ConfigIface >(*(daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::Config > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndices_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::features::interface1::FeatureIndices > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdCollection_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::features::interface1::FeatureIdCollection > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureId_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::features::interface1::FeatureId > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdMapping_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::features::interface1::FeatureIdMapping > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::RowMergedNumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::MergedNumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::SOANumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::NpyAOSNumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::Tensor > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayout_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::TensorLayout > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::NumericTable > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::NumericTableFeature > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DataCollection_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::DataCollection > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__OutputDataArchive_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::OutputDataArchive > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__InputDataArchive_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::InputDataArchive > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressedDataArchive_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::DecompressedDataArchive > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressedDataArchive_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::CompressedDataArchive > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::SerializationIface > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlockIface_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::DataBlockIface > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::DataBlock > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Config_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::Config > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Context_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::Context > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifier_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::FeatureModifier > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__PyFeatureModifier_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::PyFeatureModifier > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionStream_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::CompressionStream > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressionStream_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::DecompressionStream > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::DataArchiveIface > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveImpl_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::DataArchiveImpl > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchive_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::DataArchive > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__services__interface1__LibraryVersionInfo_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::services::interface1::LibraryVersionInfo > *)x);
}
static void *_p_daal__services__SharedPtrT_daal__services__interface1__Environment_tTo_p_daal__services__SharedPtrT_daal__Base_t(void *x, int *newmemory) {
    *newmemory = SWIG_CAST_NEW_MEMORY;
    return (void *) new daal::services::SharedPtr< daal::Base >(*(daal::services::SharedPtr< daal::services::interface1::Environment > *)x);
}
static void *_p_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_tTo_p_daal__data_management__interface1__DecompressorImpl(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DecompressorImpl *)  ((daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > *) x));
}
static void *_p_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_tTo_p_daal__data_management__interface1__DecompressorImpl(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DecompressorImpl *)  ((daal::data_management::interface1::Decompressor< daal::data_management::lzo > *) x));
}
static void *_p_daal__data_management__interface1__DecompressorT_daal__data_management__rle_tTo_p_daal__data_management__interface1__DecompressorImpl(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DecompressorImpl *)  ((daal::data_management::interface1::Decompressor< daal::data_management::rle > *) x));
}
static void *_p_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_tTo_p_daal__data_management__interface1__DecompressorImpl(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::DecompressorImpl *)  ((daal::data_management::interface1::Decompressor< daal::data_management::zlib > *) x));
}
static void *_p_daal__data_management__interface1__TensorTo_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *)  ((daal::data_management::interface1::Tensor *) x));
}
static void *_p_daal__data_management__interface1__MatrixT_double_tTo_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *) (daal::data_management::interface1::NumericTable *)(daal::data_management::interface1::HomogenNumericTable< double > *) ((daal::data_management::interface1::Matrix< double > *) x));
}
static void *_p_daal__data_management__interface1__HomogenTensorT_int_tTo_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *) (daal::data_management::interface1::Tensor *) ((daal::data_management::interface1::HomogenTensor< int > *) x));
}
static void *_p_daal__data_management__interface1__HomogenTensorT_float_tTo_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *) (daal::data_management::interface1::Tensor *) ((daal::data_management::interface1::HomogenTensor< float > *) x));
}
static void *_p_daal__data_management__interface1__HomogenTensorT_double_tTo_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *) (daal::data_management::interface1::Tensor *) ((daal::data_management::interface1::HomogenTensor< double > *) x));
}
static void *_p_daal__data_management__interface1__MatrixT_int_tTo_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *) (daal::data_management::interface1::NumericTable *)(daal::data_management::interface1::HomogenNumericTable< int > *) ((daal::data_management::interface1::Matrix< int > *) x));
}
static void *_p_daal__data_management__interface1__NumericTableTo_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *)  ((daal::data_management::interface1::NumericTable *) x));
}
static void *_p_daal__data_management__interface1__SOANumericTableTo_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::SOANumericTable *) x));
}
static void *_p_daal__data_management__interface1__CSRNumericTableTo_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::CSRNumericTable *) x));
}
static void *_p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_tTo_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *)  ((daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *) x));
}
static void *_p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_tTo_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *)  ((daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *) x));
}
static void *_p_daal__data_management__interface1__TensorOffsetLayoutTo_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *) (daal::data_management::interface1::TensorLayout *) ((daal::data_management::interface1::TensorOffsetLayout *) x));
}
static void *_p_daal__data_management__interface1__DataCollectionTo_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *)  ((daal::data_management::interface1::DataCollection *) x));
}
static void *_p_daal__data_management__interface1__RowMergedNumericTableTo_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::RowMergedNumericTable *) x));
}
static void *_p_daal__data_management__interface1__NumericTableFeatureTo_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *)  ((daal::data_management::interface1::NumericTableFeature *) x));
}
static void *_p_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_tTo_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *)  ((daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > *) x));
}
static void *_p_daal__data_management__interface1__TensorLayoutTo_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *)  ((daal::data_management::interface1::TensorLayout *) x));
}
static void *_p_daal__data_management__interface1__MatrixT_float_tTo_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *) (daal::data_management::interface1::NumericTable *)(daal::data_management::interface1::HomogenNumericTable< float > *) ((daal::data_management::interface1::Matrix< float > *) x));
}
static void *_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_tTo_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *) x));
}
static void *_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_tTo_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *) x));
}
static void *_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_tTo_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *) x));
}
static void *_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_tTo_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *) x));
}
static void *_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_tTo_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *) x));
}
static void *_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_tTo_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *) x));
}
static void *_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_tTo_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *) x));
}
static void *_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_tTo_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *) x));
}
static void *_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_tTo_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *) x));
}
static void *_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_tTo_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *) x));
}
static void *_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_tTo_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *) x));
}
static void *_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_tTo_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *) x));
}
static void *_p_daal__data_management__interface1__HomogenNumericTableT_int_tTo_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::HomogenNumericTable< int > *) x));
}
static void *_p_daal__data_management__interface1__HomogenNumericTableT_float_tTo_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::HomogenNumericTable< float > *) x));
}
static void *_p_daal__data_management__interface1__HomogenNumericTableT_double_tTo_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::HomogenNumericTable< double > *) x));
}
static void *_p_daal__data_management__interface1__NpyAOSNumericTableTo_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::NpyAOSNumericTable *) x));
}
static void *_p_daal__data_management__interface1__MergedNumericTableTo_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::MergedNumericTable *) x));
}
static void *_p_daal__data_management__interface1__DataSourceFeatureTo_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface *)  ((daal::data_management::interface1::DataSourceFeature *) x));
}
static void *_p_daal__data_management__interface1__MatrixT_double_tTo_p_daal__data_management__interface1__HomogenNumericTableT_double_t(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::HomogenNumericTable< double > *)  ((daal::data_management::interface1::Matrix< double > *) x));
}
static void *_p_daal__data_management__interface1__MatrixT_float_tTo_p_daal__data_management__interface1__HomogenNumericTableT_float_t(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::HomogenNumericTable< float > *)  ((daal::data_management::interface1::Matrix< float > *) x));
}
static void *_p_daal__data_management__interface1__MatrixT_int_tTo_p_daal__data_management__interface1__HomogenNumericTableT_int_t(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::HomogenNumericTable< int > *)  ((daal::data_management::interface1::Matrix< int > *) x));
}
static void *_p_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_tTo_p_daal__data_management__interface1__CompressorImpl(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::CompressorImpl *)  ((daal::data_management::interface1::Compressor< daal::data_management::bzip2 > *) x));
}
static void *_p_daal__data_management__interface1__CompressorT_daal__data_management__lzo_tTo_p_daal__data_management__interface1__CompressorImpl(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::CompressorImpl *)  ((daal::data_management::interface1::Compressor< daal::data_management::lzo > *) x));
}
static void *_p_daal__data_management__interface1__CompressorT_daal__data_management__rle_tTo_p_daal__data_management__interface1__CompressorImpl(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::CompressorImpl *)  ((daal::data_management::interface1::Compressor< daal::data_management::rle > *) x));
}
static void *_p_daal__data_management__interface1__CompressorT_daal__data_management__zlib_tTo_p_daal__data_management__interface1__CompressorImpl(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::CompressorImpl *)  ((daal::data_management::interface1::Compressor< daal::data_management::zlib > *) x));
}
static void *_p_daal__data_management__interface1__HomogenTensorT_double_tTo_p_daal__data_management__interface1__Tensor(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::Tensor *)  ((daal::data_management::interface1::HomogenTensor< double > *) x));
}
static void *_p_daal__data_management__interface1__HomogenTensorT_float_tTo_p_daal__data_management__interface1__Tensor(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::Tensor *)  ((daal::data_management::interface1::HomogenTensor< float > *) x));
}
static void *_p_daal__data_management__interface1__HomogenTensorT_int_tTo_p_daal__data_management__interface1__Tensor(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::Tensor *)  ((daal::data_management::interface1::HomogenTensor< int > *) x));
}
static void *_p_daal__data_management__OneHotEncoderTo_p_daal__data_management__ModifierIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::ModifierIface *)  ((daal::data_management::OneHotEncoder *) x));
}
static void *_p_daal__data_management__ColumnFilterTo_p_daal__data_management__ModifierIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::ModifierIface *)  ((daal::data_management::ColumnFilter *) x));
}
static void *_p_daal__data_management__MakeCategoricalTo_p_daal__data_management__ModifierIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::ModifierIface *)  ((daal::data_management::MakeCategorical *) x));
}
static void *_p_daal__data_management__interface1__HomogenTensorT_double_tTo_p_daal__data_management__interface1__TensorIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::TensorIface *) (daal::data_management::interface1::Tensor *) ((daal::data_management::interface1::HomogenTensor< double > *) x));
}
static void *_p_daal__data_management__interface1__HomogenTensorT_float_tTo_p_daal__data_management__interface1__TensorIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::TensorIface *) (daal::data_management::interface1::Tensor *) ((daal::data_management::interface1::HomogenTensor< float > *) x));
}
static void *_p_daal__data_management__interface1__HomogenTensorT_int_tTo_p_daal__data_management__interface1__TensorIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::TensorIface *) (daal::data_management::interface1::Tensor *) ((daal::data_management::interface1::HomogenTensor< int > *) x));
}
static void *_p_daal__data_management__interface1__TensorTo_p_daal__data_management__interface1__TensorIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::TensorIface *)  ((daal::data_management::interface1::Tensor *) x));
}
static void *_p_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_tTo_p_daal__data_management__interface1__Compression(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::Compression *) (daal::data_management::interface1::CompressorImpl *) ((daal::data_management::interface1::Compressor< daal::data_management::bzip2 > *) x));
}
static void *_p_daal__data_management__interface1__CompressorT_daal__data_management__lzo_tTo_p_daal__data_management__interface1__Compression(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::Compression *) (daal::data_management::interface1::CompressorImpl *) ((daal::data_management::interface1::Compressor< daal::data_management::lzo > *) x));
}
static void *_p_daal__data_management__interface1__CompressorT_daal__data_management__rle_tTo_p_daal__data_management__interface1__Compression(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::Compression *) (daal::data_management::interface1::CompressorImpl *) ((daal::data_management::interface1::Compressor< daal::data_management::rle > *) x));
}
static void *_p_daal__data_management__interface1__CompressorT_daal__data_management__zlib_tTo_p_daal__data_management__interface1__Compression(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::Compression *) (daal::data_management::interface1::CompressorImpl *) ((daal::data_management::interface1::Compressor< daal::data_management::zlib > *) x));
}
static void *_p_daal__data_management__interface1__DecompressorImplTo_p_daal__data_management__interface1__Compression(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::Compression *)  ((daal::data_management::interface1::DecompressorImpl *) x));
}
static void *_p_daal__data_management__interface1__CompressorImplTo_p_daal__data_management__interface1__Compression(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::Compression *)  ((daal::data_management::interface1::CompressorImpl *) x));
}
static void *_p_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_tTo_p_daal__data_management__interface1__Compression(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::Compression *) (daal::data_management::interface1::DecompressorImpl *) ((daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > *) x));
}
static void *_p_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_tTo_p_daal__data_management__interface1__Compression(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::Compression *) (daal::data_management::interface1::DecompressorImpl *) ((daal::data_management::interface1::Decompressor< daal::data_management::lzo > *) x));
}
static void *_p_daal__data_management__interface1__DecompressorT_daal__data_management__rle_tTo_p_daal__data_management__interface1__Compression(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::Compression *) (daal::data_management::interface1::DecompressorImpl *) ((daal::data_management::interface1::Decompressor< daal::data_management::rle > *) x));
}
static void *_p_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_tTo_p_daal__data_management__interface1__Compression(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::Compression *) (daal::data_management::interface1::DecompressorImpl *) ((daal::data_management::interface1::Decompressor< daal::data_management::zlib > *) x));
}
static void *_p_p_daal__data_management__interface1__TensorTo_p_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface **)  ((daal::data_management::interface1::Tensor **) x));
}
static void *_p_p_daal__data_management__interface1__MatrixT_double_tTo_p_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface **) (daal::data_management::interface1::NumericTable *)(daal::data_management::interface1::HomogenNumericTable< double > *) ((daal::data_management::interface1::Matrix< double > **) x));
}
static void *_p_p_daal__data_management__interface1__HomogenTensorT_int_tTo_p_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface **) (daal::data_management::interface1::Tensor *) ((daal::data_management::interface1::HomogenTensor< int > **) x));
}
static void *_p_p_daal__data_management__interface1__HomogenTensorT_float_tTo_p_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface **) (daal::data_management::interface1::Tensor *) ((daal::data_management::interface1::HomogenTensor< float > **) x));
}
static void *_p_p_daal__data_management__interface1__HomogenTensorT_double_tTo_p_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface **) (daal::data_management::interface1::Tensor *) ((daal::data_management::interface1::HomogenTensor< double > **) x));
}
static void *_p_p_daal__data_management__interface1__MatrixT_int_tTo_p_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface **) (daal::data_management::interface1::NumericTable *)(daal::data_management::interface1::HomogenNumericTable< int > *) ((daal::data_management::interface1::Matrix< int > **) x));
}
static void *_p_p_daal__data_management__interface1__NumericTableTo_p_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface **)  ((daal::data_management::interface1::NumericTable **) x));
}
static void *_p_p_daal__data_management__interface1__SOANumericTableTo_p_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface **) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::SOANumericTable **) x));
}
static void *_p_p_daal__data_management__interface1__CSRNumericTableTo_p_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface **) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::CSRNumericTable **) x));
}
static void *_p_p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_tTo_p_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface **)  ((daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > **) x));
}
static void *_p_p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_tTo_p_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface **)  ((daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > **) x));
}
static void *_p_p_daal__data_management__interface1__TensorOffsetLayoutTo_p_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface **) (daal::data_management::interface1::TensorLayout *) ((daal::data_management::interface1::TensorOffsetLayout **) x));
}
static void *_p_p_daal__data_management__interface1__DataCollectionTo_p_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface **)  ((daal::data_management::interface1::DataCollection **) x));
}
static void *_p_p_daal__data_management__interface1__RowMergedNumericTableTo_p_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface **) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::RowMergedNumericTable **) x));
}
static void *_p_p_daal__data_management__interface1__NumericTableFeatureTo_p_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface **)  ((daal::data_management::interface1::NumericTableFeature **) x));
}
static void *_p_p_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_tTo_p_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface **)  ((daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > **) x));
}
static void *_p_p_daal__data_management__interface1__TensorLayoutTo_p_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface **)  ((daal::data_management::interface1::TensorLayout **) x));
}
static void *_p_p_daal__data_management__interface1__MatrixT_float_tTo_p_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface **) (daal::data_management::interface1::NumericTable *)(daal::data_management::interface1::HomogenNumericTable< float > *) ((daal::data_management::interface1::Matrix< float > **) x));
}
static void *_p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_tTo_p_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface **) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > **) x));
}
static void *_p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_tTo_p_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface **) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > **) x));
}
static void *_p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_tTo_p_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface **) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > **) x));
}
static void *_p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_tTo_p_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface **) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > **) x));
}
static void *_p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_tTo_p_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface **) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > **) x));
}
static void *_p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_tTo_p_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface **) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > **) x));
}
static void *_p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_tTo_p_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface **) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > **) x));
}
static void *_p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_tTo_p_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface **) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > **) x));
}
static void *_p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_tTo_p_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface **) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > **) x));
}
static void *_p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_tTo_p_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface **) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > **) x));
}
static void *_p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_tTo_p_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface **) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > **) x));
}
static void *_p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_tTo_p_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface **) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > **) x));
}
static void *_p_p_daal__data_management__interface1__HomogenNumericTableT_int_tTo_p_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface **) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::HomogenNumericTable< int > **) x));
}
static void *_p_p_daal__data_management__interface1__HomogenNumericTableT_float_tTo_p_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface **) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::HomogenNumericTable< float > **) x));
}
static void *_p_p_daal__data_management__interface1__HomogenNumericTableT_double_tTo_p_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface **) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::HomogenNumericTable< double > **) x));
}
static void *_p_p_daal__data_management__interface1__NpyAOSNumericTableTo_p_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface **) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::NpyAOSNumericTable **) x));
}
static void *_p_p_daal__data_management__interface1__MergedNumericTableTo_p_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface **) (daal::data_management::interface1::NumericTable *) ((daal::data_management::interface1::MergedNumericTable **) x));
}
static void *_p_p_daal__data_management__interface1__DataSourceFeatureTo_p_p_daal__data_management__interface1__SerializationIface(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((daal::data_management::interface1::SerializationIface **)  ((daal::data_management::interface1::DataSourceFeature **) x));
}
static swig_type_info _swigt__p_baseDataType = {"_p_baseDataType", "baseDataType *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_char = {"_p_char", "char *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__Base = {"_p_daal__Base", "daal::Base *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__interface1__LibraryVersionInfo = {"_p_daal__services__interface1__LibraryVersionInfo", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_daal__data_management__modifiers__csv__interface1__Config = {"_p_daal__data_management__modifiers__csv__interface1__Config", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_daal__data_management__modifiers__csv__interface1__Context = {"_p_daal__data_management__modifiers__csv__interface1__Context", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_daal__data_management__modifiers__csv__interface1__FeatureModifier = {"_p_daal__data_management__modifiers__csv__interface1__FeatureModifier", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_daal__data_management__modifiers__csv__interface1__PyFeatureModifier = {"_p_daal__data_management__modifiers__csv__interface1__PyFeatureModifier", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_daal__services__interface1__Environment = {"_p_daal__services__interface1__Environment", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_daal__data_management__features__interface1__FeatureIdMapping = {"_p_daal__data_management__features__interface1__FeatureIdMapping", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_daal__data_management__features__interface1__FeatureId = {"_p_daal__data_management__features__interface1__FeatureId", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_daal__data_management__features__interface1__FeatureIdCollection = {"_p_daal__data_management__features__interface1__FeatureIdCollection", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_daal__data_management__features__interface1__FeatureIndices = {"_p_daal__data_management__features__interface1__FeatureIndices", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_daal__data_management__ColumnFilter = {"_p_daal__data_management__ColumnFilter", "daal::data_management::ColumnFilter *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__FeatureAuxData = {"_p_daal__data_management__FeatureAuxData", "daal::data_management::FeatureAuxData *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__MakeCategorical = {"_p_daal__data_management__MakeCategorical", "daal::data_management::MakeCategorical *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__ModifierIface = {"_p_daal__data_management__ModifierIface", "daal::data_management::ModifierIface *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__OneHotEncoder = {"_p_daal__data_management__OneHotEncoder", "daal::data_management::OneHotEncoder *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__features__interface1__FeatureIdCollectionIface = {"_p_daal__data_management__features__interface1__FeatureIdCollectionIface", "daal::data_management::features::FeatureIdCollectionIface *|daal::data_management::features::interface1::FeatureIdCollectionIface *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__features__interface1__FeatureIdIface = {"_p_daal__data_management__features__interface1__FeatureIdIface", "daal::data_management::features::interface1::FeatureIdIface *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__features__interface1__FeatureIdMappingIface = {"_p_daal__data_management__features__interface1__FeatureIdMappingIface", "daal::data_management::features::interface1::FeatureIdMappingIface *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__features__interface1__FeatureIndicesIface = {"_p_daal__data_management__features__interface1__FeatureIndicesIface", "daal::data_management::features::interface1::FeatureIndicesIface *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__BlockDescriptorT_double_t = {"_p_daal__data_management__interface1__BlockDescriptorT_double_t", "daal::data_management::interface1::BlockDescriptor< double > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__BlockDescriptorT_float_t = {"_p_daal__data_management__interface1__BlockDescriptorT_float_t", "daal::data_management::interface1::BlockDescriptor< float > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__BlockDescriptorT_int_t = {"_p_daal__data_management__interface1__BlockDescriptorT_int_t", "daal::data_management::interface1::BlockDescriptor< int > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__Bzip2CompressionParameter = {"_p_daal__data_management__interface1__Bzip2CompressionParameter", "daal::data_management::interface1::Bzip2CompressionParameter *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__CSRBlockDescriptorT_double_t = {"_p_daal__data_management__interface1__CSRBlockDescriptorT_double_t", "daal::data_management::interface1::CSRBlockDescriptor< double > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__CSRBlockDescriptorT_float_t = {"_p_daal__data_management__interface1__CSRBlockDescriptorT_float_t", "daal::data_management::interface1::CSRBlockDescriptor< float > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__CSRBlockDescriptorT_int_t = {"_p_daal__data_management__interface1__CSRBlockDescriptorT_int_t", "daal::data_management::interface1::CSRBlockDescriptor< int > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__CSRNumericTable = {"_p_daal__data_management__interface1__CSRNumericTable", "daal::data_management::interface1::CSRNumericTable *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__CSRNumericTableIface = {"_p_daal__data_management__interface1__CSRNumericTableIface", "daal::data_management::interface1::CSRNumericTableIface *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__CSVFeatureManager = {"_p_daal__data_management__interface1__CSVFeatureManager", "daal::data_management::interface1::CSVFeatureManager *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__CategoricalFeatureDictionary = {"_p_daal__data_management__interface1__CategoricalFeatureDictionary", "daal::data_management::interface1::CategoricalFeatureDictionary *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__CompressedDataArchive = {"_p_daal__data_management__interface1__CompressedDataArchive", "daal::data_management::interface1::CompressedDataArchive *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__Compression = {"_p_daal__data_management__interface1__Compression", "daal::data_management::interface1::Compression *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__CompressionIface = {"_p_daal__data_management__interface1__CompressionIface", "daal::data_management::interface1::CompressionIface *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__CompressionParameter = {"_p_daal__data_management__interface1__CompressionParameter", "daal::data_management::interface1::CompressionParameter *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__CompressionStream = {"_p_daal__data_management__interface1__CompressionStream", "daal::data_management::interface1::CompressionStream *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__CompressorImpl = {"_p_daal__data_management__interface1__CompressorImpl", "daal::data_management::interface1::CompressorImpl *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_t = {"_p_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_t", "daal::data_management::interface1::Compressor< daal::data_management::bzip2 > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__CompressorT_daal__data_management__lzo_t = {"_p_daal__data_management__interface1__CompressorT_daal__data_management__lzo_t", "daal::data_management::interface1::Compressor< daal::data_management::lzo > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__CompressorT_daal__data_management__rle_t = {"_p_daal__data_management__interface1__CompressorT_daal__data_management__rle_t", "daal::data_management::interface1::Compressor< daal::data_management::rle > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__CompressorT_daal__data_management__zlib_t = {"_p_daal__data_management__interface1__CompressorT_daal__data_management__zlib_t", "daal::data_management::interface1::Compressor< daal::data_management::zlib > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__CsvDataSourceOptions = {"_p_daal__data_management__interface1__CsvDataSourceOptions", "daal::data_management::interface1::CsvDataSourceOptions *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t = {"_p_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t", "daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__DataArchive = {"_p_daal__data_management__interface1__DataArchive", "daal::data_management::interface1::DataArchive *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__DataArchiveIface = {"_p_daal__data_management__interface1__DataArchiveIface", "daal::data_management::interface1::DataArchiveIface *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__DataArchiveImpl = {"_p_daal__data_management__interface1__DataArchiveImpl", "daal::data_management::interface1::DataArchiveImpl *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__DataBlock = {"_p_daal__data_management__interface1__DataBlock", "daal::data_management::interface1::DataBlock *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__DataBlockIface = {"_p_daal__data_management__interface1__DataBlockIface", "daal::data_management::interface1::DataBlockIface *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__DataCollection = {"_p_daal__data_management__interface1__DataCollection", "daal::data_management::interface1::DataCollection *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__DataSource = {"_p_daal__data_management__interface1__DataSource", "daal::data_management::interface1::DataSource *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__DataSourceFeature = {"_p_daal__data_management__interface1__DataSourceFeature", "daal::data_management::interface1::DataSourceFeature *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__DataSourceIface = {"_p_daal__data_management__interface1__DataSourceIface", "daal::data_management::interface1::DataSourceIface *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t = {"_p_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t", "daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< double >,double > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_float_t_double_t = {"_p_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_float_t_double_t", "daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< float >,double > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_int_t_double_t = {"_p_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_int_t_double_t", "daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< int >,double > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__DecompressedDataArchive = {"_p_daal__data_management__interface1__DecompressedDataArchive", "daal::data_management::interface1::DecompressedDataArchive *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__DecompressionStream = {"_p_daal__data_management__interface1__DecompressionStream", "daal::data_management::interface1::DecompressionStream *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__DecompressorImpl = {"_p_daal__data_management__interface1__DecompressorImpl", "daal::data_management::interface1::DecompressorImpl *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_t = {"_p_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_t", "daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_t = {"_p_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_t", "daal::data_management::interface1::Decompressor< daal::data_management::lzo > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__DecompressorT_daal__data_management__rle_t = {"_p_daal__data_management__interface1__DecompressorT_daal__data_management__rle_t", "daal::data_management::interface1::Decompressor< daal::data_management::rle > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_t = {"_p_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_t", "daal::data_management::interface1::Decompressor< daal::data_management::zlib > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__DenseNumericTableIface = {"_p_daal__data_management__interface1__DenseNumericTableIface", "daal::data_management::interface1::DenseNumericTableIface *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__DenseTensorIface = {"_p_daal__data_management__interface1__DenseTensorIface", "daal::data_management::interface1::DenseTensorIface *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__DictionaryIface = {"_p_daal__data_management__interface1__DictionaryIface", "daal::data_management::interface1::DictionaryIface *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t = {"_p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t", "daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > *|daal::data_management::interface1::DataSourceDictionary *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t = {"_p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t", "daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > *|daal::data_management::interface1::NumericTableDictionary *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t = {"_p_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t", "daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__HomogenNumericTableT_double_t = {"_p_daal__data_management__interface1__HomogenNumericTableT_double_t", "daal::data_management::interface1::HomogenNumericTable< double > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__HomogenNumericTableT_float_t = {"_p_daal__data_management__interface1__HomogenNumericTableT_float_t", "daal::data_management::interface1::HomogenNumericTable< float > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__HomogenNumericTableT_int_t = {"_p_daal__data_management__interface1__HomogenNumericTableT_int_t", "daal::data_management::interface1::HomogenNumericTable< int > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__HomogenTensorT_double_t = {"_p_daal__data_management__interface1__HomogenTensorT_double_t", "daal::data_management::interface1::HomogenTensor< double > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__HomogenTensorT_float_t = {"_p_daal__data_management__interface1__HomogenTensorT_float_t", "daal::data_management::interface1::HomogenTensor< float > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__HomogenTensorT_int_t = {"_p_daal__data_management__interface1__HomogenTensorT_int_t", "daal::data_management::interface1::HomogenTensor< int > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__InputDataArchive = {"_p_daal__data_management__interface1__InputDataArchive", "daal::data_management::interface1::InputDataArchive *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__KeyValueCollectionT_algorithms__Input_t = {"_p_daal__data_management__interface1__KeyValueCollectionT_algorithms__Input_t", "daal::data_management::interface1::KeyValueInputCollection *|daal::data_management::interface1::KeyValueCollection< algorithms::Input > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__KeyValueCollectionT_daal__algorithms__interface1__Input_t = {"_p_daal__data_management__interface1__KeyValueCollectionT_daal__algorithms__interface1__Input_t", "daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__KeyValueCollectionT_daal__data_management__interface1__SerializationIface_t = {"_p_daal__data_management__interface1__KeyValueCollectionT_daal__data_management__interface1__SerializationIface_t", "daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__LzoCompressionParameter = {"_p_daal__data_management__interface1__LzoCompressionParameter", "daal::data_management::interface1::LzoCompressionParameter *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__MatrixT_double_t = {"_p_daal__data_management__interface1__MatrixT_double_t", "daal::data_management::interface1::Matrix< double > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__MatrixT_float_t = {"_p_daal__data_management__interface1__MatrixT_float_t", "daal::data_management::interface1::Matrix< float > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__MatrixT_int_t = {"_p_daal__data_management__interface1__MatrixT_int_t", "daal::data_management::interface1::Matrix< int > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__MergedNumericTable = {"_p_daal__data_management__interface1__MergedNumericTable", "daal::data_management::interface1::MergedNumericTable *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__NpyAOSNumericTable = {"_p_daal__data_management__interface1__NpyAOSNumericTable", "daal::data_management::interface1::NpyAOSNumericTable *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__NumericTable = {"_p_daal__data_management__interface1__NumericTable", "daal::data_management::interface1::NumericTable *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__NumericTableFeature = {"_p_daal__data_management__interface1__NumericTableFeature", "daal::data_management::interface1::NumericTableFeature *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__NumericTableIface = {"_p_daal__data_management__interface1__NumericTableIface", "daal::data_management::interface1::NumericTableIface *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__NumericTable__BasicStatisticsDataCollection = {"_p_daal__data_management__interface1__NumericTable__BasicStatisticsDataCollection", "daal::data_management::interface1::NumericTable::BasicStatisticsDataCollection *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__OutputDataArchive = {"_p_daal__data_management__interface1__OutputDataArchive", "daal::data_management::interface1::OutputDataArchive *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__PackedArrayNumericTableIface = {"_p_daal__data_management__interface1__PackedArrayNumericTableIface", "daal::data_management::interface1::PackedArrayNumericTableIface *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t = {"_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t", "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t = {"_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t", "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t = {"_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t", "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t = {"_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t", "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t = {"_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t", "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t = {"_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t", "daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t = {"_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t", "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t = {"_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t", "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t = {"_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t", "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t = {"_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t", "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t = {"_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t", "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t = {"_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t", "daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__RleCompressionParameter = {"_p_daal__data_management__interface1__RleCompressionParameter", "daal::data_management::interface1::RleCompressionParameter *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__RowMergedNumericTable = {"_p_daal__data_management__interface1__RowMergedNumericTable", "daal::data_management::interface1::RowMergedNumericTable *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__SOANumericTable = {"_p_daal__data_management__interface1__SOANumericTable", "daal::data_management::interface1::SOANumericTable *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t = {"_p_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t", "daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > *|daal::data_management::interface1::KeyValueDataCollection *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__SerializationDesc = {"_p_daal__data_management__interface1__SerializationDesc", "daal::data_management::interface1::SerializationDesc *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__SerializationIface = {"_p_daal__data_management__interface1__SerializationIface", "daal::data_management::interface1::SerializationIface *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t = {"_p_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t", "daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__StringRowFeatureManagerIface = {"_p_daal__data_management__interface1__StringRowFeatureManagerIface", "daal::data_management::interface1::StringRowFeatureManagerIface *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__SubtensorDescriptorT_double_t = {"_p_daal__data_management__interface1__SubtensorDescriptorT_double_t", "daal::data_management::interface1::SubtensorDescriptor< double > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__SubtensorDescriptorT_float_t = {"_p_daal__data_management__interface1__SubtensorDescriptorT_float_t", "daal::data_management::interface1::SubtensorDescriptor< float > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__SubtensorDescriptorT_int_t = {"_p_daal__data_management__interface1__SubtensorDescriptorT_int_t", "daal::data_management::interface1::SubtensorDescriptor< int > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__Tensor = {"_p_daal__data_management__interface1__Tensor", "daal::data_management::interface1::Tensor *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__TensorIface = {"_p_daal__data_management__interface1__TensorIface", "daal::data_management::interface1::TensorIface *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__TensorLayout = {"_p_daal__data_management__interface1__TensorLayout", "daal::data_management::interface1::TensorLayout *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__TensorLayoutIface = {"_p_daal__data_management__interface1__TensorLayoutIface", "daal::data_management::interface1::TensorLayoutIface *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__TensorOffsetLayout = {"_p_daal__data_management__interface1__TensorOffsetLayout", "daal::data_management::interface1::TensorOffsetLayout *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__data_management__interface1__ZlibCompressionParameter = {"_p_daal__data_management__interface1__ZlibCompressionParameter", "daal::data_management::interface1::ZlibCompressionParameter *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__CollectionT_daal__data_management__FeatureAuxData_t = {"_p_daal__services__CollectionT_daal__data_management__FeatureAuxData_t", "daal::services::Collection< daal::data_management::FeatureAuxData > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__CollectionT_daal__services__SharedPtrT_daal__algorithms__interface1__Input_t_t = {"_p_daal__services__CollectionT_daal__services__SharedPtrT_daal__algorithms__interface1__Input_t_t", "daal::services::Collection< daal::services::SharedPtr< daal::algorithms::interface1::Input > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__CollectionT_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t_t = {"_p_daal__services__CollectionT_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t_t", "daal::services::Collection< daal::services::SharedPtr< daal::data_management::interface1::SerializationIface > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__CollectionT_size_t_t = {"_p_daal__services__CollectionT_size_t_t", "daal::services::Collection< size_t > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__CollectionT_void_fpFfchar_const_p_daal__data_management__FeatureAuxData_R_double_pF_t = {"_p_daal__services__CollectionT_void_fpFfchar_const_p_daal__data_management__FeatureAuxData_R_double_pF_t", "daal::services::Collection< daal::data_management::functionT > *|daal::services::Collection< void (*)(char const *,daal::data_management::FeatureAuxData &,double *) > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__Base_t = {"_p_daal__services__SharedPtrT_daal__Base_t", "daal::services::SharedPtr< daal::Base > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__batch_t_t = {"_p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__batch_t_t", "daal::services::SharedPtr< daal::algorithms::AnalysisContainerIface< daal::batch > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__distributed_t_t = {"_p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__distributed_t_t", "daal::services::SharedPtr< daal::algorithms::AnalysisContainerIface< daal::distributed > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__online_t_t = {"_p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__online_t_t", "daal::services::SharedPtr< daal::algorithms::AnalysisContainerIface< daal::online > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__batch_t_t = {"_p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__batch_t_t", "daal::services::SharedPtr< daal::algorithms::Analysis< daal::batch > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__distributed_t_t = {"_p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__distributed_t_t", "daal::services::SharedPtr< daal::algorithms::Analysis< daal::distributed > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__online_t_t = {"_p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__online_t_t", "daal::services::SharedPtr< daal::algorithms::Analysis< daal::online > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__DistributedPredictionContainerIface_t = {"_p_daal__services__SharedPtrT_daal__algorithms__DistributedPredictionContainerIface_t", "daal::services::SharedPtr< daal::algorithms::DistributedPredictionContainerIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__DistributedPrediction_t = {"_p_daal__services__SharedPtrT_daal__algorithms__DistributedPrediction_t", "daal::services::SharedPtr< daal::algorithms::DistributedPrediction > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__PredictionContainerIface_t = {"_p_daal__services__SharedPtrT_daal__algorithms__PredictionContainerIface_t", "daal::services::SharedPtr< daal::algorithms::PredictionContainerIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__Prediction_t = {"_p_daal__services__SharedPtrT_daal__algorithms__Prediction_t", "daal::services::SharedPtr< daal::algorithms::Prediction > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__batch_t_t = {"_p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__batch_t_t", "daal::services::SharedPtr< daal::algorithms::Training< daal::batch > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__distributed_t_t = {"_p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__distributed_t_t", "daal::services::SharedPtr< daal::algorithms::Training< daal::distributed > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__online_t_t = {"_p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__online_t_t", "daal::services::SharedPtr< daal::algorithms::Training< daal::online > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIfaceImpl_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIfaceImpl_t", "daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainerIfaceImpl > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIface_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIface_t", "daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainerIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__batch_t_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__batch_t_t", "daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainerImpl< daal::batch > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__distributed_t_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__distributed_t_t", "daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainerImpl< daal::distributed > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__online_t_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__online_t_t", "daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainerImpl< daal::online > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__batch_t_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__batch_t_t", "daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainer< daal::batch > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__distributed_t_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__distributed_t_t", "daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainer< daal::distributed > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__online_t_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__online_t_t", "daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmContainer< daal::online > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmDispatchContainer_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmDispatchContainer_t", "daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmDispatchContainer > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIfaceImpl_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIfaceImpl_t", "daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmIfaceImpl > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIface_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIface_t", "daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__batch_t_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__batch_t_t", "daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmImpl< daal::batch > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__distributed_t_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__distributed_t_t", "daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmImpl< daal::distributed > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__online_t_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__online_t_t", "daal::services::SharedPtr< daal::algorithms::interface1::AlgorithmImpl< daal::online > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__batch_t_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__batch_t_t", "daal::services::SharedPtr< daal::algorithms::interface1::Algorithm< daal::batch > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__distributed_t_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__distributed_t_t", "daal::services::SharedPtr< daal::algorithms::interface1::Algorithm< daal::distributed > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__online_t_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__online_t_t", "daal::services::SharedPtr< daal::algorithms::interface1::Algorithm< daal::online > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__Argument_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__Argument_t", "daal::services::SharedPtr< daal::algorithms::interface1::Argument > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__HostAppIface_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__HostAppIface_t", "daal::services::SharedPtr< daal::algorithms::interface1::HostAppIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__Input_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__Input_t", "daal::services::SharedPtr< daal::algorithms::interface1::Input > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__Kernel_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__Kernel_t", "daal::services::SharedPtr< daal::algorithms::interface1::Kernel > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__Model_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__Model_t", "daal::services::SharedPtr< daal::algorithms::interface1::Model > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__OptionalArgument_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__OptionalArgument_t", "daal::services::SharedPtr< daal::algorithms::interface1::OptionalArgument > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__Parameter_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__Parameter_t", "daal::services::SharedPtr< daal::algorithms::interface1::Parameter > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__PartialResult_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__PartialResult_t", "daal::services::SharedPtr< daal::algorithms::interface1::PartialResult > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__Result_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__Result_t", "daal::services::SharedPtr< daal::algorithms::interface1::Result > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__SerializableArgument_t = {"_p_daal__services__SharedPtrT_daal__algorithms__interface1__SerializableArgument_t", "daal::services::SharedPtr< daal::algorithms::interface1::SerializableArgument > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdCollectionIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdCollectionIface_t", "daal::data_management::features::FeatureIdCollectionIfacePtr *|daal::services::SharedPtr< daal::data_management::features::interface1::FeatureIdCollectionIface > *|daal::data_management::features::interface1::FeatureIdCollectionIfacePtr *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdCollection_t = {"_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdCollection_t", "daal::services::SharedPtr< daal::data_management::features::interface1::FeatureIdCollection > *|daal::data_management::features::interface1::FeatureIdCollectionPtr *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdIface_t", "daal::services::SharedPtr< daal::data_management::features::interface1::FeatureIdIface > *|daal::data_management::features::interface1::FeatureIdIfacePtr *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdMappingIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdMappingIface_t", "daal::services::SharedPtr< daal::data_management::features::interface1::FeatureIdMappingIface > *|daal::data_management::features::interface1::FeatureIdMappingIfacePtr *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdMapping_t = {"_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdMapping_t", "daal::services::SharedPtr< daal::data_management::features::interface1::FeatureIdMapping > *|daal::data_management::features::interface1::FeatureIdMappingPtr *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureId_t = {"_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureId_t", "daal::services::SharedPtr< daal::data_management::features::interface1::FeatureId > *|daal::data_management::features::interface1::FeatureIdPtr *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndexTraits_t = {"_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndexTraits_t", "daal::services::SharedPtr< daal::data_management::features::interface1::FeatureIndexTraits > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndicesIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndicesIface_t", "daal::services::SharedPtr< daal::data_management::features::interface1::FeatureIndicesIface > *|daal::data_management::features::interface1::FeatureIndicesIfacePtr *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndices_t = {"_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndices_t", "daal::services::SharedPtr< daal::data_management::features::interface1::FeatureIndices > *|daal::data_management::features::interface1::FeatureIndicesPtr *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__BasicStatisticsDataCollection_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__BasicStatisticsDataCollection_t", "daal::services::SharedPtr< daal::data_management::interface1::BasicStatisticsDataCollection > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t", "daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< double > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t", "daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< float > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t", "daal::services::SharedPtr< daal::data_management::interface1::BlockDescriptor< int > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_double_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_double_t_t", "daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< double > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_float_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_float_t_t", "daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< float > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_int_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_int_t_t", "daal::services::SharedPtr< daal::data_management::interface1::CSRBlockDescriptor< int > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTableIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTableIface_t", "daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTableIface > *|daal::data_management::interface1::CSRNumericTableIfacePtr *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t", "daal::services::SharedPtr< daal::data_management::interface1::CSRNumericTable > *|daal::data_management::interface1::CSRNumericTablePtr *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSVFeatureManager_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__CSVFeatureManager_t", "daal::services::SharedPtr< daal::data_management::interface1::CSVFeatureManager > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CategoricalFeatureDictionary_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__CategoricalFeatureDictionary_t", "daal::services::SharedPtr< daal::data_management::interface1::CategoricalFeatureDictionary > *|daal::data_management::interface1::CategoricalFeatureDictionaryPtr *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__ColumnFilter_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__ColumnFilter_t", "daal::services::SharedPtr< daal::data_management::interface1::ColumnFilter > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressedDataArchive_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressedDataArchive_t", "daal::services::SharedPtr< daal::data_management::interface1::CompressedDataArchive > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t", "daal::services::SharedPtr< daal::data_management::interface1::CompressionIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionStream_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionStream_t", "daal::services::SharedPtr< daal::data_management::interface1::CompressionStream > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t", "daal::services::SharedPtr< daal::data_management::interface1::Compression > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_t", "daal::services::SharedPtr< daal::data_management::interface1::CompressorImpl > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_t_t", "daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::bzip2 > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__lzo_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__lzo_t_t", "daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::lzo > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__rle_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__rle_t_t", "daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::rle > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__zlib_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__zlib_t_t", "daal::services::SharedPtr< daal::data_management::interface1::Compressor< daal::data_management::zlib > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t", "daal::services::SharedPtr< daal::data_management::interface1::CsvDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_t", "daal::services::SharedPtr< daal::data_management::interface1::DataArchiveIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveImpl_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveImpl_t", "daal::services::SharedPtr< daal::data_management::interface1::DataArchiveImpl > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchive_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchive_t", "daal::services::SharedPtr< daal::data_management::interface1::DataArchive > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlockIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlockIface_t", "daal::services::SharedPtr< daal::data_management::interface1::DataBlockIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t", "daal::data_management::interface1::DataBlockPtr *|daal::services::SharedPtr< daal::data_management::interface1::DataBlock > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataCollection_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__DataCollection_t", "daal::data_management::interface1::DataCollectionPtr *|daal::services::SharedPtr< daal::data_management::interface1::DataCollection > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t", "daal::services::SharedPtr< daal::data_management::interface1::DataSourceFeature > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t", "daal::services::SharedPtr< daal::data_management::interface1::DataSourceIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t_t", "daal::services::SharedPtr< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< double >,double > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_float_t_double_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_float_t_double_t_t", "daal::services::SharedPtr< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< float >,double > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_int_t_double_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_int_t_double_t_t", "daal::services::SharedPtr< daal::data_management::interface1::DataSourceTemplate< daal::data_management::interface1::HomogenNumericTable< int >,double > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t", "daal::services::SharedPtr< daal::data_management::interface1::DataSource > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressedDataArchive_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressedDataArchive_t", "daal::services::SharedPtr< daal::data_management::interface1::DecompressedDataArchive > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressionStream_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressionStream_t", "daal::services::SharedPtr< daal::data_management::interface1::DecompressionStream > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_t", "daal::services::SharedPtr< daal::data_management::interface1::DecompressorImpl > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_t_t", "daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::bzip2 > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_t_t", "daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::lzo > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__rle_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__rle_t_t", "daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::rle > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_t_t", "daal::services::SharedPtr< daal::data_management::interface1::Decompressor< daal::data_management::zlib > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t", "daal::services::SharedPtr< daal::data_management::interface1::DenseNumericTableIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t", "daal::services::SharedPtr< daal::data_management::interface1::DenseTensorIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryIface_t", "daal::services::SharedPtr< daal::data_management::interface1::DictionaryIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_t", "daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::DataSourceFeature,6010 > > *|daal::data_management::interface1::DataSourceDictionaryPtr *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t", "daal::data_management::interface1::NumericTableDictionaryPtr *|daal::services::SharedPtr< daal::data_management::interface1::Dictionary< daal::data_management::interface1::NumericTableFeature,6000 > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdCollectionIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdCollectionIface_t", "daal::services::SharedPtr< daal::data_management::interface1::FeatureIdCollectionIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdCollection_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdCollection_t", "daal::services::SharedPtr< daal::data_management::interface1::FeatureIdCollection > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdIface_t", "daal::services::SharedPtr< daal::data_management::interface1::FeatureIdIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdMappingIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdMappingIface_t", "daal::services::SharedPtr< daal::data_management::interface1::FeatureIdMappingIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdMapping_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdMapping_t", "daal::services::SharedPtr< daal::data_management::interface1::FeatureIdMapping > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureId_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureId_t", "daal::services::SharedPtr< daal::data_management::interface1::FeatureId > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIndexTraits_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIndexTraits_t", "daal::services::SharedPtr< daal::data_management::interface1::FeatureIndexTraits > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIndicesIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIndicesIface_t", "daal::services::SharedPtr< daal::data_management::interface1::FeatureIndicesIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIndices_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIndices_t", "daal::services::SharedPtr< daal::data_management::interface1::FeatureIndices > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t", "daal::services::SharedPtr< daal::data_management::interface1::FileDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t", "daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< double > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t", "daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< float > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t", "daal::services::SharedPtr< daal::data_management::interface1::HomogenNumericTable< int > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t", "daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< double > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t", "daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< float > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t", "daal::services::SharedPtr< daal::data_management::interface1::HomogenTensor< int > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__InputDataArchive_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__InputDataArchive_t", "daal::services::SharedPtr< daal::data_management::interface1::InputDataArchive > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_algorithms__Input_t_const_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_algorithms__Input_t_const_t", "daal::data_management::interface1::KeyValueInputCollectionConstPtr *|daal::services::SharedPtr< daal::data_management::interface1::KeyValueCollection< algorithms::Input > const > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_algorithms__Input_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_algorithms__Input_t_t", "daal::data_management::interface1::KeyValueInputCollectionPtr *|daal::services::SharedPtr< daal::data_management::interface1::KeyValueCollection< algorithms::Input > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__algorithms__interface1__Input_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__algorithms__interface1__Input_t_t", "daal::services::SharedPtr< daal::data_management::interface1::KeyValueCollection< daal::algorithms::interface1::Input > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t", "daal::services::SharedPtr< daal::data_management::interface1::KeyValueCollection< daal::data_management::interface1::SerializationIface > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MakeCategorical_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__MakeCategorical_t", "daal::services::SharedPtr< daal::data_management::interface1::MakeCategorical > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t", "daal::services::SharedPtr< daal::data_management::interface1::Matrix< double > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t", "daal::services::SharedPtr< daal::data_management::interface1::Matrix< float > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t", "daal::services::SharedPtr< daal::data_management::interface1::Matrix< int > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t", "daal::services::SharedPtr< daal::data_management::interface1::MergedNumericTable > *|daal::data_management::interface1::MergedNumericTablePtr *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__ModifierIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__ModifierIface_t", "daal::services::SharedPtr< daal::data_management::interface1::ModifierIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t", "daal::services::SharedPtr< daal::data_management::interface1::NpyAOSNumericTable > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_t", "daal::data_management::interface1::NumericTableFeaturePtr *|daal::services::SharedPtr< daal::data_management::interface1::NumericTableFeature > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t", "daal::services::SharedPtr< daal::data_management::interface1::NumericTableIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_const_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_const_t", "daal::data_management::interface1::NumericTableConstPtr *|daal::services::SharedPtr< daal::data_management::interface1::NumericTable const > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t", "daal::data_management::interface1::NumericTablePtr *|daal::services::SharedPtr< daal::data_management::interface1::NumericTable > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__OneHotEncoder_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__OneHotEncoder_t", "daal::services::SharedPtr< daal::data_management::interface1::OneHotEncoder > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__OutputDataArchive_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__OutputDataArchive_t", "daal::services::SharedPtr< daal::data_management::interface1::OutputDataArchive > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t", "daal::services::SharedPtr< daal::data_management::interface1::PackedArrayNumericTableIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t", "daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,double > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t", "daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,float > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t", "daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix,int > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t", "daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,double > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t", "daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,float > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t", "daal::services::SharedPtr< daal::data_management::interface1::PackedSymmetricMatrix< daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix,int > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t", "daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,double > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t", "daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,float > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t", "daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix,int > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t", "daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,double > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t", "daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,float > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t", "daal::services::SharedPtr< daal::data_management::interface1::PackedTriangularMatrix< daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix,int > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t", "daal::data_management::interface1::RowMergedNumericTablePtr *|daal::services::SharedPtr< daal::data_management::interface1::RowMergedNumericTable > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t", "daal::services::SharedPtr< daal::data_management::interface1::SOANumericTable > *|daal::data_management::interface1::SOANumericTablePtr *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_const_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_const_t", "daal::data_management::interface1::KeyValueDataCollectionConstPtr *|daal::services::SharedPtr< daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > const > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t", "daal::data_management::interface1::KeyValueDataCollectionPtr *|daal::services::SharedPtr< daal::data_management::interface1::SerializableKeyValueCollection< daal::data_management::interface1::SerializationIface > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t", "daal::data_management::interface1::SerializationIfacePtr *|daal::services::SharedPtr< daal::data_management::interface1::SerializationIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t", "daal::services::SharedPtr< daal::data_management::interface1::StringDataSource< daal::data_management::interface1::CSVFeatureManager,double > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__StringRowFeatureManagerIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__StringRowFeatureManagerIface_t", "daal::services::SharedPtr< daal::data_management::interface1::StringRowFeatureManagerIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t", "daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< double > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t", "daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< float > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t", "daal::services::SharedPtr< daal::data_management::interface1::SubtensorDescriptor< int > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorIface_t", "daal::services::SharedPtr< daal::data_management::interface1::TensorIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayoutIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayoutIface_t", "daal::services::SharedPtr< daal::data_management::interface1::TensorLayoutIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayout_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayout_t", "daal::data_management::interface1::TensorLayoutPtr *|daal::services::SharedPtr< daal::data_management::interface1::TensorLayout > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t", "daal::services::SharedPtr< daal::data_management::interface1::TensorOffsetLayout > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t = {"_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t", "daal::data_management::interface1::TensorPtr *|daal::services::SharedPtr< daal::data_management::interface1::Tensor > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__ConfigIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__ConfigIface_t", "daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::ConfigIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Config_t = {"_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Config_t", "daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::Config > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__ContextIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__ContextIface_t", "daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::ContextIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Context_t = {"_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Context_t", "daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::Context > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifierIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifierIface_t", "daal::data_management::modifiers::csv::interface1::FeatureModifierIfacePtr *|daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::FeatureModifierIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifier_t = {"_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifier_t", "daal::data_management::modifiers::csv::interface1::FeatureModifierPtr *|daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::FeatureModifier > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__PyFeatureModifier_t = {"_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__PyFeatureModifier_t", "daal::services::SharedPtr< daal::data_management::modifiers::csv::interface1::PyFeatureModifier > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__interface1__ConfigIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__modifiers__interface1__ConfigIface_t", "daal::services::SharedPtr< daal::data_management::modifiers::interface1::ConfigIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__interface1__ContextIface_t = {"_p_daal__services__SharedPtrT_daal__data_management__modifiers__interface1__ContextIface_t", "daal::services::SharedPtr< daal::data_management::modifiers::interface1::ContextIface > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__backward__LayerIfacePtr_t_t = {"_p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__backward__LayerIfacePtr_t_t", "daal::services::SharedPtr< daal::services::interface1::Collection< daal::algorithms::neural_networks::layers::backward::LayerIfacePtr > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__forward__LayerIfacePtr_t_t = {"_p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__forward__LayerIfacePtr_t_t", "daal::services::SharedPtr< daal::services::interface1::Collection< daal::algorithms::neural_networks::layers::forward::LayerIfacePtr > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__forward__interface1__LayerDescriptor_t_t = {"_p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__forward__interface1__LayerDescriptor_t_t", "daal::services::SharedPtr< daal::services::interface1::Collection< daal::algorithms::neural_networks::layers::forward::interface1::LayerDescriptor > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__interface1__NextLayers_t_t = {"_p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__interface1__NextLayers_t_t", "daal::services::SharedPtr< daal::services::interface1::Collection< daal::algorithms::neural_networks::layers::interface1::NextLayers > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__data_management__interface1__SerializationIfacePtr_t_t = {"_p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__data_management__interface1__SerializationIfacePtr_t_t", "daal::services::SharedPtr< daal::services::interface1::Collection< daal::data_management::interface1::SerializationIfacePtr > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t_t_t = {"_p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t_t_t", "daal::data_management::DataBlockCollectionPtr *|daal::services::SharedPtr< daal::services::interface1::Collection< daal::services::SharedPtr< daal::data_management::interface1::DataBlock > > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__services__interface1__Environment_t = {"_p_daal__services__SharedPtrT_daal__services__interface1__Environment_t", "daal::services::SharedPtr< daal::services::interface1::Environment > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__services__interface1__ErrorCollection_t = {"_p_daal__services__SharedPtrT_daal__services__interface1__ErrorCollection_t", "daal::services::interface1::ErrorCollectionPtr *|daal::services::SharedPtr< daal::services::interface1::ErrorCollection > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__services__interface1__Error_t = {"_p_daal__services__SharedPtrT_daal__services__interface1__Error_t", "daal::services::interface1::ErrorPtr *|daal::services::SharedPtr< daal::services::interface1::Error > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__services__interface1__KernelErrorCollection_t = {"_p_daal__services__SharedPtrT_daal__services__interface1__KernelErrorCollection_t", "daal::services::interface1::KernelErrorCollectionPtr *|daal::services::SharedPtr< daal::services::interface1::KernelErrorCollection > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_daal__services__interface1__LibraryVersionInfo_t = {"_p_daal__services__SharedPtrT_daal__services__interface1__LibraryVersionInfo_t", "daal::services::SharedPtr< daal::services::interface1::LibraryVersionInfo > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_double_t = {"_p_daal__services__SharedPtrT_double_t", "daal::services::SharedPtr< double > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_float_t = {"_p_daal__services__SharedPtrT_float_t", "daal::services::SharedPtr< float > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_int_t = {"_p_daal__services__SharedPtrT_int_t", "daal::services::SharedPtr< int > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_size_t_t = {"_p_daal__services__SharedPtrT_size_t_t", "daal::services::SharedPtr< size_t > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__SharedPtrT_unsigned_char_t = {"_p_daal__services__SharedPtrT_unsigned_char_t", "daal::services::SharedPtr< daal::byte > *|daal::services::SharedPtr< unsigned char > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__String = {"_p_daal__services__String", "daal::services::String *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__interface1__CollectionT_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t_t = {"_p_daal__services__interface1__CollectionT_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t_t", "daal::services::interface1::Collection< daal::services::SharedPtr< daal::data_management::interface1::DataBlock > > *|daal::data_management::DataBlockCollection *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_daal__services__interface1__Status = {"_p_daal__services__interface1__Status", "daal::services::interface1::Status *|daal::services::Status *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_double = {"_p_double", "double *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_env = {"_p_env", "env *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_f___p_daal__data_management__interface1__SerializationIface = {"_p_f___p_daal__data_management__interface1__SerializationIface", "daal::data_management::interface1::SerializationIface *(*)()|daal::data_management::interface1::SerializationDesc::creatorFunc", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_f___p_daal__data_management__interface1__MatrixT_float_t = {"_p_f___p_daal__data_management__interface1__MatrixT_float_t", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_f___p_daal__data_management__interface1__MatrixT_double_t = {"_p_f___p_daal__data_management__interface1__MatrixT_double_t", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_f___p_daal__data_management__interface1__MatrixT_int_t = {"_p_f___p_daal__data_management__interface1__MatrixT_int_t", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_f___p_daal__data_management__interface1__HomogenNumericTableT_double_t = {"_p_f___p_daal__data_management__interface1__HomogenNumericTableT_double_t", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_f___p_daal__data_management__interface1__HomogenNumericTableT_float_t = {"_p_f___p_daal__data_management__interface1__HomogenNumericTableT_float_t", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_f___p_daal__data_management__interface1__HomogenNumericTableT_int_t = {"_p_f___p_daal__data_management__interface1__HomogenNumericTableT_int_t", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_f___p_daal__data_management__interface1__HomogenTensorT_int_t = {"_p_f___p_daal__data_management__interface1__HomogenTensorT_int_t", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_f___p_daal__data_management__interface1__HomogenTensorT_float_t = {"_p_f___p_daal__data_management__interface1__HomogenTensorT_float_t", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_f___p_daal__data_management__interface1__HomogenTensorT_double_t = {"_p_f___p_daal__data_management__interface1__HomogenTensorT_double_t", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_f___p_daal__data_management__interface1__SOANumericTable = {"_p_f___p_daal__data_management__interface1__SOANumericTable", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_f___p_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t = {"_p_f___p_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t = {"_p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t = {"_p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t = {"_p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t = {"_p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t = {"_p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t = {"_p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t = {"_p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t = {"_p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t = {"_p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t = {"_p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t = {"_p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t = {"_p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_f___p_daal__data_management__interface1__TensorOffsetLayout = {"_p_f___p_daal__data_management__interface1__TensorOffsetLayout", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_f___p_daal__data_management__interface1__Tensor = {"_p_f___p_daal__data_management__interface1__Tensor", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_f___p_daal__data_management__interface1__TensorLayout = {"_p_f___p_daal__data_management__interface1__TensorLayout", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_f___p_daal__data_management__interface1__DataSourceFeature = {"_p_f___p_daal__data_management__interface1__DataSourceFeature", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_f___p_daal__data_management__interface1__NpyAOSNumericTable = {"_p_f___p_daal__data_management__interface1__NpyAOSNumericTable", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_f___p_daal__data_management__interface1__RowMergedNumericTable = {"_p_f___p_daal__data_management__interface1__RowMergedNumericTable", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_f___p_daal__data_management__interface1__DataCollection = {"_p_f___p_daal__data_management__interface1__DataCollection", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_f___p_daal__data_management__interface1__NumericTable = {"_p_f___p_daal__data_management__interface1__NumericTable", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_f___p_daal__data_management__interface1__NumericTableFeature = {"_p_f___p_daal__data_management__interface1__NumericTableFeature", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_f___p_daal__data_management__interface1__CSRNumericTable = {"_p_f___p_daal__data_management__interface1__CSRNumericTable", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_f___p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t = {"_p_f___p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_f___p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t = {"_p_f___p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_f___p_daal__data_management__interface1__MergedNumericTable = {"_p_f___p_daal__data_management__interface1__MergedNumericTable", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_first_type = {"_p_first_type", "first_type *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_float = {"_p_float", "float *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_int = {"_p_int", "int *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_numericTableType = {"_p_numericTableType", "numericTableType *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_p_daal__data_management__interface1__BlockDescriptorT_double_t = {"_p_p_daal__data_management__interface1__BlockDescriptorT_double_t", "daal::data_management::interface1::BlockDescriptor< double > **", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_p_daal__data_management__interface1__BlockDescriptorT_float_t = {"_p_p_daal__data_management__interface1__BlockDescriptorT_float_t", "daal::data_management::interface1::BlockDescriptor< float > **", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_p_daal__data_management__interface1__BlockDescriptorT_int_t = {"_p_p_daal__data_management__interface1__BlockDescriptorT_int_t", "daal::data_management::interface1::BlockDescriptor< int > **", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_p_daal__data_management__interface1__SerializationIface = {"_p_p_daal__data_management__interface1__SerializationIface", "daal::data_management::interface1::SerializationIface **", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_p_daal__data_management__interface1__DataCollection = {"_p_p_daal__data_management__interface1__DataCollection", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_p_daal__data_management__interface1__MatrixT_double_t = {"_p_p_daal__data_management__interface1__MatrixT_double_t", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_p_daal__data_management__interface1__HomogenNumericTableT_double_t = {"_p_p_daal__data_management__interface1__HomogenNumericTableT_double_t", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_p_daal__data_management__interface1__HomogenNumericTableT_float_t = {"_p_p_daal__data_management__interface1__HomogenNumericTableT_float_t", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_p_daal__data_management__interface1__HomogenNumericTableT_int_t = {"_p_p_daal__data_management__interface1__HomogenNumericTableT_int_t", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_p_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t = {"_p_p_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_p_daal__data_management__interface1__TensorOffsetLayout = {"_p_p_daal__data_management__interface1__TensorOffsetLayout", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_p_daal__data_management__interface1__SOANumericTable = {"_p_p_daal__data_management__interface1__SOANumericTable", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_p_daal__data_management__interface1__CSRNumericTable = {"_p_p_daal__data_management__interface1__CSRNumericTable", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_p_daal__data_management__interface1__NumericTableFeature = {"_p_p_daal__data_management__interface1__NumericTableFeature", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_p_daal__data_management__interface1__NumericTable = {"_p_p_daal__data_management__interface1__NumericTable", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_p_daal__data_management__interface1__TensorLayout = {"_p_p_daal__data_management__interface1__TensorLayout", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_p_daal__data_management__interface1__RowMergedNumericTable = {"_p_p_daal__data_management__interface1__RowMergedNumericTable", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_p_daal__data_management__interface1__HomogenTensorT_double_t = {"_p_p_daal__data_management__interface1__HomogenTensorT_double_t", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_p_daal__data_management__interface1__HomogenTensorT_float_t = {"_p_p_daal__data_management__interface1__HomogenTensorT_float_t", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_p_daal__data_management__interface1__HomogenTensorT_int_t = {"_p_p_daal__data_management__interface1__HomogenTensorT_int_t", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_p_daal__data_management__interface1__Tensor = {"_p_p_daal__data_management__interface1__Tensor", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_p_daal__data_management__interface1__MatrixT_int_t = {"_p_p_daal__data_management__interface1__MatrixT_int_t", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_p_daal__data_management__interface1__MergedNumericTable = {"_p_p_daal__data_management__interface1__MergedNumericTable", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t = {"_p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t = {"_p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t = {"_p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t = {"_p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t = {"_p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t = {"_p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t = {"_p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t = {"_p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t = {"_p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t = {"_p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t = {"_p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t = {"_p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_p_daal__data_management__interface1__DataSourceFeature = {"_p_p_daal__data_management__interface1__DataSourceFeature", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_p_daal__data_management__interface1__MatrixT_float_t = {"_p_p_daal__data_management__interface1__MatrixT_float_t", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t = {"_p_p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t = {"_p_p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_p_daal__data_management__interface1__NpyAOSNumericTable = {"_p_p_daal__data_management__interface1__NpyAOSNumericTable", 0, 0, 0, 0, 0};
static swig_type_info _swigt__p_p_daal__services__CollectionT_size_t_t = {"_p_p_daal__services__CollectionT_size_t_t", "daal::services::Collection< size_t > **", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_p_size_t = {"_p_p_size_t", "size_t **", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_second_type = {"_p_second_type", "second_type *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_size_t = {"_p_size_t", "size_t *|daal::data_management::features::interface1::FeatureIndex *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__mapT_std__string_std__pairT_int_int_t_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__pairT_int_int_t_t_t_t = {"_p_std__mapT_std__string_std__pairT_int_int_t_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__pairT_int_int_t_t_t_t", "std::map< std::string,std::pair< int,int > > *|std::map< std::string,std::pair< int,int >,std::less< std::string >,std::allocator< std::pair< std::string const,std::pair< int,int > > > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_super = {"_p_super", "super *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_unsigned_char = {"_p_unsigned_char", "unsigned char *|daal::byte *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_void = {"_p_void", "void *", 0, 0, (void*)0, 0};

static swig_type_info *swig_type_initial[] = {
  &_swigt__p_baseDataType,
  &_swigt__p_char,
  &_swigt__p_daal__Base,
  &_swigt__p_daal__data_management__ColumnFilter,
  &_swigt__p_daal__data_management__FeatureAuxData,
  &_swigt__p_daal__data_management__MakeCategorical,
  &_swigt__p_daal__data_management__ModifierIface,
  &_swigt__p_daal__data_management__OneHotEncoder,
  &_swigt__p_daal__data_management__features__interface1__FeatureId,
  &_swigt__p_daal__data_management__features__interface1__FeatureIdCollection,
  &_swigt__p_daal__data_management__features__interface1__FeatureIdCollectionIface,
  &_swigt__p_daal__data_management__features__interface1__FeatureIdIface,
  &_swigt__p_daal__data_management__features__interface1__FeatureIdMapping,
  &_swigt__p_daal__data_management__features__interface1__FeatureIdMappingIface,
  &_swigt__p_daal__data_management__features__interface1__FeatureIndices,
  &_swigt__p_daal__data_management__features__interface1__FeatureIndicesIface,
  &_swigt__p_daal__data_management__interface1__BlockDescriptorT_double_t,
  &_swigt__p_daal__data_management__interface1__BlockDescriptorT_float_t,
  &_swigt__p_daal__data_management__interface1__BlockDescriptorT_int_t,
  &_swigt__p_daal__data_management__interface1__Bzip2CompressionParameter,
  &_swigt__p_daal__data_management__interface1__CSRBlockDescriptorT_double_t,
  &_swigt__p_daal__data_management__interface1__CSRBlockDescriptorT_float_t,
  &_swigt__p_daal__data_management__interface1__CSRBlockDescriptorT_int_t,
  &_swigt__p_daal__data_management__interface1__CSRNumericTable,
  &_swigt__p_daal__data_management__interface1__CSRNumericTableIface,
  &_swigt__p_daal__data_management__interface1__CSVFeatureManager,
  &_swigt__p_daal__data_management__interface1__CategoricalFeatureDictionary,
  &_swigt__p_daal__data_management__interface1__CompressedDataArchive,
  &_swigt__p_daal__data_management__interface1__Compression,
  &_swigt__p_daal__data_management__interface1__CompressionIface,
  &_swigt__p_daal__data_management__interface1__CompressionParameter,
  &_swigt__p_daal__data_management__interface1__CompressionStream,
  &_swigt__p_daal__data_management__interface1__CompressorImpl,
  &_swigt__p_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_t,
  &_swigt__p_daal__data_management__interface1__CompressorT_daal__data_management__lzo_t,
  &_swigt__p_daal__data_management__interface1__CompressorT_daal__data_management__rle_t,
  &_swigt__p_daal__data_management__interface1__CompressorT_daal__data_management__zlib_t,
  &_swigt__p_daal__data_management__interface1__CsvDataSourceOptions,
  &_swigt__p_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t,
  &_swigt__p_daal__data_management__interface1__DataArchive,
  &_swigt__p_daal__data_management__interface1__DataArchiveIface,
  &_swigt__p_daal__data_management__interface1__DataArchiveImpl,
  &_swigt__p_daal__data_management__interface1__DataBlock,
  &_swigt__p_daal__data_management__interface1__DataBlockIface,
  &_swigt__p_daal__data_management__interface1__DataCollection,
  &_swigt__p_daal__data_management__interface1__DataSource,
  &_swigt__p_daal__data_management__interface1__DataSourceFeature,
  &_swigt__p_daal__data_management__interface1__DataSourceIface,
  &_swigt__p_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t,
  &_swigt__p_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_float_t_double_t,
  &_swigt__p_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_int_t_double_t,
  &_swigt__p_daal__data_management__interface1__DecompressedDataArchive,
  &_swigt__p_daal__data_management__interface1__DecompressionStream,
  &_swigt__p_daal__data_management__interface1__DecompressorImpl,
  &_swigt__p_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_t,
  &_swigt__p_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_t,
  &_swigt__p_daal__data_management__interface1__DecompressorT_daal__data_management__rle_t,
  &_swigt__p_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_t,
  &_swigt__p_daal__data_management__interface1__DenseNumericTableIface,
  &_swigt__p_daal__data_management__interface1__DenseTensorIface,
  &_swigt__p_daal__data_management__interface1__DictionaryIface,
  &_swigt__p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t,
  &_swigt__p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t,
  &_swigt__p_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t,
  &_swigt__p_daal__data_management__interface1__HomogenNumericTableT_double_t,
  &_swigt__p_daal__data_management__interface1__HomogenNumericTableT_float_t,
  &_swigt__p_daal__data_management__interface1__HomogenNumericTableT_int_t,
  &_swigt__p_daal__data_management__interface1__HomogenTensorT_double_t,
  &_swigt__p_daal__data_management__interface1__HomogenTensorT_float_t,
  &_swigt__p_daal__data_management__interface1__HomogenTensorT_int_t,
  &_swigt__p_daal__data_management__interface1__InputDataArchive,
  &_swigt__p_daal__data_management__interface1__KeyValueCollectionT_algorithms__Input_t,
  &_swigt__p_daal__data_management__interface1__KeyValueCollectionT_daal__algorithms__interface1__Input_t,
  &_swigt__p_daal__data_management__interface1__KeyValueCollectionT_daal__data_management__interface1__SerializationIface_t,
  &_swigt__p_daal__data_management__interface1__LzoCompressionParameter,
  &_swigt__p_daal__data_management__interface1__MatrixT_double_t,
  &_swigt__p_daal__data_management__interface1__MatrixT_float_t,
  &_swigt__p_daal__data_management__interface1__MatrixT_int_t,
  &_swigt__p_daal__data_management__interface1__MergedNumericTable,
  &_swigt__p_daal__data_management__interface1__NpyAOSNumericTable,
  &_swigt__p_daal__data_management__interface1__NumericTable,
  &_swigt__p_daal__data_management__interface1__NumericTableFeature,
  &_swigt__p_daal__data_management__interface1__NumericTableIface,
  &_swigt__p_daal__data_management__interface1__NumericTable__BasicStatisticsDataCollection,
  &_swigt__p_daal__data_management__interface1__OutputDataArchive,
  &_swigt__p_daal__data_management__interface1__PackedArrayNumericTableIface,
  &_swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t,
  &_swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t,
  &_swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t,
  &_swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t,
  &_swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t,
  &_swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t,
  &_swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t,
  &_swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t,
  &_swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t,
  &_swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t,
  &_swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t,
  &_swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t,
  &_swigt__p_daal__data_management__interface1__RleCompressionParameter,
  &_swigt__p_daal__data_management__interface1__RowMergedNumericTable,
  &_swigt__p_daal__data_management__interface1__SOANumericTable,
  &_swigt__p_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t,
  &_swigt__p_daal__data_management__interface1__SerializationDesc,
  &_swigt__p_daal__data_management__interface1__SerializationIface,
  &_swigt__p_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t,
  &_swigt__p_daal__data_management__interface1__StringRowFeatureManagerIface,
  &_swigt__p_daal__data_management__interface1__SubtensorDescriptorT_double_t,
  &_swigt__p_daal__data_management__interface1__SubtensorDescriptorT_float_t,
  &_swigt__p_daal__data_management__interface1__SubtensorDescriptorT_int_t,
  &_swigt__p_daal__data_management__interface1__Tensor,
  &_swigt__p_daal__data_management__interface1__TensorIface,
  &_swigt__p_daal__data_management__interface1__TensorLayout,
  &_swigt__p_daal__data_management__interface1__TensorLayoutIface,
  &_swigt__p_daal__data_management__interface1__TensorOffsetLayout,
  &_swigt__p_daal__data_management__interface1__ZlibCompressionParameter,
  &_swigt__p_daal__data_management__modifiers__csv__interface1__Config,
  &_swigt__p_daal__data_management__modifiers__csv__interface1__Context,
  &_swigt__p_daal__data_management__modifiers__csv__interface1__FeatureModifier,
  &_swigt__p_daal__data_management__modifiers__csv__interface1__PyFeatureModifier,
  &_swigt__p_daal__services__CollectionT_daal__data_management__FeatureAuxData_t,
  &_swigt__p_daal__services__CollectionT_daal__services__SharedPtrT_daal__algorithms__interface1__Input_t_t,
  &_swigt__p_daal__services__CollectionT_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t_t,
  &_swigt__p_daal__services__CollectionT_size_t_t,
  &_swigt__p_daal__services__CollectionT_void_fpFfchar_const_p_daal__data_management__FeatureAuxData_R_double_pF_t,
  &_swigt__p_daal__services__SharedPtrT_daal__Base_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__batch_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__distributed_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__online_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__batch_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__distributed_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__online_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__DistributedPredictionContainerIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__DistributedPrediction_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__PredictionContainerIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__Prediction_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__batch_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__distributed_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__online_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIfaceImpl_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__batch_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__distributed_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__online_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__batch_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__distributed_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__online_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmDispatchContainer_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIfaceImpl_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__batch_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__distributed_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__online_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__batch_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__distributed_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__online_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__Argument_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__HostAppIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__Input_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__Kernel_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__Model_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__OptionalArgument_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__Parameter_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__PartialResult_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__Result_t,
  &_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__SerializableArgument_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdCollectionIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdCollection_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdMappingIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdMapping_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureId_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndexTraits_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndicesIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndices_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__BasicStatisticsDataCollection_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_double_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_float_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_int_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTableIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSVFeatureManager_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CategoricalFeatureDictionary_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__ColumnFilter_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressedDataArchive_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionStream_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__lzo_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__rle_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__zlib_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveImpl_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchive_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlockIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataCollection_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_float_t_double_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_int_t_double_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressedDataArchive_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressionStream_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__rle_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdCollectionIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdCollection_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdMappingIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdMapping_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureId_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIndexTraits_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIndicesIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIndices_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__InputDataArchive_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_algorithms__Input_t_const_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_algorithms__Input_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__algorithms__interface1__Input_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MakeCategorical_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__ModifierIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_const_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__OneHotEncoder_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__OutputDataArchive_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_const_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__StringRowFeatureManagerIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayoutIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayout_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__ConfigIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Config_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__ContextIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Context_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifierIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifier_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__PyFeatureModifier_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__interface1__ConfigIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__interface1__ContextIface_t,
  &_swigt__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__backward__LayerIfacePtr_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__forward__LayerIfacePtr_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__forward__interface1__LayerDescriptor_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__interface1__NextLayers_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__data_management__interface1__SerializationIfacePtr_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t_t_t,
  &_swigt__p_daal__services__SharedPtrT_daal__services__interface1__Environment_t,
  &_swigt__p_daal__services__SharedPtrT_daal__services__interface1__ErrorCollection_t,
  &_swigt__p_daal__services__SharedPtrT_daal__services__interface1__Error_t,
  &_swigt__p_daal__services__SharedPtrT_daal__services__interface1__KernelErrorCollection_t,
  &_swigt__p_daal__services__SharedPtrT_daal__services__interface1__LibraryVersionInfo_t,
  &_swigt__p_daal__services__SharedPtrT_double_t,
  &_swigt__p_daal__services__SharedPtrT_float_t,
  &_swigt__p_daal__services__SharedPtrT_int_t,
  &_swigt__p_daal__services__SharedPtrT_size_t_t,
  &_swigt__p_daal__services__SharedPtrT_unsigned_char_t,
  &_swigt__p_daal__services__String,
  &_swigt__p_daal__services__interface1__CollectionT_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t_t,
  &_swigt__p_daal__services__interface1__Environment,
  &_swigt__p_daal__services__interface1__LibraryVersionInfo,
  &_swigt__p_daal__services__interface1__Status,
  &_swigt__p_double,
  &_swigt__p_env,
  &_swigt__p_f___p_daal__data_management__interface1__CSRNumericTable,
  &_swigt__p_f___p_daal__data_management__interface1__DataCollection,
  &_swigt__p_f___p_daal__data_management__interface1__DataSourceFeature,
  &_swigt__p_f___p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t,
  &_swigt__p_f___p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t,
  &_swigt__p_f___p_daal__data_management__interface1__HomogenNumericTableT_double_t,
  &_swigt__p_f___p_daal__data_management__interface1__HomogenNumericTableT_float_t,
  &_swigt__p_f___p_daal__data_management__interface1__HomogenNumericTableT_int_t,
  &_swigt__p_f___p_daal__data_management__interface1__HomogenTensorT_double_t,
  &_swigt__p_f___p_daal__data_management__interface1__HomogenTensorT_float_t,
  &_swigt__p_f___p_daal__data_management__interface1__HomogenTensorT_int_t,
  &_swigt__p_f___p_daal__data_management__interface1__MatrixT_double_t,
  &_swigt__p_f___p_daal__data_management__interface1__MatrixT_float_t,
  &_swigt__p_f___p_daal__data_management__interface1__MatrixT_int_t,
  &_swigt__p_f___p_daal__data_management__interface1__MergedNumericTable,
  &_swigt__p_f___p_daal__data_management__interface1__NpyAOSNumericTable,
  &_swigt__p_f___p_daal__data_management__interface1__NumericTable,
  &_swigt__p_f___p_daal__data_management__interface1__NumericTableFeature,
  &_swigt__p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t,
  &_swigt__p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t,
  &_swigt__p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t,
  &_swigt__p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t,
  &_swigt__p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t,
  &_swigt__p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t,
  &_swigt__p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t,
  &_swigt__p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t,
  &_swigt__p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t,
  &_swigt__p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t,
  &_swigt__p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t,
  &_swigt__p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t,
  &_swigt__p_f___p_daal__data_management__interface1__RowMergedNumericTable,
  &_swigt__p_f___p_daal__data_management__interface1__SOANumericTable,
  &_swigt__p_f___p_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t,
  &_swigt__p_f___p_daal__data_management__interface1__SerializationIface,
  &_swigt__p_f___p_daal__data_management__interface1__Tensor,
  &_swigt__p_f___p_daal__data_management__interface1__TensorLayout,
  &_swigt__p_f___p_daal__data_management__interface1__TensorOffsetLayout,
  &_swigt__p_first_type,
  &_swigt__p_float,
  &_swigt__p_int,
  &_swigt__p_numericTableType,
  &_swigt__p_p_daal__data_management__interface1__BlockDescriptorT_double_t,
  &_swigt__p_p_daal__data_management__interface1__BlockDescriptorT_float_t,
  &_swigt__p_p_daal__data_management__interface1__BlockDescriptorT_int_t,
  &_swigt__p_p_daal__data_management__interface1__CSRNumericTable,
  &_swigt__p_p_daal__data_management__interface1__DataCollection,
  &_swigt__p_p_daal__data_management__interface1__DataSourceFeature,
  &_swigt__p_p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t,
  &_swigt__p_p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t,
  &_swigt__p_p_daal__data_management__interface1__HomogenNumericTableT_double_t,
  &_swigt__p_p_daal__data_management__interface1__HomogenNumericTableT_float_t,
  &_swigt__p_p_daal__data_management__interface1__HomogenNumericTableT_int_t,
  &_swigt__p_p_daal__data_management__interface1__HomogenTensorT_double_t,
  &_swigt__p_p_daal__data_management__interface1__HomogenTensorT_float_t,
  &_swigt__p_p_daal__data_management__interface1__HomogenTensorT_int_t,
  &_swigt__p_p_daal__data_management__interface1__MatrixT_double_t,
  &_swigt__p_p_daal__data_management__interface1__MatrixT_float_t,
  &_swigt__p_p_daal__data_management__interface1__MatrixT_int_t,
  &_swigt__p_p_daal__data_management__interface1__MergedNumericTable,
  &_swigt__p_p_daal__data_management__interface1__NpyAOSNumericTable,
  &_swigt__p_p_daal__data_management__interface1__NumericTable,
  &_swigt__p_p_daal__data_management__interface1__NumericTableFeature,
  &_swigt__p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t,
  &_swigt__p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t,
  &_swigt__p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t,
  &_swigt__p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t,
  &_swigt__p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t,
  &_swigt__p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t,
  &_swigt__p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t,
  &_swigt__p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t,
  &_swigt__p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t,
  &_swigt__p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t,
  &_swigt__p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t,
  &_swigt__p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t,
  &_swigt__p_p_daal__data_management__interface1__RowMergedNumericTable,
  &_swigt__p_p_daal__data_management__interface1__SOANumericTable,
  &_swigt__p_p_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t,
  &_swigt__p_p_daal__data_management__interface1__SerializationIface,
  &_swigt__p_p_daal__data_management__interface1__Tensor,
  &_swigt__p_p_daal__data_management__interface1__TensorLayout,
  &_swigt__p_p_daal__data_management__interface1__TensorOffsetLayout,
  &_swigt__p_p_daal__services__CollectionT_size_t_t,
  &_swigt__p_p_size_t,
  &_swigt__p_second_type,
  &_swigt__p_size_t,
  &_swigt__p_std__mapT_std__string_std__pairT_int_int_t_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__pairT_int_int_t_t_t_t,
  &_swigt__p_super,
  &_swigt__p_unsigned_char,
  &_swigt__p_void,
};

static swig_cast_info _swigc__p_baseDataType[] = {  {&_swigt__p_baseDataType, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_char[] = {  {&_swigt__p_char, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__interface1__LibraryVersionInfo[] = {{&_swigt__p_daal__services__interface1__LibraryVersionInfo, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__modifiers__csv__interface1__Config[] = {{&_swigt__p_daal__data_management__modifiers__csv__interface1__Config, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__modifiers__csv__interface1__Context[] = {{&_swigt__p_daal__data_management__modifiers__csv__interface1__Context, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__modifiers__csv__interface1__FeatureModifier[] = {{&_swigt__p_daal__data_management__modifiers__csv__interface1__FeatureModifier, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__modifiers__csv__interface1__PyFeatureModifier[] = {{&_swigt__p_daal__data_management__modifiers__csv__interface1__PyFeatureModifier, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__interface1__Environment[] = {{&_swigt__p_daal__services__interface1__Environment, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__features__interface1__FeatureIdMapping[] = {{&_swigt__p_daal__data_management__features__interface1__FeatureIdMapping, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__features__interface1__FeatureId[] = {{&_swigt__p_daal__data_management__features__interface1__FeatureId, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__features__interface1__FeatureIdCollection[] = {{&_swigt__p_daal__data_management__features__interface1__FeatureIdCollection, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__features__interface1__FeatureIndices[] = {{&_swigt__p_daal__data_management__features__interface1__FeatureIndices, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__Base[] = {  {&_swigt__p_daal__data_management__interface1__DataArchiveImpl, _p_daal__data_management__interface1__DataArchiveImplTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__interface1__DataArchiveIface, _p_daal__data_management__interface1__DataArchiveIfaceTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__interface1__MatrixT_int_t, _p_daal__data_management__interface1__MatrixT_int_tTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__interface1__HomogenTensorT_double_t, _p_daal__data_management__interface1__HomogenTensorT_double_tTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__interface1__HomogenTensorT_float_t, _p_daal__data_management__interface1__HomogenTensorT_float_tTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__interface1__HomogenTensorT_int_t, _p_daal__data_management__interface1__HomogenTensorT_int_tTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__interface1__DataSourceFeature, _p_daal__data_management__interface1__DataSourceFeatureTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t, _p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_tTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t, _p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_tTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t, _p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_tTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t, _p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_tTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t, _p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_tTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t, _p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_tTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__interface1__DecompressionStream, _p_daal__data_management__interface1__DecompressionStreamTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__services__interface1__LibraryVersionInfo, _p_daal__services__interface1__LibraryVersionInfoTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__interface1__RowMergedNumericTable, _p_daal__data_management__interface1__RowMergedNumericTableTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__interface1__NumericTable, _p_daal__data_management__interface1__NumericTableTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__interface1__NumericTableFeature, _p_daal__data_management__interface1__NumericTableFeatureTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t, _p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_tTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t, _p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_tTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t, _p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_tTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t, _p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_tTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t, _p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_tTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t, _p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_tTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__Base, 0, 0, 0},  {&_swigt__p_daal__data_management__interface1__DecompressedDataArchive, _p_daal__data_management__interface1__DecompressedDataArchiveTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__interface1__MergedNumericTable, _p_daal__data_management__interface1__MergedNumericTableTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__interface1__DataBlock, _p_daal__data_management__interface1__DataBlockTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__interface1__Tensor, _p_daal__data_management__interface1__TensorTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__interface1__DataBlockIface, _p_daal__data_management__interface1__DataBlockIfaceTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__interface1__DataArchive, _p_daal__data_management__interface1__DataArchiveTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__interface1__SerializationIface, _p_daal__data_management__interface1__SerializationIfaceTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__interface1__CompressionStream, _p_daal__data_management__interface1__CompressionStreamTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__interface1__MatrixT_double_t, _p_daal__data_management__interface1__MatrixT_double_tTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__interface1__MatrixT_float_t, _p_daal__data_management__interface1__MatrixT_float_tTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__interface1__TensorLayout, _p_daal__data_management__interface1__TensorLayoutTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__modifiers__csv__interface1__Config, _p_daal__data_management__modifiers__csv__interface1__ConfigTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__modifiers__csv__interface1__Context, _p_daal__data_management__modifiers__csv__interface1__ContextTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__modifiers__csv__interface1__FeatureModifier, _p_daal__data_management__modifiers__csv__interface1__FeatureModifierTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__modifiers__csv__interface1__PyFeatureModifier, _p_daal__data_management__modifiers__csv__interface1__PyFeatureModifierTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__interface1__CompressedDataArchive, _p_daal__data_management__interface1__CompressedDataArchiveTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t, _p_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_tTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__interface1__OutputDataArchive, _p_daal__data_management__interface1__OutputDataArchiveTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__interface1__NpyAOSNumericTable, _p_daal__data_management__interface1__NpyAOSNumericTableTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__interface1__DataCollection, _p_daal__data_management__interface1__DataCollectionTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__interface1__TensorOffsetLayout, _p_daal__data_management__interface1__TensorOffsetLayoutTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__interface1__InputDataArchive, _p_daal__data_management__interface1__InputDataArchiveTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__services__interface1__Environment, _p_daal__services__interface1__EnvironmentTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__interface1__SOANumericTable, _p_daal__data_management__interface1__SOANumericTableTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__interface1__CSRNumericTable, _p_daal__data_management__interface1__CSRNumericTableTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t, _p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_tTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t, _p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_tTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__features__interface1__FeatureIdMapping, _p_daal__data_management__features__interface1__FeatureIdMappingTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__features__interface1__FeatureId, _p_daal__data_management__features__interface1__FeatureIdTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__features__interface1__FeatureIdCollection, _p_daal__data_management__features__interface1__FeatureIdCollectionTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__features__interface1__FeatureIndices, _p_daal__data_management__features__interface1__FeatureIndicesTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__interface1__HomogenNumericTableT_double_t, _p_daal__data_management__interface1__HomogenNumericTableT_double_tTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__interface1__HomogenNumericTableT_float_t, _p_daal__data_management__interface1__HomogenNumericTableT_float_tTo_p_daal__Base, 0, 0},  {&_swigt__p_daal__data_management__interface1__HomogenNumericTableT_int_t, _p_daal__data_management__interface1__HomogenNumericTableT_int_tTo_p_daal__Base, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__ColumnFilter[] = {  {&_swigt__p_daal__data_management__ColumnFilter, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__FeatureAuxData[] = {  {&_swigt__p_daal__data_management__FeatureAuxData, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__MakeCategorical[] = {  {&_swigt__p_daal__data_management__MakeCategorical, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__ModifierIface[] = {  {&_swigt__p_daal__data_management__OneHotEncoder, _p_daal__data_management__OneHotEncoderTo_p_daal__data_management__ModifierIface, 0, 0},  {&_swigt__p_daal__data_management__ModifierIface, 0, 0, 0},  {&_swigt__p_daal__data_management__ColumnFilter, _p_daal__data_management__ColumnFilterTo_p_daal__data_management__ModifierIface, 0, 0},  {&_swigt__p_daal__data_management__MakeCategorical, _p_daal__data_management__MakeCategoricalTo_p_daal__data_management__ModifierIface, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__OneHotEncoder[] = {  {&_swigt__p_daal__data_management__OneHotEncoder, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__features__interface1__FeatureIdCollectionIface[] = {  {&_swigt__p_daal__data_management__features__interface1__FeatureIdCollectionIface, 0, 0, 0},  {&_swigt__p_daal__data_management__features__interface1__FeatureIdCollection, _p_daal__data_management__features__interface1__FeatureIdCollectionTo_p_daal__data_management__features__interface1__FeatureIdCollectionIface, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__features__interface1__FeatureIdIface[] = {  {&_swigt__p_daal__data_management__features__interface1__FeatureIdIface, 0, 0, 0},  {&_swigt__p_daal__data_management__features__interface1__FeatureId, _p_daal__data_management__features__interface1__FeatureIdTo_p_daal__data_management__features__interface1__FeatureIdIface, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__features__interface1__FeatureIdMappingIface[] = {  {&_swigt__p_daal__data_management__features__interface1__FeatureIdMappingIface, 0, 0, 0},  {&_swigt__p_daal__data_management__features__interface1__FeatureIdMapping, _p_daal__data_management__features__interface1__FeatureIdMappingTo_p_daal__data_management__features__interface1__FeatureIdMappingIface, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__features__interface1__FeatureIndicesIface[] = {  {&_swigt__p_daal__data_management__features__interface1__FeatureIndicesIface, 0, 0, 0},  {&_swigt__p_daal__data_management__features__interface1__FeatureIndices, _p_daal__data_management__features__interface1__FeatureIndicesTo_p_daal__data_management__features__interface1__FeatureIndicesIface, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__BlockDescriptorT_double_t[] = {  {&_swigt__p_daal__data_management__interface1__BlockDescriptorT_double_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__BlockDescriptorT_float_t[] = {  {&_swigt__p_daal__data_management__interface1__BlockDescriptorT_float_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__BlockDescriptorT_int_t[] = {  {&_swigt__p_daal__data_management__interface1__BlockDescriptorT_int_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__Bzip2CompressionParameter[] = {  {&_swigt__p_daal__data_management__interface1__Bzip2CompressionParameter, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__CSRBlockDescriptorT_double_t[] = {  {&_swigt__p_daal__data_management__interface1__CSRBlockDescriptorT_double_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__CSRBlockDescriptorT_float_t[] = {  {&_swigt__p_daal__data_management__interface1__CSRBlockDescriptorT_float_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__CSRBlockDescriptorT_int_t[] = {  {&_swigt__p_daal__data_management__interface1__CSRBlockDescriptorT_int_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__CSRNumericTable[] = {  {&_swigt__p_daal__data_management__interface1__CSRNumericTable, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__CSRNumericTableIface[] = {  {&_swigt__p_daal__data_management__interface1__CSRNumericTableIface, 0, 0, 0},  {&_swigt__p_daal__data_management__interface1__CSRNumericTable, _p_daal__data_management__interface1__CSRNumericTableTo_p_daal__data_management__interface1__CSRNumericTableIface, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__CSVFeatureManager[] = {  {&_swigt__p_daal__data_management__interface1__CSVFeatureManager, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__CategoricalFeatureDictionary[] = {  {&_swigt__p_daal__data_management__interface1__CategoricalFeatureDictionary, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__CompressedDataArchive[] = {  {&_swigt__p_daal__data_management__interface1__CompressedDataArchive, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__Compression[] = {  {&_swigt__p_daal__data_management__interface1__DecompressorImpl, _p_daal__data_management__interface1__DecompressorImplTo_p_daal__data_management__interface1__Compression, 0, 0},  {&_swigt__p_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_t, _p_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_tTo_p_daal__data_management__interface1__Compression, 0, 0},  {&_swigt__p_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_t, _p_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_tTo_p_daal__data_management__interface1__Compression, 0, 0},  {&_swigt__p_daal__data_management__interface1__DecompressorT_daal__data_management__rle_t, _p_daal__data_management__interface1__DecompressorT_daal__data_management__rle_tTo_p_daal__data_management__interface1__Compression, 0, 0},  {&_swigt__p_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_t, _p_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_tTo_p_daal__data_management__interface1__Compression, 0, 0},  {&_swigt__p_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_t, _p_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_tTo_p_daal__data_management__interface1__Compression, 0, 0},  {&_swigt__p_daal__data_management__interface1__CompressorT_daal__data_management__lzo_t, _p_daal__data_management__interface1__CompressorT_daal__data_management__lzo_tTo_p_daal__data_management__interface1__Compression, 0, 0},  {&_swigt__p_daal__data_management__interface1__CompressorT_daal__data_management__rle_t, _p_daal__data_management__interface1__CompressorT_daal__data_management__rle_tTo_p_daal__data_management__interface1__Compression, 0, 0},  {&_swigt__p_daal__data_management__interface1__CompressorT_daal__data_management__zlib_t, _p_daal__data_management__interface1__CompressorT_daal__data_management__zlib_tTo_p_daal__data_management__interface1__Compression, 0, 0},  {&_swigt__p_daal__data_management__interface1__Compression, 0, 0, 0},  {&_swigt__p_daal__data_management__interface1__CompressorImpl, _p_daal__data_management__interface1__CompressorImplTo_p_daal__data_management__interface1__Compression, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__CompressionIface[] = {  {&_swigt__p_daal__data_management__interface1__DecompressorImpl, _p_daal__data_management__interface1__DecompressorImplTo_p_daal__data_management__interface1__CompressionIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_t, _p_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_tTo_p_daal__data_management__interface1__CompressionIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_t, _p_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_tTo_p_daal__data_management__interface1__CompressionIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__DecompressorT_daal__data_management__rle_t, _p_daal__data_management__interface1__DecompressorT_daal__data_management__rle_tTo_p_daal__data_management__interface1__CompressionIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_t, _p_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_tTo_p_daal__data_management__interface1__CompressionIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__CompressionIface, 0, 0, 0},  {&_swigt__p_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_t, _p_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_tTo_p_daal__data_management__interface1__CompressionIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__CompressorT_daal__data_management__lzo_t, _p_daal__data_management__interface1__CompressorT_daal__data_management__lzo_tTo_p_daal__data_management__interface1__CompressionIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__CompressorT_daal__data_management__rle_t, _p_daal__data_management__interface1__CompressorT_daal__data_management__rle_tTo_p_daal__data_management__interface1__CompressionIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__CompressorT_daal__data_management__zlib_t, _p_daal__data_management__interface1__CompressorT_daal__data_management__zlib_tTo_p_daal__data_management__interface1__CompressionIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__CompressorImpl, _p_daal__data_management__interface1__CompressorImplTo_p_daal__data_management__interface1__CompressionIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__Compression, _p_daal__data_management__interface1__CompressionTo_p_daal__data_management__interface1__CompressionIface, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__CompressionParameter[] = {  {&_swigt__p_daal__data_management__interface1__ZlibCompressionParameter, _p_daal__data_management__interface1__ZlibCompressionParameterTo_p_daal__data_management__interface1__CompressionParameter, 0, 0},  {&_swigt__p_daal__data_management__interface1__CompressionParameter, 0, 0, 0},  {&_swigt__p_daal__data_management__interface1__Bzip2CompressionParameter, _p_daal__data_management__interface1__Bzip2CompressionParameterTo_p_daal__data_management__interface1__CompressionParameter, 0, 0},  {&_swigt__p_daal__data_management__interface1__LzoCompressionParameter, _p_daal__data_management__interface1__LzoCompressionParameterTo_p_daal__data_management__interface1__CompressionParameter, 0, 0},  {&_swigt__p_daal__data_management__interface1__RleCompressionParameter, _p_daal__data_management__interface1__RleCompressionParameterTo_p_daal__data_management__interface1__CompressionParameter, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__CompressionStream[] = {  {&_swigt__p_daal__data_management__interface1__CompressionStream, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__CompressorImpl[] = {  {&_swigt__p_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_t, _p_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_tTo_p_daal__data_management__interface1__CompressorImpl, 0, 0},  {&_swigt__p_daal__data_management__interface1__CompressorT_daal__data_management__lzo_t, _p_daal__data_management__interface1__CompressorT_daal__data_management__lzo_tTo_p_daal__data_management__interface1__CompressorImpl, 0, 0},  {&_swigt__p_daal__data_management__interface1__CompressorT_daal__data_management__rle_t, _p_daal__data_management__interface1__CompressorT_daal__data_management__rle_tTo_p_daal__data_management__interface1__CompressorImpl, 0, 0},  {&_swigt__p_daal__data_management__interface1__CompressorT_daal__data_management__zlib_t, _p_daal__data_management__interface1__CompressorT_daal__data_management__zlib_tTo_p_daal__data_management__interface1__CompressorImpl, 0, 0},  {&_swigt__p_daal__data_management__interface1__CompressorImpl, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_t[] = {  {&_swigt__p_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__CompressorT_daal__data_management__lzo_t[] = {  {&_swigt__p_daal__data_management__interface1__CompressorT_daal__data_management__lzo_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__CompressorT_daal__data_management__rle_t[] = {  {&_swigt__p_daal__data_management__interface1__CompressorT_daal__data_management__rle_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__CompressorT_daal__data_management__zlib_t[] = {  {&_swigt__p_daal__data_management__interface1__CompressorT_daal__data_management__zlib_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__CsvDataSourceOptions[] = {  {&_swigt__p_daal__data_management__interface1__CsvDataSourceOptions, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t[] = {  {&_swigt__p_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t, _p_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_tTo_p_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t, 0, 0},  {&_swigt__p_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t, 0, 0, 0},  {&_swigt__p_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t, _p_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_tTo_p_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__DataArchive[] = {  {&_swigt__p_daal__data_management__interface1__DataArchive, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__DataArchiveIface[] = {  {&_swigt__p_daal__data_management__interface1__DataArchiveIface, 0, 0, 0},  {&_swigt__p_daal__data_management__interface1__DataArchiveImpl, _p_daal__data_management__interface1__DataArchiveImplTo_p_daal__data_management__interface1__DataArchiveIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__DecompressedDataArchive, _p_daal__data_management__interface1__DecompressedDataArchiveTo_p_daal__data_management__interface1__DataArchiveIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__DataArchive, _p_daal__data_management__interface1__DataArchiveTo_p_daal__data_management__interface1__DataArchiveIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__CompressedDataArchive, _p_daal__data_management__interface1__CompressedDataArchiveTo_p_daal__data_management__interface1__DataArchiveIface, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__DataArchiveImpl[] = {  {&_swigt__p_daal__data_management__interface1__DataArchiveImpl, 0, 0, 0},  {&_swigt__p_daal__data_management__interface1__DecompressedDataArchive, _p_daal__data_management__interface1__DecompressedDataArchiveTo_p_daal__data_management__interface1__DataArchiveImpl, 0, 0},  {&_swigt__p_daal__data_management__interface1__DataArchive, _p_daal__data_management__interface1__DataArchiveTo_p_daal__data_management__interface1__DataArchiveImpl, 0, 0},  {&_swigt__p_daal__data_management__interface1__CompressedDataArchive, _p_daal__data_management__interface1__CompressedDataArchiveTo_p_daal__data_management__interface1__DataArchiveImpl, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__DataBlock[] = {  {&_swigt__p_daal__data_management__interface1__DataBlock, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__DataBlockIface[] = {  {&_swigt__p_daal__data_management__interface1__DataBlock, _p_daal__data_management__interface1__DataBlockTo_p_daal__data_management__interface1__DataBlockIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__DataBlockIface, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__DataCollection[] = {  {&_swigt__p_daal__data_management__interface1__DataCollection, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__DataSource[] = {  {&_swigt__p_daal__data_management__interface1__DataSource, 0, 0, 0},  {&_swigt__p_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t, _p_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_tTo_p_daal__data_management__interface1__DataSource, 0, 0},  {&_swigt__p_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t, _p_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_tTo_p_daal__data_management__interface1__DataSource, 0, 0},  {&_swigt__p_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t, _p_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_tTo_p_daal__data_management__interface1__DataSource, 0, 0},  {&_swigt__p_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_float_t_double_t, _p_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_float_t_double_tTo_p_daal__data_management__interface1__DataSource, 0, 0},  {&_swigt__p_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_int_t_double_t, _p_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_int_t_double_tTo_p_daal__data_management__interface1__DataSource, 0, 0},  {&_swigt__p_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t, _p_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_tTo_p_daal__data_management__interface1__DataSource, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__DataSourceFeature[] = {  {&_swigt__p_daal__data_management__interface1__DataSourceFeature, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__DataSourceIface[] = {  {&_swigt__p_daal__data_management__interface1__DataSource, _p_daal__data_management__interface1__DataSourceTo_p_daal__data_management__interface1__DataSourceIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t, _p_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_tTo_p_daal__data_management__interface1__DataSourceIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__DataSourceIface, 0, 0, 0},  {&_swigt__p_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t, _p_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_tTo_p_daal__data_management__interface1__DataSourceIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t, _p_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_tTo_p_daal__data_management__interface1__DataSourceIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_float_t_double_t, _p_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_float_t_double_tTo_p_daal__data_management__interface1__DataSourceIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_int_t_double_t, _p_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_int_t_double_tTo_p_daal__data_management__interface1__DataSourceIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t, _p_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_tTo_p_daal__data_management__interface1__DataSourceIface, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t[] = {  {&_swigt__p_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t, _p_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_tTo_p_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t, 0, 0},  {&_swigt__p_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t, _p_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_tTo_p_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t, 0, 0},  {&_swigt__p_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t, 0, 0, 0},  {&_swigt__p_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t, _p_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_tTo_p_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_float_t_double_t[] = {  {&_swigt__p_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_float_t_double_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_int_t_double_t[] = {  {&_swigt__p_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_int_t_double_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__DecompressedDataArchive[] = {  {&_swigt__p_daal__data_management__interface1__DecompressedDataArchive, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__DecompressionStream[] = {  {&_swigt__p_daal__data_management__interface1__DecompressionStream, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__DecompressorImpl[] = {  {&_swigt__p_daal__data_management__interface1__DecompressorImpl, 0, 0, 0},  {&_swigt__p_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_t, _p_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_tTo_p_daal__data_management__interface1__DecompressorImpl, 0, 0},  {&_swigt__p_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_t, _p_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_tTo_p_daal__data_management__interface1__DecompressorImpl, 0, 0},  {&_swigt__p_daal__data_management__interface1__DecompressorT_daal__data_management__rle_t, _p_daal__data_management__interface1__DecompressorT_daal__data_management__rle_tTo_p_daal__data_management__interface1__DecompressorImpl, 0, 0},  {&_swigt__p_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_t, _p_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_tTo_p_daal__data_management__interface1__DecompressorImpl, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_t[] = {  {&_swigt__p_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_t[] = {  {&_swigt__p_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__DecompressorT_daal__data_management__rle_t[] = {  {&_swigt__p_daal__data_management__interface1__DecompressorT_daal__data_management__rle_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_t[] = {  {&_swigt__p_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__DenseNumericTableIface[] = {  {&_swigt__p_daal__data_management__interface1__MergedNumericTable, _p_daal__data_management__interface1__MergedNumericTableTo_p_daal__data_management__interface1__DenseNumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__NumericTable, _p_daal__data_management__interface1__NumericTableTo_p_daal__data_management__interface1__DenseNumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__MatrixT_int_t, _p_daal__data_management__interface1__MatrixT_int_tTo_p_daal__data_management__interface1__DenseNumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t, _p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_tTo_p_daal__data_management__interface1__DenseNumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t, _p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_tTo_p_daal__data_management__interface1__DenseNumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t, _p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_tTo_p_daal__data_management__interface1__DenseNumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t, _p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_tTo_p_daal__data_management__interface1__DenseNumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t, _p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_tTo_p_daal__data_management__interface1__DenseNumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t, _p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_tTo_p_daal__data_management__interface1__DenseNumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t, _p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_tTo_p_daal__data_management__interface1__DenseNumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t, _p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_tTo_p_daal__data_management__interface1__DenseNumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t, _p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_tTo_p_daal__data_management__interface1__DenseNumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t, _p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_tTo_p_daal__data_management__interface1__DenseNumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t, _p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_tTo_p_daal__data_management__interface1__DenseNumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t, _p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_tTo_p_daal__data_management__interface1__DenseNumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__HomogenNumericTableT_int_t, _p_daal__data_management__interface1__HomogenNumericTableT_int_tTo_p_daal__data_management__interface1__DenseNumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__HomogenNumericTableT_float_t, _p_daal__data_management__interface1__HomogenNumericTableT_float_tTo_p_daal__data_management__interface1__DenseNumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__HomogenNumericTableT_double_t, _p_daal__data_management__interface1__HomogenNumericTableT_double_tTo_p_daal__data_management__interface1__DenseNumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__DenseNumericTableIface, 0, 0, 0},  {&_swigt__p_daal__data_management__interface1__RowMergedNumericTable, _p_daal__data_management__interface1__RowMergedNumericTableTo_p_daal__data_management__interface1__DenseNumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__SOANumericTable, _p_daal__data_management__interface1__SOANumericTableTo_p_daal__data_management__interface1__DenseNumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__CSRNumericTable, _p_daal__data_management__interface1__CSRNumericTableTo_p_daal__data_management__interface1__DenseNumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__NpyAOSNumericTable, _p_daal__data_management__interface1__NpyAOSNumericTableTo_p_daal__data_management__interface1__DenseNumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__MatrixT_float_t, _p_daal__data_management__interface1__MatrixT_float_tTo_p_daal__data_management__interface1__DenseNumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__MatrixT_double_t, _p_daal__data_management__interface1__MatrixT_double_tTo_p_daal__data_management__interface1__DenseNumericTableIface, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__DenseTensorIface[] = {  {&_swigt__p_daal__data_management__interface1__DenseTensorIface, 0, 0, 0},  {&_swigt__p_daal__data_management__interface1__HomogenTensorT_double_t, _p_daal__data_management__interface1__HomogenTensorT_double_tTo_p_daal__data_management__interface1__DenseTensorIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__HomogenTensorT_float_t, _p_daal__data_management__interface1__HomogenTensorT_float_tTo_p_daal__data_management__interface1__DenseTensorIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__HomogenTensorT_int_t, _p_daal__data_management__interface1__HomogenTensorT_int_tTo_p_daal__data_management__interface1__DenseTensorIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__Tensor, _p_daal__data_management__interface1__TensorTo_p_daal__data_management__interface1__DenseTensorIface, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__DictionaryIface[] = {  {&_swigt__p_daal__data_management__interface1__DictionaryIface, 0, 0, 0},  {&_swigt__p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t, _p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_tTo_p_daal__data_management__interface1__DictionaryIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t, _p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_tTo_p_daal__data_management__interface1__DictionaryIface, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t[] = {  {&_swigt__p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t[] = {  {&_swigt__p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t[] = {  {&_swigt__p_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__HomogenNumericTableT_double_t[] = {  {&_swigt__p_daal__data_management__interface1__HomogenNumericTableT_double_t, 0, 0, 0},  {&_swigt__p_daal__data_management__interface1__MatrixT_double_t, _p_daal__data_management__interface1__MatrixT_double_tTo_p_daal__data_management__interface1__HomogenNumericTableT_double_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__HomogenNumericTableT_float_t[] = {  {&_swigt__p_daal__data_management__interface1__HomogenNumericTableT_float_t, 0, 0, 0},  {&_swigt__p_daal__data_management__interface1__MatrixT_float_t, _p_daal__data_management__interface1__MatrixT_float_tTo_p_daal__data_management__interface1__HomogenNumericTableT_float_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__HomogenNumericTableT_int_t[] = {  {&_swigt__p_daal__data_management__interface1__MatrixT_int_t, _p_daal__data_management__interface1__MatrixT_int_tTo_p_daal__data_management__interface1__HomogenNumericTableT_int_t, 0, 0},  {&_swigt__p_daal__data_management__interface1__HomogenNumericTableT_int_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__HomogenTensorT_double_t[] = {  {&_swigt__p_daal__data_management__interface1__HomogenTensorT_double_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__HomogenTensorT_float_t[] = {  {&_swigt__p_daal__data_management__interface1__HomogenTensorT_float_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__HomogenTensorT_int_t[] = {  {&_swigt__p_daal__data_management__interface1__HomogenTensorT_int_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__InputDataArchive[] = {  {&_swigt__p_daal__data_management__interface1__InputDataArchive, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__KeyValueCollectionT_algorithms__Input_t[] = {  {&_swigt__p_daal__data_management__interface1__KeyValueCollectionT_algorithms__Input_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__KeyValueCollectionT_daal__algorithms__interface1__Input_t[] = {  {&_swigt__p_daal__data_management__interface1__KeyValueCollectionT_daal__algorithms__interface1__Input_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__KeyValueCollectionT_daal__data_management__interface1__SerializationIface_t[] = {  {&_swigt__p_daal__data_management__interface1__KeyValueCollectionT_daal__data_management__interface1__SerializationIface_t, 0, 0, 0},  {&_swigt__p_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t, _p_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_tTo_p_daal__data_management__interface1__KeyValueCollectionT_daal__data_management__interface1__SerializationIface_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__LzoCompressionParameter[] = {  {&_swigt__p_daal__data_management__interface1__LzoCompressionParameter, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__MatrixT_double_t[] = {  {&_swigt__p_daal__data_management__interface1__MatrixT_double_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__MatrixT_float_t[] = {  {&_swigt__p_daal__data_management__interface1__MatrixT_float_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__MatrixT_int_t[] = {  {&_swigt__p_daal__data_management__interface1__MatrixT_int_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__MergedNumericTable[] = {  {&_swigt__p_daal__data_management__interface1__MergedNumericTable, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__NpyAOSNumericTable[] = {  {&_swigt__p_daal__data_management__interface1__NpyAOSNumericTable, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__NumericTable[] = {  {&_swigt__p_daal__data_management__interface1__MergedNumericTable, _p_daal__data_management__interface1__MergedNumericTableTo_p_daal__data_management__interface1__NumericTable, 0, 0},  {&_swigt__p_daal__data_management__interface1__NumericTable, 0, 0, 0},  {&_swigt__p_daal__data_management__interface1__MatrixT_int_t, _p_daal__data_management__interface1__MatrixT_int_tTo_p_daal__data_management__interface1__NumericTable, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t, _p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_tTo_p_daal__data_management__interface1__NumericTable, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t, _p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_tTo_p_daal__data_management__interface1__NumericTable, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t, _p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_tTo_p_daal__data_management__interface1__NumericTable, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t, _p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_tTo_p_daal__data_management__interface1__NumericTable, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t, _p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_tTo_p_daal__data_management__interface1__NumericTable, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t, _p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_tTo_p_daal__data_management__interface1__NumericTable, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t, _p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_tTo_p_daal__data_management__interface1__NumericTable, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t, _p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_tTo_p_daal__data_management__interface1__NumericTable, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t, _p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_tTo_p_daal__data_management__interface1__NumericTable, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t, _p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_tTo_p_daal__data_management__interface1__NumericTable, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t, _p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_tTo_p_daal__data_management__interface1__NumericTable, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t, _p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_tTo_p_daal__data_management__interface1__NumericTable, 0, 0},  {&_swigt__p_daal__data_management__interface1__HomogenNumericTableT_int_t, _p_daal__data_management__interface1__HomogenNumericTableT_int_tTo_p_daal__data_management__interface1__NumericTable, 0, 0},  {&_swigt__p_daal__data_management__interface1__HomogenNumericTableT_float_t, _p_daal__data_management__interface1__HomogenNumericTableT_float_tTo_p_daal__data_management__interface1__NumericTable, 0, 0},  {&_swigt__p_daal__data_management__interface1__HomogenNumericTableT_double_t, _p_daal__data_management__interface1__HomogenNumericTableT_double_tTo_p_daal__data_management__interface1__NumericTable, 0, 0},  {&_swigt__p_daal__data_management__interface1__RowMergedNumericTable, _p_daal__data_management__interface1__RowMergedNumericTableTo_p_daal__data_management__interface1__NumericTable, 0, 0},  {&_swigt__p_daal__data_management__interface1__SOANumericTable, _p_daal__data_management__interface1__SOANumericTableTo_p_daal__data_management__interface1__NumericTable, 0, 0},  {&_swigt__p_daal__data_management__interface1__CSRNumericTable, _p_daal__data_management__interface1__CSRNumericTableTo_p_daal__data_management__interface1__NumericTable, 0, 0},  {&_swigt__p_daal__data_management__interface1__NpyAOSNumericTable, _p_daal__data_management__interface1__NpyAOSNumericTableTo_p_daal__data_management__interface1__NumericTable, 0, 0},  {&_swigt__p_daal__data_management__interface1__MatrixT_float_t, _p_daal__data_management__interface1__MatrixT_float_tTo_p_daal__data_management__interface1__NumericTable, 0, 0},  {&_swigt__p_daal__data_management__interface1__MatrixT_double_t, _p_daal__data_management__interface1__MatrixT_double_tTo_p_daal__data_management__interface1__NumericTable, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__NumericTableFeature[] = {  {&_swigt__p_daal__data_management__interface1__NumericTableFeature, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__NumericTableIface[] = {  {&_swigt__p_daal__data_management__interface1__MergedNumericTable, _p_daal__data_management__interface1__MergedNumericTableTo_p_daal__data_management__interface1__NumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__NumericTable, _p_daal__data_management__interface1__NumericTableTo_p_daal__data_management__interface1__NumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__NumericTableIface, 0, 0, 0},  {&_swigt__p_daal__data_management__interface1__MatrixT_int_t, _p_daal__data_management__interface1__MatrixT_int_tTo_p_daal__data_management__interface1__NumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t, _p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_tTo_p_daal__data_management__interface1__NumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t, _p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_tTo_p_daal__data_management__interface1__NumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t, _p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_tTo_p_daal__data_management__interface1__NumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t, _p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_tTo_p_daal__data_management__interface1__NumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t, _p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_tTo_p_daal__data_management__interface1__NumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t, _p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_tTo_p_daal__data_management__interface1__NumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t, _p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_tTo_p_daal__data_management__interface1__NumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t, _p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_tTo_p_daal__data_management__interface1__NumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t, _p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_tTo_p_daal__data_management__interface1__NumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t, _p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_tTo_p_daal__data_management__interface1__NumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t, _p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_tTo_p_daal__data_management__interface1__NumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t, _p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_tTo_p_daal__data_management__interface1__NumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__HomogenNumericTableT_int_t, _p_daal__data_management__interface1__HomogenNumericTableT_int_tTo_p_daal__data_management__interface1__NumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__HomogenNumericTableT_float_t, _p_daal__data_management__interface1__HomogenNumericTableT_float_tTo_p_daal__data_management__interface1__NumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__HomogenNumericTableT_double_t, _p_daal__data_management__interface1__HomogenNumericTableT_double_tTo_p_daal__data_management__interface1__NumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__RowMergedNumericTable, _p_daal__data_management__interface1__RowMergedNumericTableTo_p_daal__data_management__interface1__NumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__SOANumericTable, _p_daal__data_management__interface1__SOANumericTableTo_p_daal__data_management__interface1__NumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__CSRNumericTable, _p_daal__data_management__interface1__CSRNumericTableTo_p_daal__data_management__interface1__NumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__NpyAOSNumericTable, _p_daal__data_management__interface1__NpyAOSNumericTableTo_p_daal__data_management__interface1__NumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__MatrixT_float_t, _p_daal__data_management__interface1__MatrixT_float_tTo_p_daal__data_management__interface1__NumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__MatrixT_double_t, _p_daal__data_management__interface1__MatrixT_double_tTo_p_daal__data_management__interface1__NumericTableIface, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__NumericTable__BasicStatisticsDataCollection[] = {  {&_swigt__p_daal__data_management__interface1__NumericTable__BasicStatisticsDataCollection, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__OutputDataArchive[] = {  {&_swigt__p_daal__data_management__interface1__OutputDataArchive, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__PackedArrayNumericTableIface[] = {  {&_swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t, _p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_tTo_p_daal__data_management__interface1__PackedArrayNumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t, _p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_tTo_p_daal__data_management__interface1__PackedArrayNumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t, _p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_tTo_p_daal__data_management__interface1__PackedArrayNumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t, _p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_tTo_p_daal__data_management__interface1__PackedArrayNumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t, _p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_tTo_p_daal__data_management__interface1__PackedArrayNumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t, _p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_tTo_p_daal__data_management__interface1__PackedArrayNumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t, _p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_tTo_p_daal__data_management__interface1__PackedArrayNumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t, _p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_tTo_p_daal__data_management__interface1__PackedArrayNumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t, _p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_tTo_p_daal__data_management__interface1__PackedArrayNumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t, _p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_tTo_p_daal__data_management__interface1__PackedArrayNumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t, _p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_tTo_p_daal__data_management__interface1__PackedArrayNumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t, _p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_tTo_p_daal__data_management__interface1__PackedArrayNumericTableIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedArrayNumericTableIface, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t[] = {  {&_swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t[] = {  {&_swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t[] = {  {&_swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t[] = {  {&_swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t[] = {  {&_swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t[] = {  {&_swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t[] = {  {&_swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t[] = {  {&_swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t[] = {  {&_swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t[] = {  {&_swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t[] = {  {&_swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t[] = {  {&_swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__RleCompressionParameter[] = {  {&_swigt__p_daal__data_management__interface1__RleCompressionParameter, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__RowMergedNumericTable[] = {  {&_swigt__p_daal__data_management__interface1__RowMergedNumericTable, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__SOANumericTable[] = {  {&_swigt__p_daal__data_management__interface1__SOANumericTable, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t[] = {  {&_swigt__p_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__SerializationDesc[] = {  {&_swigt__p_daal__data_management__interface1__SerializationDesc, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__SerializationIface[] = {  {&_swigt__p_daal__data_management__interface1__MatrixT_int_t, _p_daal__data_management__interface1__MatrixT_int_tTo_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__HomogenTensorT_int_t, _p_daal__data_management__interface1__HomogenTensorT_int_tTo_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__HomogenTensorT_float_t, _p_daal__data_management__interface1__HomogenTensorT_float_tTo_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__HomogenTensorT_double_t, _p_daal__data_management__interface1__HomogenTensorT_double_tTo_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__DataSourceFeature, _p_daal__data_management__interface1__DataSourceFeatureTo_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t, _p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_tTo_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t, _p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_tTo_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t, _p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_tTo_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t, _p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_tTo_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t, _p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_tTo_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t, _p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_tTo_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__RowMergedNumericTable, _p_daal__data_management__interface1__RowMergedNumericTableTo_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__NumericTable, _p_daal__data_management__interface1__NumericTableTo_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__NumericTableFeature, _p_daal__data_management__interface1__NumericTableFeatureTo_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t, _p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_tTo_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t, _p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_tTo_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t, _p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_tTo_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t, _p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_tTo_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t, _p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_tTo_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t, _p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_tTo_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__Tensor, _p_daal__data_management__interface1__TensorTo_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__MergedNumericTable, _p_daal__data_management__interface1__MergedNumericTableTo_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__SerializationIface, 0, 0, 0},  {&_swigt__p_daal__data_management__interface1__TensorLayout, _p_daal__data_management__interface1__TensorLayoutTo_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__MatrixT_double_t, _p_daal__data_management__interface1__MatrixT_double_tTo_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__MatrixT_float_t, _p_daal__data_management__interface1__MatrixT_float_tTo_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t, _p_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_tTo_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__NpyAOSNumericTable, _p_daal__data_management__interface1__NpyAOSNumericTableTo_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__DataCollection, _p_daal__data_management__interface1__DataCollectionTo_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__TensorOffsetLayout, _p_daal__data_management__interface1__TensorOffsetLayoutTo_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__CSRNumericTable, _p_daal__data_management__interface1__CSRNumericTableTo_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__SOANumericTable, _p_daal__data_management__interface1__SOANumericTableTo_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t, _p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_tTo_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t, _p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_tTo_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__HomogenNumericTableT_double_t, _p_daal__data_management__interface1__HomogenNumericTableT_double_tTo_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__HomogenNumericTableT_float_t, _p_daal__data_management__interface1__HomogenNumericTableT_float_tTo_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__HomogenNumericTableT_int_t, _p_daal__data_management__interface1__HomogenNumericTableT_int_tTo_p_daal__data_management__interface1__SerializationIface, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t[] = {  {&_swigt__p_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__StringRowFeatureManagerIface[] = {  {&_swigt__p_daal__data_management__interface1__StringRowFeatureManagerIface, 0, 0, 0},  {&_swigt__p_daal__data_management__interface1__CSVFeatureManager, _p_daal__data_management__interface1__CSVFeatureManagerTo_p_daal__data_management__interface1__StringRowFeatureManagerIface, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__SubtensorDescriptorT_double_t[] = {  {&_swigt__p_daal__data_management__interface1__SubtensorDescriptorT_double_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__SubtensorDescriptorT_float_t[] = {  {&_swigt__p_daal__data_management__interface1__SubtensorDescriptorT_float_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__SubtensorDescriptorT_int_t[] = {  {&_swigt__p_daal__data_management__interface1__SubtensorDescriptorT_int_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__Tensor[] = {  {&_swigt__p_daal__data_management__interface1__HomogenTensorT_double_t, _p_daal__data_management__interface1__HomogenTensorT_double_tTo_p_daal__data_management__interface1__Tensor, 0, 0},  {&_swigt__p_daal__data_management__interface1__HomogenTensorT_float_t, _p_daal__data_management__interface1__HomogenTensorT_float_tTo_p_daal__data_management__interface1__Tensor, 0, 0},  {&_swigt__p_daal__data_management__interface1__HomogenTensorT_int_t, _p_daal__data_management__interface1__HomogenTensorT_int_tTo_p_daal__data_management__interface1__Tensor, 0, 0},  {&_swigt__p_daal__data_management__interface1__Tensor, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__TensorIface[] = {  {&_swigt__p_daal__data_management__interface1__TensorIface, 0, 0, 0},  {&_swigt__p_daal__data_management__interface1__HomogenTensorT_double_t, _p_daal__data_management__interface1__HomogenTensorT_double_tTo_p_daal__data_management__interface1__TensorIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__HomogenTensorT_float_t, _p_daal__data_management__interface1__HomogenTensorT_float_tTo_p_daal__data_management__interface1__TensorIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__HomogenTensorT_int_t, _p_daal__data_management__interface1__HomogenTensorT_int_tTo_p_daal__data_management__interface1__TensorIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__Tensor, _p_daal__data_management__interface1__TensorTo_p_daal__data_management__interface1__TensorIface, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__TensorLayout[] = {  {&_swigt__p_daal__data_management__interface1__TensorLayout, 0, 0, 0},  {&_swigt__p_daal__data_management__interface1__TensorOffsetLayout, _p_daal__data_management__interface1__TensorOffsetLayoutTo_p_daal__data_management__interface1__TensorLayout, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__TensorLayoutIface[] = {  {&_swigt__p_daal__data_management__interface1__TensorLayoutIface, 0, 0, 0},  {&_swigt__p_daal__data_management__interface1__TensorLayout, _p_daal__data_management__interface1__TensorLayoutTo_p_daal__data_management__interface1__TensorLayoutIface, 0, 0},  {&_swigt__p_daal__data_management__interface1__TensorOffsetLayout, _p_daal__data_management__interface1__TensorOffsetLayoutTo_p_daal__data_management__interface1__TensorLayoutIface, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__TensorOffsetLayout[] = {  {&_swigt__p_daal__data_management__interface1__TensorOffsetLayout, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__data_management__interface1__ZlibCompressionParameter[] = {  {&_swigt__p_daal__data_management__interface1__ZlibCompressionParameter, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__CollectionT_daal__data_management__FeatureAuxData_t[] = {  {&_swigt__p_daal__services__CollectionT_daal__data_management__FeatureAuxData_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__CollectionT_daal__services__SharedPtrT_daal__algorithms__interface1__Input_t_t[] = {  {&_swigt__p_daal__services__CollectionT_daal__services__SharedPtrT_daal__algorithms__interface1__Input_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__CollectionT_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t_t[] = {  {&_swigt__p_daal__data_management__interface1__DataCollection, _p_daal__data_management__interface1__DataCollectionTo_p_daal__services__CollectionT_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t_t, 0, 0},  {&_swigt__p_daal__services__CollectionT_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__CollectionT_size_t_t[] = {  {&_swigt__p_daal__services__CollectionT_size_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__CollectionT_void_fpFfchar_const_p_daal__data_management__FeatureAuxData_R_double_pF_t[] = {  {&_swigt__p_daal__services__CollectionT_void_fpFfchar_const_p_daal__data_management__FeatureAuxData_R_double_pF_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__Base_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayout_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayout_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlockIface_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlockIface_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchive_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchive_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveImpl_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveImpl_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressedDataArchive_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CompressedDataArchive_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressedDataArchive_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressedDataArchive_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressionStream_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressionStream_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionStream_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionStream_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__PyFeatureModifier_t, _p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__PyFeatureModifier_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifier_t, _p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifier_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Context_t, _p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Context_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Config_t, _p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Config_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataCollection_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DataCollection_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__InputDataArchive_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__InputDataArchive_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__OutputDataArchive_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__OutputDataArchive_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndices_t, _p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndices_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdCollection_t, _p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdCollection_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureId_t, _p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureId_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdMapping_t, _p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdMapping_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__services__interface1__LibraryVersionInfo_t, _p_daal__services__SharedPtrT_daal__services__interface1__LibraryVersionInfo_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__services__interface1__Environment_t, _p_daal__services__SharedPtrT_daal__services__interface1__Environment_tTo_p_daal__services__SharedPtrT_daal__Base_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__Base_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__batch_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__batch_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__distributed_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__distributed_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__online_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__online_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__batch_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__batch_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__distributed_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__distributed_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__online_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__online_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__DistributedPredictionContainerIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__DistributedPredictionContainerIface_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__DistributedPrediction_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__DistributedPrediction_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__PredictionContainerIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__PredictionContainerIface_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__Prediction_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__Prediction_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__batch_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__batch_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__distributed_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__distributed_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__online_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__online_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIfaceImpl_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIfaceImpl_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIface_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__batch_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__batch_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__distributed_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__distributed_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__online_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__online_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__batch_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__batch_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__distributed_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__distributed_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__online_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__online_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmDispatchContainer_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmDispatchContainer_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIfaceImpl_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIfaceImpl_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIface_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__batch_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__batch_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__distributed_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__distributed_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__online_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__online_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__batch_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__batch_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__distributed_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__distributed_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__online_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__online_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__Argument_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__Argument_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__HostAppIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__HostAppIface_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__Input_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__Input_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__Kernel_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__Kernel_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__Model_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__Model_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__OptionalArgument_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__OptionalArgument_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__Parameter_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__Parameter_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__PartialResult_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__PartialResult_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__Result_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__Result_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__SerializableArgument_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__algorithms__interface1__SerializableArgument_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdCollectionIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdCollectionIface_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdCollection_t, _p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdCollection_tTo_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdCollectionIface_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdCollection_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdCollection_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdIface_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureId_t, _p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureId_tTo_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdIface_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdMappingIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdMappingIface_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdMapping_t, _p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdMapping_tTo_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdMappingIface_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdMapping_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdMapping_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureId_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureId_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndexTraits_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndexTraits_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndicesIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndicesIface_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndices_t, _p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndices_tTo_p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndicesIface_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndices_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndices_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__BasicStatisticsDataCollection_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__BasicStatisticsDataCollection_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_double_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_double_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_float_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_float_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_int_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_int_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTableIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTableIface_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTableIface_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CSVFeatureManager_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSVFeatureManager_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CategoricalFeatureDictionary_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CategoricalFeatureDictionary_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__ColumnFilter_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__ColumnFilter_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressedDataArchive_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressedDataArchive_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__lzo_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__lzo_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__rle_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__rle_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__zlib_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__zlib_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__rle_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__rle_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionStream_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionStream_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__lzo_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__lzo_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__rle_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__rle_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__zlib_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__zlib_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__rle_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__rle_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__lzo_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__lzo_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__rle_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__rle_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__zlib_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__zlib_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__lzo_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__lzo_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__rle_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__rle_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__zlib_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__zlib_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveImpl_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveImpl_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchive_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchive_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressedDataArchive_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CompressedDataArchive_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressedDataArchive_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressedDataArchive_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveImpl_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveImpl_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchive_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchive_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveImpl_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressedDataArchive_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CompressedDataArchive_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveImpl_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressedDataArchive_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressedDataArchive_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveImpl_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchive_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchive_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlockIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlockIface_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlockIface_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DataCollection_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataCollection_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_float_t_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_float_t_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_int_t_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_int_t_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_float_t_double_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_float_t_double_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_int_t_double_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_int_t_double_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_float_t_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_float_t_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_int_t_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_int_t_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressedDataArchive_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressedDataArchive_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressionStream_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressionStream_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__rle_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__rle_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__rle_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__rle_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryIface_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryIface_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdCollectionIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdCollectionIface_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdCollection_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdCollection_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdIface_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdMappingIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdMappingIface_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdMapping_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdMapping_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureId_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureId_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIndexTraits_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIndexTraits_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIndicesIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIndicesIface_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIndices_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIndices_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__InputDataArchive_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__InputDataArchive_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_algorithms__Input_t_const_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_algorithms__Input_t_const_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_algorithms__Input_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_algorithms__Input_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__algorithms__interface1__Input_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__algorithms__interface1__Input_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__MakeCategorical_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MakeCategorical_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__ModifierIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__ModifierIface_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_const_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_const_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__OneHotEncoder_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__OneHotEncoder_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__OutputDataArchive_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__OutputDataArchive_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_const_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_const_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayout_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayout_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DataCollection_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DataCollection_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__StringRowFeatureManagerIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__StringRowFeatureManagerIface_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__CSVFeatureManager_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__CSVFeatureManager_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__StringRowFeatureManagerIface_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorIface_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorIface_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayoutIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayoutIface_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayout_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayout_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayoutIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayoutIface_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayout_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayout_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayout_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t, _p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_tTo_p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__ConfigIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__ConfigIface_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Config_t, _p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Config_tTo_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__ConfigIface_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Config_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Config_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__ContextIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__ContextIface_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Context_t, _p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Context_tTo_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__ContextIface_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Context_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Context_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifierIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifierIface_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifier_t, _p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifier_tTo_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifierIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__PyFeatureModifier_t, _p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__PyFeatureModifier_tTo_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifierIface_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifier_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifier_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__PyFeatureModifier_t, _p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__PyFeatureModifier_tTo_p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifier_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__PyFeatureModifier_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__PyFeatureModifier_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__modifiers__interface1__ConfigIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__interface1__ConfigIface_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__ConfigIface_t, _p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__ConfigIface_tTo_p_daal__services__SharedPtrT_daal__data_management__modifiers__interface1__ConfigIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Config_t, _p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Config_tTo_p_daal__services__SharedPtrT_daal__data_management__modifiers__interface1__ConfigIface_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__data_management__modifiers__interface1__ContextIface_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__interface1__ContextIface_t, 0, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__ContextIface_t, _p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__ContextIface_tTo_p_daal__services__SharedPtrT_daal__data_management__modifiers__interface1__ContextIface_t, 0, 0},  {&_swigt__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Context_t, _p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Context_tTo_p_daal__services__SharedPtrT_daal__data_management__modifiers__interface1__ContextIface_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__backward__LayerIfacePtr_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__backward__LayerIfacePtr_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__forward__LayerIfacePtr_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__forward__LayerIfacePtr_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__forward__interface1__LayerDescriptor_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__forward__interface1__LayerDescriptor_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__interface1__NextLayers_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__interface1__NextLayers_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__data_management__interface1__SerializationIfacePtr_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__data_management__interface1__SerializationIfacePtr_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__services__interface1__Environment_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__services__interface1__Environment_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__services__interface1__ErrorCollection_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__services__interface1__ErrorCollection_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__services__interface1__Error_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__services__interface1__Error_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__services__interface1__KernelErrorCollection_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__services__interface1__KernelErrorCollection_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_daal__services__interface1__LibraryVersionInfo_t[] = {  {&_swigt__p_daal__services__SharedPtrT_daal__services__interface1__LibraryVersionInfo_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_double_t[] = {  {&_swigt__p_daal__services__SharedPtrT_double_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_float_t[] = {  {&_swigt__p_daal__services__SharedPtrT_float_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_int_t[] = {  {&_swigt__p_daal__services__SharedPtrT_int_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_size_t_t[] = {  {&_swigt__p_daal__services__SharedPtrT_size_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__SharedPtrT_unsigned_char_t[] = {  {&_swigt__p_daal__services__SharedPtrT_unsigned_char_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__String[] = {  {&_swigt__p_daal__services__String, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__interface1__CollectionT_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t_t[] = {  {&_swigt__p_daal__services__interface1__CollectionT_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_daal__services__interface1__Status[] = {  {&_swigt__p_daal__services__interface1__Status, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_double[] = {  {&_swigt__p_double, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_env[] = {  {&_swigt__p_env, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_f___p_daal__data_management__interface1__MatrixT_float_t[] = {{&_swigt__p_f___p_daal__data_management__interface1__MatrixT_float_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_f___p_daal__data_management__interface1__MatrixT_double_t[] = {{&_swigt__p_f___p_daal__data_management__interface1__MatrixT_double_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_f___p_daal__data_management__interface1__MatrixT_int_t[] = {{&_swigt__p_f___p_daal__data_management__interface1__MatrixT_int_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_f___p_daal__data_management__interface1__HomogenNumericTableT_double_t[] = {{&_swigt__p_f___p_daal__data_management__interface1__HomogenNumericTableT_double_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_f___p_daal__data_management__interface1__HomogenNumericTableT_float_t[] = {{&_swigt__p_f___p_daal__data_management__interface1__HomogenNumericTableT_float_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_f___p_daal__data_management__interface1__HomogenNumericTableT_int_t[] = {{&_swigt__p_f___p_daal__data_management__interface1__HomogenNumericTableT_int_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_f___p_daal__data_management__interface1__HomogenTensorT_int_t[] = {{&_swigt__p_f___p_daal__data_management__interface1__HomogenTensorT_int_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_f___p_daal__data_management__interface1__HomogenTensorT_float_t[] = {{&_swigt__p_f___p_daal__data_management__interface1__HomogenTensorT_float_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_f___p_daal__data_management__interface1__HomogenTensorT_double_t[] = {{&_swigt__p_f___p_daal__data_management__interface1__HomogenTensorT_double_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_f___p_daal__data_management__interface1__SOANumericTable[] = {{&_swigt__p_f___p_daal__data_management__interface1__SOANumericTable, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_f___p_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t[] = {{&_swigt__p_f___p_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t[] = {{&_swigt__p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t[] = {{&_swigt__p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t[] = {{&_swigt__p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t[] = {{&_swigt__p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t[] = {{&_swigt__p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t[] = {{&_swigt__p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t[] = {{&_swigt__p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t[] = {{&_swigt__p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t[] = {{&_swigt__p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t[] = {{&_swigt__p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t[] = {{&_swigt__p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t[] = {{&_swigt__p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_f___p_daal__data_management__interface1__TensorOffsetLayout[] = {{&_swigt__p_f___p_daal__data_management__interface1__TensorOffsetLayout, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_f___p_daal__data_management__interface1__Tensor[] = {{&_swigt__p_f___p_daal__data_management__interface1__Tensor, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_f___p_daal__data_management__interface1__TensorLayout[] = {{&_swigt__p_f___p_daal__data_management__interface1__TensorLayout, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_f___p_daal__data_management__interface1__DataSourceFeature[] = {{&_swigt__p_f___p_daal__data_management__interface1__DataSourceFeature, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_f___p_daal__data_management__interface1__NpyAOSNumericTable[] = {{&_swigt__p_f___p_daal__data_management__interface1__NpyAOSNumericTable, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_f___p_daal__data_management__interface1__RowMergedNumericTable[] = {{&_swigt__p_f___p_daal__data_management__interface1__RowMergedNumericTable, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_f___p_daal__data_management__interface1__DataCollection[] = {{&_swigt__p_f___p_daal__data_management__interface1__DataCollection, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_f___p_daal__data_management__interface1__NumericTable[] = {{&_swigt__p_f___p_daal__data_management__interface1__NumericTable, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_f___p_daal__data_management__interface1__NumericTableFeature[] = {{&_swigt__p_f___p_daal__data_management__interface1__NumericTableFeature, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_f___p_daal__data_management__interface1__CSRNumericTable[] = {{&_swigt__p_f___p_daal__data_management__interface1__CSRNumericTable, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_f___p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t[] = {{&_swigt__p_f___p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_f___p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t[] = {{&_swigt__p_f___p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_f___p_daal__data_management__interface1__MergedNumericTable[] = {{&_swigt__p_f___p_daal__data_management__interface1__MergedNumericTable, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_f___p_daal__data_management__interface1__SerializationIface[] = {  {&_swigt__p_f___p_daal__data_management__interface1__MatrixT_float_t, _p_f___p_daal__data_management__interface1__MatrixT_float_tTo_p_f___p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_f___p_daal__data_management__interface1__MatrixT_double_t, _p_f___p_daal__data_management__interface1__MatrixT_double_tTo_p_f___p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_f___p_daal__data_management__interface1__MatrixT_int_t, _p_f___p_daal__data_management__interface1__MatrixT_int_tTo_p_f___p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_f___p_daal__data_management__interface1__HomogenNumericTableT_double_t, _p_f___p_daal__data_management__interface1__HomogenNumericTableT_double_tTo_p_f___p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_f___p_daal__data_management__interface1__HomogenNumericTableT_float_t, _p_f___p_daal__data_management__interface1__HomogenNumericTableT_float_tTo_p_f___p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_f___p_daal__data_management__interface1__HomogenNumericTableT_int_t, _p_f___p_daal__data_management__interface1__HomogenNumericTableT_int_tTo_p_f___p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_f___p_daal__data_management__interface1__HomogenTensorT_int_t, _p_f___p_daal__data_management__interface1__HomogenTensorT_int_tTo_p_f___p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_f___p_daal__data_management__interface1__HomogenTensorT_float_t, _p_f___p_daal__data_management__interface1__HomogenTensorT_float_tTo_p_f___p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_f___p_daal__data_management__interface1__HomogenTensorT_double_t, _p_f___p_daal__data_management__interface1__HomogenTensorT_double_tTo_p_f___p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_f___p_daal__data_management__interface1__SOANumericTable, _p_f___p_daal__data_management__interface1__SOANumericTableTo_p_f___p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_f___p_daal__data_management__interface1__SerializationIface, 0, 0, 0},  {&_swigt__p_f___p_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t, _p_f___p_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_tTo_p_f___p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t, _p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_tTo_p_f___p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t, _p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_tTo_p_f___p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t, _p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_tTo_p_f___p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t, _p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_tTo_p_f___p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t, _p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_tTo_p_f___p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t, _p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_tTo_p_f___p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t, _p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_tTo_p_f___p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t, _p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_tTo_p_f___p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t, _p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_tTo_p_f___p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t, _p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_tTo_p_f___p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t, _p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_tTo_p_f___p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t, _p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_tTo_p_f___p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_f___p_daal__data_management__interface1__TensorOffsetLayout, _p_f___p_daal__data_management__interface1__TensorOffsetLayoutTo_p_f___p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_f___p_daal__data_management__interface1__Tensor, _p_f___p_daal__data_management__interface1__TensorTo_p_f___p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_f___p_daal__data_management__interface1__TensorLayout, _p_f___p_daal__data_management__interface1__TensorLayoutTo_p_f___p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_f___p_daal__data_management__interface1__DataSourceFeature, _p_f___p_daal__data_management__interface1__DataSourceFeatureTo_p_f___p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_f___p_daal__data_management__interface1__NpyAOSNumericTable, _p_f___p_daal__data_management__interface1__NpyAOSNumericTableTo_p_f___p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_f___p_daal__data_management__interface1__RowMergedNumericTable, _p_f___p_daal__data_management__interface1__RowMergedNumericTableTo_p_f___p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_f___p_daal__data_management__interface1__DataCollection, _p_f___p_daal__data_management__interface1__DataCollectionTo_p_f___p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_f___p_daal__data_management__interface1__NumericTable, _p_f___p_daal__data_management__interface1__NumericTableTo_p_f___p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_f___p_daal__data_management__interface1__NumericTableFeature, _p_f___p_daal__data_management__interface1__NumericTableFeatureTo_p_f___p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_f___p_daal__data_management__interface1__CSRNumericTable, _p_f___p_daal__data_management__interface1__CSRNumericTableTo_p_f___p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_f___p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t, _p_f___p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_tTo_p_f___p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_f___p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t, _p_f___p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_tTo_p_f___p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_f___p_daal__data_management__interface1__MergedNumericTable, _p_f___p_daal__data_management__interface1__MergedNumericTableTo_p_f___p_daal__data_management__interface1__SerializationIface, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_first_type[] = {  {&_swigt__p_first_type, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_float[] = {  {&_swigt__p_float, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_int[] = {  {&_swigt__p_int, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_numericTableType[] = {  {&_swigt__p_numericTableType, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_p_daal__data_management__interface1__BlockDescriptorT_double_t[] = {  {&_swigt__p_p_daal__data_management__interface1__BlockDescriptorT_double_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_p_daal__data_management__interface1__BlockDescriptorT_float_t[] = {  {&_swigt__p_p_daal__data_management__interface1__BlockDescriptorT_float_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_p_daal__data_management__interface1__BlockDescriptorT_int_t[] = {  {&_swigt__p_p_daal__data_management__interface1__BlockDescriptorT_int_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_p_daal__data_management__interface1__DataCollection[] = {{&_swigt__p_p_daal__data_management__interface1__DataCollection, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_p_daal__data_management__interface1__MatrixT_double_t[] = {{&_swigt__p_p_daal__data_management__interface1__MatrixT_double_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_p_daal__data_management__interface1__HomogenNumericTableT_double_t[] = {{&_swigt__p_p_daal__data_management__interface1__HomogenNumericTableT_double_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_p_daal__data_management__interface1__HomogenNumericTableT_float_t[] = {{&_swigt__p_p_daal__data_management__interface1__HomogenNumericTableT_float_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_p_daal__data_management__interface1__HomogenNumericTableT_int_t[] = {{&_swigt__p_p_daal__data_management__interface1__HomogenNumericTableT_int_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_p_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t[] = {{&_swigt__p_p_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_p_daal__data_management__interface1__TensorOffsetLayout[] = {{&_swigt__p_p_daal__data_management__interface1__TensorOffsetLayout, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_p_daal__data_management__interface1__SOANumericTable[] = {{&_swigt__p_p_daal__data_management__interface1__SOANumericTable, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_p_daal__data_management__interface1__CSRNumericTable[] = {{&_swigt__p_p_daal__data_management__interface1__CSRNumericTable, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_p_daal__data_management__interface1__NumericTableFeature[] = {{&_swigt__p_p_daal__data_management__interface1__NumericTableFeature, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_p_daal__data_management__interface1__NumericTable[] = {{&_swigt__p_p_daal__data_management__interface1__NumericTable, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_p_daal__data_management__interface1__TensorLayout[] = {{&_swigt__p_p_daal__data_management__interface1__TensorLayout, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_p_daal__data_management__interface1__RowMergedNumericTable[] = {{&_swigt__p_p_daal__data_management__interface1__RowMergedNumericTable, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_p_daal__data_management__interface1__HomogenTensorT_double_t[] = {{&_swigt__p_p_daal__data_management__interface1__HomogenTensorT_double_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_p_daal__data_management__interface1__HomogenTensorT_float_t[] = {{&_swigt__p_p_daal__data_management__interface1__HomogenTensorT_float_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_p_daal__data_management__interface1__HomogenTensorT_int_t[] = {{&_swigt__p_p_daal__data_management__interface1__HomogenTensorT_int_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_p_daal__data_management__interface1__Tensor[] = {{&_swigt__p_p_daal__data_management__interface1__Tensor, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_p_daal__data_management__interface1__MatrixT_int_t[] = {{&_swigt__p_p_daal__data_management__interface1__MatrixT_int_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_p_daal__data_management__interface1__MergedNumericTable[] = {{&_swigt__p_p_daal__data_management__interface1__MergedNumericTable, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t[] = {{&_swigt__p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t[] = {{&_swigt__p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t[] = {{&_swigt__p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t[] = {{&_swigt__p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t[] = {{&_swigt__p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t[] = {{&_swigt__p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t[] = {{&_swigt__p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t[] = {{&_swigt__p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t[] = {{&_swigt__p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t[] = {{&_swigt__p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t[] = {{&_swigt__p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t[] = {{&_swigt__p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_p_daal__data_management__interface1__DataSourceFeature[] = {{&_swigt__p_p_daal__data_management__interface1__DataSourceFeature, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_p_daal__data_management__interface1__MatrixT_float_t[] = {{&_swigt__p_p_daal__data_management__interface1__MatrixT_float_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t[] = {{&_swigt__p_p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t[] = {{&_swigt__p_p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_p_daal__data_management__interface1__NpyAOSNumericTable[] = {{&_swigt__p_p_daal__data_management__interface1__NpyAOSNumericTable, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_p_daal__data_management__interface1__SerializationIface[] = {  {&_swigt__p_p_daal__data_management__interface1__DataCollection, _p_p_daal__data_management__interface1__DataCollectionTo_p_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_p_daal__data_management__interface1__MatrixT_double_t, _p_p_daal__data_management__interface1__MatrixT_double_tTo_p_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_p_daal__data_management__interface1__HomogenNumericTableT_double_t, _p_p_daal__data_management__interface1__HomogenNumericTableT_double_tTo_p_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_p_daal__data_management__interface1__HomogenNumericTableT_float_t, _p_p_daal__data_management__interface1__HomogenNumericTableT_float_tTo_p_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_p_daal__data_management__interface1__HomogenNumericTableT_int_t, _p_p_daal__data_management__interface1__HomogenNumericTableT_int_tTo_p_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_p_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t, _p_p_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_tTo_p_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_p_daal__data_management__interface1__TensorOffsetLayout, _p_p_daal__data_management__interface1__TensorOffsetLayoutTo_p_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_p_daal__data_management__interface1__SOANumericTable, _p_p_daal__data_management__interface1__SOANumericTableTo_p_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_p_daal__data_management__interface1__CSRNumericTable, _p_p_daal__data_management__interface1__CSRNumericTableTo_p_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_p_daal__data_management__interface1__NumericTableFeature, _p_p_daal__data_management__interface1__NumericTableFeatureTo_p_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_p_daal__data_management__interface1__NumericTable, _p_p_daal__data_management__interface1__NumericTableTo_p_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_p_daal__data_management__interface1__TensorLayout, _p_p_daal__data_management__interface1__TensorLayoutTo_p_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_p_daal__data_management__interface1__RowMergedNumericTable, _p_p_daal__data_management__interface1__RowMergedNumericTableTo_p_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_p_daal__data_management__interface1__HomogenTensorT_double_t, _p_p_daal__data_management__interface1__HomogenTensorT_double_tTo_p_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_p_daal__data_management__interface1__HomogenTensorT_float_t, _p_p_daal__data_management__interface1__HomogenTensorT_float_tTo_p_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_p_daal__data_management__interface1__HomogenTensorT_int_t, _p_p_daal__data_management__interface1__HomogenTensorT_int_tTo_p_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_p_daal__data_management__interface1__Tensor, _p_p_daal__data_management__interface1__TensorTo_p_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_p_daal__data_management__interface1__MatrixT_int_t, _p_p_daal__data_management__interface1__MatrixT_int_tTo_p_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_p_daal__data_management__interface1__MergedNumericTable, _p_p_daal__data_management__interface1__MergedNumericTableTo_p_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t, _p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_tTo_p_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t, _p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_tTo_p_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t, _p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_tTo_p_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t, _p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_tTo_p_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t, _p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_tTo_p_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t, _p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_tTo_p_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t, _p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_tTo_p_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t, _p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_tTo_p_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t, _p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_tTo_p_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t, _p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_tTo_p_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t, _p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_tTo_p_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t, _p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_tTo_p_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_p_daal__data_management__interface1__SerializationIface, 0, 0, 0},  {&_swigt__p_p_daal__data_management__interface1__DataSourceFeature, _p_p_daal__data_management__interface1__DataSourceFeatureTo_p_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_p_daal__data_management__interface1__MatrixT_float_t, _p_p_daal__data_management__interface1__MatrixT_float_tTo_p_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t, _p_p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_tTo_p_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t, _p_p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_tTo_p_p_daal__data_management__interface1__SerializationIface, 0, 0},  {&_swigt__p_p_daal__data_management__interface1__NpyAOSNumericTable, _p_p_daal__data_management__interface1__NpyAOSNumericTableTo_p_p_daal__data_management__interface1__SerializationIface, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_p_daal__services__CollectionT_size_t_t[] = {  {&_swigt__p_p_daal__services__CollectionT_size_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_p_size_t[] = {  {&_swigt__p_p_size_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_second_type[] = {  {&_swigt__p_second_type, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_size_t[] = {  {&_swigt__p_size_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__mapT_std__string_std__pairT_int_int_t_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__pairT_int_int_t_t_t_t[] = {  {&_swigt__p_std__mapT_std__string_std__pairT_int_int_t_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__pairT_int_int_t_t_t_t, 0, 0, 0},  {&_swigt__p_daal__data_management__interface1__CategoricalFeatureDictionary, _p_daal__data_management__interface1__CategoricalFeatureDictionaryTo_p_std__mapT_std__string_std__pairT_int_int_t_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__pairT_int_int_t_t_t_t, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_super[] = {  {&_swigt__p_super, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_unsigned_char[] = {  {&_swigt__p_unsigned_char, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_void[] = {  {&_swigt__p_void, 0, 0, 0},{0, 0, 0, 0}};

static swig_cast_info *swig_cast_initial[] = {
  _swigc__p_baseDataType,
  _swigc__p_char,
  _swigc__p_daal__Base,
  _swigc__p_daal__data_management__ColumnFilter,
  _swigc__p_daal__data_management__FeatureAuxData,
  _swigc__p_daal__data_management__MakeCategorical,
  _swigc__p_daal__data_management__ModifierIface,
  _swigc__p_daal__data_management__OneHotEncoder,
  _swigc__p_daal__data_management__features__interface1__FeatureId,
  _swigc__p_daal__data_management__features__interface1__FeatureIdCollection,
  _swigc__p_daal__data_management__features__interface1__FeatureIdCollectionIface,
  _swigc__p_daal__data_management__features__interface1__FeatureIdIface,
  _swigc__p_daal__data_management__features__interface1__FeatureIdMapping,
  _swigc__p_daal__data_management__features__interface1__FeatureIdMappingIface,
  _swigc__p_daal__data_management__features__interface1__FeatureIndices,
  _swigc__p_daal__data_management__features__interface1__FeatureIndicesIface,
  _swigc__p_daal__data_management__interface1__BlockDescriptorT_double_t,
  _swigc__p_daal__data_management__interface1__BlockDescriptorT_float_t,
  _swigc__p_daal__data_management__interface1__BlockDescriptorT_int_t,
  _swigc__p_daal__data_management__interface1__Bzip2CompressionParameter,
  _swigc__p_daal__data_management__interface1__CSRBlockDescriptorT_double_t,
  _swigc__p_daal__data_management__interface1__CSRBlockDescriptorT_float_t,
  _swigc__p_daal__data_management__interface1__CSRBlockDescriptorT_int_t,
  _swigc__p_daal__data_management__interface1__CSRNumericTable,
  _swigc__p_daal__data_management__interface1__CSRNumericTableIface,
  _swigc__p_daal__data_management__interface1__CSVFeatureManager,
  _swigc__p_daal__data_management__interface1__CategoricalFeatureDictionary,
  _swigc__p_daal__data_management__interface1__CompressedDataArchive,
  _swigc__p_daal__data_management__interface1__Compression,
  _swigc__p_daal__data_management__interface1__CompressionIface,
  _swigc__p_daal__data_management__interface1__CompressionParameter,
  _swigc__p_daal__data_management__interface1__CompressionStream,
  _swigc__p_daal__data_management__interface1__CompressorImpl,
  _swigc__p_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_t,
  _swigc__p_daal__data_management__interface1__CompressorT_daal__data_management__lzo_t,
  _swigc__p_daal__data_management__interface1__CompressorT_daal__data_management__rle_t,
  _swigc__p_daal__data_management__interface1__CompressorT_daal__data_management__zlib_t,
  _swigc__p_daal__data_management__interface1__CsvDataSourceOptions,
  _swigc__p_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t,
  _swigc__p_daal__data_management__interface1__DataArchive,
  _swigc__p_daal__data_management__interface1__DataArchiveIface,
  _swigc__p_daal__data_management__interface1__DataArchiveImpl,
  _swigc__p_daal__data_management__interface1__DataBlock,
  _swigc__p_daal__data_management__interface1__DataBlockIface,
  _swigc__p_daal__data_management__interface1__DataCollection,
  _swigc__p_daal__data_management__interface1__DataSource,
  _swigc__p_daal__data_management__interface1__DataSourceFeature,
  _swigc__p_daal__data_management__interface1__DataSourceIface,
  _swigc__p_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t,
  _swigc__p_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_float_t_double_t,
  _swigc__p_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_int_t_double_t,
  _swigc__p_daal__data_management__interface1__DecompressedDataArchive,
  _swigc__p_daal__data_management__interface1__DecompressionStream,
  _swigc__p_daal__data_management__interface1__DecompressorImpl,
  _swigc__p_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_t,
  _swigc__p_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_t,
  _swigc__p_daal__data_management__interface1__DecompressorT_daal__data_management__rle_t,
  _swigc__p_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_t,
  _swigc__p_daal__data_management__interface1__DenseNumericTableIface,
  _swigc__p_daal__data_management__interface1__DenseTensorIface,
  _swigc__p_daal__data_management__interface1__DictionaryIface,
  _swigc__p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t,
  _swigc__p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t,
  _swigc__p_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t,
  _swigc__p_daal__data_management__interface1__HomogenNumericTableT_double_t,
  _swigc__p_daal__data_management__interface1__HomogenNumericTableT_float_t,
  _swigc__p_daal__data_management__interface1__HomogenNumericTableT_int_t,
  _swigc__p_daal__data_management__interface1__HomogenTensorT_double_t,
  _swigc__p_daal__data_management__interface1__HomogenTensorT_float_t,
  _swigc__p_daal__data_management__interface1__HomogenTensorT_int_t,
  _swigc__p_daal__data_management__interface1__InputDataArchive,
  _swigc__p_daal__data_management__interface1__KeyValueCollectionT_algorithms__Input_t,
  _swigc__p_daal__data_management__interface1__KeyValueCollectionT_daal__algorithms__interface1__Input_t,
  _swigc__p_daal__data_management__interface1__KeyValueCollectionT_daal__data_management__interface1__SerializationIface_t,
  _swigc__p_daal__data_management__interface1__LzoCompressionParameter,
  _swigc__p_daal__data_management__interface1__MatrixT_double_t,
  _swigc__p_daal__data_management__interface1__MatrixT_float_t,
  _swigc__p_daal__data_management__interface1__MatrixT_int_t,
  _swigc__p_daal__data_management__interface1__MergedNumericTable,
  _swigc__p_daal__data_management__interface1__NpyAOSNumericTable,
  _swigc__p_daal__data_management__interface1__NumericTable,
  _swigc__p_daal__data_management__interface1__NumericTableFeature,
  _swigc__p_daal__data_management__interface1__NumericTableIface,
  _swigc__p_daal__data_management__interface1__NumericTable__BasicStatisticsDataCollection,
  _swigc__p_daal__data_management__interface1__OutputDataArchive,
  _swigc__p_daal__data_management__interface1__PackedArrayNumericTableIface,
  _swigc__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t,
  _swigc__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t,
  _swigc__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t,
  _swigc__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t,
  _swigc__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t,
  _swigc__p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t,
  _swigc__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t,
  _swigc__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t,
  _swigc__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t,
  _swigc__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t,
  _swigc__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t,
  _swigc__p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t,
  _swigc__p_daal__data_management__interface1__RleCompressionParameter,
  _swigc__p_daal__data_management__interface1__RowMergedNumericTable,
  _swigc__p_daal__data_management__interface1__SOANumericTable,
  _swigc__p_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t,
  _swigc__p_daal__data_management__interface1__SerializationDesc,
  _swigc__p_daal__data_management__interface1__SerializationIface,
  _swigc__p_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t,
  _swigc__p_daal__data_management__interface1__StringRowFeatureManagerIface,
  _swigc__p_daal__data_management__interface1__SubtensorDescriptorT_double_t,
  _swigc__p_daal__data_management__interface1__SubtensorDescriptorT_float_t,
  _swigc__p_daal__data_management__interface1__SubtensorDescriptorT_int_t,
  _swigc__p_daal__data_management__interface1__Tensor,
  _swigc__p_daal__data_management__interface1__TensorIface,
  _swigc__p_daal__data_management__interface1__TensorLayout,
  _swigc__p_daal__data_management__interface1__TensorLayoutIface,
  _swigc__p_daal__data_management__interface1__TensorOffsetLayout,
  _swigc__p_daal__data_management__interface1__ZlibCompressionParameter,
  _swigc__p_daal__data_management__modifiers__csv__interface1__Config,
  _swigc__p_daal__data_management__modifiers__csv__interface1__Context,
  _swigc__p_daal__data_management__modifiers__csv__interface1__FeatureModifier,
  _swigc__p_daal__data_management__modifiers__csv__interface1__PyFeatureModifier,
  _swigc__p_daal__services__CollectionT_daal__data_management__FeatureAuxData_t,
  _swigc__p_daal__services__CollectionT_daal__services__SharedPtrT_daal__algorithms__interface1__Input_t_t,
  _swigc__p_daal__services__CollectionT_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t_t,
  _swigc__p_daal__services__CollectionT_size_t_t,
  _swigc__p_daal__services__CollectionT_void_fpFfchar_const_p_daal__data_management__FeatureAuxData_R_double_pF_t,
  _swigc__p_daal__services__SharedPtrT_daal__Base_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__batch_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__distributed_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__AnalysisContainerIfaceT_daal__online_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__batch_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__distributed_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__AnalysisT_daal__online_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__DistributedPredictionContainerIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__DistributedPrediction_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__PredictionContainerIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__Prediction_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__batch_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__distributed_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__TrainingT_daal__online_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIfaceImpl_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__batch_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__distributed_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerImplT_daal__online_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__batch_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__distributed_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmContainerT_daal__online_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmDispatchContainer_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIfaceImpl_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__batch_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__distributed_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmImplT_daal__online_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__batch_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__distributed_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__AlgorithmT_daal__online_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__Argument_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__HostAppIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__Input_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__Kernel_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__Model_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__OptionalArgument_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__Parameter_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__PartialResult_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__Result_t,
  _swigc__p_daal__services__SharedPtrT_daal__algorithms__interface1__SerializableArgument_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdCollectionIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdCollection_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdMappingIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIdMapping_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureId_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndexTraits_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndicesIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__features__interface1__FeatureIndices_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__BasicStatisticsDataCollection_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_double_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_float_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__BlockDescriptorT_int_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_double_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_float_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRBlockDescriptorT_int_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTableIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CSRNumericTable_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CSVFeatureManager_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CategoricalFeatureDictionary_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__ColumnFilter_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressedDataArchive_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressionStream_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__Compression_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorImpl_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__bzip2_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__lzo_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__rle_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CompressorT_daal__data_management__zlib_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__CsvDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchiveImpl_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DataArchive_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlockIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DataCollection_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceFeature_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_double_t_double_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_float_t_double_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSourceTemplateT_daal__data_management__interface1__HomogenNumericTableT_int_t_double_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DataSource_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressedDataArchive_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressionStream_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorImpl_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__bzip2_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__lzo_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__rle_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DecompressorT_daal__data_management__zlib_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DenseNumericTableIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DenseTensorIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdCollectionIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdCollection_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdMappingIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIdMapping_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureId_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIndexTraits_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIndicesIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__FeatureIndices_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__FileDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_double_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_float_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenNumericTableT_int_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_double_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_float_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__HomogenTensorT_int_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__InputDataArchive_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_algorithms__Input_t_const_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_algorithms__Input_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__algorithms__interface1__Input_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__KeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__MakeCategorical_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_double_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_float_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__MatrixT_int_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__MergedNumericTable_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__ModifierIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__NpyAOSNumericTable_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableFeature_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTableIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_const_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__NumericTable_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__OneHotEncoder_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__OutputDataArchive_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedArrayNumericTableIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__RowMergedNumericTable_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__SOANumericTable_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_const_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__SerializationIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__StringDataSourceT_daal__data_management__interface1__CSVFeatureManager_double_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__StringRowFeatureManagerIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_double_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_float_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__SubtensorDescriptorT_int_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayoutIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorLayout_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__TensorOffsetLayout_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__interface1__Tensor_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__ConfigIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Config_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__ContextIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__Context_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifierIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__FeatureModifier_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__modifiers__csv__interface1__PyFeatureModifier_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__modifiers__interface1__ConfigIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__data_management__modifiers__interface1__ContextIface_t,
  _swigc__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__backward__LayerIfacePtr_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__forward__LayerIfacePtr_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__forward__interface1__LayerDescriptor_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__algorithms__neural_networks__layers__interface1__NextLayers_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__data_management__interface1__SerializationIfacePtr_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__services__interface1__CollectionT_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t_t_t,
  _swigc__p_daal__services__SharedPtrT_daal__services__interface1__Environment_t,
  _swigc__p_daal__services__SharedPtrT_daal__services__interface1__ErrorCollection_t,
  _swigc__p_daal__services__SharedPtrT_daal__services__interface1__Error_t,
  _swigc__p_daal__services__SharedPtrT_daal__services__interface1__KernelErrorCollection_t,
  _swigc__p_daal__services__SharedPtrT_daal__services__interface1__LibraryVersionInfo_t,
  _swigc__p_daal__services__SharedPtrT_double_t,
  _swigc__p_daal__services__SharedPtrT_float_t,
  _swigc__p_daal__services__SharedPtrT_int_t,
  _swigc__p_daal__services__SharedPtrT_size_t_t,
  _swigc__p_daal__services__SharedPtrT_unsigned_char_t,
  _swigc__p_daal__services__String,
  _swigc__p_daal__services__interface1__CollectionT_daal__services__SharedPtrT_daal__data_management__interface1__DataBlock_t_t,
  _swigc__p_daal__services__interface1__Environment,
  _swigc__p_daal__services__interface1__LibraryVersionInfo,
  _swigc__p_daal__services__interface1__Status,
  _swigc__p_double,
  _swigc__p_env,
  _swigc__p_f___p_daal__data_management__interface1__CSRNumericTable,
  _swigc__p_f___p_daal__data_management__interface1__DataCollection,
  _swigc__p_f___p_daal__data_management__interface1__DataSourceFeature,
  _swigc__p_f___p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t,
  _swigc__p_f___p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t,
  _swigc__p_f___p_daal__data_management__interface1__HomogenNumericTableT_double_t,
  _swigc__p_f___p_daal__data_management__interface1__HomogenNumericTableT_float_t,
  _swigc__p_f___p_daal__data_management__interface1__HomogenNumericTableT_int_t,
  _swigc__p_f___p_daal__data_management__interface1__HomogenTensorT_double_t,
  _swigc__p_f___p_daal__data_management__interface1__HomogenTensorT_float_t,
  _swigc__p_f___p_daal__data_management__interface1__HomogenTensorT_int_t,
  _swigc__p_f___p_daal__data_management__interface1__MatrixT_double_t,
  _swigc__p_f___p_daal__data_management__interface1__MatrixT_float_t,
  _swigc__p_f___p_daal__data_management__interface1__MatrixT_int_t,
  _swigc__p_f___p_daal__data_management__interface1__MergedNumericTable,
  _swigc__p_f___p_daal__data_management__interface1__NpyAOSNumericTable,
  _swigc__p_f___p_daal__data_management__interface1__NumericTable,
  _swigc__p_f___p_daal__data_management__interface1__NumericTableFeature,
  _swigc__p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t,
  _swigc__p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t,
  _swigc__p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t,
  _swigc__p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t,
  _swigc__p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t,
  _swigc__p_f___p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t,
  _swigc__p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t,
  _swigc__p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t,
  _swigc__p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t,
  _swigc__p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t,
  _swigc__p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t,
  _swigc__p_f___p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t,
  _swigc__p_f___p_daal__data_management__interface1__RowMergedNumericTable,
  _swigc__p_f___p_daal__data_management__interface1__SOANumericTable,
  _swigc__p_f___p_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t,
  _swigc__p_f___p_daal__data_management__interface1__SerializationIface,
  _swigc__p_f___p_daal__data_management__interface1__Tensor,
  _swigc__p_f___p_daal__data_management__interface1__TensorLayout,
  _swigc__p_f___p_daal__data_management__interface1__TensorOffsetLayout,
  _swigc__p_first_type,
  _swigc__p_float,
  _swigc__p_int,
  _swigc__p_numericTableType,
  _swigc__p_p_daal__data_management__interface1__BlockDescriptorT_double_t,
  _swigc__p_p_daal__data_management__interface1__BlockDescriptorT_float_t,
  _swigc__p_p_daal__data_management__interface1__BlockDescriptorT_int_t,
  _swigc__p_p_daal__data_management__interface1__CSRNumericTable,
  _swigc__p_p_daal__data_management__interface1__DataCollection,
  _swigc__p_p_daal__data_management__interface1__DataSourceFeature,
  _swigc__p_p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__DataSourceFeature_6010_t,
  _swigc__p_p_daal__data_management__interface1__DictionaryT_daal__data_management__interface1__NumericTableFeature_6000_t,
  _swigc__p_p_daal__data_management__interface1__HomogenNumericTableT_double_t,
  _swigc__p_p_daal__data_management__interface1__HomogenNumericTableT_float_t,
  _swigc__p_p_daal__data_management__interface1__HomogenNumericTableT_int_t,
  _swigc__p_p_daal__data_management__interface1__HomogenTensorT_double_t,
  _swigc__p_p_daal__data_management__interface1__HomogenTensorT_float_t,
  _swigc__p_p_daal__data_management__interface1__HomogenTensorT_int_t,
  _swigc__p_p_daal__data_management__interface1__MatrixT_double_t,
  _swigc__p_p_daal__data_management__interface1__MatrixT_float_t,
  _swigc__p_p_daal__data_management__interface1__MatrixT_int_t,
  _swigc__p_p_daal__data_management__interface1__MergedNumericTable,
  _swigc__p_p_daal__data_management__interface1__NpyAOSNumericTable,
  _swigc__p_p_daal__data_management__interface1__NumericTable,
  _swigc__p_p_daal__data_management__interface1__NumericTableFeature,
  _swigc__p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_double_t,
  _swigc__p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_float_t,
  _swigc__p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedSymmetricMatrix_int_t,
  _swigc__p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_double_t,
  _swigc__p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_float_t,
  _swigc__p_p_daal__data_management__interface1__PackedSymmetricMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedSymmetricMatrix_int_t,
  _swigc__p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_double_t,
  _swigc__p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_float_t,
  _swigc__p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__lowerPackedTriangularMatrix_int_t,
  _swigc__p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_double_t,
  _swigc__p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_float_t,
  _swigc__p_p_daal__data_management__interface1__PackedTriangularMatrixT_daal__data_management__interface1__NumericTableIface__upperPackedTriangularMatrix_int_t,
  _swigc__p_p_daal__data_management__interface1__RowMergedNumericTable,
  _swigc__p_p_daal__data_management__interface1__SOANumericTable,
  _swigc__p_p_daal__data_management__interface1__SerializableKeyValueCollectionT_daal__data_management__interface1__SerializationIface_t,
  _swigc__p_p_daal__data_management__interface1__SerializationIface,
  _swigc__p_p_daal__data_management__interface1__Tensor,
  _swigc__p_p_daal__data_management__interface1__TensorLayout,
  _swigc__p_p_daal__data_management__interface1__TensorOffsetLayout,
  _swigc__p_p_daal__services__CollectionT_size_t_t,
  _swigc__p_p_size_t,
  _swigc__p_second_type,
  _swigc__p_size_t,
  _swigc__p_std__mapT_std__string_std__pairT_int_int_t_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__pairT_int_int_t_t_t_t,
  _swigc__p_super,
  _swigc__p_unsigned_char,
  _swigc__p_void,
};


/* -------- TYPE CONVERSION AND EQUIVALENCE RULES (END) -------- */

static swig_const_info swig_const_table[] = {
{0, 0, 0, 0.0, 0, 0}};

#ifdef __cplusplus
}
#endif
/* -----------------------------------------------------------------------------
 * Type initialization:
 * This problem is tough by the requirement that no dynamic
 * memory is used. Also, since swig_type_info structures store pointers to
 * swig_cast_info structures and swig_cast_info structures store pointers back
 * to swig_type_info structures, we need some lookup code at initialization.
 * The idea is that swig generates all the structures that are needed.
 * The runtime then collects these partially filled structures.
 * The SWIG_InitializeModule function takes these initial arrays out of
 * swig_module, and does all the lookup, filling in the swig_module.types
 * array with the correct data and linking the correct swig_cast_info
 * structures together.
 *
 * The generated swig_type_info structures are assigned statically to an initial
 * array. We just loop through that array, and handle each type individually.
 * First we lookup if this type has been already loaded, and if so, use the
 * loaded structure instead of the generated one. Then we have to fill in the
 * cast linked list. The cast data is initially stored in something like a
 * two-dimensional array. Each row corresponds to a type (there are the same
 * number of rows as there are in the swig_type_initial array). Each entry in
 * a column is one of the swig_cast_info structures for that type.
 * The cast_initial array is actually an array of arrays, because each row has
 * a variable number of columns. So to actually build the cast linked list,
 * we find the array of casts associated with the type, and loop through it
 * adding the casts to the list. The one last trick we need to do is making
 * sure the type pointer in the swig_cast_info struct is correct.
 *
 * First off, we lookup the cast->type name to see if it is already loaded.
 * There are three cases to handle:
 *  1) If the cast->type has already been loaded AND the type we are adding
 *     casting info to has not been loaded (it is in this module), THEN we
 *     replace the cast->type pointer with the type pointer that has already
 *     been loaded.
 *  2) If BOTH types (the one we are adding casting info to, and the
 *     cast->type) are loaded, THEN the cast info has already been loaded by
 *     the previous module so we just ignore it.
 *  3) Finally, if cast->type has not already been loaded, then we add that
 *     swig_cast_info to the linked list (because the cast->type) pointer will
 *     be correct.
 * ----------------------------------------------------------------------------- */

#ifdef __cplusplus
extern "C" {
#if 0
} /* c-mode */
#endif
#endif

#if 0
#define SWIGRUNTIME_DEBUG
#endif


SWIGRUNTIME void
SWIG_InitializeModule(void *clientdata) {
  size_t i;
  swig_module_info *module_head, *iter;
  int init;
  
  /* check to see if the circular list has been setup, if not, set it up */
  if (swig_module.next==0) {
    /* Initialize the swig_module */
    swig_module.type_initial = swig_type_initial;
    swig_module.cast_initial = swig_cast_initial;
    swig_module.next = &swig_module;
    init = 1;
  } else {
    init = 0;
  }
  
  /* Try and load any already created modules */
  module_head = SWIG_GetModule(clientdata);
  if (!module_head) {
    /* This is the first module loaded for this interpreter */
    /* so set the swig module into the interpreter */
    SWIG_SetModule(clientdata, &swig_module);
  } else {
    /* the interpreter has loaded a SWIG module, but has it loaded this one? */
    iter=module_head;
    do {
      if (iter==&swig_module) {
        /* Our module is already in the list, so there's nothing more to do. */
        return;
      }
      iter=iter->next;
    } while (iter!= module_head);
    
    /* otherwise we must add our module into the list */
    swig_module.next = module_head->next;
    module_head->next = &swig_module;
  }
  
  /* When multiple interpreters are used, a module could have already been initialized in
       a different interpreter, but not yet have a pointer in this interpreter.
       In this case, we do not want to continue adding types... everything should be
       set up already */
  if (init == 0) return;
  
  /* Now work on filling in swig_module.types */
#ifdef SWIGRUNTIME_DEBUG
  printf("SWIG_InitializeModule: size %d\n", swig_module.size);
#endif
  for (i = 0; i < swig_module.size; ++i) {
    swig_type_info *type = 0;
    swig_type_info *ret;
    swig_cast_info *cast;
    
#ifdef SWIGRUNTIME_DEBUG
    printf("SWIG_InitializeModule: type %d %s\n", i, swig_module.type_initial[i]->name);
#endif
    
    /* if there is another module already loaded */
    if (swig_module.next != &swig_module) {
      type = SWIG_MangledTypeQueryModule(swig_module.next, &swig_module, swig_module.type_initial[i]->name);
    }
    if (type) {
      /* Overwrite clientdata field */
#ifdef SWIGRUNTIME_DEBUG
      printf("SWIG_InitializeModule: found type %s\n", type->name);
#endif
      if (swig_module.type_initial[i]->clientdata) {
        type->clientdata = swig_module.type_initial[i]->clientdata;
#ifdef SWIGRUNTIME_DEBUG
        printf("SWIG_InitializeModule: found and overwrite type %s \n", type->name);
#endif
      }
    } else {
      type = swig_module.type_initial[i];
    }
    
    /* Insert casting types */
    cast = swig_module.cast_initial[i];
    while (cast->type) {
      /* Don't need to add information already in the list */
      ret = 0;
#ifdef SWIGRUNTIME_DEBUG
      printf("SWIG_InitializeModule: look cast %s\n", cast->type->name);
#endif
      if (swig_module.next != &swig_module) {
        ret = SWIG_MangledTypeQueryModule(swig_module.next, &swig_module, cast->type->name);
#ifdef SWIGRUNTIME_DEBUG
        if (ret) printf("SWIG_InitializeModule: found cast %s\n", ret->name);
#endif
      }
      if (ret) {
        if (type == swig_module.type_initial[i]) {
#ifdef SWIGRUNTIME_DEBUG
          printf("SWIG_InitializeModule: skip old type %s\n", ret->name);
#endif
          cast->type = ret;
          ret = 0;
        } else {
          /* Check for casting already in the list */
          swig_cast_info *ocast = SWIG_TypeCheck(ret->name, type);
#ifdef SWIGRUNTIME_DEBUG
          if (ocast) printf("SWIG_InitializeModule: skip old cast %s\n", ret->name);
#endif
          if (!ocast) ret = 0;
        }
      }
      
      if (!ret) {
#ifdef SWIGRUNTIME_DEBUG
        printf("SWIG_InitializeModule: adding cast %s\n", cast->type->name);
#endif
        if (type->cast) {
          type->cast->prev = cast;
          cast->next = type->cast;
        }
        type->cast = cast;
      }
      cast++;
    }
    /* Set entry in modules->types array equal to the type */
    swig_module.types[i] = type;
  }
  swig_module.types[i] = 0;
  
#ifdef SWIGRUNTIME_DEBUG
  printf("**** SWIG_InitializeModule: Cast List ******\n");
  for (i = 0; i < swig_module.size; ++i) {
    int j = 0;
    swig_cast_info *cast = swig_module.cast_initial[i];
    printf("SWIG_InitializeModule: type %d %s\n", i, swig_module.type_initial[i]->name);
    while (cast->type) {
      printf("SWIG_InitializeModule: cast type %s\n", cast->type->name);
      cast++;
      ++j;
    }
    printf("---- Total casts: %d\n",j);
  }
  printf("**** SWIG_InitializeModule: Cast List ******\n");
#endif
}

/* This function will propagate the clientdata field of type to
* any new swig_type_info structures that have been added into the list
* of equivalent types.  It is like calling
* SWIG_TypeClientData(type, clientdata) a second time.
*/
SWIGRUNTIME void
SWIG_PropagateClientData(void) {
  size_t i;
  swig_cast_info *equiv;
  static int init_run = 0;
  
  if (init_run) return;
  init_run = 1;
  
  for (i = 0; i < swig_module.size; i++) {
    if (swig_module.types[i]->clientdata) {
      equiv = swig_module.types[i]->cast;
      while (equiv) {
        if (!equiv->converter) {
          if (equiv->type && !equiv->type->clientdata)
          SWIG_TypeClientData(equiv->type, swig_module.types[i]->clientdata);
        }
        equiv = equiv->next;
      }
    }
  }
}

#ifdef __cplusplus
#if 0
{
  /* c-mode */
#endif
}
#endif



#ifdef __cplusplus
extern "C" {
#endif
  
  /* Python-specific SWIG API */
#define SWIG_newvarlink()                             SWIG_Python_newvarlink()
#define SWIG_addvarlink(p, name, get_attr, set_attr)  SWIG_Python_addvarlink(p, name, get_attr, set_attr)
#define SWIG_InstallConstants(d, constants)           SWIG_Python_InstallConstants(d, constants)
  
  /* -----------------------------------------------------------------------------
   * global variable support code.
   * ----------------------------------------------------------------------------- */
  
  typedef struct swig_globalvar {
    char       *name;                  /* Name of global variable */
    PyObject *(*get_attr)(void);       /* Return the current value */
    int       (*set_attr)(PyObject *); /* Set the value */
    struct swig_globalvar *next;
  } swig_globalvar;
  
  typedef struct swig_varlinkobject {
    PyObject_HEAD
    swig_globalvar *vars;
  } swig_varlinkobject;
  
  SWIGINTERN PyObject *
  swig_varlink_repr(swig_varlinkobject *SWIGUNUSEDPARM(v)) {
#if PY_VERSION_HEX >= 0x03000000
    return PyUnicode_InternFromString("<Swig global variables>");
#else
    return PyString_FromString("<Swig global variables>");
#endif
  }
  
  SWIGINTERN PyObject *
  swig_varlink_str(swig_varlinkobject *v) {
#if PY_VERSION_HEX >= 0x03000000
    PyObject *str = PyUnicode_InternFromString("(");
    PyObject *tail;
    PyObject *joined;
    swig_globalvar *var;
    for (var = v->vars; var; var=var->next) {
      tail = PyUnicode_FromString(var->name);
      joined = PyUnicode_Concat(str, tail);
      Py_DecRef(str);
      Py_DecRef(tail);
      str = joined;
      if (var->next) {
        tail = PyUnicode_InternFromString(", ");
        joined = PyUnicode_Concat(str, tail);
        Py_DecRef(str);
        Py_DecRef(tail);
        str = joined;
      }
    }
    tail = PyUnicode_InternFromString(")");
    joined = PyUnicode_Concat(str, tail);
    Py_DecRef(str);
    Py_DecRef(tail);
    str = joined;
#else
    PyObject *str = PyString_FromString("(");
    swig_globalvar *var;
    for (var = v->vars; var; var=var->next) {
      PyString_ConcatAndDel(&str,PyString_FromString(var->name));
      if (var->next) PyString_ConcatAndDel(&str,PyString_FromString(", "));
    }
    PyString_ConcatAndDel(&str,PyString_FromString(")"));
#endif
    return str;
  }
  
  SWIGINTERN int
  swig_varlink_print(swig_varlinkobject *v, FILE *fp, int SWIGUNUSEDPARM(flags)) {
    char *tmp;
    PyObject *str = swig_varlink_str(v);
    fprintf(fp,"Swig global variables ");
    fprintf(fp,"%s\n", tmp = SWIG_Python_str_AsChar(str));
    SWIG_Python_str_DelForPy3(tmp);
    Py_DECREF(str);
    return 0;
  }
  
  SWIGINTERN void
  swig_varlink_dealloc(swig_varlinkobject *v) {
    swig_globalvar *var = v->vars;
    while (var) {
      swig_globalvar *n = var->next;
      free(var->name);
      free(var);
      var = n;
    }
  }
  
  SWIGINTERN PyObject *
  swig_varlink_getattr(swig_varlinkobject *v, char *n) {
    PyObject *res = NULL;
    swig_globalvar *var = v->vars;
    while (var) {
      if (strcmp(var->name,n) == 0) {
        res = (*var->get_attr)();
        break;
      }
      var = var->next;
    }
    if (res == NULL && !PyErr_Occurred()) {
      PyErr_Format(PyExc_AttributeError, "Unknown C global variable '%s'", n);
    }
    return res;
  }
  
  SWIGINTERN int
  swig_varlink_setattr(swig_varlinkobject *v, char *n, PyObject *p) {
    int res = 1;
    swig_globalvar *var = v->vars;
    while (var) {
      if (strcmp(var->name,n) == 0) {
        res = (*var->set_attr)(p);
        break;
      }
      var = var->next;
    }
    if (res == 1 && !PyErr_Occurred()) {
      PyErr_Format(PyExc_AttributeError, "Unknown C global variable '%s'", n);
    }
    return res;
  }
  
  SWIGINTERN PyTypeObject*
  swig_varlink_type(void) {
    static char varlink__doc__[] = "Swig var link object";
    static PyTypeObject varlink_type;
    static int type_init = 0;
    if (!type_init) {
      const PyTypeObject tmp = {
        /* PyObject header changed in Python 3 */
#if PY_VERSION_HEX >= 0x03000000
        PyVarObject_HEAD_INIT(NULL, 0)
#else
        PyObject_HEAD_INIT(NULL)
        0,                                  /* ob_size */
#endif
        (char *)"swigvarlink",              /* tp_name */
        sizeof(swig_varlinkobject),         /* tp_basicsize */
        0,                                  /* tp_itemsize */
        (destructor) swig_varlink_dealloc,  /* tp_dealloc */
        (printfunc) swig_varlink_print,     /* tp_print */
        (getattrfunc) swig_varlink_getattr, /* tp_getattr */
        (setattrfunc) swig_varlink_setattr, /* tp_setattr */
        0,                                  /* tp_compare */
        (reprfunc) swig_varlink_repr,       /* tp_repr */
        0,                                  /* tp_as_number */
        0,                                  /* tp_as_sequence */
        0,                                  /* tp_as_mapping */
        0,                                  /* tp_hash */
        0,                                  /* tp_call */
        (reprfunc) swig_varlink_str,        /* tp_str */
        0,                                  /* tp_getattro */
        0,                                  /* tp_setattro */
        0,                                  /* tp_as_buffer */
        0,                                  /* tp_flags */
        varlink__doc__,                     /* tp_doc */
        0,                                  /* tp_traverse */
        0,                                  /* tp_clear */
        0,                                  /* tp_richcompare */
        0,                                  /* tp_weaklistoffset */
#if PY_VERSION_HEX >= 0x02020000
        0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0, /* tp_iter -> tp_weaklist */
#endif
#if PY_VERSION_HEX >= 0x02030000
        0,                                  /* tp_del */
#endif
#if PY_VERSION_HEX >= 0x02060000
        0,                                  /* tp_version */
#endif
#ifdef COUNT_ALLOCS
        0,0,0,0                             /* tp_alloc -> tp_next */
#endif
      };
      varlink_type = tmp;
      type_init = 1;
#if PY_VERSION_HEX < 0x02020000
      varlink_type.ob_type = &PyType_Type;
#else
      if (PyType_Ready(&varlink_type) < 0)
      return NULL;
#endif
    }
    return &varlink_type;
  }
  
  /* Create a variable linking object for use later */
  SWIGINTERN PyObject *
  SWIG_Python_newvarlink(void) {
    swig_varlinkobject *result = PyObject_NEW(swig_varlinkobject, swig_varlink_type());
    if (result) {
      result->vars = 0;
    }
    return ((PyObject*) result);
  }
  
  SWIGINTERN void 
  SWIG_Python_addvarlink(PyObject *p, char *name, PyObject *(*get_attr)(void), int (*set_attr)(PyObject *p)) {
    swig_varlinkobject *v = (swig_varlinkobject *) p;
    swig_globalvar *gv = (swig_globalvar *) malloc(sizeof(swig_globalvar));
    if (gv) {
      size_t size = strlen(name)+1;
      gv->name = (char *)malloc(size);
      if (gv->name) {
        strncpy(gv->name,name,size);
        gv->get_attr = get_attr;
        gv->set_attr = set_attr;
        gv->next = v->vars;
      }
    }
    v->vars = gv;
  }
  
  SWIGINTERN PyObject *
  SWIG_globals(void) {
    static PyObject *_SWIG_globals = 0; 
    if (!_SWIG_globals) _SWIG_globals = SWIG_newvarlink();  
    return _SWIG_globals;
  }
  
  /* -----------------------------------------------------------------------------
   * constants/methods manipulation
   * ----------------------------------------------------------------------------- */
  
  /* Install Constants */
  SWIGINTERN void
  SWIG_Python_InstallConstants(PyObject *d, swig_const_info constants[]) {
    PyObject *obj = 0;
    size_t i;
    for (i = 0; constants[i].type; ++i) {
      switch(constants[i].type) {
      case SWIG_PY_POINTER:
        obj = SWIG_InternalNewPointerObj(constants[i].pvalue, *(constants[i]).ptype,0);
        break;
      case SWIG_PY_BINARY:
        obj = SWIG_NewPackedObj(constants[i].pvalue, constants[i].lvalue, *(constants[i].ptype));
        break;
      default:
        obj = 0;
        break;
      }
      if (obj) {
        PyDict_SetItemString(d, constants[i].name, obj);
        Py_DECREF(obj);
      }
    }
  }
  
  /* -----------------------------------------------------------------------------*/
  /* Fix SwigMethods to carry the callback ptrs when needed */
  /* -----------------------------------------------------------------------------*/
  
  SWIGINTERN void
  SWIG_Python_FixMethods(PyMethodDef *methods,
    swig_const_info *const_table,
    swig_type_info **types,
    swig_type_info **types_initial) {
    size_t i;
    for (i = 0; methods[i].ml_name; ++i) {
      const char *c = methods[i].ml_doc;
      if (c && (c = strstr(c, "swig_ptr: "))) {
        int j;
        swig_const_info *ci = 0;
        const char *name = c + 10;
        for (j = 0; const_table[j].type; ++j) {
          if (strncmp(const_table[j].name, name, 
              strlen(const_table[j].name)) == 0) {
            ci = &(const_table[j]);
            break;
          }
        }
        if (ci) {
          void *ptr = (ci->type == SWIG_PY_POINTER) ? ci->pvalue : 0;
          if (ptr) {
            size_t shift = (ci->ptype) - types;
            swig_type_info *ty = types_initial[shift];
            size_t ldoc = (c - methods[i].ml_doc);
            size_t lptr = strlen(ty->name)+2*sizeof(void*)+2;
            char *ndoc = (char*)malloc(ldoc + lptr + 10);
            if (ndoc) {
              char *buff = ndoc;
              strncpy(buff, methods[i].ml_doc, ldoc);
              buff += ldoc;
              strncpy(buff, "swig_ptr: ", 10);
              buff += 10;
              SWIG_PackVoidPtr(buff, ptr, ty->name, lptr);
              methods[i].ml_doc = ndoc;
            }
          }
        }
      }
    }
  } 
  
#ifdef __cplusplus
}
#endif

/* -----------------------------------------------------------------------------*
 *  Partial Init method
 * -----------------------------------------------------------------------------*/

#ifdef __cplusplus
extern "C"
#endif

SWIGEXPORT 
#if PY_VERSION_HEX >= 0x03000000
PyObject*
#else
void
#endif
SWIG_init(void) {
  PyObject *m, *d, *md;
#if PY_VERSION_HEX >= 0x03000000
  static struct PyModuleDef SWIG_module = {
# if PY_VERSION_HEX >= 0x03020000
    PyModuleDef_HEAD_INIT,
# else
    {
      PyObject_HEAD_INIT(NULL)
      NULL, /* m_init */
      0,    /* m_index */
      NULL, /* m_copy */
    },
# endif
    (char *) SWIG_name,
    NULL,
    -1,
    SwigMethods,
    NULL,
    NULL,
    NULL,
    NULL
  };
#endif
  
#if defined(SWIGPYTHON_BUILTIN)
  static SwigPyClientData SwigPyObject_clientdata = {
    0, 0, 0, 0, 0, 0, 0
  };
  static PyGetSetDef this_getset_def = {
    (char *)"this", &SwigPyBuiltin_ThisClosure, NULL, NULL, NULL
  };
  static SwigPyGetSet thisown_getset_closure = {
    (PyCFunction) SwigPyObject_own,
    (PyCFunction) SwigPyObject_own
  };
  static PyGetSetDef thisown_getset_def = {
    (char *)"thisown", SwigPyBuiltin_GetterClosure, SwigPyBuiltin_SetterClosure, NULL, &thisown_getset_closure
  };
  PyObject *metatype_args;
  PyTypeObject *builtin_pytype;
  int builtin_base_count;
  swig_type_info *builtin_basetype;
  PyObject *tuple;
  PyGetSetDescrObject *static_getset;
  PyTypeObject *metatype;
  SwigPyClientData *cd;
  PyObject *public_interface, *public_symbol;
  PyObject *this_descr;
  PyObject *thisown_descr;
  PyObject *self = 0;
  int i;
  
  (void)builtin_pytype;
  (void)builtin_base_count;
  (void)builtin_basetype;
  (void)tuple;
  (void)static_getset;
  (void)self;
  
  /* metatype is used to implement static member variables. */
  metatype_args = Py_BuildValue("(s(O){})", "SwigPyObjectType", &PyType_Type);
  assert(metatype_args);
  metatype = (PyTypeObject *) PyType_Type.tp_call((PyObject *) &PyType_Type, metatype_args, NULL);
  assert(metatype);
  Py_DECREF(metatype_args);
  metatype->tp_setattro = (setattrofunc) &SwigPyObjectType_setattro;
  assert(PyType_Ready(metatype) >= 0);
#endif
  
  /* Fix SwigMethods to carry the callback ptrs when needed */
  SWIG_Python_FixMethods(SwigMethods, swig_const_table, swig_types, swig_type_initial);
  
#if PY_VERSION_HEX >= 0x03000000
  m = PyModule_Create(&SWIG_module);
#else
  m = Py_InitModule((char *) SWIG_name, SwigMethods);
#endif
  
  md = d = PyModule_GetDict(m);
  (void)md;
  
  SWIG_InitializeModule(0);
  
#ifdef SWIGPYTHON_BUILTIN
  SwigPyObject_stype = SWIG_MangledTypeQuery("_p_SwigPyObject");
  assert(SwigPyObject_stype);
  cd = (SwigPyClientData*) SwigPyObject_stype->clientdata;
  if (!cd) {
    SwigPyObject_stype->clientdata = &SwigPyObject_clientdata;
    SwigPyObject_clientdata.pytype = SwigPyObject_TypeOnce();
  } else if (SwigPyObject_TypeOnce()->tp_basicsize != cd->pytype->tp_basicsize) {
    PyErr_SetString(PyExc_RuntimeError, "Import error: attempted to load two incompatible swig-generated modules.");
# if PY_VERSION_HEX >= 0x03000000
    return NULL;
# else
    return;
# endif
  }
  
  /* All objects have a 'this' attribute */
  this_descr = PyDescr_NewGetSet(SwigPyObject_type(), &this_getset_def);
  (void)this_descr;
  
  /* All objects have a 'thisown' attribute */
  thisown_descr = PyDescr_NewGetSet(SwigPyObject_type(), &thisown_getset_def);
  (void)thisown_descr;
  
  public_interface = PyList_New(0);
  public_symbol = 0;
  (void)public_symbol;
  
  PyDict_SetItemString(md, "__all__", public_interface);
  Py_DECREF(public_interface);
  for (i = 0; SwigMethods[i].ml_name != NULL; ++i)
  SwigPyBuiltin_AddPublicSymbol(public_interface, SwigMethods[i].ml_name);
  for (i = 0; swig_const_table[i].name != 0; ++i)
  SwigPyBuiltin_AddPublicSymbol(public_interface, swig_const_table[i].name);
#endif
  
  SWIG_InstallConstants(d,swig_const_table);
  
  
  import_array();
  
  SWIG_Python_SetConstant(d, "DictionaryIface_notEqual",SWIG_From_int(static_cast< int >(daal::data_management::interface1::DictionaryIface::notEqual)));
  SWIG_Python_SetConstant(d, "DictionaryIface_equal",SWIG_From_int(static_cast< int >(daal::data_management::interface1::DictionaryIface::equal)));
  SWIG_Python_SetConstant(d, "NumericTableIface_notAllocated",SWIG_From_int(static_cast< int >(daal::data_management::interface1::NumericTableIface::notAllocated)));
  SWIG_Python_SetConstant(d, "NumericTableIface_userAllocated",SWIG_From_int(static_cast< int >(daal::data_management::interface1::NumericTableIface::userAllocated)));
  SWIG_Python_SetConstant(d, "NumericTableIface_internallyAllocated",SWIG_From_int(static_cast< int >(daal::data_management::interface1::NumericTableIface::internallyAllocated)));
  SWIG_Python_SetConstant(d, "NumericTableIface_doNotAllocate",SWIG_From_int(static_cast< int >(daal::data_management::interface1::NumericTableIface::doNotAllocate)));
  SWIG_Python_SetConstant(d, "NumericTableIface_notAllocate",SWIG_From_int(static_cast< int >(daal::data_management::interface1::NumericTableIface::notAllocate)));
  SWIG_Python_SetConstant(d, "NumericTableIface_doAllocate",SWIG_From_int(static_cast< int >(daal::data_management::interface1::NumericTableIface::doAllocate)));
  SWIG_Python_SetConstant(d, "NumericTableIface_minimum",SWIG_From_int(static_cast< int >(daal::data_management::interface1::NumericTableIface::minimum)));
  SWIG_Python_SetConstant(d, "NumericTableIface_maximum",SWIG_From_int(static_cast< int >(daal::data_management::interface1::NumericTableIface::maximum)));
  SWIG_Python_SetConstant(d, "NumericTableIface_sum",SWIG_From_int(static_cast< int >(daal::data_management::interface1::NumericTableIface::sum)));
  SWIG_Python_SetConstant(d, "NumericTableIface_sumSquares",SWIG_From_int(static_cast< int >(daal::data_management::interface1::NumericTableIface::sumSquares)));
  SWIG_Python_SetConstant(d, "NumericTableIface_counters",SWIG_From_int(static_cast< int >(daal::data_management::interface1::NumericTableIface::counters)));
  SWIG_Python_SetConstant(d, "NumericTableIface_nonNormalized",SWIG_From_int(static_cast< int >(daal::data_management::interface1::NumericTableIface::nonNormalized)));
  SWIG_Python_SetConstant(d, "NumericTableIface_standardScoreNormalized",SWIG_From_int(static_cast< int >(daal::data_management::interface1::NumericTableIface::standardScoreNormalized)));
  SWIG_Python_SetConstant(d, "NumericTableIface_minMaxNormalized",SWIG_From_int(static_cast< int >(daal::data_management::interface1::NumericTableIface::minMaxNormalized)));
  SWIG_Python_SetConstant(d, "NumericTableIface_soa",SWIG_From_int(static_cast< int >(daal::data_management::interface1::NumericTableIface::soa)));
  SWIG_Python_SetConstant(d, "NumericTableIface_aos",SWIG_From_int(static_cast< int >(daal::data_management::interface1::NumericTableIface::aos)));
  SWIG_Python_SetConstant(d, "NumericTableIface_csrArray",SWIG_From_int(static_cast< int >(daal::data_management::interface1::NumericTableIface::csrArray)));
  SWIG_Python_SetConstant(d, "NumericTableIface_upperPackedSymmetricMatrix",SWIG_From_int(static_cast< int >(daal::data_management::interface1::NumericTableIface::upperPackedSymmetricMatrix)));
  SWIG_Python_SetConstant(d, "NumericTableIface_lowerPackedSymmetricMatrix",SWIG_From_int(static_cast< int >(daal::data_management::interface1::NumericTableIface::lowerPackedSymmetricMatrix)));
  SWIG_Python_SetConstant(d, "NumericTableIface_upperPackedTriangularMatrix",SWIG_From_int(static_cast< int >(daal::data_management::interface1::NumericTableIface::upperPackedTriangularMatrix)));
  SWIG_Python_SetConstant(d, "NumericTableIface_lowerPackedTriangularMatrix",SWIG_From_int(static_cast< int >(daal::data_management::interface1::NumericTableIface::lowerPackedTriangularMatrix)));
  SWIG_Python_SetConstant(d, "NumericTableIface_layout_unknown",SWIG_From_int(static_cast< int >(daal::data_management::interface1::NumericTableIface::layout_unknown)));
  PyDict_SetItemString(md,(char*)"cvar", SWIG_globals());
  SWIG_addvarlink(SWIG_globals(),(char*)"packed_mask",Swig_var_packed_mask_get, Swig_var_packed_mask_set);
  SWIG_Python_SetConstant(d, "TensorIface_notAllocated",SWIG_From_int(static_cast< int >(daal::data_management::interface1::TensorIface::notAllocated)));
  SWIG_Python_SetConstant(d, "TensorIface_userAllocated",SWIG_From_int(static_cast< int >(daal::data_management::interface1::TensorIface::userAllocated)));
  SWIG_Python_SetConstant(d, "TensorIface_internallyAllocated",SWIG_From_int(static_cast< int >(daal::data_management::interface1::TensorIface::internallyAllocated)));
  SWIG_Python_SetConstant(d, "TensorIface_doNotAllocate",SWIG_From_int(static_cast< int >(daal::data_management::interface1::TensorIface::doNotAllocate)));
  SWIG_Python_SetConstant(d, "TensorIface_notAllocate",SWIG_From_int(static_cast< int >(daal::data_management::interface1::TensorIface::notAllocate)));
  SWIG_Python_SetConstant(d, "TensorIface_doAllocate",SWIG_From_int(static_cast< int >(daal::data_management::interface1::TensorIface::doAllocate)));
  SWIG_Python_SetConstant(d, "CSRNumericTableIface_zeroBased",SWIG_From_int(static_cast< int >(daal::data_management::interface1::CSRNumericTableIface::zeroBased)));
  SWIG_Python_SetConstant(d, "CSRNumericTableIface_oneBased",SWIG_From_int(static_cast< int >(daal::data_management::interface1::CSRNumericTableIface::oneBased)));
  SWIG_Python_SetConstant(d, "DataSourceIface_readyForLoad",SWIG_From_int(static_cast< int >(daal::data_management::interface1::DataSourceIface::readyForLoad)));
  SWIG_Python_SetConstant(d, "DataSourceIface_waitingForRows",SWIG_From_int(static_cast< int >(daal::data_management::interface1::DataSourceIface::waitingForRows)));
  SWIG_Python_SetConstant(d, "DataSourceIface_endOfData",SWIG_From_int(static_cast< int >(daal::data_management::interface1::DataSourceIface::endOfData)));
  SWIG_Python_SetConstant(d, "DataSourceIface_notReady",SWIG_From_int(static_cast< int >(daal::data_management::interface1::DataSourceIface::notReady)));
  SWIG_Python_SetConstant(d, "DataSourceIface_notDictionaryFromContext",SWIG_From_int(static_cast< int >(daal::data_management::interface1::DataSourceIface::notDictionaryFromContext)));
  SWIG_Python_SetConstant(d, "DataSourceIface_doDictionaryFromContext",SWIG_From_int(static_cast< int >(daal::data_management::interface1::DataSourceIface::doDictionaryFromContext)));
  SWIG_Python_SetConstant(d, "DataSourceIface_notAllocateNumericTable",SWIG_From_int(static_cast< int >(daal::data_management::interface1::DataSourceIface::notAllocateNumericTable)));
  SWIG_Python_SetConstant(d, "DataSourceIface_doAllocateNumericTable",SWIG_From_int(static_cast< int >(daal::data_management::interface1::DataSourceIface::doAllocateNumericTable)));
  SWIG_Python_SetConstant(d, "CsvDataSourceOptions_byDefault",SWIG_From_int(static_cast< int >(daal::data_management::interface1::CsvDataSourceOptions::byDefault)));
  SWIG_Python_SetConstant(d, "CsvDataSourceOptions_allocateNumericTable",SWIG_From_int(static_cast< int >(daal::data_management::interface1::CsvDataSourceOptions::allocateNumericTable)));
  SWIG_Python_SetConstant(d, "CsvDataSourceOptions_createDictionaryFromContext",SWIG_From_int(static_cast< int >(daal::data_management::interface1::CsvDataSourceOptions::createDictionaryFromContext)));
  SWIG_Python_SetConstant(d, "CsvDataSourceOptions_parseHeader",SWIG_From_int(static_cast< int >(daal::data_management::interface1::CsvDataSourceOptions::parseHeader)));
  
  /* Initialize threading */
  SWIG_PYTHON_INITIALIZE_THREADS;
#if PY_VERSION_HEX >= 0x03000000
  return m;
#else
  return;
#endif
}

